#!/usr/bin/python3
# This file gets amended at build time by `reconf.sh` with data generated by
# `buildtools/build-langtags.py`.
# The data comes from `resources/standards-data/langtag/langtags.json`.

class LangTagsMap():
    def lookupLangTags(language):
        if language in LangTagsMap.__langTags:
            return LangTagsMap.__langTags[language]
        return None

    def lookupAllTags(language):
        if language in LangTagsMap.__allTags:
            return LangTagsMap.__allTags[language]
        return None

    def translateISO6393ToBCP47(code):
        if code in LangTagsMap.__map3To2:
            return LangTagsMap.__map3To2[code]
        return code

    __langTags = {
        'aa': {'full': 'aa-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'aa-Arab': {'full': 'aa-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'aa-DJ': {'full': 'aa-Latn-DJ', 'region': 'DJ', 'script': 'Latn', 'suppress': False},
        'aa-ER': {'full': 'aa-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': False},
        'aa-Ethi': {'full': 'aa-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'aaa': {'full': 'aaa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aab': {'full': 'aab-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aac': {'full': 'aac-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aad': {'full': 'aad-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aae': {'full': 'aae-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'aae-Grek': {'full': 'aae-Grek-IT', 'region': 'IT', 'script': 'Grek', 'suppress': False},
        'aaf': {'full': 'aaf-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'aag': {'full': 'aag-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aah': {'full': 'aah-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aai': {'full': 'aai-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aak': {'full': 'aak-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aal': {'full': 'aal-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'aan': {'full': 'aan-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'aao': {'full': 'aao-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': False},
        'aap': {'full': 'aap-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'aaq': {'full': 'aaq-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'aas': {'full': 'aas-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'aat': {'full': 'aat-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'aau': {'full': 'aau-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aaw': {'full': 'aaw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aax': {'full': 'aax-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aaz': {'full': 'aaz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ab': {'full': 'ab-Cyrl-GE', 'region': 'GE', 'script': 'Cyrl', 'suppress': True},
        'ab-Geor': {'full': 'ab-Geor-GE', 'region': 'GE', 'script': 'Geor', 'suppress': False},
        'aba': {'full': 'aba-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'abb': {'full': 'abb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'abc': {'full': 'abc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'abd': {'full': 'abd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'abe': {'full': 'abe-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'abf': {'full': 'abf-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'abg': {'full': 'abg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'abh': {'full': 'abh-Arab-TJ', 'region': 'TJ', 'script': 'Arab', 'suppress': False},
        'abi': {'full': 'abi-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'abj': {'full': 'abj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'abl': {'full': 'abl-Rjng-ID', 'region': 'ID', 'script': 'Rjng', 'suppress': False},
        'abm': {'full': 'abm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'abn': {'full': 'abn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'abo': {'full': 'abo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'abp': {'full': 'abp-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'abq-Cyrl': {'full': 'abq-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'abq-Latn': {'full': 'abq-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'abr': {'full': 'abr-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'abs': {'full': 'abs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'abt': {'full': 'abt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'abt-x-maprik': {'full': 'abt-Latn-PG-x-maprik', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'abt-x-woserak': {'full': 'abt-Latn-PG-x-woserak', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'abu': {'full': 'abu-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'abv': {'full': 'abv-Arab-BH', 'region': 'BH', 'script': 'Arab', 'suppress': False},
        'abw': {'full': 'abw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'abx': {'full': 'abx-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'aby': {'full': 'aby-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'abz': {'full': 'abz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aca': {'full': 'aca-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'acb': {'full': 'acb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'acd': {'full': 'acd-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ace': {'full': 'ace-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ace-Arab': {'full': 'ace-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'acf': {'full': 'acf-Latn-LC', 'region': 'LC', 'script': 'Latn', 'suppress': False},
        'ach': {'full': 'ach-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'aci': {'full': 'aci-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ack': {'full': 'ack-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'acl': {'full': 'acl-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'acm': {'full': 'acm-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': False},
        'acn': {'full': 'acn-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'acp': {'full': 'acp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'acq': {'full': 'acq-Arab-YE', 'region': 'YE', 'script': 'Arab', 'suppress': False},
        'acr': {'full': 'acr-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'acr-x-cubulco': {'full': 'acr-Latn-GT-x-cubulco', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'acr-x-rabinal': {'full': 'acr-Latn-GT-x-rabinal', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'acs': {'full': 'acs-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'act': {'full': 'act-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'acu': {'full': 'acu-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'acv': {'full': 'acv-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'acw': {'full': 'acw-Arab-SA', 'region': 'SA', 'script': 'Arab', 'suppress': False},
        'acx': {'full': 'acx-Arab-OM', 'region': 'OM', 'script': 'Arab', 'suppress': False},
        'acy': {'full': 'acy-Latn-CY', 'region': 'CY', 'script': 'Latn', 'suppress': False},
        'acy-Arab': {'full': 'acy-Arab-CY', 'region': 'CY', 'script': 'Arab', 'suppress': False},
        'acy-Grek': {'full': 'acy-Grek-CY', 'region': 'CY', 'script': 'Grek', 'suppress': False},
        'acz': {'full': 'acz-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ada': {'full': 'ada-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'adb': {'full': 'adb-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'add': {'full': 'add-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ade': {'full': 'ade-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'adf': {'full': 'adf-Arab-OM', 'region': 'OM', 'script': 'Arab', 'suppress': False},
        'adg': {'full': 'adg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'adh': {'full': 'adh-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'adi': {'full': 'adi-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'adi-Tibt': {'full': 'adi-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'adj': {'full': 'adj-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'adl': {'full': 'adl-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'adn': {'full': 'adn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ado': {'full': 'ado-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'adq': {'full': 'adq-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'adr': {'full': 'adr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ads': {'full': 'ads-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ads-Zxxx': {'full': 'ads-Zxxx-GH', 'region': 'GH', 'script': 'Zxxx', 'suppress': False},
        'adt': {'full': 'adt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'adu': {'full': 'adu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'adw': {'full': 'adw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'adx': {'full': 'adx-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'ady': {'full': 'ady-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'ady-Arab': {'full': 'ady-Arab-RU', 'region': 'RU', 'script': 'Arab', 'suppress': False},
        'ady-Latn': {'full': 'ady-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'adz': {'full': 'adz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ae': {'full': 'ae-Avst-IR', 'region': 'IR', 'script': 'Avst', 'suppress': False},
        'ae-Arab': {'full': 'ae-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'ae-Gujr': {'full': 'ae-Gujr-IR', 'region': 'IR', 'script': 'Gujr', 'suppress': False},
        'aea': {'full': 'aea-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'aeb': {'full': 'aeb-Arab-TN', 'region': 'TN', 'script': 'Arab', 'suppress': False},
        'aeb-Latn': {'full': 'aeb-Latn-TN', 'region': 'TN', 'script': 'Latn', 'suppress': False},
        'aec': {'full': 'aec-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': False},
        'aed': {'full': 'aed-Zxxx-AR', 'region': 'AR', 'script': 'Zxxx', 'suppress': False},
        'aee': {'full': 'aee-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'aek': {'full': 'aek-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ael': {'full': 'ael-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'aem': {'full': 'aem-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'aen': {'full': 'aen-Zxxx-AM', 'region': 'AM', 'script': 'Zxxx', 'suppress': False},
        'aeq': {'full': 'aeq-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'aer': {'full': 'aer-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'aes': {'full': 'aes-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'aeu': {'full': 'aeu-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'aew': {'full': 'aew-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aey': {'full': 'aey-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aez': {'full': 'aez-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'af': {'full': 'af-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'af-Arab': {'full': 'af-Arab-ZA', 'region': 'ZA', 'script': 'Arab', 'suppress': False},
        'af-Brai': {'full': 'af-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'af-NA': {'full': 'af-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': True},
        'afb': {'full': 'afb-Arab-KW', 'region': 'KW', 'script': 'Arab', 'suppress': False},
        'afd': {'full': 'afd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'afe': {'full': 'afe-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'afg': {'full': 'afg-Zxxx-AF', 'region': 'AF', 'script': 'Zxxx', 'suppress': False},
        'afh': {'full': 'afh-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'afi': {'full': 'afi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'afk': {'full': 'afk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'afn': {'full': 'afn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'afo': {'full': 'afo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'afp': {'full': 'afp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'afs': {'full': 'afs-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'aft': {'full': 'aft-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'afu': {'full': 'afu-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'afz': {'full': 'afz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aga': {'full': 'aga-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'agb': {'full': 'agb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'agc': {'full': 'agc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'agd': {'full': 'agd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'age': {'full': 'age-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'agf': {'full': 'agf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'agg': {'full': 'agg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'agh': {'full': 'agh-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'agi': {'full': 'agi-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'agj': {'full': 'agj-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'agj-Arab': {'full': 'agj-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'agk': {'full': 'agk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'agl': {'full': 'agl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'agm': {'full': 'agm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'agn': {'full': 'agn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ago': {'full': 'ago-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'agq': {'full': 'agq-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'agr': {'full': 'agr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ags': {'full': 'ags-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'agt': {'full': 'agt-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'agu': {'full': 'agu-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'agv': {'full': 'agv-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'agw': {'full': 'agw-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'agx': {'full': 'agx-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'agy': {'full': 'agy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'agz': {'full': 'agz-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'aha': {'full': 'aha-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ahb': {'full': 'ahb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ahg': {'full': 'ahg-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'ahh': {'full': 'ahh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ahi': {'full': 'ahi-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ahk': {'full': 'ahk-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'ahk-Latn-x-louma': {'full': 'ahk-Latn-LA-x-louma', 'region': 'LA', 'script': 'Latn', 'suppress': False},
        'ahk-Mymr': {'full': 'ahk-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'ahk-TH': {'full': 'ahk-Latn-TH', 'region': 'TH', 'script': 'Latn', 'suppress': False},
        'ahk-Thai': {'full': 'ahk-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'ahl': {'full': 'ahl-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'ahm': {'full': 'ahm-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ahn': {'full': 'ahn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aho': {'full': 'aho-Ahom-IN', 'region': 'IN', 'script': 'Ahom', 'suppress': False},
        'ahp': {'full': 'ahp-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ahr': {'full': 'ahr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ahs': {'full': 'ahs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aht': {'full': 'aht-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'aia': {'full': 'aia-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'aib': {'full': 'aib-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'aic': {'full': 'aic-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aid': {'full': 'aid-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'aie': {'full': 'aie-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aif': {'full': 'aif-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aig': {'full': 'aig-Latn-AG', 'region': 'AG', 'script': 'Latn', 'suppress': False},
        'aih': {'full': 'aih-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'aii-Cyrl': {'full': 'aii-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'aii-Syrc': {'full': 'aii-Syrc-IQ', 'region': 'IQ', 'script': 'Syrc', 'suppress': False},
        'aij': {'full': 'aij-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'aik': {'full': 'aik-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ail': {'full': 'ail-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aim': {'full': 'aim-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'ain': {'full': 'ain-Kana-JP', 'region': 'JP', 'script': 'Kana', 'suppress': False},
        'ain-Latn': {'full': 'ain-Latn-JP', 'region': 'JP', 'script': 'Latn', 'suppress': False},
        'aio': {'full': 'aio-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'aip': {'full': 'aip-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aiq': {'full': 'aiq-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'air': {'full': 'air-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ait': {'full': 'ait-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'aiw-Arab': {'full': 'aiw-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'aiw-Ethi': {'full': 'aiw-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'aiw-Latn': {'full': 'aiw-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'aix': {'full': 'aix-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aiy': {'full': 'aiy-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'aja': {'full': 'aja-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'ajg': {'full': 'ajg-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'aji': {'full': 'aji-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ajn': {'full': 'ajn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ajp': {'full': 'ajp-Arab-JO', 'region': 'JO', 'script': 'Arab', 'suppress': False},
        'ajt': {'full': 'ajt-Arab-TN', 'region': 'TN', 'script': 'Arab', 'suppress': False},
        'ajt-Hebr': {'full': 'ajt-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'aju-Arab': {'full': 'aju-Arab-MA', 'region': 'MA', 'script': 'Arab', 'suppress': False},
        'ajw': {'full': 'ajw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ajz': {'full': 'ajz-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'ak': {'full': 'ak-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ak-Arab': {'full': 'ak-Arab-GH', 'region': 'GH', 'script': 'Arab', 'suppress': False},
        'akb': {'full': 'akb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'akb-Batk': {'full': 'akb-Batk-ID', 'region': 'ID', 'script': 'Batk', 'suppress': False},
        'akc': {'full': 'akc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'akd': {'full': 'akd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ake': {'full': 'ake-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'akf': {'full': 'akf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'akg': {'full': 'akg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'akh': {'full': 'akh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aki': {'full': 'aki-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'akj': {'full': 'akj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'akk': {'full': 'akk-Xsux-IQ', 'region': 'IQ', 'script': 'Xsux', 'suppress': False},
        'akl': {'full': 'akl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'akm': {'full': 'akm-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ako': {'full': 'ako-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'akp': {'full': 'akp-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'akq': {'full': 'akq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'akr': {'full': 'akr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'aks': {'full': 'aks-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'akt': {'full': 'akt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aku': {'full': 'aku-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'akv': {'full': 'akv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'akw': {'full': 'akw-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'akx': {'full': 'akx-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'aky': {'full': 'aky-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'akz': {'full': 'akz-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ala': {'full': 'ala-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'alc': {'full': 'alc-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': False},
        'ald': {'full': 'ald-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ale': {'full': 'ale-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ale-Cyrs': {'full': 'ale-Cyrs-US', 'region': 'US', 'script': 'Cyrs', 'suppress': False},
        'alf': {'full': 'alf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'alh': {'full': 'alh-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ali': {'full': 'ali-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'alj': {'full': 'alj-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'alk': {'full': 'alk-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'all': {'full': 'all-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'alm': {'full': 'alm-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'aln': {'full': 'aln-Latn-XK', 'region': 'XK', 'script': 'Latn', 'suppress': False},
        'aln-Brai': {'full': 'aln-Brai-AL', 'region': 'AL', 'script': 'Brai', 'suppress': False},
        'alo': {'full': 'alo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'alp': {'full': 'alp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'alq': {'full': 'alq-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'alr': {'full': 'alr-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'alt': {'full': 'alt-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'alt-Mong': {'full': 'alt-Mong-RU', 'region': 'RU', 'script': 'Mong', 'suppress': False},
        'alu': {'full': 'alu-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'alw': {'full': 'alw-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'alx': {'full': 'alx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aly': {'full': 'aly-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'alz': {'full': 'alz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'am': {'full': 'am-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': True},
        'am-Arab': {'full': 'am-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'am-Brai': {'full': 'am-Brai-ET', 'region': 'ET', 'script': 'Brai', 'suppress': False},
        'ama': {'full': 'ama-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'amb': {'full': 'amb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'amc': {'full': 'amc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ame': {'full': 'ame-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'amf-Ethi': {'full': 'amf-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'amf-Latn': {'full': 'amf-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'amg': {'full': 'amg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ami': {'full': 'ami-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'ami-Zyyy-TW': {'full': 'ami-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'amj': {'full': 'amj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'amk': {'full': 'amk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aml': {'full': 'aml-Zyyy-BD', 'region': 'BD', 'script': 'Zyyy', 'suppress': False},
        'amm': {'full': 'amm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'amn': {'full': 'amn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'amo': {'full': 'amo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'amp': {'full': 'amp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'amq': {'full': 'amq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'amr': {'full': 'amr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ams': {'full': 'ams-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'amt': {'full': 'amt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'amu': {'full': 'amu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'amv': {'full': 'amv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'amw-Arab': {'full': 'amw-Arab-SY', 'region': 'SY', 'script': 'Arab', 'suppress': False},
        'amw-Armi': {'full': 'amw-Armi-SY', 'region': 'SY', 'script': 'Armi', 'suppress': False},
        'amw-Latn': {'full': 'amw-Latn-SY', 'region': 'SY', 'script': 'Latn', 'suppress': False},
        'amw-Syrj': {'full': 'amw-Syrj-SY', 'region': 'SY', 'script': 'Syrj', 'suppress': False},
        'amx': {'full': 'amx-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'amy': {'full': 'amy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'amz': {'full': 'amz-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'an': {'full': 'an-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'ana': {'full': 'ana-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'anb': {'full': 'anb-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'anc': {'full': 'anc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'and': {'full': 'and-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ane': {'full': 'ane-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'anf': {'full': 'anf-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ang': {'full': 'ang-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'anh': {'full': 'anh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ani': {'full': 'ani-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'anj': {'full': 'anj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ank': {'full': 'ank-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'anl': {'full': 'anl-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'anm': {'full': 'anm-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'ann': {'full': 'ann-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ano': {'full': 'ano-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'anp': {'full': 'anp-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'anq': {'full': 'anq-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'anr': {'full': 'anr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'ans': {'full': 'ans-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ant': {'full': 'ant-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'anu': {'full': 'anu-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'anu-Arab': {'full': 'anu-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'anu-Latn': {'full': 'anu-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'anv': {'full': 'anv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'anw': {'full': 'anw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'anx': {'full': 'anx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'any': {'full': 'any-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'anz': {'full': 'anz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aoa': {'full': 'aoa-Latn-ST', 'region': 'ST', 'script': 'Latn', 'suppress': False},
        'aob': {'full': 'aob-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aoc': {'full': 'aoc-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'aod': {'full': 'aod-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aoe': {'full': 'aoe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aof': {'full': 'aof-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aog': {'full': 'aog-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aoh': {'full': 'aoh-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'aoi': {'full': 'aoi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'aoj': {'full': 'aoj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aoj-x-balif': {'full': 'aoj-Latn-PG-x-balif', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aoj-x-filifita': {'full': 'aoj-Latn-PG-x-filifita', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aok': {'full': 'aok-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'aol': {'full': 'aol-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aom': {'full': 'aom-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aon': {'full': 'aon-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aor': {'full': 'aor-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'aos': {'full': 'aos-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aot': {'full': 'aot-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'aou': {'full': 'aou-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'aox': {'full': 'aox-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'aoz': {'full': 'aoz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'apb': {'full': 'apb-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'apc': {'full': 'apc-Arab-SY', 'region': 'SY', 'script': 'Arab', 'suppress': False},
        'apd': {'full': 'apd-Arab-TG', 'region': 'TG', 'script': 'Arab', 'suppress': False},
        'apd-Latn': {'full': 'apd-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ape': {'full': 'ape-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ape-x-coastal': {'full': 'ape-Latn-PG-x-coastal', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ape-x-mountain': {'full': 'ape-Latn-PG-x-mountain', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'apf': {'full': 'apf-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'apg': {'full': 'apg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aph': {'full': 'aph-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'api': {'full': 'api-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'apj': {'full': 'apj-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'apk': {'full': 'apk-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'apl': {'full': 'apl-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'apm': {'full': 'apm-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'apn': {'full': 'apn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'apo': {'full': 'apo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'app': {'full': 'app-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'apq': {'full': 'apq-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'apr': {'full': 'apr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aps': {'full': 'aps-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'apt': {'full': 'apt-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'apu': {'full': 'apu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'apv': {'full': 'apv-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'apw': {'full': 'apw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'apx': {'full': 'apx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'apy': {'full': 'apy-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'apz': {'full': 'apz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aqc': {'full': 'aqc-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'aqd': {'full': 'aqd-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'aqg': {'full': 'aqg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aqm': {'full': 'aqm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aqn': {'full': 'aqn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'aqp': {'full': 'aqp-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'aqr': {'full': 'aqr-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'aqt': {'full': 'aqt-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'aqz': {'full': 'aqz-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ar': {'full': 'ar-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': True},
        'ar-AE': {'full': 'ar-Arab-AE', 'region': 'AE', 'script': 'Arab', 'suppress': True},
        'ar-Brai': {'full': 'ar-Brai-SA', 'region': 'SA', 'script': 'Brai', 'suppress': False},
        'ar-DJ': {'full': 'ar-Arab-DJ', 'region': 'DJ', 'script': 'Arab', 'suppress': True},
        'ar-DZ': {'full': 'ar-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': True},
        'ar-EH': {'full': 'ar-Arab-EH', 'region': 'EH', 'script': 'Arab', 'suppress': True},
        'ar-ER': {'full': 'ar-Arab-ER', 'region': 'ER', 'script': 'Arab', 'suppress': True},
        'ar-IL': {'full': 'ar-Arab-IL', 'region': 'IL', 'script': 'Arab', 'suppress': True},
        'ar-IQ': {'full': 'ar-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': True},
        'ar-JO': {'full': 'ar-Arab-JO', 'region': 'JO', 'script': 'Arab', 'suppress': True},
        'ar-KM': {'full': 'ar-Arab-KM', 'region': 'KM', 'script': 'Arab', 'suppress': True},
        'ar-LB': {'full': 'ar-Arab-LB', 'region': 'LB', 'script': 'Arab', 'suppress': True},
        'ar-LY': {'full': 'ar-Arab-LY', 'region': 'LY', 'script': 'Arab', 'suppress': True},
        'ar-MA': {'full': 'ar-Arab-MA', 'region': 'MA', 'script': 'Arab', 'suppress': True},
        'ar-MR': {'full': 'ar-Arab-MR', 'region': 'MR', 'script': 'Arab', 'suppress': True},
        'ar-PS': {'full': 'ar-Arab-PS', 'region': 'PS', 'script': 'Arab', 'suppress': True},
        'ar-SA': {'full': 'ar-Arab-SA', 'region': 'SA', 'script': 'Arab', 'suppress': True},
        'ar-SO': {'full': 'ar-Arab-SO', 'region': 'SO', 'script': 'Arab', 'suppress': True},
        'ar-SS': {'full': 'ar-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': True},
        'ar-SY': {'full': 'ar-Arab-SY', 'region': 'SY', 'script': 'Arab', 'suppress': True},
        'ar-Syrc': {'full': 'ar-Syrc-SA', 'region': 'SA', 'script': 'Syrc', 'suppress': False},
        'ar-TN': {'full': 'ar-Arab-TN', 'region': 'TN', 'script': 'Arab', 'suppress': True},
        'arc': {'full': 'arc-Armi-IR', 'region': 'IR', 'script': 'Armi', 'suppress': False},
        'arc-Nbat': {'full': 'arc-Nbat-JO', 'region': 'JO', 'script': 'Nbat', 'suppress': False},
        'arc-Palm': {'full': 'arc-Palm-SY', 'region': 'SY', 'script': 'Palm', 'suppress': False},
        'arc-Syrc': {'full': 'arc-Syrc-XX', 'region': 'XX', 'script': 'Syrc', 'suppress': False},
        'ard': {'full': 'ard-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'are': {'full': 'are-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'arh': {'full': 'arh-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ari': {'full': 'ari-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'arj': {'full': 'arj-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ark': {'full': 'ark-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'arl': {'full': 'arl-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'arn': {'full': 'arn-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': False},
        'aro': {'full': 'aro-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'arp': {'full': 'arp-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'arq': {'full': 'arq-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': False},
        'arr': {'full': 'arr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ars': {'full': 'ars-Arab-SA', 'region': 'SA', 'script': 'Arab', 'suppress': False},
        'aru': {'full': 'aru-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'arv': {'full': 'arv-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'arw': {'full': 'arw-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'arx': {'full': 'arx-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ary': {'full': 'ary-Arab-MA', 'region': 'MA', 'script': 'Arab', 'suppress': False},
        'arz': {'full': 'arz-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': False},
        'arz-Brai': {'full': 'arz-Brai-EG', 'region': 'EG', 'script': 'Brai', 'suppress': False},
        'as': {'full': 'as-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': True},
        'asa': {'full': 'asa-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'asb': {'full': 'asb-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'asc': {'full': 'asc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ase': {'full': 'ase-Sgnw-US', 'region': 'US', 'script': 'Sgnw', 'suppress': False},
        'ase-Zxxx': {'full': 'ase-Zxxx-US', 'region': 'US', 'script': 'Zxxx', 'suppress': False},
        'asf': {'full': 'asf-Zxxx-AU', 'region': 'AU', 'script': 'Zxxx', 'suppress': False},
        'asg': {'full': 'asg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ash': {'full': 'ash-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'asi': {'full': 'asi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'asj': {'full': 'asj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ask': {'full': 'ask-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'asl': {'full': 'asl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'asn': {'full': 'asn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'aso': {'full': 'aso-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'asp': {'full': 'asp-Zxxx-DZ', 'region': 'DZ', 'script': 'Zxxx', 'suppress': False},
        'asq': {'full': 'asq-Zxxx-AT', 'region': 'AT', 'script': 'Zxxx', 'suppress': False},
        'asr-Deva': {'full': 'asr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'ass': {'full': 'ass-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ast': {'full': 'ast-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'asu': {'full': 'asu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'asv': {'full': 'asv-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'asw': {'full': 'asw-Zxxx-AU', 'region': 'AU', 'script': 'Zxxx', 'suppress': False},
        'asx': {'full': 'asx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'asy': {'full': 'asy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'asz': {'full': 'asz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ata': {'full': 'ata-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'atb': {'full': 'atb-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'atb-Lisu': {'full': 'atb-Lisu-CN', 'region': 'CN', 'script': 'Lisu', 'suppress': False},
        'atc': {'full': 'atc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'atd': {'full': 'atd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ate': {'full': 'ate-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'atg': {'full': 'atg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ati': {'full': 'ati-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'atj': {'full': 'atj-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'atk': {'full': 'atk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'atl': {'full': 'atl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'atm': {'full': 'atm-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'atn': {'full': 'atn-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'ato': {'full': 'ato-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'atp': {'full': 'atp-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'atq': {'full': 'atq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'atr': {'full': 'atr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ats': {'full': 'ats-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'att': {'full': 'att-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'atu': {'full': 'atu-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'atv': {'full': 'atv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'atw': {'full': 'atw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'atx': {'full': 'atx-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'aty': {'full': 'aty-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'atz': {'full': 'atz-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'aua': {'full': 'aua-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'aub': {'full': 'aub-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'auc': {'full': 'auc-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'aud': {'full': 'aud-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'aug': {'full': 'aug-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'auh': {'full': 'auh-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'aui': {'full': 'aui-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'auj': {'full': 'auj-Zyyy-LY', 'region': 'LY', 'script': 'Zyyy', 'suppress': False},
        'auk': {'full': 'auk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aul': {'full': 'aul-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'aum': {'full': 'aum-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aun': {'full': 'aun-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'auo': {'full': 'auo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'aup': {'full': 'aup-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'auq': {'full': 'auq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aur': {'full': 'aur-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'aut': {'full': 'aut-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'auu': {'full': 'auu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'auw': {'full': 'auw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aux': {'full': 'aux-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'auy': {'full': 'auy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'auz': {'full': 'auz-Arab-UZ', 'region': 'UZ', 'script': 'Arab', 'suppress': False},
        'av': {'full': 'av-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'avb': {'full': 'avb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'avd': {'full': 'avd-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'avi': {'full': 'avi-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'avk': {'full': 'avk-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'avl': {'full': 'avl-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': False},
        'avm': {'full': 'avm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'avn': {'full': 'avn-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'avo': {'full': 'avo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'avs': {'full': 'avs-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'avt': {'full': 'avt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'avu': {'full': 'avu-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'avu-SD': {'full': 'avu-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'avv': {'full': 'avv-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'awa': {'full': 'awa-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'awb': {'full': 'awb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'awc': {'full': 'awc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'awe': {'full': 'awe-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'awg': {'full': 'awg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'awh': {'full': 'awh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'awi': {'full': 'awi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'awk': {'full': 'awk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'awm': {'full': 'awm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'awn': {'full': 'awn-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'awo': {'full': 'awo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'awr': {'full': 'awr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aws': {'full': 'aws-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'awt': {'full': 'awt-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'awu': {'full': 'awu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'awv': {'full': 'awv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'aww': {'full': 'aww-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'awx': {'full': 'awx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'awy': {'full': 'awy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'axb': {'full': 'axb-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'axe': {'full': 'axe-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'axg': {'full': 'axg-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'axk': {'full': 'axk-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'axl': {'full': 'axl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'axm': {'full': 'axm-Zyyy-AM', 'region': 'AM', 'script': 'Zyyy', 'suppress': False},
        'axx': {'full': 'axx-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ay': {'full': 'ay-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': True},
        'aya': {'full': 'aya-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ayb': {'full': 'ayb-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'ayc': {'full': 'ayc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ayd': {'full': 'ayd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'aye': {'full': 'aye-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ayg': {'full': 'ayg-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'ayh': {'full': 'ayh-Arab-YE', 'region': 'YE', 'script': 'Arab', 'suppress': False},
        'ayi': {'full': 'ayi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ayk': {'full': 'ayk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ayl': {'full': 'ayl-Arab-LY', 'region': 'LY', 'script': 'Arab', 'suppress': False},
        'ayn': {'full': 'ayn-Arab-YE', 'region': 'YE', 'script': 'Arab', 'suppress': False},
        'ayo': {'full': 'ayo-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'ayp': {'full': 'ayp-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': False},
        'ayq': {'full': 'ayq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ays': {'full': 'ays-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ayt': {'full': 'ayt-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ayu': {'full': 'ayu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ayy': {'full': 'ayy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ayz': {'full': 'ayz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'az': {'full': 'az-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'az-Brai': {'full': 'az-Brai-IR', 'region': 'IR', 'script': 'Brai', 'suppress': False},
        'az-Cyrl-AZ': {'full': 'az-Cyrl-AZ', 'region': 'AZ', 'script': 'Cyrl', 'suppress': False},
        'az-IQ': {'full': 'az-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': False},
        'az-IR': {'full': 'az-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'az-RU': {'full': 'az-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'aza': {'full': 'aza-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'azb': {'full': 'azb-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'azb-Cyrl': {'full': 'azb-Cyrl-AZ', 'region': 'AZ', 'script': 'Cyrl', 'suppress': False},
        'azd': {'full': 'azd-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'azg': {'full': 'azg-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'azm': {'full': 'azm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'azn': {'full': 'azn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'azo': {'full': 'azo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'azt': {'full': 'azt-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'azz': {'full': 'azz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ba': {'full': 'ba-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'baa': {'full': 'baa-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'bab': {'full': 'bab-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'bac': {'full': 'bac-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bae': {'full': 'bae-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'baf': {'full': 'baf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bag': {'full': 'bag-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bah': {'full': 'bah-Latn-BS', 'region': 'BS', 'script': 'Latn', 'suppress': False},
        'baj': {'full': 'baj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bal': {'full': 'bal-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'bal-Latn': {'full': 'bal-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'ban': {'full': 'ban-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ban-Bali': {'full': 'ban-Bali-ID', 'region': 'ID', 'script': 'Bali', 'suppress': False},
        'ban-Java': {'full': 'ban-Java-ID', 'region': 'ID', 'script': 'Java', 'suppress': False},
        'bao': {'full': 'bao-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'bap': {'full': 'bap-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'bar': {'full': 'bar-Latn-AT', 'region': 'AT', 'script': 'Latn', 'suppress': False},
        'bas': {'full': 'bas-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bau': {'full': 'bau-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bav': {'full': 'bav-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'baw': {'full': 'baw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bax': {'full': 'bax-Bamu-CM', 'region': 'CM', 'script': 'Bamu', 'suppress': False},
        'bax-Latn': {'full': 'bax-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bay': {'full': 'bay-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bba': {'full': 'bba-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'bbb': {'full': 'bbb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bbc': {'full': 'bbc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bbc-Batk': {'full': 'bbc-Batk-ID', 'region': 'ID', 'script': 'Batk', 'suppress': False},
        'bbd': {'full': 'bbd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bbe': {'full': 'bbe-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bbf': {'full': 'bbf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bbg': {'full': 'bbg-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'bbh': {'full': 'bbh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bbi': {'full': 'bbi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bbj': {'full': 'bbj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bbk': {'full': 'bbk-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bbl': {'full': 'bbl-Zyyy-GE', 'region': 'GE', 'script': 'Zyyy', 'suppress': False},
        'bbm': {'full': 'bbm-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bbn': {'full': 'bbn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bbo': {'full': 'bbo-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bbp': {'full': 'bbp-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bbq': {'full': 'bbq-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bbr': {'full': 'bbr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bbs': {'full': 'bbs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bbt': {'full': 'bbt-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bbu': {'full': 'bbu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bbv': {'full': 'bbv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bbw': {'full': 'bbw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bbx': {'full': 'bbx-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bby': {'full': 'bby-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bbz': {'full': 'bbz-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bca': {'full': 'bca-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'bca-Hani': {'full': 'bca-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'bcb': {'full': 'bcb-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'bcd': {'full': 'bcd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bce': {'full': 'bce-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bcf': {'full': 'bcf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bcg': {'full': 'bcg-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'bch': {'full': 'bch-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bci': {'full': 'bci-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'bcj': {'full': 'bcj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bck': {'full': 'bck-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bcm': {'full': 'bcm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bcn': {'full': 'bcn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bco': {'full': 'bco-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bcp': {'full': 'bcp-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bcq': {'full': 'bcq-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'bcq-Latn': {'full': 'bcq-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'bcr': {'full': 'bcr-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'bcs': {'full': 'bcs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bct': {'full': 'bct-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bcu': {'full': 'bcu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bcv': {'full': 'bcv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bcw': {'full': 'bcw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bcy': {'full': 'bcy-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bcz': {'full': 'bcz-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'bda': {'full': 'bda-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'bdb': {'full': 'bdb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bdc': {'full': 'bdc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'bdd': {'full': 'bdd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bde': {'full': 'bde-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bdf': {'full': 'bdf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bdg': {'full': 'bdg-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'bdh': {'full': 'bdh-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bdi': {'full': 'bdi-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'bdj': {'full': 'bdj-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bdk': {'full': 'bdk-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'bdl': {'full': 'bdl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bdm': {'full': 'bdm-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bdn': {'full': 'bdn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bdo': {'full': 'bdo-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bdp': {'full': 'bdp-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'bdq': {'full': 'bdq-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'bdr': {'full': 'bdr-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'bds': {'full': 'bds-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'bdt': {'full': 'bdt-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bdu': {'full': 'bdu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bdv': {'full': 'bdv-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'bdw': {'full': 'bdw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bdx': {'full': 'bdx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bdy': {'full': 'bdy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bdz': {'full': 'bdz-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'be': {'full': 'be-Cyrl-BY', 'region': 'BY', 'script': 'Cyrl', 'suppress': True},
        'be-Brai': {'full': 'be-Brai-BY', 'region': 'BY', 'script': 'Brai', 'suppress': False},
        'be-Latn': {'full': 'be-Latn-BY', 'region': 'BY', 'script': 'Latn', 'suppress': False},
        'bea': {'full': 'bea-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'bea-Cans': {'full': 'bea-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'beb': {'full': 'beb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bec': {'full': 'bec-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bed': {'full': 'bed-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bee': {'full': 'bee-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bef': {'full': 'bef-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'beg': {'full': 'beg-Zyyy-BN', 'region': 'BN', 'script': 'Zyyy', 'suppress': False},
        'beh': {'full': 'beh-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'bei': {'full': 'bei-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bej': {'full': 'bej-Arab-SD', 'region': 'SD', 'script': 'Arab', 'suppress': False},
        'bej-Latn': {'full': 'bej-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': False},
        'bek': {'full': 'bek-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bem': {'full': 'bem-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'bem-Brai': {'full': 'bem-Brai-ZM', 'region': 'ZM', 'script': 'Brai', 'suppress': False},
        'beo': {'full': 'beo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bep': {'full': 'bep-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'beq': {'full': 'beq-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'bes': {'full': 'bes-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bet': {'full': 'bet-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'beu': {'full': 'beu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bev': {'full': 'bev-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'bew': {'full': 'bew-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bex': {'full': 'bex-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bex-Arab': {'full': 'bex-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'bey': {'full': 'bey-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bez': {'full': 'bez-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'bfa': {'full': 'bfa-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bfa-Arab': {'full': 'bfa-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'bfb': {'full': 'bfb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bfc': {'full': 'bfc-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'bfd': {'full': 'bfd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bfe': {'full': 'bfe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bff': {'full': 'bff-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bfg': {'full': 'bfg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bfh': {'full': 'bfh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bfi': {'full': 'bfi-Zxxx-GB', 'region': 'GB', 'script': 'Zxxx', 'suppress': False},
        'bfi-x-stokoe': {'full': 'bfi-Zzzz-GB-x-stokoe', 'region': 'GB', 'script': 'Zzzz', 'suppress': False},
        'bfj': {'full': 'bfj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bfk': {'full': 'bfk-Zxxx-TH', 'region': 'TH', 'script': 'Zxxx', 'suppress': False},
        'bfl': {'full': 'bfl-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bfm': {'full': 'bfm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bfn': {'full': 'bfn-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'bfo': {'full': 'bfo-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bfp': {'full': 'bfp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bfq': {'full': 'bfq-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'bfq-Knda': {'full': 'bfq-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'bfq-Latn': {'full': 'bfq-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'bfq-x-badaga': {'full': 'bfq-Zzzz-IN-x-badaga', 'region': 'IN', 'script': 'Zzzz', 'suppress': False},
        'bfr': {'full': 'bfr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'bfs': {'full': 'bfs-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'bfs-Hani': {'full': 'bfs-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'bft': {'full': 'bft-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'bft-Tibt': {'full': 'bft-Tibt-PK', 'region': 'PK', 'script': 'Tibt', 'suppress': False},
        'bft-x-baltia': {'full': 'bft-Zzzz-PK-x-baltia', 'region': 'PK', 'script': 'Zzzz', 'suppress': False},
        'bfu': {'full': 'bfu-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'bfu-Takr': {'full': 'bfu-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'bfw': {'full': 'bfw-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'bfx': {'full': 'bfx-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bfy': {'full': 'bfy-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bfz': {'full': 'bfz-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bg': {'full': 'bg-Cyrl-BG', 'region': 'BG', 'script': 'Cyrl', 'suppress': True},
        'bg-Brai': {'full': 'bg-Brai-BG', 'region': 'BG', 'script': 'Brai', 'suppress': False},
        'bg-Latn': {'full': 'bg-Latn-BG', 'region': 'BG', 'script': 'Latn', 'suppress': False},
        'bga': {'full': 'bga-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bgb': {'full': 'bgb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bgc': {'full': 'bgc-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bgd': {'full': 'bgd-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bge': {'full': 'bge-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'bgf': {'full': 'bgf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bgg': {'full': 'bgg-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'bgi': {'full': 'bgi-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bgj': {'full': 'bgj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bgk': {'full': 'bgk-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'bgl': {'full': 'bgl-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'bgn': {'full': 'bgn-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'bgn-Cyrl': {'full': 'bgn-Cyrl-TM', 'region': 'TM', 'script': 'Cyrl', 'suppress': False},
        'bgo': {'full': 'bgo-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'bgp': {'full': 'bgp-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'bgq': {'full': 'bgq-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bgr': {'full': 'bgr-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'bgs': {'full': 'bgs-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bgt': {'full': 'bgt-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'bgu': {'full': 'bgu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bgv': {'full': 'bgv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bgw': {'full': 'bgw-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bgx': {'full': 'bgx-Grek-TR', 'region': 'TR', 'script': 'Grek', 'suppress': False},
        'bgx-Latn': {'full': 'bgx-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'bgy': {'full': 'bgy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bgz': {'full': 'bgz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bha': {'full': 'bha-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bhb': {'full': 'bhb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bhb-Gujr': {'full': 'bhb-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'bhc': {'full': 'bhc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bhd-Arab': {'full': 'bhd-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'bhd-Deva': {'full': 'bhd-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bhe': {'full': 'bhe-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'bhf': {'full': 'bhf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bhg': {'full': 'bhg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bhh': {'full': 'bhh-Cyrl-IL', 'region': 'IL', 'script': 'Cyrl', 'suppress': False},
        'bhh-Hebr': {'full': 'bhh-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'bhh-Latn': {'full': 'bhh-Latn-IL', 'region': 'IL', 'script': 'Latn', 'suppress': False},
        'bhi': {'full': 'bhi-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bhj': {'full': 'bhj-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'bhl': {'full': 'bhl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bhm': {'full': 'bhm-Arab-OM', 'region': 'OM', 'script': 'Arab', 'suppress': False},
        'bhn': {'full': 'bhn-Syrc-GE', 'region': 'GE', 'script': 'Syrc', 'suppress': False},
        'bho': {'full': 'bho-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bho-Kthi': {'full': 'bho-Kthi-IN', 'region': 'IN', 'script': 'Kthi', 'suppress': False},
        'bhp': {'full': 'bhp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bhq': {'full': 'bhq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bhr': {'full': 'bhr-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'bhs': {'full': 'bhs-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bht': {'full': 'bht-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'bhu': {'full': 'bhu-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bhv': {'full': 'bhv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bhw': {'full': 'bhw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bhx': {'full': 'bhx-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'bhy': {'full': 'bhy-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bhz': {'full': 'bhz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bi': {'full': 'bi-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'bia': {'full': 'bia-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bib': {'full': 'bib-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bic': {'full': 'bic-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bid': {'full': 'bid-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bie': {'full': 'bie-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bif': {'full': 'bif-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'big': {'full': 'big-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bij': {'full': 'bij-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bik': {'full': 'bik-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bik-Brai': {'full': 'bik-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'bil': {'full': 'bil-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bim': {'full': 'bim-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'bin': {'full': 'bin-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bio': {'full': 'bio-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bip': {'full': 'bip-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'biq': {'full': 'biq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bir': {'full': 'bir-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bit': {'full': 'bit-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'biu': {'full': 'biu-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'biv': {'full': 'biv-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'biw': {'full': 'biw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bix': {'full': 'bix-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'biy': {'full': 'biy-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'biz': {'full': 'biz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bja': {'full': 'bja-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bjb': {'full': 'bjb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bjc': {'full': 'bjc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bje': {'full': 'bje-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bjf': {'full': 'bjf-Syrc-IL', 'region': 'IL', 'script': 'Syrc', 'suppress': False},
        'bjg': {'full': 'bjg-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'bjh': {'full': 'bjh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bji': {'full': 'bji-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'bjj': {'full': 'bjj-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bjk': {'full': 'bjk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bjl': {'full': 'bjl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bjm': {'full': 'bjm-Zyyy-IQ', 'region': 'IQ', 'script': 'Zyyy', 'suppress': False},
        'bjn': {'full': 'bjn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bjn-Arab': {'full': 'bjn-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'bjo': {'full': 'bjo-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bjp': {'full': 'bjp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bjr': {'full': 'bjr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bjs': {'full': 'bjs-Latn-BB', 'region': 'BB', 'script': 'Latn', 'suppress': False},
        'bjt': {'full': 'bjt-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'bjt-Arab': {'full': 'bjt-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'bju': {'full': 'bju-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bjv': {'full': 'bjv-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bjw': {'full': 'bjw-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'bjx': {'full': 'bjx-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bjy': {'full': 'bjy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bjz': {'full': 'bjz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bka': {'full': 'bka-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bkc': {'full': 'bkc-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bkd': {'full': 'bkd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bkf': {'full': 'bkf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bkg': {'full': 'bkg-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bkh': {'full': 'bkh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bki': {'full': 'bki-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'bkj': {'full': 'bkj-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bkk-x-baltia': {'full': 'bkk-Zzzz-IN-x-baltia', 'region': 'IN', 'script': 'Zzzz', 'suppress': False},
        'bkl': {'full': 'bkl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bkm': {'full': 'bkm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bkn': {'full': 'bkn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bko': {'full': 'bko-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bkp': {'full': 'bkp-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bkq': {'full': 'bkq-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'bkr': {'full': 'bkr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bks': {'full': 'bks-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bkt': {'full': 'bkt-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bku': {'full': 'bku-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bku-Buhd': {'full': 'bku-Buhd-PH', 'region': 'PH', 'script': 'Buhd', 'suppress': False},
        'bkv': {'full': 'bkv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bkw': {'full': 'bkw-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'bkx': {'full': 'bkx-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'bky': {'full': 'bky-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bkz': {'full': 'bkz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bla': {'full': 'bla-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'bla-Cans': {'full': 'bla-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'blb': {'full': 'blb-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'blc': {'full': 'blc-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'bld': {'full': 'bld-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ble': {'full': 'ble-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'blf': {'full': 'blf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'blg': {'full': 'blg-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'blh': {'full': 'blh-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'bli': {'full': 'bli-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'blj': {'full': 'blj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'blk': {'full': 'blk-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'bll': {'full': 'bll-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'blm': {'full': 'blm-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bln': {'full': 'bln-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'blo': {'full': 'blo-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'blp': {'full': 'blp-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'blq': {'full': 'blq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'blr': {'full': 'blr-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'blr-Latn-x-pangpung': {'full': 'blr-Latn-MM-x-pangpung', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'blr-Tale': {'full': 'blr-Tale-CN', 'region': 'CN', 'script': 'Tale', 'suppress': False},
        'blr-Thai': {'full': 'blr-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'bls': {'full': 'bls-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'blt': {'full': 'blt-Tavt-VN', 'region': 'VN', 'script': 'Tavt', 'suppress': False},
        'blt-Laoo': {'full': 'blt-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'blt-Latn': {'full': 'blt-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'blv': {'full': 'blv-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'blw': {'full': 'blw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'blx': {'full': 'blx-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bly': {'full': 'bly-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'blz': {'full': 'blz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bm': {'full': 'bm-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'bm-Arab': {'full': 'bm-Arab-ML', 'region': 'ML', 'script': 'Arab', 'suppress': False},
        'bm-Nkoo': {'full': 'bm-Nkoo-ML', 'region': 'ML', 'script': 'Nkoo', 'suppress': False},
        'bma': {'full': 'bma-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bmb': {'full': 'bmb-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bmc': {'full': 'bmc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bmd': {'full': 'bmd-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'bme': {'full': 'bme-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bmf': {'full': 'bmf-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'bmg': {'full': 'bmg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bmh': {'full': 'bmh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bmi': {'full': 'bmi-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bmj': {'full': 'bmj-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'bmk': {'full': 'bmk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bml': {'full': 'bml-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bmm': {'full': 'bmm-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'bmn': {'full': 'bmn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bmo': {'full': 'bmo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bmp': {'full': 'bmp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bmq': {'full': 'bmq-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'bmr': {'full': 'bmr-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'bms': {'full': 'bms-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'bmt': {'full': 'bmt-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bmu': {'full': 'bmu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bmv': {'full': 'bmv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bmw': {'full': 'bmw-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'bmx': {'full': 'bmx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bmz': {'full': 'bmz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bn': {'full': 'bn-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': True},
        'bn-Brai': {'full': 'bn-Brai-BD', 'region': 'BD', 'script': 'Brai', 'suppress': False},
        'bn-IN': {'full': 'bn-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': True},
        'bn-Newa': {'full': 'bn-Newa-NP', 'region': 'NP', 'script': 'Newa', 'suppress': False},
        'bna': {'full': 'bna-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bnb': {'full': 'bnb-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'bnc': {'full': 'bnc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bnd': {'full': 'bnd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bne': {'full': 'bne-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bnf': {'full': 'bnf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bng': {'full': 'bng-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'bni': {'full': 'bni-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bnj': {'full': 'bnj-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bnk': {'full': 'bnk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'bnl': {'full': 'bnl-Zyyy-SO', 'region': 'SO', 'script': 'Zyyy', 'suppress': False},
        'bnm': {'full': 'bnm-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'bnn': {'full': 'bnn-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'bno': {'full': 'bno-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bnp': {'full': 'bnp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bnq': {'full': 'bnq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bnr': {'full': 'bnr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'bns': {'full': 'bns-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bnu': {'full': 'bnu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bnv': {'full': 'bnv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bnw': {'full': 'bnw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bnx': {'full': 'bnx-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bny': {'full': 'bny-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'bnz': {'full': 'bnz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bo': {'full': 'bo-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'bo-IN': {'full': 'bo-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'bo-Latn': {'full': 'bo-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'bo-Marc': {'full': 'bo-Marc-CN', 'region': 'CN', 'script': 'Marc', 'suppress': False},
        'bo-Phag': {'full': 'bo-Phag-CN', 'region': 'CN', 'script': 'Phag', 'suppress': False},
        'boa': {'full': 'boa-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'bob': {'full': 'bob-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'boe': {'full': 'boe-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bof': {'full': 'bof-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bog': {'full': 'bog-Zxxx-ML', 'region': 'ML', 'script': 'Zxxx', 'suppress': False},
        'boh': {'full': 'boh-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'boi': {'full': 'boi-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'boj': {'full': 'boj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bok': {'full': 'bok-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'bol': {'full': 'bol-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bom': {'full': 'bom-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bon': {'full': 'bon-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'boo': {'full': 'boo-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'bop': {'full': 'bop-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'boq': {'full': 'boq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bor': {'full': 'bor-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'bot': {'full': 'bot-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bou': {'full': 'bou-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'bov': {'full': 'bov-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'bow': {'full': 'bow-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'box': {'full': 'box-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'boy': {'full': 'boy-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'boz': {'full': 'boz-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'boz-Arab': {'full': 'boz-Arab-ML', 'region': 'ML', 'script': 'Arab', 'suppress': False},
        'bpa': {'full': 'bpa-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'bpb': {'full': 'bpb-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'bpd': {'full': 'bpd-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bpg': {'full': 'bpg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bph': {'full': 'bph-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'bpi': {'full': 'bpi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bpj': {'full': 'bpj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bpk': {'full': 'bpk-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'bpl': {'full': 'bpl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bpm': {'full': 'bpm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bpn': {'full': 'bpn-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bpo': {'full': 'bpo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bpp': {'full': 'bpp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bpq': {'full': 'bpq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bpr': {'full': 'bpr-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bps': {'full': 'bps-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bpt': {'full': 'bpt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bpu': {'full': 'bpu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bpv': {'full': 'bpv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bpw': {'full': 'bpw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bpx': {'full': 'bpx-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'bpy': {'full': 'bpy-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'bpz': {'full': 'bpz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bqa': {'full': 'bqa-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'bqb': {'full': 'bqb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bqc': {'full': 'bqc-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'bqd': {'full': 'bqd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bqf': {'full': 'bqf-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'bqf-Arab': {'full': 'bqf-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'bqg': {'full': 'bqg-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'bqh': {'full': 'bqh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bqi': {'full': 'bqi-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'bqj': {'full': 'bqj-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'bqk': {'full': 'bqk-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bql': {'full': 'bql-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bqm': {'full': 'bqm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bqn': {'full': 'bqn-Zxxx-BG', 'region': 'BG', 'script': 'Zxxx', 'suppress': False},
        'bqo': {'full': 'bqo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bqp': {'full': 'bqp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bqq': {'full': 'bqq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bqr': {'full': 'bqr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bqs': {'full': 'bqs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bqt': {'full': 'bqt-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bqu': {'full': 'bqu-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bqv': {'full': 'bqv-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'bqw': {'full': 'bqw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bqx': {'full': 'bqx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bqy': {'full': 'bqy-Zxxx-ID', 'region': 'ID', 'script': 'Zxxx', 'suppress': False},
        'bqz': {'full': 'bqz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'br': {'full': 'br-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'bra': {'full': 'bra-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'brb': {'full': 'brb-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'brb-Laoo': {'full': 'brb-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'brb-Latn': {'full': 'brb-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'brc': {'full': 'brc-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'brd': {'full': 'brd-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'brf': {'full': 'brf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'brg': {'full': 'brg-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'brh': {'full': 'brh-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'brh-Latn': {'full': 'brh-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'bri': {'full': 'bri-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'brj': {'full': 'brj-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'brk': {'full': 'brk-Arab-SD', 'region': 'SD', 'script': 'Arab', 'suppress': False},
        'brl': {'full': 'brl-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'brm': {'full': 'brm-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'brn': {'full': 'brn-Latn-CR', 'region': 'CR', 'script': 'Latn', 'suppress': False},
        'bro': {'full': 'bro-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'brp': {'full': 'brp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'brq': {'full': 'brq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'brr': {'full': 'brr-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'brs': {'full': 'brs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'brt': {'full': 'brt-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bru': {'full': 'bru-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'bru-Laoo': {'full': 'bru-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'bru-Thai': {'full': 'bru-Thai-LA', 'region': 'LA', 'script': 'Thai', 'suppress': False},
        'brv': {'full': 'brv-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'brv-Thai-x-donglng': {'full': 'brv-Thai-TH-x-donglng', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'brv-Thai-x-khongchm': {'full': 'brv-Thai-TH-x-khongchm', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'brv-Thai-x-sakonnkn': {'full': 'brv-Thai-TH-x-sakonnkn', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'brw': {'full': 'brw-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'brx': {'full': 'brx-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'brx-Beng': {'full': 'brx-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'brx-Latn': {'full': 'brx-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'bry': {'full': 'bry-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'brz': {'full': 'brz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bs': {'full': 'bs-Latn-BA', 'region': 'BA', 'script': 'Latn', 'suppress': True},
        'bs-Cyrl': {'full': 'bs-Cyrl-BA', 'region': 'BA', 'script': 'Cyrl', 'suppress': False},
        'bsa': {'full': 'bsa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bsb': {'full': 'bsb-Latn-BN', 'region': 'BN', 'script': 'Latn', 'suppress': False},
        'bsc': {'full': 'bsc-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'bse': {'full': 'bse-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bsf': {'full': 'bsf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bsg': {'full': 'bsg-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'bsh': {'full': 'bsh-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'bsi': {'full': 'bsi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bsj': {'full': 'bsj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bsk': {'full': 'bsk-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'bsk-Latn': {'full': 'bsk-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'bsl': {'full': 'bsl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bsm': {'full': 'bsm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bsn': {'full': 'bsn-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'bso': {'full': 'bso-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bsp': {'full': 'bsp-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'bsq': {'full': 'bsq-Bass-LR', 'region': 'LR', 'script': 'Bass', 'suppress': False},
        'bsq-Latn': {'full': 'bsq-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'bsr': {'full': 'bsr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bss': {'full': 'bss-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bst': {'full': 'bst-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'bst-Latn': {'full': 'bst-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'bsu': {'full': 'bsu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bsv': {'full': 'bsv-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'bsv-Arab': {'full': 'bsv-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'bsw': {'full': 'bsw-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'bsx': {'full': 'bsx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bsy': {'full': 'bsy-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'bta': {'full': 'bta-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'btb': {'full': 'btb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'btc': {'full': 'btc-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'btd': {'full': 'btd-Batk-ID', 'region': 'ID', 'script': 'Batk', 'suppress': False},
        'bte': {'full': 'bte-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'btf': {'full': 'btf-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'btg': {'full': 'btg-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'bth': {'full': 'bth-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'bti': {'full': 'bti-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'btj': {'full': 'btj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'btm': {'full': 'btm-Batk-ID', 'region': 'ID', 'script': 'Batk', 'suppress': False},
        'btn': {'full': 'btn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bto': {'full': 'bto-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'btp': {'full': 'btp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'btq': {'full': 'btq-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'btr': {'full': 'btr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'bts': {'full': 'bts-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bts-Batk': {'full': 'bts-Batk-ID', 'region': 'ID', 'script': 'Batk', 'suppress': False},
        'btt': {'full': 'btt-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'btu': {'full': 'btu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'btv': {'full': 'btv-Deva-PK', 'region': 'PK', 'script': 'Deva', 'suppress': False},
        'btw': {'full': 'btw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'btx': {'full': 'btx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'btx-Batk': {'full': 'btx-Batk-ID', 'region': 'ID', 'script': 'Batk', 'suppress': False},
        'bty': {'full': 'bty-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'btz': {'full': 'btz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bua': {'full': 'bua-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'bub': {'full': 'bub-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'buc': {'full': 'buc-Latn-YT', 'region': 'YT', 'script': 'Latn', 'suppress': False},
        'bud': {'full': 'bud-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'bud-Brai': {'full': 'bud-Brai-TG', 'region': 'TG', 'script': 'Brai', 'suppress': False},
        'bue': {'full': 'bue-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'buf': {'full': 'buf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bug': {'full': 'bug-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bug-Bugi': {'full': 'bug-Bugi-ID', 'region': 'ID', 'script': 'Bugi', 'suppress': False},
        'buh': {'full': 'buh-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'bui': {'full': 'bui-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'buj': {'full': 'buj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'buk': {'full': 'buk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bum': {'full': 'bum-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bun': {'full': 'bun-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'buo': {'full': 'buo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bup': {'full': 'bup-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'buq': {'full': 'buq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bus': {'full': 'bus-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'but': {'full': 'but-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'buu': {'full': 'buu-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'buv': {'full': 'buv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'buw': {'full': 'buw-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'bux': {'full': 'bux-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'buy': {'full': 'buy-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'buz': {'full': 'buz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bva': {'full': 'bva-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bvb': {'full': 'bvb-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'bvc': {'full': 'bvc-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'bvd': {'full': 'bvd-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'bve': {'full': 'bve-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bvf': {'full': 'bvf-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bvg': {'full': 'bvg-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bvh': {'full': 'bvh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bvi': {'full': 'bvi-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bvj': {'full': 'bvj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bvk': {'full': 'bvk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bvl': {'full': 'bvl-Zxxx-BO', 'region': 'BO', 'script': 'Zxxx', 'suppress': False},
        'bvm': {'full': 'bvm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bvn': {'full': 'bvn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bvo': {'full': 'bvo-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bvp': {'full': 'bvp-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bvq': {'full': 'bvq-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'bvr': {'full': 'bvr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bvt': {'full': 'bvt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bvu': {'full': 'bvu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bvv': {'full': 'bvv-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'bvw': {'full': 'bvw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bvx': {'full': 'bvx-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'bvy': {'full': 'bvy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'bvz': {'full': 'bvz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bwa': {'full': 'bwa-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'bwb': {'full': 'bwb-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'bwc': {'full': 'bwc-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'bwd': {'full': 'bwd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bwe': {'full': 'bwe-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'bwe-Latn': {'full': 'bwe-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'bwf': {'full': 'bwf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bwg': {'full': 'bwg-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'bwh': {'full': 'bwh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bwi': {'full': 'bwi-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'bwj': {'full': 'bwj-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bwk': {'full': 'bwk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bwl': {'full': 'bwl-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bwm': {'full': 'bwm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bwn': {'full': 'bwn-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bwo': {'full': 'bwo-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'bwo-Ethi': {'full': 'bwo-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'bwp': {'full': 'bwp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bwq': {'full': 'bwq-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bwr': {'full': 'bwr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bws': {'full': 'bws-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bwt': {'full': 'bwt-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bwu': {'full': 'bwu-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'bww': {'full': 'bww-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bwx': {'full': 'bwx-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'bwy': {'full': 'bwy-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bwz': {'full': 'bwz-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'bxa': {'full': 'bxa-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'bxb': {'full': 'bxb-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'bxc': {'full': 'bxc-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'bxd': {'full': 'bxd-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bxe': {'full': 'bxe-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'bxf': {'full': 'bxf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bxg': {'full': 'bxg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bxh': {'full': 'bxh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bxi': {'full': 'bxi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bxj': {'full': 'bxj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bxl': {'full': 'bxl-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'bxm': {'full': 'bxm-Cyrl-MN', 'region': 'MN', 'script': 'Cyrl', 'suppress': False},
        'bxm-Latn': {'full': 'bxm-Latn-MN', 'region': 'MN', 'script': 'Latn', 'suppress': False},
        'bxm-Mong': {'full': 'bxm-Mong-MN', 'region': 'MN', 'script': 'Mong', 'suppress': False},
        'bxn': {'full': 'bxn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bxo': {'full': 'bxo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bxp': {'full': 'bxp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bxq': {'full': 'bxq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bxs': {'full': 'bxs-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bxu': {'full': 'bxu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'bxv': {'full': 'bxv-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'bxw': {'full': 'bxw-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'bxz': {'full': 'bxz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bya': {'full': 'bya-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'byb': {'full': 'byb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'byc': {'full': 'byc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'byd': {'full': 'byd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bye': {'full': 'bye-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'byf': {'full': 'byf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'byg': {'full': 'byg-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'byh': {'full': 'byh-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'byi': {'full': 'byi-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'byj': {'full': 'byj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'byk': {'full': 'byk-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'byl': {'full': 'byl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bym': {'full': 'bym-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'byn': {'full': 'byn-Ethi-ER', 'region': 'ER', 'script': 'Ethi', 'suppress': False},
        'byn-Latn': {'full': 'byn-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': False},
        'byo': {'full': 'byo-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'byp': {'full': 'byp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'byq': {'full': 'byq-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'byr': {'full': 'byr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bys': {'full': 'bys-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'byt': {'full': 'byt-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'byv': {'full': 'byv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'byw': {'full': 'byw-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'byx': {'full': 'byx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'byz': {'full': 'byz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bza': {'full': 'bza-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'bzb': {'full': 'bzb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bzc': {'full': 'bzc-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'bzd': {'full': 'bzd-Latn-CR', 'region': 'CR', 'script': 'Latn', 'suppress': False},
        'bze': {'full': 'bze-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'bze-Arab': {'full': 'bze-Arab-ML', 'region': 'ML', 'script': 'Arab', 'suppress': False},
        'bzf': {'full': 'bzf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bzg': {'full': 'bzg-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'bzh': {'full': 'bzh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'bzi': {'full': 'bzi-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'bzj': {'full': 'bzj-Latn-BZ', 'region': 'BZ', 'script': 'Latn', 'suppress': False},
        'bzk': {'full': 'bzk-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'bzl': {'full': 'bzl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bzm': {'full': 'bzm-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bzn': {'full': 'bzn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bzo': {'full': 'bzo-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'bzp': {'full': 'bzp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bzq': {'full': 'bzq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bzr': {'full': 'bzr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'bzs': {'full': 'bzs-Zxxx-BR', 'region': 'BR', 'script': 'Zxxx', 'suppress': False},
        'bzt': {'full': 'bzt-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'bzu': {'full': 'bzu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'bzv': {'full': 'bzv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'bzw': {'full': 'bzw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bzx': {'full': 'bzx-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'bzy': {'full': 'bzy-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'bzz': {'full': 'bzz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ca': {'full': 'ca-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': True},
        'ca-FR': {'full': 'ca-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': True},
        'ca-valencia': {'full': 'ca-Latn-ES-valencia', 'region': 'ES', 'script': 'Latn', 'suppress': True},
        'caa': {'full': 'caa-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'cab': {'full': 'cab-Latn-HN', 'region': 'HN', 'script': 'Latn', 'suppress': False},
        'cac': {'full': 'cac-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'cad': {'full': 'cad-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'cae': {'full': 'cae-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'caf': {'full': 'caf-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'caf-Cans': {'full': 'caf-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'cag': {'full': 'cag-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'cah': {'full': 'cah-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'caj': {'full': 'caj-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'cak': {'full': 'cak-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'cal': {'full': 'cal-Latn-MP', 'region': 'MP', 'script': 'Latn', 'suppress': False},
        'cam': {'full': 'cam-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'can': {'full': 'can-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'cao': {'full': 'cao-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'cap': {'full': 'cap-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'caq': {'full': 'caq-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'car': {'full': 'car-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'cas': {'full': 'cas-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'cav': {'full': 'cav-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'caw': {'full': 'caw-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'cax': {'full': 'cax-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'cay': {'full': 'cay-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'caz': {'full': 'caz-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'cbb': {'full': 'cbb-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cbc': {'full': 'cbc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cbd': {'full': 'cbd-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cbg': {'full': 'cbg-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cbi': {'full': 'cbi-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'cbj': {'full': 'cbj-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'cbk': {'full': 'cbk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'cbk-Brai': {'full': 'cbk-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'cbl': {'full': 'cbl-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cbn': {'full': 'cbn-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'cbo': {'full': 'cbo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cbq': {'full': 'cbq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cbr': {'full': 'cbr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cbs': {'full': 'cbs-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cbt': {'full': 'cbt-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cbu': {'full': 'cbu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cbv': {'full': 'cbv-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cbw': {'full': 'cbw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'cby': {'full': 'cby-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cca': {'full': 'cca-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ccc': {'full': 'ccc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ccd': {'full': 'ccd-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'cce': {'full': 'cce-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'ccg': {'full': 'ccg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cch': {'full': 'cch-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ccj': {'full': 'ccj-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'ccl': {'full': 'ccl-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ccm': {'full': 'ccm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'cco': {'full': 'cco-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ccp': {'full': 'ccp-Cakm-BD', 'region': 'BD', 'script': 'Cakm', 'suppress': False},
        'ccp-Beng': {'full': 'ccp-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'ccp-Latn': {'full': 'ccp-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'ccr': {'full': 'ccr-Latn-SV', 'region': 'SV', 'script': 'Latn', 'suppress': False},
        'cda': {'full': 'cda-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'cde': {'full': 'cde-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'cdf': {'full': 'cdf-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'cdf-Beng': {'full': 'cdf-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'cdg': {'full': 'cdg-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'cdh': {'full': 'cdh-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'cdh-Takr': {'full': 'cdh-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'cdi': {'full': 'cdi-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'cdj': {'full': 'cdj-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'cdm': {'full': 'cdm-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'cdm-Latn': {'full': 'cdm-Latn-NP', 'region': 'NP', 'script': 'Latn', 'suppress': False},
        'cdn': {'full': 'cdn-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'cdo-Hans': {'full': 'cdo-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'cdo-Hant': {'full': 'cdo-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'cdo-Latn': {'full': 'cdo-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'cdr': {'full': 'cdr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cds': {'full': 'cds-Zxxx-TD', 'region': 'TD', 'script': 'Zxxx', 'suppress': False},
        'cdy': {'full': 'cdy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'cdz': {'full': 'cdz-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'ce': {'full': 'ce-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'ce-Arab': {'full': 'ce-Arab-RU', 'region': 'RU', 'script': 'Arab', 'suppress': False},
        'ce-Latn': {'full': 'ce-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'cea': {'full': 'cea-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ceb': {'full': 'ceb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ceb-Brai': {'full': 'ceb-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'ceg': {'full': 'ceg-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'cek': {'full': 'cek-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-asang': {'full': 'cek-Latn-MM-x-asang', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-hnise': {'full': 'cek-Latn-MM-x-hnise', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-kanise': {'full': 'cek-Latn-MM-x-kanise', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-khawngtu': {'full': 'cek-Latn-MM-x-khawngtu', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-khongtu': {'full': 'cek-Latn-MM-x-khongtu', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-lemi': {'full': 'cek-Latn-MM-x-lemi', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-likhy': {'full': 'cek-Latn-MM-x-likhy', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-rengcaa': {'full': 'cek-Latn-MM-x-rengcaa', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cek-x-taaw': {'full': 'cek-Latn-MM-x-taaw', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cen': {'full': 'cen-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cet': {'full': 'cet-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cey': {'full': 'cey-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cfa': {'full': 'cfa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cfd': {'full': 'cfd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cfg': {'full': 'cfg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cfm': {'full': 'cfm-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cfm-Beng': {'full': 'cfm-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'cfm-Latn-x-khuals': {'full': 'cfm-Latn-MM-x-khuals', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cfm-Latn-x-lente': {'full': 'cfm-Latn-MM-x-lente', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cfm-Latn-x-zannia': {'full': 'cfm-Latn-MM-x-zannia', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cga': {'full': 'cga-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'cgc': {'full': 'cgc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'cgg': {'full': 'cgg-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'cgk': {'full': 'cgk-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'ch': {'full': 'ch-Latn-GU', 'region': 'GU', 'script': 'Latn', 'suppress': True},
        'chb': {'full': 'chb-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'chc': {'full': 'chc-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'chd': {'full': 'chd-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'chf': {'full': 'chf-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'chg': {'full': 'chg-Zyyy-TM', 'region': 'TM', 'script': 'Zyyy', 'suppress': False},
        'chh': {'full': 'chh-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'chj': {'full': 'chj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'chk': {'full': 'chk-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'chl': {'full': 'chl-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'chm': {'full': 'chm-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'chm-Latn': {'full': 'chm-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'chn': {'full': 'chn-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'chn-Dupl': {'full': 'chn-Dupl-US', 'region': 'US', 'script': 'Dupl', 'suppress': False},
        'cho': {'full': 'cho-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'chp': {'full': 'chp-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'chp-Cans': {'full': 'chp-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'chq': {'full': 'chq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'chr': {'full': 'chr-Cher-US', 'region': 'US', 'script': 'Cher', 'suppress': False},
        'chr-Latn': {'full': 'chr-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'cht': {'full': 'cht-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'chw': {'full': 'chw-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'chx': {'full': 'chx-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'chy': {'full': 'chy-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'chz': {'full': 'chz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cia': {'full': 'cia-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'cia-Arab': {'full': 'cia-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'cia-Hang': {'full': 'cia-Hang-ID', 'region': 'ID', 'script': 'Hang', 'suppress': False},
        'cib': {'full': 'cib-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'cic': {'full': 'cic-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'cid': {'full': 'cid-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cie': {'full': 'cie-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'cih': {'full': 'cih-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'cik': {'full': 'cik-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'cim': {'full': 'cim-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'cin': {'full': 'cin-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'cip': {'full': 'cip-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cir': {'full': 'cir-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ciw': {'full': 'ciw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ciw-Cans': {'full': 'ciw-Cans-US', 'region': 'US', 'script': 'Cans', 'suppress': False},
        'ciy': {'full': 'ciy-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'cja': {'full': 'cja-Arab-KH', 'region': 'KH', 'script': 'Arab', 'suppress': False},
        'cja-Cham': {'full': 'cja-Cham-KH', 'region': 'KH', 'script': 'Cham', 'suppress': False},
        'cja-Latn': {'full': 'cja-Latn-KH', 'region': 'KH', 'script': 'Latn', 'suppress': False},
        'cje': {'full': 'cje-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'cjh': {'full': 'cjh-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cji': {'full': 'cji-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'cjk': {'full': 'cjk-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'cjm': {'full': 'cjm-Cham-VN', 'region': 'VN', 'script': 'Cham', 'suppress': False},
        'cjm-Arab': {'full': 'cjm-Arab-VN', 'region': 'VN', 'script': 'Arab', 'suppress': False},
        'cjm-Latn': {'full': 'cjm-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'cjn': {'full': 'cjn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'cjo': {'full': 'cjo-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cjp': {'full': 'cjp-Latn-CR', 'region': 'CR', 'script': 'Latn', 'suppress': False},
        'cjs': {'full': 'cjs-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'cjs-Cyrl': {'full': 'cjs-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'cjv': {'full': 'cjv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'cjy-Hans': {'full': 'cjy-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'cjy-Hant': {'full': 'cjy-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'ckb': {'full': 'ckb-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': False},
        'ckb-IR': {'full': 'ckb-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'ckb-Latn': {'full': 'ckb-Latn-IQ', 'region': 'IQ', 'script': 'Latn', 'suppress': False},
        'ckh': {'full': 'ckh-Zyyy-BD', 'region': 'BD', 'script': 'Zyyy', 'suppress': False},
        'ckl': {'full': 'ckl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ckm': {'full': 'ckm-Latn-HR', 'region': 'HR', 'script': 'Latn', 'suppress': False},
        'ckm-Glag': {'full': 'ckm-Glag-HR', 'region': 'HR', 'script': 'Glag', 'suppress': False},
        'ckn': {'full': 'ckn-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cko': {'full': 'cko-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ckq': {'full': 'ckq-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'ckr': {'full': 'ckr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'cks': {'full': 'cks-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ckt': {'full': 'ckt-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'cku': {'full': 'cku-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ckv': {'full': 'ckv-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'ckx': {'full': 'ckx-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'cky': {'full': 'cky-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ckz': {'full': 'ckz-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'cla': {'full': 'cla-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'clc': {'full': 'clc-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'cle': {'full': 'cle-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'clh': {'full': 'clh-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'cli': {'full': 'cli-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'clj': {'full': 'clj-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'clk': {'full': 'clk-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'clk-Tibt': {'full': 'clk-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'cll': {'full': 'cll-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'clm': {'full': 'clm-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'clo': {'full': 'clo-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'clt': {'full': 'clt-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'clu': {'full': 'clu-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'clw': {'full': 'clw-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'cly': {'full': 'cly-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cma': {'full': 'cma-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'cme': {'full': 'cme-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'cmg-Soyo': {'full': 'cmg-Soyo-MN', 'region': 'MN', 'script': 'Soyo', 'suppress': False},
        'cmi': {'full': 'cmi-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cml': {'full': 'cml-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'cmm': {'full': 'cmm-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cmo-Khmr': {'full': 'cmo-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'cmo-Latn': {'full': 'cmo-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'cmo-Latn-KH': {'full': 'cmo-Latn-KH', 'region': 'KH', 'script': 'Latn', 'suppress': False},
        'cmr': {'full': 'cmr-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cms': {'full': 'cms-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'cmt': {'full': 'cmt-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'cna': {'full': 'cna-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'cnb': {'full': 'cnb-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cnc': {'full': 'cnc-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'cng': {'full': 'cng-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'cnh': {'full': 'cnh-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cni': {'full': 'cni-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cnk': {'full': 'cnk-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cnl': {'full': 'cnl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cno': {'full': 'cno-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'cnp-Hans': {'full': 'cnp-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'cnp-Hant': {'full': 'cnp-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'cnr': {'full': 'cnr-Cyrl-ME', 'region': 'ME', 'script': 'Cyrl', 'suppress': False},
        'cnr-Latn': {'full': 'cnr-Latn-ME', 'region': 'ME', 'script': 'Latn', 'suppress': False},
        'cns': {'full': 'cns-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'cnt': {'full': 'cnt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cnu': {'full': 'cnu-Zyyy-DZ', 'region': 'DZ', 'script': 'Zyyy', 'suppress': False},
        'cnw': {'full': 'cnw-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cnx': {'full': 'cnx-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'co': {'full': 'co-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'coa': {'full': 'coa-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'cob': {'full': 'cob-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'coc': {'full': 'coc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cod': {'full': 'cod-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'coe': {'full': 'coe-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cof': {'full': 'cof-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'cog': {'full': 'cog-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'coh': {'full': 'coh-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'coj': {'full': 'coj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cok': {'full': 'cok-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'col': {'full': 'col-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'com': {'full': 'com-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'con': {'full': 'con-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'coo': {'full': 'coo-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'cop': {'full': 'cop-Copt-EG', 'region': 'EG', 'script': 'Copt', 'suppress': False},
        'cop-Arab': {'full': 'cop-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': False},
        'cop-Grek': {'full': 'cop-Grek-EG', 'region': 'EG', 'script': 'Grek', 'suppress': False},
        'coq': {'full': 'coq-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cot': {'full': 'cot-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cou': {'full': 'cou-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'cov': {'full': 'cov-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'cow': {'full': 'cow-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cox': {'full': 'cox-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'coz': {'full': 'coz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cpa': {'full': 'cpa-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cpb': {'full': 'cpb-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cpc': {'full': 'cpc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cpg': {'full': 'cpg-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'cpi': {'full': 'cpi-Latn-NR', 'region': 'NR', 'script': 'Latn', 'suppress': False},
        'cpn': {'full': 'cpn-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'cpo': {'full': 'cpo-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'cps': {'full': 'cps-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'cpu': {'full': 'cpu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cpx': {'full': 'cpx-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'cpy': {'full': 'cpy-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cqd': {'full': 'cqd-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'cr': {'full': 'cr-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'cr-Latn': {'full': 'cr-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'cra': {'full': 'cra-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'crb': {'full': 'crb-Latn-VC', 'region': 'VC', 'script': 'Latn', 'suppress': False},
        'crc': {'full': 'crc-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'crd': {'full': 'crd-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'crf': {'full': 'crf-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'crg': {'full': 'crg-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'crh': {'full': 'crh-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': False},
        'crh-Arab': {'full': 'crh-Arab-UZ', 'region': 'UZ', 'script': 'Arab', 'suppress': False},
        'crh-Latn': {'full': 'crh-Latn-UA', 'region': 'UA', 'script': 'Latn', 'suppress': False},
        'cri': {'full': 'cri-Latn-ST', 'region': 'ST', 'script': 'Latn', 'suppress': False},
        'crj': {'full': 'crj-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'crj-Latn': {'full': 'crj-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'crk': {'full': 'crk-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'crk-Latn': {'full': 'crk-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'crl': {'full': 'crl-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'crl-Latn': {'full': 'crl-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'crm': {'full': 'crm-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'crn': {'full': 'crn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cro': {'full': 'cro-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'crq': {'full': 'crq-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'crr': {'full': 'crr-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'crs': {'full': 'crs-Latn-SC', 'region': 'SC', 'script': 'Latn', 'suppress': False},
        'crt': {'full': 'crt-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'crv': {'full': 'crv-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'crw': {'full': 'crw-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'crx': {'full': 'crx-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'crx-Cans': {'full': 'crx-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'cry': {'full': 'cry-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'crz': {'full': 'crz-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cs': {'full': 'cs-Latn-CZ', 'region': 'CZ', 'script': 'Latn', 'suppress': True},
        'cs-Brai': {'full': 'cs-Brai-CZ', 'region': 'CZ', 'script': 'Brai', 'suppress': False},
        'csa': {'full': 'csa-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'csb': {'full': 'csb-Latn-PL', 'region': 'PL', 'script': 'Latn', 'suppress': False},
        'csc': {'full': 'csc-Zxxx-ES', 'region': 'ES', 'script': 'Zxxx', 'suppress': False},
        'csd': {'full': 'csd-Zxxx-TH', 'region': 'TH', 'script': 'Zxxx', 'suppress': False},
        'cse': {'full': 'cse-Zxxx-CZ', 'region': 'CZ', 'script': 'Zxxx', 'suppress': False},
        'csf': {'full': 'csf-Zxxx-CU', 'region': 'CU', 'script': 'Zxxx', 'suppress': False},
        'csg': {'full': 'csg-Zxxx-CL', 'region': 'CL', 'script': 'Zxxx', 'suppress': False},
        'csh': {'full': 'csh-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'csh-Latn': {'full': 'csh-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'csi': {'full': 'csi-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'csj': {'full': 'csj-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'csk': {'full': 'csk-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'csl': {'full': 'csl-Zxxx-CN', 'region': 'CN', 'script': 'Zxxx', 'suppress': False},
        'csm': {'full': 'csm-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'csn': {'full': 'csn-Zxxx-CO', 'region': 'CO', 'script': 'Zxxx', 'suppress': False},
        'cso': {'full': 'cso-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'csp-Hans': {'full': 'csp-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'csp-Hant': {'full': 'csp-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'csq': {'full': 'csq-Zxxx-HR', 'region': 'HR', 'script': 'Zxxx', 'suppress': False},
        'csr': {'full': 'csr-Zxxx-CR', 'region': 'CR', 'script': 'Zxxx', 'suppress': False},
        'css': {'full': 'css-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cst': {'full': 'cst-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'csv': {'full': 'csv-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'csw': {'full': 'csw-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'csy': {'full': 'csy-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'csz': {'full': 'csz-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'cta': {'full': 'cta-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ctc': {'full': 'ctc-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ctd': {'full': 'ctd-Pauc-MM', 'region': 'MM', 'script': 'Pauc', 'suppress': False},
        'ctd-Latn': {'full': 'ctd-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'cte': {'full': 'cte-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ctg': {'full': 'ctg-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'ctg-Arab': {'full': 'ctg-Arab-BD', 'region': 'BD', 'script': 'Arab', 'suppress': False},
        'ctg-Latn': {'full': 'ctg-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'cth': {'full': 'cth-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'ctl': {'full': 'ctl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ctm': {'full': 'ctm-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ctn': {'full': 'ctn-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'cto': {'full': 'cto-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ctp': {'full': 'ctp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cts': {'full': 'cts-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ctt': {'full': 'ctt-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'ctu': {'full': 'ctu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ctu-x-tila': {'full': 'ctu-Latn-MX-x-tila', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ctu-x-tumbala': {'full': 'ctu-Latn-MX-x-tumbala', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ctz': {'full': 'ctz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cu': {'full': 'cu-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'cu-Cyrs': {'full': 'cu-Cyrs-RU', 'region': 'RU', 'script': 'Cyrs', 'suppress': False},
        'cu-Glag': {'full': 'cu-Glag-BG', 'region': 'BG', 'script': 'Glag', 'suppress': False},
        'cua': {'full': 'cua-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'cub': {'full': 'cub-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cuc': {'full': 'cuc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cug': {'full': 'cug-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'cuh': {'full': 'cuh-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'cui': {'full': 'cui-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'cuj': {'full': 'cuj-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'cuk': {'full': 'cuk-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': False},
        'cul': {'full': 'cul-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'cuo': {'full': 'cuo-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'cup': {'full': 'cup-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'cuq': {'full': 'cuq-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'cur': {'full': 'cur-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'cut': {'full': 'cut-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cuu': {'full': 'cuu-Lana-CN', 'region': 'CN', 'script': 'Lana', 'suppress': False},
        'cuv': {'full': 'cuv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'cuw': {'full': 'cuw-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'cux': {'full': 'cux-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cuy': {'full': 'cuy-Latn-XX', 'region': 'XX', 'script': 'Latn', 'suppress': False},
        'cv': {'full': 'cv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'cvg': {'full': 'cvg-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'cvg-Tibt': {'full': 'cvg-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'cvn': {'full': 'cvn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cwa': {'full': 'cwa-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'cwb': {'full': 'cwb-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'cwe': {'full': 'cwe-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'cwg': {'full': 'cwg-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'cwt': {'full': 'cwt-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'cy': {'full': 'cy-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': True},
        'cy-Brai': {'full': 'cy-Brai-GB', 'region': 'GB', 'script': 'Brai', 'suppress': False},
        'cya': {'full': 'cya-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'cyb': {'full': 'cyb-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'cyo': {'full': 'cyo-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'czh-Hans': {'full': 'czh-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'czh-Hant': {'full': 'czh-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'czk': {'full': 'czk-Zyyy-CZ', 'region': 'CZ', 'script': 'Zyyy', 'suppress': False},
        'czn': {'full': 'czn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'czo': {'full': 'czo-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'czt': {'full': 'czt-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'da': {'full': 'da-Latn-DK', 'region': 'DK', 'script': 'Latn', 'suppress': True},
        'da-Brai': {'full': 'da-Brai-DK', 'region': 'DK', 'script': 'Brai', 'suppress': False},
        'daa': {'full': 'daa-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'dac': {'full': 'dac-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dad': {'full': 'dad-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dae': {'full': 'dae-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dag': {'full': 'dag-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'dag-Arab': {'full': 'dag-Arab-GH', 'region': 'GH', 'script': 'Arab', 'suppress': False},
        'dah': {'full': 'dah-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dai': {'full': 'dai-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'daj': {'full': 'daj-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'dak': {'full': 'dak-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'dal': {'full': 'dal-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'dam': {'full': 'dam-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dao': {'full': 'dao-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'dao-x-khengdai': {'full': 'dao-Latn-MM-x-khengdai', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'dao-x-matlic': {'full': 'dao-Latn-MM-x-matlic', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'dao-x-mattui': {'full': 'dao-Latn-MM-x-mattui', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'dao-x-yindu': {'full': 'dao-Latn-MM-x-yindu', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'daq': {'full': 'daq-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'dar': {'full': 'dar-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'das': {'full': 'das-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'dau': {'full': 'dau-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'dav': {'full': 'dav-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'daw': {'full': 'daw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'dax': {'full': 'dax-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'daz': {'full': 'daz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dba': {'full': 'dba-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dbb': {'full': 'dbb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbd': {'full': 'dbd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbe': {'full': 'dbe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dbf': {'full': 'dbf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dbg': {'full': 'dbg-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dbi': {'full': 'dbi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbj': {'full': 'dbj-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dbj-Arab': {'full': 'dbj-Arab-MY', 'region': 'MY', 'script': 'Arab', 'suppress': False},
        'dbl': {'full': 'dbl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dbm': {'full': 'dbm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbn': {'full': 'dbn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dbo': {'full': 'dbo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbp': {'full': 'dbp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbq': {'full': 'dbq-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dbr': {'full': 'dbr-Zyyy-SO', 'region': 'SO', 'script': 'Zyyy', 'suppress': False},
        'dbt': {'full': 'dbt-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dbu': {'full': 'dbu-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dbv': {'full': 'dbv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dbw': {'full': 'dbw-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dby': {'full': 'dby-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dcc': {'full': 'dcc-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'dcc-Deva': {'full': 'dcc-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'dcr': {'full': 'dcr-Latn-VI', 'region': 'VI', 'script': 'Latn', 'suppress': False},
        'dda': {'full': 'dda-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ddd': {'full': 'ddd-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'dde': {'full': 'dde-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'ddg': {'full': 'ddg-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'ddi': {'full': 'ddi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ddj': {'full': 'ddj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ddn': {'full': 'ddn-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'ddo': {'full': 'ddo-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'ddr': {'full': 'ddr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dds': {'full': 'dds-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'ddw': {'full': 'ddw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'de': {'full': 'de-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'de-AT': {'full': 'de-Latn-AT', 'region': 'AT', 'script': 'Latn', 'suppress': True},
        'de-Brai': {'full': 'de-Brai-DE', 'region': 'DE', 'script': 'Brai', 'suppress': False},
        'de-CH': {'full': 'de-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': True},
        'de-Dupl': {'full': 'de-Dupl-DE', 'region': 'DE', 'script': 'Dupl', 'suppress': False},
        'de-IT': {'full': 'de-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': True},
        'de-LI': {'full': 'de-Latn-LI', 'region': 'LI', 'script': 'Latn', 'suppress': True},
        'de-LU': {'full': 'de-Latn-LU', 'region': 'LU', 'script': 'Latn', 'suppress': True},
        'de-Latf': {'full': 'de-Latf-DE', 'region': 'DE', 'script': 'Latf', 'suppress': False},
        'de-Runr': {'full': 'de-Runr-DE', 'region': 'DE', 'script': 'Runr', 'suppress': False},
        'dec': {'full': 'dec-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ded': {'full': 'ded-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dee': {'full': 'dee-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'def': {'full': 'def-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'deg': {'full': 'deg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'deh': {'full': 'deh-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'dei': {'full': 'dei-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dek': {'full': 'dek-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'del': {'full': 'del-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'del-Latn-CA': {'full': 'del-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'dem': {'full': 'dem-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'den': {'full': 'den-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'den-Cans': {'full': 'den-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'dep': {'full': 'dep-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'deq': {'full': 'deq-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'der-Beng': {'full': 'der-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'der-Latn': {'full': 'der-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'des': {'full': 'des-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'dev': {'full': 'dev-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dez': {'full': 'dez-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'dga': {'full': 'dga-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'dgb': {'full': 'dgb-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dgc': {'full': 'dgc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'dgd': {'full': 'dgd-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dge': {'full': 'dge-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dgg': {'full': 'dgg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dgh': {'full': 'dgh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dgi': {'full': 'dgi-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dgk': {'full': 'dgk-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'dgl-Arab': {'full': 'dgl-Arab-SD', 'region': 'SD', 'script': 'Arab', 'suppress': False},
        'dgl-Copt': {'full': 'dgl-Copt-SD-x-olnubian', 'region': 'SD', 'script': 'Copt', 'suppress': False},
        'dgl-Latn': {'full': 'dgl-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'dgn': {'full': 'dgn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dgr': {'full': 'dgr-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'dgs': {'full': 'dgs-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dgt': {'full': 'dgt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dgu': {'full': 'dgu-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'dgw': {'full': 'dgw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dgx': {'full': 'dgx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dgz': {'full': 'dgz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dhg': {'full': 'dhg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dhi': {'full': 'dhi-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'dhl': {'full': 'dhl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dhm': {'full': 'dhm-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'dhn': {'full': 'dhn-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'dho': {'full': 'dho-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'dhr': {'full': 'dhr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dhs': {'full': 'dhs-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'dhu': {'full': 'dhu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dhv': {'full': 'dhv-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'dhw': {'full': 'dhw-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'dhx': {'full': 'dhx-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dia': {'full': 'dia-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dib': {'full': 'dib-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'dic': {'full': 'dic-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'did': {'full': 'did-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'dif': {'full': 'dif-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dig': {'full': 'dig-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'dih': {'full': 'dih-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'dii': {'full': 'dii-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dij': {'full': 'dij-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dik-Arab': {'full': 'dik-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'dil': {'full': 'dil-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'dim': {'full': 'dim-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'din': {'full': 'din-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'din-Arab': {'full': 'din-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'dio': {'full': 'dio-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dip': {'full': 'dip-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'dir': {'full': 'dir-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dis-Beng': {'full': 'dis-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'dis-Latn': {'full': 'dis-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'diu': {'full': 'diu-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'diw': {'full': 'diw-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'dix': {'full': 'dix-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'diy': {'full': 'diy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'diz': {'full': 'diz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'dja': {'full': 'dja-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'djb': {'full': 'djb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'djc': {'full': 'djc-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'djd': {'full': 'djd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dje': {'full': 'dje-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'dje-Arab': {'full': 'dje-Arab-NE', 'region': 'NE', 'script': 'Arab', 'suppress': False},
        'dje-Brai': {'full': 'dje-Brai-NE', 'region': 'NE', 'script': 'Brai', 'suppress': False},
        'djf': {'full': 'djf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dji': {'full': 'dji-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'djj': {'full': 'djj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'djk': {'full': 'djk-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'djk-Afak': {'full': 'djk-Afak-SR', 'region': 'SR', 'script': 'Afak', 'suppress': False},
        'djm': {'full': 'djm-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'djn': {'full': 'djn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'djo': {'full': 'djo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'djr': {'full': 'djr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dju': {'full': 'dju-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'djw': {'full': 'djw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dka': {'full': 'dka-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'dkk': {'full': 'dkk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dkr': {'full': 'dkr-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dks': {'full': 'dks-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'dkx': {'full': 'dkx-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dlg': {'full': 'dlg-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'dlk': {'full': 'dlk-Zyyy-ER', 'region': 'ER', 'script': 'Zyyy', 'suppress': False},
        'dlm': {'full': 'dlm-Latn-HR', 'region': 'HR', 'script': 'Latn', 'suppress': False},
        'dln': {'full': 'dln-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'dma': {'full': 'dma-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'dmb': {'full': 'dmb-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dmc': {'full': 'dmc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dmd': {'full': 'dmd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dme': {'full': 'dme-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dmf': {'full': 'dmf-Medf-NG', 'region': 'NG', 'script': 'Medf', 'suppress': False},
        'dmg': {'full': 'dmg-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dmk': {'full': 'dmk-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'dml': {'full': 'dml-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'dmm': {'full': 'dmm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dmo': {'full': 'dmo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dmr': {'full': 'dmr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dms': {'full': 'dms-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dmu': {'full': 'dmu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dmv': {'full': 'dmv-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dmw': {'full': 'dmw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dmx': {'full': 'dmx-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'dmy': {'full': 'dmy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dna': {'full': 'dna-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dnd': {'full': 'dnd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dne': {'full': 'dne-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'dng': {'full': 'dng-Cyrl-KG', 'region': 'KG', 'script': 'Cyrl', 'suppress': False},
        'dni': {'full': 'dni-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dnj': {'full': 'dnj-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'dnj-LR': {'full': 'dnj-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'dnk': {'full': 'dnk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dnn': {'full': 'dnn-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dno': {'full': 'dno-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'dnr': {'full': 'dnr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dnt': {'full': 'dnt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dnu': {'full': 'dnu-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'dnv': {'full': 'dnv-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'dnw': {'full': 'dnw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dny': {'full': 'dny-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'doa': {'full': 'doa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dob': {'full': 'dob-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'doc': {'full': 'doc-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'doe': {'full': 'doe-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'dof': {'full': 'dof-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'doh': {'full': 'doh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'doi': {'full': 'doi-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'doi-Deva': {'full': 'doi-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'doi-Takr': {'full': 'doi-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'dok': {'full': 'dok-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dol': {'full': 'dol-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'don': {'full': 'don-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'doo': {'full': 'doo-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'dop': {'full': 'dop-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'doq': {'full': 'doq-Zxxx-DO', 'region': 'DO', 'script': 'Zxxx', 'suppress': False},
        'dor': {'full': 'dor-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'dos': {'full': 'dos-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dot': {'full': 'dot-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dov': {'full': 'dov-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': False},
        'dow': {'full': 'dow-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dox': {'full': 'dox-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'doy': {'full': 'doy-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'doz': {'full': 'doz-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'dpp': {'full': 'dpp-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'drb': {'full': 'drb-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'drc': {'full': 'drc-Latn-PT', 'region': 'PT', 'script': 'Latn', 'suppress': False},
        'drd': {'full': 'drd-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'dre': {'full': 'dre-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'drg': {'full': 'drg-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dri': {'full': 'dri-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'drl': {'full': 'drl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'drn': {'full': 'drn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dro': {'full': 'dro-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'drq': {'full': 'drq-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'drs': {'full': 'drs-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'drt': {'full': 'drt-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'dru': {'full': 'dru-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'dry': {'full': 'dry-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'dsb': {'full': 'dsb-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'dse': {'full': 'dse-Zxxx-NL', 'region': 'NL', 'script': 'Zxxx', 'suppress': False},
        'dsh': {'full': 'dsh-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'dsi': {'full': 'dsi-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'dsl': {'full': 'dsl-Zxxx-DK', 'region': 'DK', 'script': 'Zxxx', 'suppress': False},
        'dsn': {'full': 'dsn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dso': {'full': 'dso-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'dsq-Arab': {'full': 'dsq-Arab-ML', 'region': 'ML', 'script': 'Arab', 'suppress': False},
        'dsq-Latn': {'full': 'dsq-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dta': {'full': 'dta-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'dta-Cyrl': {'full': 'dta-Cyrl-CN', 'region': 'CN', 'script': 'Cyrl', 'suppress': False},
        'dta-Hans': {'full': 'dta-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'dta-Mong-x-manchu': {'full': 'dta-Mong-CN-x-manchu', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'dtb': {'full': 'dtb-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dtd': {'full': 'dtd-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'dth': {'full': 'dth-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dti': {'full': 'dti-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dtk': {'full': 'dtk-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dtm': {'full': 'dtm-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dtn': {'full': 'dtn-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'dto': {'full': 'dto-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dtp': {'full': 'dtp-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dtr': {'full': 'dtr-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'dts': {'full': 'dts-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dtt': {'full': 'dtt-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dtu': {'full': 'dtu-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dty': {'full': 'dty-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'dua': {'full': 'dua-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dub': {'full': 'dub-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'duc': {'full': 'duc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'due': {'full': 'due-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'duf': {'full': 'duf-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'dug': {'full': 'dug-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'duh-Deva': {'full': 'duh-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'duh-Gujr': {'full': 'duh-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'dui': {'full': 'dui-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'duk': {'full': 'duk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dul': {'full': 'dul-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'dum': {'full': 'dum-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'dun': {'full': 'dun-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'duo': {'full': 'duo-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'dup': {'full': 'dup-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'duq': {'full': 'duq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dur': {'full': 'dur-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dus': {'full': 'dus-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'duu': {'full': 'duu-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'duv': {'full': 'duv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'duw': {'full': 'duw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'dux': {'full': 'dux-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'duy': {'full': 'duy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'duz': {'full': 'duz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'dv': {'full': 'dv-Thaa-MV', 'region': 'MV', 'script': 'Thaa', 'suppress': True},
        'dv-Diak': {'full': 'dv-Diak-MV', 'region': 'MV', 'script': 'Diak', 'suppress': False},
        'dva': {'full': 'dva-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dwa': {'full': 'dwa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dwk': {'full': 'dwk-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'dwr': {'full': 'dwr-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'dwr-Ethi': {'full': 'dwr-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'dws': {'full': 'dws-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'dwu': {'full': 'dwu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dww': {'full': 'dww-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'dwy': {'full': 'dwy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dwz': {'full': 'dwz-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'dya': {'full': 'dya-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dyb': {'full': 'dyb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dyd': {'full': 'dyd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dyg': {'full': 'dyg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'dyi': {'full': 'dyi-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'dym': {'full': 'dym-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'dyn': {'full': 'dyn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dyo': {'full': 'dyo-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'dyo-Arab': {'full': 'dyo-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'dyu': {'full': 'dyu-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'dyu-Arab': {'full': 'dyu-Arab-CI', 'region': 'CI', 'script': 'Arab', 'suppress': False},
        'dyu-Nkoo': {'full': 'dyu-Nkoo-CI', 'region': 'CI', 'script': 'Nkoo', 'suppress': False},
        'dyy': {'full': 'dyy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dz': {'full': 'dz-Tibt-BT', 'region': 'BT', 'script': 'Tibt', 'suppress': True},
        'dza': {'full': 'dza-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'dze': {'full': 'dze-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'dzg': {'full': 'dzg-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'dzl': {'full': 'dzl-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'dzn': {'full': 'dzn-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'eaa': {'full': 'eaa-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ebc': {'full': 'ebc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ebg': {'full': 'ebg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ebk': {'full': 'ebk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ebo': {'full': 'ebo-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'ebr': {'full': 'ebr-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ebu': {'full': 'ebu-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'ecr': {'full': 'ecr-Zyyy-GR', 'region': 'GR', 'script': 'Zyyy', 'suppress': False},
        'ecs': {'full': 'ecs-Zxxx-EC', 'region': 'EC', 'script': 'Zxxx', 'suppress': False},
        'ecy': {'full': 'ecy-Zyyy-CY', 'region': 'CY', 'script': 'Zyyy', 'suppress': False},
        'ee': {'full': 'ee-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ee-Brai': {'full': 'ee-Brai-GH', 'region': 'GH', 'script': 'Brai', 'suppress': False},
        'ee-TG': {'full': 'ee-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'eee': {'full': 'eee-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'efa': {'full': 'efa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'efe': {'full': 'efe-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'efi': {'full': 'efi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ega': {'full': 'ega-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'egl': {'full': 'egl-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'ego': {'full': 'ego-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'egy': {'full': 'egy-Egyp-EG', 'region': 'EG', 'script': 'Egyp', 'suppress': False},
        'ehu': {'full': 'ehu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'eip': {'full': 'eip-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'eit': {'full': 'eit-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'eiv': {'full': 'eiv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'eja': {'full': 'eja-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'eka': {'full': 'eka-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'eka-Latn-NG-x-ekajuk': {'full': 'eka-Latn-NG-x-ekajuk', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ekc': {'full': 'ekc-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'eke': {'full': 'eke-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ekg': {'full': 'ekg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'eki': {'full': 'eki-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ekl': {'full': 'ekl-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'ekm': {'full': 'ekm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'eko': {'full': 'eko-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'eko-Arab': {'full': 'eko-Arab-MZ', 'region': 'MZ', 'script': 'Arab', 'suppress': False},
        'ekp': {'full': 'ekp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ekr': {'full': 'ekr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'eky': {'full': 'eky-Kali-MM', 'region': 'MM', 'script': 'Kali', 'suppress': False},
        'el': {'full': 'el-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': True},
        'el-Brai': {'full': 'el-Brai-GR', 'region': 'GR', 'script': 'Brai', 'suppress': False},
        'el-Cyrl': {'full': 'el-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': False},
        'ele': {'full': 'ele-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'elh': {'full': 'elh-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'eli': {'full': 'eli-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'elk': {'full': 'elk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'elm': {'full': 'elm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'elo': {'full': 'elo-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'elu': {'full': 'elu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'elx': {'full': 'elx-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'ema': {'full': 'ema-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'emb': {'full': 'emb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'eme': {'full': 'eme-Latn-GF', 'region': 'GF', 'script': 'Latn', 'suppress': False},
        'emg': {'full': 'emg-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'emi': {'full': 'emi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'emm': {'full': 'emm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'emn': {'full': 'emn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'emp': {'full': 'emp-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': False},
        'ems': {'full': 'ems-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ems-Cyrl': {'full': 'ems-Cyrl-US', 'region': 'US', 'script': 'Cyrl', 'suppress': False},
        'emu': {'full': 'emu-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'emw': {'full': 'emw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'emx': {'full': 'emx-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'emy': {'full': 'emy-Zyyy-MX', 'region': 'MX', 'script': 'Zyyy', 'suppress': False},
        'en': {'full': 'en-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': True},
        'en-001': {'full': 'en-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': True},
        'en-150': {'full': 'en-Latn-150', 'region': '150', 'script': 'Latn', 'suppress': True},
        'en-AE': {'full': 'en-Latn-AE', 'region': 'AE', 'script': 'Latn', 'suppress': True},
        'en-AG': {'full': 'en-Latn-AG', 'region': 'AG', 'script': 'Latn', 'suppress': True},
        'en-AI': {'full': 'en-Latn-AI', 'region': 'AI', 'script': 'Latn', 'suppress': True},
        'en-AT': {'full': 'en-Latn-AT', 'region': 'AT', 'script': 'Latn', 'suppress': True},
        'en-AU': {'full': 'en-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': True},
        'en-BB': {'full': 'en-Latn-BB', 'region': 'BB', 'script': 'Latn', 'suppress': True},
        'en-BE': {'full': 'en-Latn-BE', 'region': 'BE', 'script': 'Latn', 'suppress': True},
        'en-BI': {'full': 'en-Latn-BI', 'region': 'BI', 'script': 'Latn', 'suppress': True},
        'en-BM': {'full': 'en-Latn-BM', 'region': 'BM', 'script': 'Latn', 'suppress': True},
        'en-BS': {'full': 'en-Latn-BS', 'region': 'BS', 'script': 'Latn', 'suppress': True},
        'en-BW': {'full': 'en-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': True},
        'en-BZ': {'full': 'en-Latn-BZ', 'region': 'BZ', 'script': 'Latn', 'suppress': True},
        'en-Brai': {'full': 'en-Brai-GB', 'region': 'GB', 'script': 'Brai', 'suppress': False},
        'en-CA': {'full': 'en-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': True},
        'en-CC': {'full': 'en-Latn-CC', 'region': 'CC', 'script': 'Latn', 'suppress': True},
        'en-CH': {'full': 'en-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': True},
        'en-CK': {'full': 'en-Latn-CK', 'region': 'CK', 'script': 'Latn', 'suppress': True},
        'en-CM': {'full': 'en-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': True},
        'en-CX': {'full': 'en-Latn-CX', 'region': 'CX', 'script': 'Latn', 'suppress': True},
        'en-DE': {'full': 'en-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'en-DG': {'full': 'en-Latn-DG', 'region': 'DG', 'script': 'Latn', 'suppress': True},
        'en-DK': {'full': 'en-Latn-DK', 'region': 'DK', 'script': 'Latn', 'suppress': True},
        'en-DM': {'full': 'en-Latn-DM', 'region': 'DM', 'script': 'Latn', 'suppress': True},
        'en-Dsrt': {'full': 'en-Dsrt-US', 'region': 'US', 'script': 'Dsrt', 'suppress': False},
        'en-Dupl': {'full': 'en-Dupl-US', 'region': 'US', 'script': 'Dupl', 'suppress': False},
        'en-ER': {'full': 'en-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': True},
        'en-FI': {'full': 'en-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': True},
        'en-FJ': {'full': 'en-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': True},
        'en-FK': {'full': 'en-Latn-FK', 'region': 'FK', 'script': 'Latn', 'suppress': True},
        'en-GB': {'full': 'en-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': True},
        'en-GD': {'full': 'en-Latn-GD', 'region': 'GD', 'script': 'Latn', 'suppress': True},
        'en-GG': {'full': 'en-Latn-GG', 'region': 'GG', 'script': 'Latn', 'suppress': True},
        'en-GH': {'full': 'en-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': True},
        'en-GI': {'full': 'en-Latn-GI', 'region': 'GI', 'script': 'Latn', 'suppress': True},
        'en-GM': {'full': 'en-Latn-GM', 'region': 'GM', 'script': 'Latn', 'suppress': True},
        'en-GU': {'full': 'en-Latn-GU', 'region': 'GU', 'script': 'Latn', 'suppress': True},
        'en-GY': {'full': 'en-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': True},
        'en-HK': {'full': 'en-Latn-HK', 'region': 'HK', 'script': 'Latn', 'suppress': True},
        'en-IE': {'full': 'en-Latn-IE', 'region': 'IE', 'script': 'Latn', 'suppress': True},
        'en-IL': {'full': 'en-Latn-IL', 'region': 'IL', 'script': 'Latn', 'suppress': True},
        'en-IM': {'full': 'en-Latn-IM', 'region': 'IM', 'script': 'Latn', 'suppress': True},
        'en-IN': {'full': 'en-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': True},
        'en-IO': {'full': 'en-Latn-IO', 'region': 'IO', 'script': 'Latn', 'suppress': True},
        'en-JE': {'full': 'en-Latn-JE', 'region': 'JE', 'script': 'Latn', 'suppress': True},
        'en-JM': {'full': 'en-Latn-JM', 'region': 'JM', 'script': 'Latn', 'suppress': True},
        'en-KE': {'full': 'en-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': True},
        'en-KI': {'full': 'en-Latn-KI', 'region': 'KI', 'script': 'Latn', 'suppress': True},
        'en-KN': {'full': 'en-Latn-KN', 'region': 'KN', 'script': 'Latn', 'suppress': True},
        'en-KY': {'full': 'en-Latn-KY', 'region': 'KY', 'script': 'Latn', 'suppress': True},
        'en-LC': {'full': 'en-Latn-LC', 'region': 'LC', 'script': 'Latn', 'suppress': True},
        'en-LR': {'full': 'en-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': True},
        'en-LS': {'full': 'en-Latn-LS', 'region': 'LS', 'script': 'Latn', 'suppress': True},
        'en-MG': {'full': 'en-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': True},
        'en-MH': {'full': 'en-Latn-MH', 'region': 'MH', 'script': 'Latn', 'suppress': True},
        'en-MO': {'full': 'en-Latn-MO', 'region': 'MO', 'script': 'Latn', 'suppress': True},
        'en-MP': {'full': 'en-Latn-MP', 'region': 'MP', 'script': 'Latn', 'suppress': True},
        'en-MS': {'full': 'en-Latn-MS', 'region': 'MS', 'script': 'Latn', 'suppress': True},
        'en-MT': {'full': 'en-Latn-MT', 'region': 'MT', 'script': 'Latn', 'suppress': True},
        'en-MU': {'full': 'en-Latn-MU', 'region': 'MU', 'script': 'Latn', 'suppress': True},
        'en-MW': {'full': 'en-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': True},
        'en-MY': {'full': 'en-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': True},
        'en-NA': {'full': 'en-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': True},
        'en-NF': {'full': 'en-Latn-NF', 'region': 'NF', 'script': 'Latn', 'suppress': True},
        'en-NG': {'full': 'en-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': True},
        'en-NL': {'full': 'en-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': True},
        'en-NR': {'full': 'en-Latn-NR', 'region': 'NR', 'script': 'Latn', 'suppress': True},
        'en-NU': {'full': 'en-Latn-NU', 'region': 'NU', 'script': 'Latn', 'suppress': True},
        'en-NZ': {'full': 'en-Latn-NZ', 'region': 'NZ', 'script': 'Latn', 'suppress': True},
        'en-PG': {'full': 'en-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': True},
        'en-PH': {'full': 'en-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': True},
        'en-PK': {'full': 'en-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': True},
        'en-PN': {'full': 'en-Latn-PN', 'region': 'PN', 'script': 'Latn', 'suppress': True},
        'en-PW': {'full': 'en-Latn-PW', 'region': 'PW', 'script': 'Latn', 'suppress': True},
        'en-RW': {'full': 'en-Latn-RW', 'region': 'RW', 'script': 'Latn', 'suppress': True},
        'en-SB': {'full': 'en-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': True},
        'en-SC': {'full': 'en-Latn-SC', 'region': 'SC', 'script': 'Latn', 'suppress': True},
        'en-SD': {'full': 'en-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': True},
        'en-SE': {'full': 'en-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': True},
        'en-SG': {'full': 'en-Latn-SG', 'region': 'SG', 'script': 'Latn', 'suppress': True},
        'en-SH': {'full': 'en-Latn-SH', 'region': 'SH', 'script': 'Latn', 'suppress': True},
        'en-SI': {'full': 'en-Latn-SI', 'region': 'SI', 'script': 'Latn', 'suppress': True},
        'en-SL': {'full': 'en-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': True},
        'en-SS': {'full': 'en-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': True},
        'en-SX': {'full': 'en-Latn-SX', 'region': 'SX', 'script': 'Latn', 'suppress': True},
        'en-SZ': {'full': 'en-Latn-SZ', 'region': 'SZ', 'script': 'Latn', 'suppress': True},
        'en-Shaw': {'full': 'en-Shaw-GB', 'region': 'GB', 'script': 'Shaw', 'suppress': False},
        'en-TK': {'full': 'en-Latn-TK', 'region': 'TK', 'script': 'Latn', 'suppress': True},
        'en-TO': {'full': 'en-Latn-TO', 'region': 'TO', 'script': 'Latn', 'suppress': True},
        'en-TT': {'full': 'en-Latn-TT', 'region': 'TT', 'script': 'Latn', 'suppress': True},
        'en-TV': {'full': 'en-Latn-TV', 'region': 'TV', 'script': 'Latn', 'suppress': True},
        'en-TZ': {'full': 'en-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': True},
        'en-UG': {'full': 'en-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': True},
        'en-VC': {'full': 'en-Latn-VC', 'region': 'VC', 'script': 'Latn', 'suppress': True},
        'en-VU': {'full': 'en-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': True},
        'en-WS': {'full': 'en-Latn-WS', 'region': 'WS', 'script': 'Latn', 'suppress': True},
        'en-ZA': {'full': 'en-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'en-ZM': {'full': 'en-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': True},
        'en-ZW': {'full': 'en-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': True},
        'ena': {'full': 'ena-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'enb': {'full': 'enb-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'enc': {'full': 'enc-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'end': {'full': 'end-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'enf': {'full': 'enf-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'enh': {'full': 'enh-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'enl': {'full': 'enl-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'enm': {'full': 'enm-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'enn': {'full': 'enn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'eno': {'full': 'eno-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'enq': {'full': 'enq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'enr': {'full': 'enr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'enu': {'full': 'enu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'env': {'full': 'env-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'enw': {'full': 'enw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'enx': {'full': 'enx-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'eo': {'full': 'eo-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': True},
        'eot': {'full': 'eot-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'epi': {'full': 'epi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'era': {'full': 'era-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'erg': {'full': 'erg-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'erh': {'full': 'erh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'eri': {'full': 'eri-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'erk': {'full': 'erk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ero': {'full': 'ero-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'err': {'full': 'err-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ers': {'full': 'ers-Zzzz-CN-x-ersushab', 'region': 'CN', 'script': 'Zzzz', 'suppress': False},
        'ert': {'full': 'ert-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'erw': {'full': 'erw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'es': {'full': 'es-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': True},
        'es-419': {'full': 'es-Latn-419', 'region': '419', 'script': 'Latn', 'suppress': True},
        'es-AR': {'full': 'es-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': True},
        'es-BO': {'full': 'es-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': True},
        'es-BR': {'full': 'es-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': True},
        'es-BZ': {'full': 'es-Latn-BZ', 'region': 'BZ', 'script': 'Latn', 'suppress': True},
        'es-Brai': {'full': 'es-Brai-ES', 'region': 'ES', 'script': 'Brai', 'suppress': False},
        'es-CL': {'full': 'es-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': True},
        'es-CO': {'full': 'es-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': True},
        'es-CR': {'full': 'es-Latn-CR', 'region': 'CR', 'script': 'Latn', 'suppress': True},
        'es-CU': {'full': 'es-Latn-CU', 'region': 'CU', 'script': 'Latn', 'suppress': True},
        'es-DO': {'full': 'es-Latn-DO', 'region': 'DO', 'script': 'Latn', 'suppress': True},
        'es-Dupl': {'full': 'es-Dupl-ES', 'region': 'ES', 'script': 'Dupl', 'suppress': False},
        'es-EC': {'full': 'es-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': True},
        'es-GQ': {'full': 'es-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': True},
        'es-GT': {'full': 'es-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': True},
        'es-HN': {'full': 'es-Latn-HN', 'region': 'HN', 'script': 'Latn', 'suppress': True},
        'es-MX': {'full': 'es-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': True},
        'es-NI': {'full': 'es-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': True},
        'es-PA': {'full': 'es-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': True},
        'es-PE': {'full': 'es-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': True},
        'es-PH': {'full': 'es-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': True},
        'es-PR': {'full': 'es-Latn-PR', 'region': 'PR', 'script': 'Latn', 'suppress': True},
        'es-PY': {'full': 'es-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': True},
        'es-SV': {'full': 'es-Latn-SV', 'region': 'SV', 'script': 'Latn', 'suppress': True},
        'es-US': {'full': 'es-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': True},
        'es-UY': {'full': 'es-Latn-UY', 'region': 'UY', 'script': 'Latn', 'suppress': True},
        'es-VE': {'full': 'es-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': True},
        'ese': {'full': 'ese-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'esg': {'full': 'esg-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'esg-Gonm': {'full': 'esg-Gonm-IN', 'region': 'IN', 'script': 'Gonm', 'suppress': False},
        'esg-Telu': {'full': 'esg-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'esh': {'full': 'esh-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'esi': {'full': 'esi-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'esl': {'full': 'esl-Zxxx-EG', 'region': 'EG', 'script': 'Zxxx', 'suppress': False},
        'esm': {'full': 'esm-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'esn': {'full': 'esn-Zxxx-SV', 'region': 'SV', 'script': 'Zxxx', 'suppress': False},
        'eso': {'full': 'eso-Zxxx-EE', 'region': 'EE', 'script': 'Zxxx', 'suppress': False},
        'esq': {'full': 'esq-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ess': {'full': 'ess-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ess-Cyrl': {'full': 'ess-Cyrl-US', 'region': 'US', 'script': 'Cyrl', 'suppress': False},
        'esu': {'full': 'esu-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'esy': {'full': 'esy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'esy-Zzzz-x-eskaya': {'full': 'esy-Zzzz-PH-x-eskaya', 'region': 'PH', 'script': 'Zzzz', 'suppress': False},
        'et': {'full': 'et-Latn-EE', 'region': 'EE', 'script': 'Latn', 'suppress': True},
        'et-Brai': {'full': 'et-Brai-EE', 'region': 'EE', 'script': 'Brai', 'suppress': False},
        'etb': {'full': 'etb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'etc': {'full': 'etc-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'eth': {'full': 'eth-Zxxx-ET', 'region': 'ET', 'script': 'Zxxx', 'suppress': False},
        'etn': {'full': 'etn-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'eto': {'full': 'eto-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'etr': {'full': 'etr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ets': {'full': 'ets-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ett': {'full': 'ett-Ital-IT', 'region': 'IT', 'script': 'Ital', 'suppress': False},
        'ett-Latn': {'full': 'ett-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'etu': {'full': 'etu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'etx': {'full': 'etx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'etz': {'full': 'etz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'eu': {'full': 'eu-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': True},
        'eve': {'full': 'eve-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'evh': {'full': 'evh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'evn': {'full': 'evn-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'evn-Latn': {'full': 'evn-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'evn-Mong': {'full': 'evn-Mong-CN', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'ewo': {'full': 'ewo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ext': {'full': 'ext-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'eya': {'full': 'eya-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'eyo': {'full': 'eyo-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'eza': {'full': 'eza-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'eze': {'full': 'eze-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fa': {'full': 'fa-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': True},
        'fa-AF': {'full': 'fa-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': True},
        'faa': {'full': 'faa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fab': {'full': 'fab-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'fad': {'full': 'fad-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'faf': {'full': 'faf-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'fag': {'full': 'fag-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fah': {'full': 'fah-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fai': {'full': 'fai-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'faj': {'full': 'faj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fak': {'full': 'fak-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'fal': {'full': 'fal-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'fam': {'full': 'fam-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fan': {'full': 'fan-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'fap': {'full': 'fap-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'far': {'full': 'far-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'fau': {'full': 'fau-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'fax': {'full': 'fax-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'fay': {'full': 'fay-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'faz': {'full': 'faz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'fbl': {'full': 'fbl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'fcs': {'full': 'fcs-Zxxx-CA', 'region': 'CA', 'script': 'Zxxx', 'suppress': False},
        'fer': {'full': 'fer-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'ff': {'full': 'ff-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'ff-Adlm': {'full': 'ff-Adlm-GN', 'region': 'GN', 'script': 'Adlm', 'suppress': False},
        'ff-Arab': {'full': 'ff-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'ff-GH': {'full': 'ff-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ff-GM': {'full': 'ff-Latn-GM', 'region': 'GM', 'script': 'Latn', 'suppress': False},
        'ff-GN': {'full': 'ff-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'ff-LR': {'full': 'ff-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'ff-MR': {'full': 'ff-Latn-MR', 'region': 'MR', 'script': 'Latn', 'suppress': False},
        'ff-NG': {'full': 'ff-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ff-SL': {'full': 'ff-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'ffi': {'full': 'ffi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ffm': {'full': 'ffm-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'ffm-Arab': {'full': 'ffm-Arab-ML', 'region': 'ML', 'script': 'Arab', 'suppress': False},
        'fgr': {'full': 'fgr-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'fi': {'full': 'fi-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': True},
        'fi-Brai': {'full': 'fi-Brai-FI', 'region': 'FI', 'script': 'Brai', 'suppress': False},
        'fia': {'full': 'fia-Arab-SD', 'region': 'SD', 'script': 'Arab', 'suppress': False},
        'fia-Copt': {'full': 'fia-Copt-SD-x-olnubian', 'region': 'SD', 'script': 'Copt', 'suppress': False},
        'fia-Latn': {'full': 'fia-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'fie': {'full': 'fie-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fil': {'full': 'fil-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'fil-Tglg': {'full': 'fil-Tglg-PH', 'region': 'PH', 'script': 'Tglg', 'suppress': False},
        'fip': {'full': 'fip-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'fir': {'full': 'fir-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fit': {'full': 'fit-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'fiw': {'full': 'fiw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fj': {'full': 'fj-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': True},
        'fkk': {'full': 'fkk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fkv': {'full': 'fkv-Latn-NO', 'region': 'NO', 'script': 'Latn', 'suppress': False},
        'fla': {'full': 'fla-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'flh': {'full': 'flh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'fli': {'full': 'fli-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fll': {'full': 'fll-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'fln': {'full': 'fln-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'flr': {'full': 'flr-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'fly': {'full': 'fly-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'fmp': {'full': 'fmp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'fmu': {'full': 'fmu-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'fnb': {'full': 'fnb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'fng': {'full': 'fng-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'fni': {'full': 'fni-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'fo': {'full': 'fo-Latn-FO', 'region': 'FO', 'script': 'Latn', 'suppress': True},
        'fo-DK': {'full': 'fo-Latn-DK', 'region': 'DK', 'script': 'Latn', 'suppress': True},
        'fod': {'full': 'fod-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'foi': {'full': 'foi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fom': {'full': 'fom-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'fon': {'full': 'fon-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'for': {'full': 'for-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fos': {'full': 'fos-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'fpe': {'full': 'fpe-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'fqs': {'full': 'fqs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fr': {'full': 'fr-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': True},
        'fr-BE': {'full': 'fr-Latn-BE', 'region': 'BE', 'script': 'Latn', 'suppress': True},
        'fr-BI': {'full': 'fr-Latn-BI', 'region': 'BI', 'script': 'Latn', 'suppress': True},
        'fr-Brai': {'full': 'fr-Brai-FR', 'region': 'FR', 'script': 'Brai', 'suppress': False},
        'fr-CA': {'full': 'fr-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': True},
        'fr-CD': {'full': 'fr-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': True},
        'fr-CH': {'full': 'fr-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': True},
        'fr-CI': {'full': 'fr-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': True},
        'fr-CM': {'full': 'fr-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': True},
        'fr-DJ': {'full': 'fr-Latn-DJ', 'region': 'DJ', 'script': 'Latn', 'suppress': True},
        'fr-DZ': {'full': 'fr-Latn-DZ', 'region': 'DZ', 'script': 'Latn', 'suppress': True},
        'fr-Dupl': {'full': 'fr-Dupl-FR', 'region': 'FR', 'script': 'Dupl', 'suppress': False},
        'fr-GF': {'full': 'fr-Latn-GF', 'region': 'GF', 'script': 'Latn', 'suppress': True},
        'fr-GN': {'full': 'fr-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': True},
        'fr-HT': {'full': 'fr-Latn-HT', 'region': 'HT', 'script': 'Latn', 'suppress': True},
        'fr-KM': {'full': 'fr-Latn-KM', 'region': 'KM', 'script': 'Latn', 'suppress': True},
        'fr-LU': {'full': 'fr-Latn-LU', 'region': 'LU', 'script': 'Latn', 'suppress': True},
        'fr-MA': {'full': 'fr-Latn-MA', 'region': 'MA', 'script': 'Latn', 'suppress': True},
        'fr-MG': {'full': 'fr-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': True},
        'fr-ML': {'full': 'fr-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': True},
        'fr-MR': {'full': 'fr-Latn-MR', 'region': 'MR', 'script': 'Latn', 'suppress': True},
        'fr-MU': {'full': 'fr-Latn-MU', 'region': 'MU', 'script': 'Latn', 'suppress': True},
        'fr-RE': {'full': 'fr-Latn-RE', 'region': 'RE', 'script': 'Latn', 'suppress': True},
        'fr-RW': {'full': 'fr-Latn-RW', 'region': 'RW', 'script': 'Latn', 'suppress': True},
        'fr-SC': {'full': 'fr-Latn-SC', 'region': 'SC', 'script': 'Latn', 'suppress': True},
        'fr-SN': {'full': 'fr-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': True},
        'fr-SY': {'full': 'fr-Latn-SY', 'region': 'SY', 'script': 'Latn', 'suppress': True},
        'fr-TD': {'full': 'fr-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': True},
        'fr-TN': {'full': 'fr-Latn-TN', 'region': 'TN', 'script': 'Latn', 'suppress': True},
        'fr-VU': {'full': 'fr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': True},
        'frc': {'full': 'frc-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'frd': {'full': 'frd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'frk': {'full': 'frk-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'frm': {'full': 'frm-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'fro': {'full': 'fro-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'frp': {'full': 'frp-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'frq': {'full': 'frq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'frr': {'full': 'frr-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'frs': {'full': 'frs-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'frt': {'full': 'frt-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'fse': {'full': 'fse-Zxxx-FI', 'region': 'FI', 'script': 'Zxxx', 'suppress': False},
        'fsl': {'full': 'fsl-Zxxx-FR', 'region': 'FR', 'script': 'Zxxx', 'suppress': False},
        'fss': {'full': 'fss-Zxxx-FI', 'region': 'FI', 'script': 'Zxxx', 'suppress': False},
        'fub': {'full': 'fub-Arab-CM', 'region': 'CM', 'script': 'Arab', 'suppress': False},
        'fub-Latn': {'full': 'fub-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'fud': {'full': 'fud-Latn-WF', 'region': 'WF', 'script': 'Latn', 'suppress': False},
        'fue': {'full': 'fue-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'fuf': {'full': 'fuf-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'fuf-Adlm': {'full': 'fuf-Adlm-GN', 'region': 'GN', 'script': 'Adlm', 'suppress': False},
        'fuf-Arab': {'full': 'fuf-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'fuh-Arab': {'full': 'fuh-Arab-NE', 'region': 'NE', 'script': 'Arab', 'suppress': False},
        'fuh-BF': {'full': 'fuh-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'fuh-Latn': {'full': 'fuh-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'fui': {'full': 'fui-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'fuj': {'full': 'fuj-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'fum': {'full': 'fum-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fun': {'full': 'fun-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'fuq': {'full': 'fuq-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'fur': {'full': 'fur-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'fut': {'full': 'fut-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'fuu': {'full': 'fuu-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'fuv': {'full': 'fuv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'fuv-Arab': {'full': 'fuv-Arab-NG', 'region': 'NG', 'script': 'Arab', 'suppress': False},
        'fuy': {'full': 'fuy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'fvr': {'full': 'fvr-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'fwa': {'full': 'fwa-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'fwe': {'full': 'fwe-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'fy': {'full': 'fy-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': True},
        'ga': {'full': 'ga-Latn-IE', 'region': 'IE', 'script': 'Latn', 'suppress': True},
        'ga-Latg': {'full': 'ga-Latg-IE', 'region': 'IE', 'script': 'Latg', 'suppress': False},
        'ga-Ogam': {'full': 'ga-Ogam-IE', 'region': 'IE', 'script': 'Ogam', 'suppress': False},
        'gaa': {'full': 'gaa-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'gaa-Arab': {'full': 'gaa-Arab-GH', 'region': 'GH', 'script': 'Arab', 'suppress': False},
        'gab': {'full': 'gab-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'gac': {'full': 'gac-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'gad': {'full': 'gad-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'gae': {'full': 'gae-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'gaf': {'full': 'gaf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gag': {'full': 'gag-Latn-MD', 'region': 'MD', 'script': 'Latn', 'suppress': False},
        'gag-Cyrl': {'full': 'gag-Cyrl-MD', 'region': 'MD', 'script': 'Cyrl', 'suppress': False},
        'gag-Grek': {'full': 'gag-Grek-MD', 'region': 'MD', 'script': 'Grek', 'suppress': False},
        'gah': {'full': 'gah-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gai': {'full': 'gai-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gaj': {'full': 'gaj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gak': {'full': 'gak-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gal': {'full': 'gal-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'gam': {'full': 'gam-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gan': {'full': 'gan-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'gan-Hant': {'full': 'gan-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'gan-Latn': {'full': 'gan-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'gao': {'full': 'gao-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gap': {'full': 'gap-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gaq': {'full': 'gaq-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'gar': {'full': 'gar-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gas': {'full': 'gas-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'gat': {'full': 'gat-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gau': {'full': 'gau-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'gaw': {'full': 'gaw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gax': {'full': 'gax-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'gax-Ethi': {'full': 'gax-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gax-Ethi-x-borana': {'full': 'gax-Ethi-ET-x-borana', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gax-Ethi-x-guji': {'full': 'gax-Ethi-ET-x-guji', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gay': {'full': 'gay-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gba': {'full': 'gba-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gba-Arab': {'full': 'gba-Arab-CF', 'region': 'CF', 'script': 'Arab', 'suppress': False},
        'gbb': {'full': 'gbb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gbd': {'full': 'gbd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gbe': {'full': 'gbe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gbf': {'full': 'gbf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gbg': {'full': 'gbg-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gbh': {'full': 'gbh-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'gbi': {'full': 'gbi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gbj': {'full': 'gbj-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'gbk': {'full': 'gbk-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gbk-Takr': {'full': 'gbk-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'gbl': {'full': 'gbl-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'gbl-Deva': {'full': 'gbl-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gbm': {'full': 'gbm-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gbn': {'full': 'gbn-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'gbp': {'full': 'gbp-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gbq': {'full': 'gbq-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gbr': {'full': 'gbr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gbs': {'full': 'gbs-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'gbu': {'full': 'gbu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gbv': {'full': 'gbv-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gbw': {'full': 'gbw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gbx': {'full': 'gbx-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'gby': {'full': 'gby-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gbz': {'full': 'gbz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'gcc': {'full': 'gcc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gcd': {'full': 'gcd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gce': {'full': 'gce-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'gcf': {'full': 'gcf-Latn-GP', 'region': 'GP', 'script': 'Latn', 'suppress': False},
        'gcl': {'full': 'gcl-Latn-GD', 'region': 'GD', 'script': 'Latn', 'suppress': False},
        'gcn': {'full': 'gcn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gcr': {'full': 'gcr-Latn-GF', 'region': 'GF', 'script': 'Latn', 'suppress': False},
        'gct': {'full': 'gct-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'gd': {'full': 'gd-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'gda': {'full': 'gda-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'gdb': {'full': 'gdb-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'gdb-Telu': {'full': 'gdb-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'gdc': {'full': 'gdc-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gdd': {'full': 'gdd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gde': {'full': 'gde-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gdf': {'full': 'gdf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gdg': {'full': 'gdg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'gdh': {'full': 'gdh-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gdi': {'full': 'gdi-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gdj': {'full': 'gdj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gdk': {'full': 'gdk-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'gdl': {'full': 'gdl-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'gdl-Ethi': {'full': 'gdl-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gdm': {'full': 'gdm-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'gdn': {'full': 'gdn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gdo': {'full': 'gdo-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'gdq': {'full': 'gdq-Latn-YE', 'region': 'YE', 'script': 'Latn', 'suppress': False},
        'gdr': {'full': 'gdr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gds': {'full': 'gds-Zxxx-NP', 'region': 'NP', 'script': 'Zxxx', 'suppress': False},
        'gdt': {'full': 'gdt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gdu': {'full': 'gdu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gdx': {'full': 'gdx-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'gea': {'full': 'gea-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'geb': {'full': 'geb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gec': {'full': 'gec-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'ged': {'full': 'ged-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gef': {'full': 'gef-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'geg': {'full': 'geg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'geh': {'full': 'geh-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'gei': {'full': 'gei-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gej': {'full': 'gej-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'gek': {'full': 'gek-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gel': {'full': 'gel-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'geq': {'full': 'geq-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'ges': {'full': 'ges-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gev': {'full': 'gev-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'gew': {'full': 'gew-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gex': {'full': 'gex-Zyyy-SO', 'region': 'SO', 'script': 'Zyyy', 'suppress': False},
        'gey': {'full': 'gey-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'gez': {'full': 'gez-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gfk': {'full': 'gfk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gft': {'full': 'gft-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'gga': {'full': 'gga-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ggb': {'full': 'ggb-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'ggd': {'full': 'ggd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gge': {'full': 'gge-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ggg': {'full': 'ggg-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'ggk': {'full': 'ggk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ggl': {'full': 'ggl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ggt': {'full': 'ggt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ggu': {'full': 'ggu-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ggw': {'full': 'ggw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gha': {'full': 'gha-Zyyy-LY', 'region': 'LY', 'script': 'Zyyy', 'suppress': False},
        'ghc': {'full': 'ghc-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'ghe': {'full': 'ghe-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'ghh': {'full': 'ghh-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'ghk': {'full': 'ghk-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'ghl': {'full': 'ghl-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'ghn': {'full': 'ghn-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'gho': {'full': 'gho-Zyyy-MA', 'region': 'MA', 'script': 'Zyyy', 'suppress': False},
        'ghr': {'full': 'ghr-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'ghs': {'full': 'ghs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ght': {'full': 'ght-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'gia': {'full': 'gia-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gib': {'full': 'gib-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gic': {'full': 'gic-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'gid': {'full': 'gid-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gie': {'full': 'gie-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'gig': {'full': 'gig-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'gih': {'full': 'gih-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gil': {'full': 'gil-Latn-KI', 'region': 'KI', 'script': 'Latn', 'suppress': False},
        'gim': {'full': 'gim-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gin': {'full': 'gin-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'gip': {'full': 'gip-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'giq': {'full': 'giq-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'gir': {'full': 'gir-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'gis': {'full': 'gis-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'git': {'full': 'git-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'giu': {'full': 'giu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'giw': {'full': 'giw-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'gix': {'full': 'gix-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'giy': {'full': 'giy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'giz': {'full': 'giz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gji': {'full': 'gji-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gjk': {'full': 'gjk-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'gjk-Gujr': {'full': 'gjk-Gujr-PK', 'region': 'PK', 'script': 'Gujr', 'suppress': False},
        'gjm': {'full': 'gjm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gjn': {'full': 'gjn-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'gjn-Arab': {'full': 'gjn-Arab-GH', 'region': 'GH', 'script': 'Arab', 'suppress': False},
        'gjr': {'full': 'gjr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gju': {'full': 'gju-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'gju-Deva': {'full': 'gju-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gka': {'full': 'gka-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gkd': {'full': 'gkd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gke': {'full': 'gke-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gkn': {'full': 'gkn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gko': {'full': 'gko-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gkp': {'full': 'gkp-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'gku': {'full': 'gku-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'gl': {'full': 'gl-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': True},
        'glc': {'full': 'glc-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'gld': {'full': 'gld-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'glh': {'full': 'glh-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'glj': {'full': 'glj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'glk': {'full': 'glk-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'glk-Latn': {'full': 'glk-Latn-IR', 'region': 'IR', 'script': 'Latn', 'suppress': False},
        'gll': {'full': 'gll-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'glo': {'full': 'glo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'glr': {'full': 'glr-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'glu': {'full': 'glu-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'glw': {'full': 'glw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gly': {'full': 'gly-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'gma': {'full': 'gma-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gmb': {'full': 'gmb-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'gmd': {'full': 'gmd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gmg': {'full': 'gmg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gmh': {'full': 'gmh-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'gml': {'full': 'gml-Latf-DE', 'region': 'DE', 'script': 'Latf', 'suppress': False},
        'gmm': {'full': 'gmm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gmn': {'full': 'gmn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gmr': {'full': 'gmr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gmu': {'full': 'gmu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gmv': {'full': 'gmv-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gmv-Latn': {'full': 'gmv-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'gmx': {'full': 'gmx-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'gmy': {'full': 'gmy-Zyyy-GR', 'region': 'GR', 'script': 'Zyyy', 'suppress': False},
        'gmz': {'full': 'gmz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gn': {'full': 'gn-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': True},
        'gna': {'full': 'gna-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'gnb': {'full': 'gnb-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'gnc': {'full': 'gnc-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'gnd': {'full': 'gnd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gne': {'full': 'gne-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gng': {'full': 'gng-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'gnh': {'full': 'gnh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gni': {'full': 'gni-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gnj': {'full': 'gnj-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'gnk': {'full': 'gnk-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'gnl': {'full': 'gnl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gnm': {'full': 'gnm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gnn': {'full': 'gnn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gnq': {'full': 'gnq-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'gnr': {'full': 'gnr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gnt': {'full': 'gnt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gnu': {'full': 'gnu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gnw': {'full': 'gnw-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'gnz': {'full': 'gnz-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'goa': {'full': 'goa-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'gob': {'full': 'gob-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'goc': {'full': 'goc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'god': {'full': 'god-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'goe': {'full': 'goe-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'gof': {'full': 'gof-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gof-Latn': {'full': 'gof-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'gog': {'full': 'gog-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'goh': {'full': 'goh-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'goi': {'full': 'goi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'goj': {'full': 'goj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'gok': {'full': 'gok-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gol': {'full': 'gol-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'gom': {'full': 'gom-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gom-Knda': {'full': 'gom-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'gom-Latn': {'full': 'gom-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'gon': {'full': 'gon-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'gon-Deva': {'full': 'gon-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gon-Gonm': {'full': 'gon-Gonm-IN', 'region': 'IN', 'script': 'Gonm', 'suppress': False},
        'goo': {'full': 'goo-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'gop': {'full': 'gop-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'goq': {'full': 'goq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gor': {'full': 'gor-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'gos': {'full': 'gos-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'got': {'full': 'got-Goth-UA', 'region': 'UA', 'script': 'Goth', 'suppress': False},
        'gou': {'full': 'gou-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gow': {'full': 'gow-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'gox': {'full': 'gox-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'goy': {'full': 'goy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'goz': {'full': 'goz-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'gpa': {'full': 'gpa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gpe': {'full': 'gpe-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'gpn': {'full': 'gpn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gqa': {'full': 'gqa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gqi': {'full': 'gqi-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'gqn': {'full': 'gqn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'gqr': {'full': 'gqr-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'gqu': {'full': 'gqu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'gra-Deva': {'full': 'gra-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'gra-Gujr': {'full': 'gra-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'grb': {'full': 'grb-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'grc': {'full': 'grc-Cprt-CY', 'region': 'CY', 'script': 'Cprt', 'suppress': False},
        'grc-Grek': {'full': 'grc-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'grc-Linb': {'full': 'grc-Linb-GR', 'region': 'GR', 'script': 'Linb', 'suppress': False},
        'grd': {'full': 'grd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'grg': {'full': 'grg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'grh': {'full': 'grh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gri': {'full': 'gri-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'grj': {'full': 'grj-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'grm': {'full': 'grm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'gro': {'full': 'gro-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'grq': {'full': 'grq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'grr': {'full': 'grr-Zyyy-DZ', 'region': 'DZ', 'script': 'Zyyy', 'suppress': False},
        'grs': {'full': 'grs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'grt': {'full': 'grt-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'grt-Brai': {'full': 'grt-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'grt-Latn': {'full': 'grt-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'gru': {'full': 'gru-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gru-Latn': {'full': 'gru-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'grv': {'full': 'grv-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'grw': {'full': 'grw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'grx': {'full': 'grx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gry': {'full': 'gry-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'grz': {'full': 'grz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gse': {'full': 'gse-Zxxx-GH', 'region': 'GH', 'script': 'Zxxx', 'suppress': False},
        'gsg': {'full': 'gsg-Zxxx-DE', 'region': 'DE', 'script': 'Zxxx', 'suppress': False},
        'gsl': {'full': 'gsl-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'gsm': {'full': 'gsm-Zxxx-GT', 'region': 'GT', 'script': 'Zxxx', 'suppress': False},
        'gsn': {'full': 'gsn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gso': {'full': 'gso-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gsp': {'full': 'gsp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gss': {'full': 'gss-Zxxx-GR', 'region': 'GR', 'script': 'Zxxx', 'suppress': False},
        'gsw': {'full': 'gsw-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': True},
        'gta': {'full': 'gta-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'gtu': {'full': 'gtu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gu': {'full': 'gu-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': True},
        'gu-Brai': {'full': 'gu-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'gu-Khoj': {'full': 'gu-Khoj-IN', 'region': 'IN', 'script': 'Khoj', 'suppress': False},
        'gua': {'full': 'gua-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gub': {'full': 'gub-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'guc': {'full': 'guc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'gud': {'full': 'gud-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'gue': {'full': 'gue-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'guf': {'full': 'guf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'guh': {'full': 'guh-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'gui': {'full': 'gui-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'guk': {'full': 'guk-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'guk-Ethi': {'full': 'guk-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'gul': {'full': 'gul-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'gum': {'full': 'gum-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'gun': {'full': 'gun-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'guo': {'full': 'guo-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'gup': {'full': 'gup-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'guq': {'full': 'guq-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'gur': {'full': 'gur-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'gus': {'full': 'gus-Zxxx-GN', 'region': 'GN', 'script': 'Zxxx', 'suppress': False},
        'gut': {'full': 'gut-Latn-CR', 'region': 'CR', 'script': 'Latn', 'suppress': False},
        'guu': {'full': 'guu-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'guw': {'full': 'guw-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'gux': {'full': 'gux-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'guz': {'full': 'guz-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'gv': {'full': 'gv-Latn-IM', 'region': 'IM', 'script': 'Latn', 'suppress': True},
        'gva': {'full': 'gva-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'gvc': {'full': 'gvc-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'gve': {'full': 'gve-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gvf': {'full': 'gvf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gvj': {'full': 'gvj-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'gvl': {'full': 'gvl-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'gvm': {'full': 'gvm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gvn': {'full': 'gvn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gvo': {'full': 'gvo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'gvp': {'full': 'gvp-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'gvr': {'full': 'gvr-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'gvr-Latn': {'full': 'gvr-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'gvs': {'full': 'gvs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gvy': {'full': 'gvy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gwa': {'full': 'gwa-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'gwb': {'full': 'gwb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gwc': {'full': 'gwc-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'gwd': {'full': 'gwd-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'gwe': {'full': 'gwe-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'gwf': {'full': 'gwf-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'gwg': {'full': 'gwg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gwi': {'full': 'gwi-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'gwj': {'full': 'gwj-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'gwm': {'full': 'gwm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gwn': {'full': 'gwn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gwr': {'full': 'gwr-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'gwt': {'full': 'gwt-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'gwu': {'full': 'gwu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gww': {'full': 'gww-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gwx': {'full': 'gwx-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'gxx': {'full': 'gxx-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'gyb': {'full': 'gyb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'gyd': {'full': 'gyd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gye': {'full': 'gye-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'gyf': {'full': 'gyf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gyg': {'full': 'gyg-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'gyi': {'full': 'gyi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'gyl': {'full': 'gyl-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'gym': {'full': 'gym-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': False},
        'gyn': {'full': 'gyn-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'gyo': {'full': 'gyo-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'gyr': {'full': 'gyr-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'gyy': {'full': 'gyy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'gza': {'full': 'gza-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'gzi': {'full': 'gzi-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'gzn': {'full': 'gzn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ha': {'full': 'ha-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ha-Arab': {'full': 'ha-Arab-NG', 'region': 'NG', 'script': 'Arab', 'suppress': False},
        'ha-Brai': {'full': 'ha-Brai-NG', 'region': 'NG', 'script': 'Brai', 'suppress': False},
        'ha-CM': {'full': 'ha-Arab-CM', 'region': 'CM', 'script': 'Arab', 'suppress': False},
        'ha-GH': {'full': 'ha-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ha-NE': {'full': 'ha-Arab-NE', 'region': 'NE', 'script': 'Arab', 'suppress': False},
        'ha-SD': {'full': 'ha-Arab-SD', 'region': 'SD', 'script': 'Arab', 'suppress': False},
        'haa': {'full': 'haa-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'hab': {'full': 'hab-Zxxx-VN', 'region': 'VN', 'script': 'Zxxx', 'suppress': False},
        'hac': {'full': 'hac-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'had': {'full': 'had-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hae': {'full': 'hae-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'haf': {'full': 'haf-Zxxx-VN', 'region': 'VN', 'script': 'Zxxx', 'suppress': False},
        'hag': {'full': 'hag-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'hah': {'full': 'hah-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hai': {'full': 'hai-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'haj': {'full': 'haj-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'haj-Beng': {'full': 'haj-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'hak': {'full': 'hak-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'hak-Hant': {'full': 'hak-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'hak-Latn': {'full': 'hak-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'hal': {'full': 'hal-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'ham': {'full': 'ham-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'han': {'full': 'han-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'hao': {'full': 'hao-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hap': {'full': 'hap-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'haq': {'full': 'haq-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'har': {'full': 'har-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'har-Arab': {'full': 'har-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'har-Latn': {'full': 'har-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'has': {'full': 'has-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'hav': {'full': 'hav-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'haw': {'full': 'haw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'hax': {'full': 'hax-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'hay': {'full': 'hay-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'haz': {'full': 'haz-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'hba': {'full': 'hba-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'hbb': {'full': 'hbb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'hbn': {'full': 'hbn-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'hbo': {'full': 'hbo-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'hbu': {'full': 'hbu-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'hca': {'full': 'hca-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'hch': {'full': 'hch-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'hds': {'full': 'hds-Zxxx-HN', 'region': 'HN', 'script': 'Zxxx', 'suppress': False},
        'hdy': {'full': 'hdy-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'hdy-Latn': {'full': 'hdy-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'he': {'full': 'he-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': True},
        'he-Brai': {'full': 'he-Brai-IL', 'region': 'IL', 'script': 'Brai', 'suppress': False},
        'hed': {'full': 'hed-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'heg': {'full': 'heg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'heh': {'full': 'heh-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'hei': {'full': 'hei-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'hem': {'full': 'hem-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'hgm': {'full': 'hgm-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'hgw': {'full': 'hgw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hhi': {'full': 'hhi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hhr': {'full': 'hhr-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'hhy': {'full': 'hhy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hi': {'full': 'hi-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': True},
        'hi-Brai': {'full': 'hi-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'hi-Mahj': {'full': 'hi-Mahj-IN', 'region': 'IN', 'script': 'Mahj', 'suppress': False},
        'hi-Newa': {'full': 'hi-Newa-IN', 'region': 'IN', 'script': 'Newa', 'suppress': False},
        'hia': {'full': 'hia-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'hib': {'full': 'hib-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'hid': {'full': 'hid-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'hif': {'full': 'hif-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'hif-Deva': {'full': 'hif-Deva-FJ', 'region': 'FJ', 'script': 'Deva', 'suppress': False},
        'hig': {'full': 'hig-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'hih': {'full': 'hih-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hii': {'full': 'hii-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'hij': {'full': 'hij-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'hik': {'full': 'hik-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hil': {'full': 'hil-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'hil-Brai': {'full': 'hil-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'hio': {'full': 'hio-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'hir': {'full': 'hir-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'hit': {'full': 'hit-Xsux-TR', 'region': 'TR', 'script': 'Xsux', 'suppress': False},
        'hiw': {'full': 'hiw-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'hix': {'full': 'hix-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'hji': {'full': 'hji-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hka': {'full': 'hka-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'hke': {'full': 'hke-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'hkk': {'full': 'hkk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hkn': {'full': 'hkn-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'hks': {'full': 'hks-Zxxx-HK', 'region': 'HK', 'script': 'Zxxx', 'suppress': False},
        'hla': {'full': 'hla-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hlb': {'full': 'hlb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'hld': {'full': 'hld-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'hle': {'full': 'hle-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hlt': {'full': 'hlt-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'hlu': {'full': 'hlu-Hluw-TR', 'region': 'TR', 'script': 'Hluw', 'suppress': False},
        'hma': {'full': 'hma-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmb': {'full': 'hmb-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'hmc': {'full': 'hmc-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmd': {'full': 'hmd-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'hmd-Hmng': {'full': 'hmd-Hmng-CN', 'region': 'CN', 'script': 'Hmng', 'suppress': False},
        'hmd-Latn': {'full': 'hmd-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'hme': {'full': 'hme-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmf': {'full': 'hmf-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'hmg': {'full': 'hmg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmh': {'full': 'hmh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmi': {'full': 'hmi-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmj': {'full': 'hmj-Bopo-CN', 'region': 'CN', 'script': 'Bopo', 'suppress': False},
        'hmk': {'full': 'hmk-Zyyy-KR', 'region': 'KR', 'script': 'Zyyy', 'suppress': False},
        'hml': {'full': 'hml-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmm': {'full': 'hmm-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmn': {'full': 'hmn-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'hmn-Bopo': {'full': 'hmn-Bopo-CN', 'region': 'CN', 'script': 'Bopo', 'suppress': False},
        'hmn-Hmng': {'full': 'hmn-Hmng-CN', 'region': 'CN', 'script': 'Hmng', 'suppress': False},
        'hmp': {'full': 'hmp-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmq': {'full': 'hmq-Bopo-CN', 'region': 'CN', 'script': 'Bopo', 'suppress': False},
        'hmr': {'full': 'hmr-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'hms': {'full': 'hms-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'hmt': {'full': 'hmt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hmu': {'full': 'hmu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hmv': {'full': 'hmv-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'hmw': {'full': 'hmw-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmy': {'full': 'hmy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hmz-Latn': {'full': 'hmz-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'hmz-Plrd': {'full': 'hmz-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'hna': {'full': 'hna-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'hnd': {'full': 'hnd-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'hne': {'full': 'hne-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'hng': {'full': 'hng-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'hnh': {'full': 'hnh-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'hni': {'full': 'hni-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'hnj': {'full': 'hnj-Hmng-LA', 'region': 'LA', 'script': 'Hmng', 'suppress': False},
        'hnj-Laoo': {'full': 'hnj-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'hnj-Latn': {'full': 'hnj-Latn-LA', 'region': 'LA', 'script': 'Latn', 'suppress': False},
        'hnj-Plrd': {'full': 'hnj-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'hnj-Thai': {'full': 'hnj-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'hnn': {'full': 'hnn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'hnn-Hano': {'full': 'hnn-Hano-PH', 'region': 'PH', 'script': 'Hano', 'suppress': False},
        'hno': {'full': 'hno-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'hns': {'full': 'hns-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'hnu': {'full': 'hnu-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'ho': {'full': 'ho-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ho-Brai': {'full': 'ho-Brai-PG', 'region': 'PG', 'script': 'Brai', 'suppress': False},
        'hoa': {'full': 'hoa-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'hob': {'full': 'hob-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hoc': {'full': 'hoc-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'hoc-Latn': {'full': 'hoc-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'hoc-Orya': {'full': 'hoc-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'hoc-Telu': {'full': 'hoc-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'hoc-Wara': {'full': 'hoc-Wara-IN', 'region': 'IN', 'script': 'Wara', 'suppress': False},
        'hod': {'full': 'hod-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'hoe': {'full': 'hoe-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'hoh': {'full': 'hoh-Zyyy-OM', 'region': 'OM', 'script': 'Zyyy', 'suppress': False},
        'hoi': {'full': 'hoi-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'hoj': {'full': 'hoj-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'hol': {'full': 'hol-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'hom': {'full': 'hom-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'hoo': {'full': 'hoo-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'hop': {'full': 'hop-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'hor': {'full': 'hor-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'hos': {'full': 'hos-Zxxx-VN', 'region': 'VN', 'script': 'Zxxx', 'suppress': False},
        'hot': {'full': 'hot-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hov': {'full': 'hov-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'how': {'full': 'how-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'hoy': {'full': 'hoy-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'hoz': {'full': 'hoz-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'hpo': {'full': 'hpo-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'hps': {'full': 'hps-Zxxx-US', 'region': 'US', 'script': 'Zxxx', 'suppress': False},
        'hr': {'full': 'hr-Latn-HR', 'region': 'HR', 'script': 'Latn', 'suppress': True},
        'hr-BA': {'full': 'hr-Latn-BA', 'region': 'BA', 'script': 'Latn', 'suppress': True},
        'hr-Brai': {'full': 'hr-Brai-HR', 'region': 'HR', 'script': 'Brai', 'suppress': False},
        'hra': {'full': 'hra-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'hrc': {'full': 'hrc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hre': {'full': 'hre-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'hre-x-1960': {'full': 'hre-Latn-VN-x-1960', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'hrk': {'full': 'hrk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hrm': {'full': 'hrm-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hro': {'full': 'hro-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'hrp': {'full': 'hrp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'hrt': {'full': 'hrt-Syrc-TR', 'region': 'TR', 'script': 'Syrc', 'suppress': False},
        'hru': {'full': 'hru-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'hrw': {'full': 'hrw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hrx': {'full': 'hrx-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'hrz': {'full': 'hrz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'hsb': {'full': 'hsb-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'hsh': {'full': 'hsh-Zxxx-HU', 'region': 'HU', 'script': 'Zxxx', 'suppress': False},
        'hsl': {'full': 'hsl-Zxxx-NG', 'region': 'NG', 'script': 'Zxxx', 'suppress': False},
        'hsn': {'full': 'hsn-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'hsn-Hant': {'full': 'hsn-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'hsn-Nshu': {'full': 'hsn-Nshu-CN', 'region': 'CN', 'script': 'Nshu', 'suppress': False},
        'hss': {'full': 'hss-Zyyy-OM', 'region': 'OM', 'script': 'Zyyy', 'suppress': False},
        'ht': {'full': 'ht-Latn-HT', 'region': 'HT', 'script': 'Latn', 'suppress': True},
        'hti': {'full': 'hti-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hto': {'full': 'hto-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'hts': {'full': 'hts-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'htu': {'full': 'htu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'htx': {'full': 'htx-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'hu': {'full': 'hu-Latn-HU', 'region': 'HU', 'script': 'Latn', 'suppress': True},
        'hu-Brai': {'full': 'hu-Brai-HU', 'region': 'HU', 'script': 'Brai', 'suppress': False},
        'hub': {'full': 'hub-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'huc': {'full': 'huc-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'hud': {'full': 'hud-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hue': {'full': 'hue-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'huf': {'full': 'huf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hug': {'full': 'hug-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'huh': {'full': 'huh-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': False},
        'hui': {'full': 'hui-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'huj': {'full': 'huj-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'huk': {'full': 'huk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hul': {'full': 'hul-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'hum': {'full': 'hum-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'huo': {'full': 'huo-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hup': {'full': 'hup-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'huq': {'full': 'huq-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'hur': {'full': 'hur-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'hus': {'full': 'hus-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'hut': {'full': 'hut-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'huu': {'full': 'huu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'huv': {'full': 'huv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'huw': {'full': 'huw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hux': {'full': 'hux-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'huy': {'full': 'huy-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'huz': {'full': 'huz-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'hvc': {'full': 'hvc-Latn-HT', 'region': 'HT', 'script': 'Latn', 'suppress': False},
        'hve': {'full': 'hve-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'hvk': {'full': 'hvk-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'hvn': {'full': 'hvn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'hvv': {'full': 'hvv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'hwa': {'full': 'hwa-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'hwc': {'full': 'hwc-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'hwo': {'full': 'hwo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'hy': {'full': 'hy-Armn-AM', 'region': 'AM', 'script': 'Armn', 'suppress': True},
        'hy-Brai': {'full': 'hy-Brai-AM', 'region': 'AM', 'script': 'Brai', 'suppress': False},
        'hya': {'full': 'hya-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'hyw': {'full': 'hyw-Armn-AM', 'region': 'AM', 'script': 'Armn', 'suppress': False},
        'hz': {'full': 'hz-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'ia': {'full': 'ia-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'iai': {'full': 'iai-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ian': {'full': 'ian-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'iap': {'full': 'iap-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'iar': {'full': 'iar-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'iba': {'full': 'iba-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'ibb': {'full': 'ibb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ibd': {'full': 'ibd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ibe': {'full': 'ibe-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ibg': {'full': 'ibg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ibh': {'full': 'ibh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'ibl': {'full': 'ibl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ibm': {'full': 'ibm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ibn': {'full': 'ibn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ibr': {'full': 'ibr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ibu': {'full': 'ibu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'iby': {'full': 'iby-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ica': {'full': 'ica-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'ich': {'full': 'ich-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'icl': {'full': 'icl-Zxxx-IS', 'region': 'IS', 'script': 'Zxxx', 'suppress': False},
        'icr': {'full': 'icr-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'id': {'full': 'id-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': True},
        'id-Arab': {'full': 'id-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'id-Brai': {'full': 'id-Brai-ID', 'region': 'ID', 'script': 'Brai', 'suppress': False},
        'ida': {'full': 'ida-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'idb': {'full': 'idb-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'idc': {'full': 'idc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'idd': {'full': 'idd-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'ide': {'full': 'ide-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'idi': {'full': 'idi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'idr': {'full': 'idr-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'ids': {'full': 'ids-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'idt': {'full': 'idt-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'idu': {'full': 'idu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ie': {'full': 'ie-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'ifa': {'full': 'ifa-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ifb': {'full': 'ifb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ife': {'full': 'ife-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'ife-BJ': {'full': 'ife-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'iff': {'full': 'iff-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ifk': {'full': 'ifk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ifm': {'full': 'ifm-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'ifu': {'full': 'ifu-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ify': {'full': 'ify-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ig': {'full': 'ig-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'igb': {'full': 'igb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ige': {'full': 'ige-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'igg': {'full': 'igg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'igl': {'full': 'igl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'igm': {'full': 'igm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ign': {'full': 'ign-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'igo': {'full': 'igo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'igs': {'full': 'igs-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'igw': {'full': 'igw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ihb': {'full': 'ihb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ihi': {'full': 'ihi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ihp': {'full': 'ihp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ihw': {'full': 'ihw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ii': {'full': 'ii-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'ii-Latn': {'full': 'ii-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'iin': {'full': 'iin-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ijc': {'full': 'ijc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ije': {'full': 'ije-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ijj': {'full': 'ijj-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'ijn': {'full': 'ijn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ijs': {'full': 'ijs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ik': {'full': 'ik-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ike-Latn': {'full': 'ike-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'iki': {'full': 'iki-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ikk': {'full': 'ikk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ikl': {'full': 'ikl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'iko': {'full': 'iko-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ikp': {'full': 'ikp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ikr': {'full': 'ikr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'iks': {'full': 'iks-Zxxx-CA', 'region': 'CA', 'script': 'Zxxx', 'suppress': False},
        'ikt': {'full': 'ikt-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ikt-Cans': {'full': 'ikt-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'ikv': {'full': 'ikv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ikw': {'full': 'ikw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ikx': {'full': 'ikx-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'ikz': {'full': 'ikz-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ila': {'full': 'ila-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ilb': {'full': 'ilb-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'ilg': {'full': 'ilg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ili': {'full': 'ili-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ilk': {'full': 'ilk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ilm': {'full': 'ilm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'ilo': {'full': 'ilo-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ilo-Brai': {'full': 'ilo-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'ilo-Tglg': {'full': 'ilo-Tglg-PH', 'region': 'PH', 'script': 'Tglg', 'suppress': False},
        'ilp': {'full': 'ilp-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ils': {'full': 'ils-Zxxx-IT', 'region': 'IT', 'script': 'Zxxx', 'suppress': False},
        'ilu': {'full': 'ilu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ilv': {'full': 'ilv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ima': {'full': 'ima-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'imi': {'full': 'imi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'iml': {'full': 'iml-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'imn': {'full': 'imn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'imo': {'full': 'imo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'imr': {'full': 'imr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ims': {'full': 'ims-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'imy': {'full': 'imy-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'inb': {'full': 'inb-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ing': {'full': 'ing-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'inh': {'full': 'inh-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'inh-Arab': {'full': 'inh-Arab-RU', 'region': 'RU', 'script': 'Arab', 'suppress': False},
        'inh-Latn': {'full': 'inh-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'inj': {'full': 'inj-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'inl': {'full': 'inl-Zxxx-ID', 'region': 'ID', 'script': 'Zxxx', 'suppress': False},
        'inm': {'full': 'inm-Zyyy-YE', 'region': 'YE', 'script': 'Zyyy', 'suppress': False},
        'inn': {'full': 'inn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ino': {'full': 'ino-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'inp': {'full': 'inp-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ins': {'full': 'ins-Zxxx-IN', 'region': 'IN', 'script': 'Zxxx', 'suppress': False},
        'int': {'full': 'int-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'inz': {'full': 'inz-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'io': {'full': 'io-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'ior': {'full': 'ior-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'iou': {'full': 'iou-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'iow': {'full': 'iow-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ipi': {'full': 'ipi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ipo': {'full': 'ipo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'iqu': {'full': 'iqu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'iqw': {'full': 'iqw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ire': {'full': 'ire-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'irh': {'full': 'irh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'iri': {'full': 'iri-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'irk': {'full': 'irk-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'irn': {'full': 'irn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'irr': {'full': 'irr-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'iru': {'full': 'iru-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'iru-Mlym': {'full': 'iru-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'irx': {'full': 'irx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'iry': {'full': 'iry-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'is': {'full': 'is-Latn-IS', 'region': 'IS', 'script': 'Latn', 'suppress': True},
        'isa': {'full': 'isa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'isc': {'full': 'isc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'isd': {'full': 'isd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ise': {'full': 'ise-Zxxx-IT', 'region': 'IT', 'script': 'Zxxx', 'suppress': False},
        'isg': {'full': 'isg-Zxxx-IE', 'region': 'IE', 'script': 'Zxxx', 'suppress': False},
        'ish': {'full': 'ish-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'isi': {'full': 'isi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'isk': {'full': 'isk-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'ism': {'full': 'ism-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'isn': {'full': 'isn-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'iso': {'full': 'iso-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'isr': {'full': 'isr-Zxxx-IL', 'region': 'IL', 'script': 'Zxxx', 'suppress': False},
        'ist': {'full': 'ist-Latn-HR', 'region': 'HR', 'script': 'Latn', 'suppress': False},
        'isu': {'full': 'isu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'it': {'full': 'it-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': True},
        'it-Brai': {'full': 'it-Brai-IT', 'region': 'IT', 'script': 'Brai', 'suppress': False},
        'it-CH': {'full': 'it-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': True},
        'itb': {'full': 'itb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'itd': {'full': 'itd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ite': {'full': 'ite-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'iti': {'full': 'iti-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'itk': {'full': 'itk-Hebr-IT', 'region': 'IT', 'script': 'Hebr', 'suppress': False},
        'itl': {'full': 'itl-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'itm': {'full': 'itm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ito': {'full': 'ito-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'itr': {'full': 'itr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'its': {'full': 'its-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'itt': {'full': 'itt-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'itv': {'full': 'itv-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'itw': {'full': 'itw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'itx': {'full': 'itx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ity': {'full': 'ity-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'itz': {'full': 'itz-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'iu': {'full': 'iu-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'iu-Latn': {'full': 'iu-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ium': {'full': 'ium-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'ium-Hani': {'full': 'ium-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'ium-Laoo': {'full': 'ium-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'ium-Thai': {'full': 'ium-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'ium-x-1954': {'full': 'ium-Latn-CN-x-1954', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'ivb': {'full': 'ivb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ivv': {'full': 'ivv-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'iwk': {'full': 'iwk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'iwm': {'full': 'iwm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'iwo': {'full': 'iwo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'iws': {'full': 'iws-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ixc': {'full': 'ixc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ixl': {'full': 'ixl-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'iya': {'full': 'iya-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'iyo': {'full': 'iyo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'iyx': {'full': 'iyx-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'izh': {'full': 'izh-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'izr': {'full': 'izr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'izz': {'full': 'izz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ja': {'full': 'ja-Jpan-JP', 'region': 'JP', 'script': 'Jpan', 'suppress': True},
        'ja-Brai': {'full': 'ja-Brai-JP', 'region': 'JP', 'script': 'Brai', 'suppress': False},
        'ja-Latn': {'full': 'ja-Latn-JP', 'region': 'JP', 'script': 'Latn', 'suppress': False},
        'jaa': {'full': 'jaa-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'jab': {'full': 'jab-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jac': {'full': 'jac-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'jad': {'full': 'jad-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'jae': {'full': 'jae-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jaf': {'full': 'jaf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jah': {'full': 'jah-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'jaj': {'full': 'jaj-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'jak': {'full': 'jak-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'jal': {'full': 'jal-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jam': {'full': 'jam-Latn-JM', 'region': 'JM', 'script': 'Latn', 'suppress': False},
        'jan': {'full': 'jan-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jao': {'full': 'jao-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jaq': {'full': 'jaq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jas': {'full': 'jas-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'jat': {'full': 'jat-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'jau': {'full': 'jau-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jax': {'full': 'jax-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jay': {'full': 'jay-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jaz': {'full': 'jaz-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'jbe': {'full': 'jbe-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'jbi': {'full': 'jbi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jbj': {'full': 'jbj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jbk': {'full': 'jbk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jbn': {'full': 'jbn-Arab-LY', 'region': 'LY', 'script': 'Arab', 'suppress': False},
        'jbo': {'full': 'jbo-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'jbr': {'full': 'jbr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jbt': {'full': 'jbt-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'jbu': {'full': 'jbu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'jbw': {'full': 'jbw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jcs': {'full': 'jcs-Zxxx-JM', 'region': 'JM', 'script': 'Zxxx', 'suppress': False},
        'jct': {'full': 'jct-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': False},
        'jct-Latn': {'full': 'jct-Latn-UA', 'region': 'UA', 'script': 'Latn', 'suppress': False},
        'jda': {'full': 'jda-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'jdg': {'full': 'jdg-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'jdt': {'full': 'jdt-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'jdt-Hebr': {'full': 'jdt-Hebr-RU', 'region': 'RU', 'script': 'Hebr', 'suppress': False},
        'jdt-Latn': {'full': 'jdt-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'jeb': {'full': 'jeb-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'jee': {'full': 'jee-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'jeh': {'full': 'jeh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'jeh-Laoo': {'full': 'jeh-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'jei': {'full': 'jei-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jek': {'full': 'jek-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'jel': {'full': 'jel-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jen': {'full': 'jen-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jer': {'full': 'jer-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jet': {'full': 'jet-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jeu': {'full': 'jeu-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'jgb': {'full': 'jgb-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'jge': {'full': 'jge-Zyyy-IL', 'region': 'IL', 'script': 'Zyyy', 'suppress': False},
        'jgk': {'full': 'jgk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jgo': {'full': 'jgo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'jhi': {'full': 'jhi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'jhs': {'full': 'jhs-Zxxx-NP', 'region': 'NP', 'script': 'Zxxx', 'suppress': False},
        'jia': {'full': 'jia-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'jib': {'full': 'jib-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jic': {'full': 'jic-Latn-HN', 'region': 'HN', 'script': 'Latn', 'suppress': False},
        'jid': {'full': 'jid-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jie': {'full': 'jie-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jig': {'full': 'jig-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jih': {'full': 'jih-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'jii': {'full': 'jii-Zyyy-SO', 'region': 'SO', 'script': 'Zyyy', 'suppress': False},
        'jil': {'full': 'jil-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jim': {'full': 'jim-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'jio': {'full': 'jio-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'jiq': {'full': 'jiq-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'jit': {'full': 'jit-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'jiu': {'full': 'jiu-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'jiv': {'full': 'jiv-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'jiy': {'full': 'jiy-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'jje': {'full': 'jje-Hang-KR', 'region': 'KR', 'script': 'Hang', 'suppress': False},
        'jjr': {'full': 'jjr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jka': {'full': 'jka-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jkm': {'full': 'jkm-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'jko': {'full': 'jko-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jkp': {'full': 'jkp-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'jkr': {'full': 'jkr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'jku': {'full': 'jku-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jle': {'full': 'jle-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'jls': {'full': 'jls-Zxxx-JM', 'region': 'JM', 'script': 'Zxxx', 'suppress': False},
        'jma': {'full': 'jma-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jmb': {'full': 'jmb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jmc': {'full': 'jmc-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'jmd': {'full': 'jmd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jmi': {'full': 'jmi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jml': {'full': 'jml-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'jmn': {'full': 'jmn-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'jmr': {'full': 'jmr-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'jms': {'full': 'jms-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jmw': {'full': 'jmw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'jmx': {'full': 'jmx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'jna': {'full': 'jna-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'jnd': {'full': 'jnd-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'jng': {'full': 'jng-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'jni': {'full': 'jni-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jnj': {'full': 'jnj-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'jnl': {'full': 'jnl-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'jns': {'full': 'jns-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'jns-Latn': {'full': 'jns-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'jns-Takr': {'full': 'jns-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'job': {'full': 'job-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'jod': {'full': 'jod-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'jog': {'full': 'jog-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'jor': {'full': 'jor-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'jos': {'full': 'jos-Zxxx-JO', 'region': 'JO', 'script': 'Zxxx', 'suppress': False},
        'jow': {'full': 'jow-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'jpa': {'full': 'jpa-Zyyy-PS', 'region': 'PS', 'script': 'Zyyy', 'suppress': False},
        'jpr': {'full': 'jpr-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'jqr': {'full': 'jqr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'jra': {'full': 'jra-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'jra-Khmr': {'full': 'jra-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'jrb': {'full': 'jrb-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'jrr': {'full': 'jrr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jrt': {'full': 'jrt-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jru': {'full': 'jru-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'jsl': {'full': 'jsl-Zxxx-JP', 'region': 'JP', 'script': 'Zxxx', 'suppress': False},
        'jua': {'full': 'jua-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'jub': {'full': 'jub-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'juc': {'full': 'juc-Jurc-CN', 'region': 'CN', 'script': 'Jurc', 'suppress': False},
        'jud': {'full': 'jud-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'juh': {'full': 'juh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jui': {'full': 'jui-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'juk': {'full': 'juk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jul': {'full': 'jul-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'jum': {'full': 'jum-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'jun': {'full': 'jun-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'juo': {'full': 'juo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'jup': {'full': 'jup-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'jur': {'full': 'jur-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'jus': {'full': 'jus-Zxxx-NP', 'region': 'NP', 'script': 'Zxxx', 'suppress': False},
        'jut': {'full': 'jut-Latn-DK', 'region': 'DK', 'script': 'Latn', 'suppress': False},
        'juu': {'full': 'juu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'juw': {'full': 'juw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'juy': {'full': 'juy-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'jv': {'full': 'jv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jv-Java': {'full': 'jv-Java-ID', 'region': 'ID', 'script': 'Java', 'suppress': False},
        'jvd': {'full': 'jvd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'jvn': {'full': 'jvn-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'jwi': {'full': 'jwi-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'jya': {'full': 'jya-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'jye': {'full': 'jye-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'jyy': {'full': 'jyy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'ka': {'full': 'ka-Geor-GE', 'region': 'GE', 'script': 'Geor', 'suppress': True},
        'ka-Brai': {'full': 'ka-Brai-GE', 'region': 'GE', 'script': 'Brai', 'suppress': False},
        'ka-Geok': {'full': 'ka-Geok-GE', 'region': 'GE', 'script': 'Geok', 'suppress': False},
        'kaa': {'full': 'kaa-Cyrl-UZ', 'region': 'UZ', 'script': 'Cyrl', 'suppress': False},
        'kaa-Arab': {'full': 'kaa-Arab-UZ', 'region': 'UZ', 'script': 'Arab', 'suppress': False},
        'kaa-Latn': {'full': 'kaa-Latn-UZ', 'region': 'UZ', 'script': 'Latn', 'suppress': False},
        'kab': {'full': 'kab-Latn-DZ', 'region': 'DZ', 'script': 'Latn', 'suppress': False},
        'kab-Arab': {'full': 'kab-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': False},
        'kab-Tfng': {'full': 'kab-Tfng-DZ', 'region': 'DZ', 'script': 'Tfng', 'suppress': False},
        'kac': {'full': 'kac-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'kad': {'full': 'kad-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kae': {'full': 'kae-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'kaf': {'full': 'kaf-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'kag': {'full': 'kag-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kah': {'full': 'kah-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'kai': {'full': 'kai-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kaj': {'full': 'kaj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kak': {'full': 'kak-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kam': {'full': 'kam-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'kao': {'full': 'kao-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'kap': {'full': 'kap-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kaq': {'full': 'kaq-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'kav': {'full': 'kav-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kaw': {'full': 'kaw-Bali-MY', 'region': 'MY', 'script': 'Bali', 'suppress': False},
        'kax': {'full': 'kax-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kay': {'full': 'kay-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kba': {'full': 'kba-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kbb': {'full': 'kbb-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kbc': {'full': 'kbc-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kbd': {'full': 'kbd-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kbe': {'full': 'kbe-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kbg-Tibt': {'full': 'kbg-Tibt-IN-x-hingna', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'kbh': {'full': 'kbh-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'kbi': {'full': 'kbi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kbj': {'full': 'kbj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kbk': {'full': 'kbk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kbl': {'full': 'kbl-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kbm': {'full': 'kbm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kbn': {'full': 'kbn-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'kbo': {'full': 'kbo-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'kbp': {'full': 'kbp-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'kbp-Brai': {'full': 'kbp-Brai-TG', 'region': 'TG', 'script': 'Brai', 'suppress': False},
        'kbq': {'full': 'kbq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kbr': {'full': 'kbr-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'kbr-Ethi': {'full': 'kbr-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'kbs': {'full': 'kbs-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'kbt': {'full': 'kbt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kbu': {'full': 'kbu-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'kbv': {'full': 'kbv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kbw': {'full': 'kbw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kbx': {'full': 'kbx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kby': {'full': 'kby-Arab-NE', 'region': 'NE', 'script': 'Arab', 'suppress': False},
        'kby-Latn': {'full': 'kby-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'kbz': {'full': 'kbz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kca': {'full': 'kca-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kcb': {'full': 'kcb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kcc': {'full': 'kcc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kcd': {'full': 'kcd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kce': {'full': 'kce-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kcf': {'full': 'kcf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kcg': {'full': 'kcg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kch': {'full': 'kch-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kci': {'full': 'kci-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kcj': {'full': 'kcj-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'kck': {'full': 'kck-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': False},
        'kcl': {'full': 'kcl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kcm': {'full': 'kcm-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'kcn': {'full': 'kcn-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'kco': {'full': 'kco-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kcp': {'full': 'kcp-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'kcq': {'full': 'kcq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kcr': {'full': 'kcr-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'kcs': {'full': 'kcs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kct': {'full': 'kct-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kcu': {'full': 'kcu-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kcv': {'full': 'kcv-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kcw': {'full': 'kcw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kcx': {'full': 'kcx-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'kcy': {'full': 'kcy-Zyyy-DZ', 'region': 'DZ', 'script': 'Zyyy', 'suppress': False},
        'kcz': {'full': 'kcz-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kda': {'full': 'kda-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kdc': {'full': 'kdc-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kdd': {'full': 'kdd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kde': {'full': 'kde-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kdf': {'full': 'kdf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kdg': {'full': 'kdg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kdh': {'full': 'kdh-Arab-TG', 'region': 'TG', 'script': 'Arab', 'suppress': False},
        'kdh-Latn': {'full': 'kdh-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'kdi': {'full': 'kdi-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'kdj': {'full': 'kdj-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'kdk': {'full': 'kdk-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'kdl': {'full': 'kdl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kdm': {'full': 'kdm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kdn': {'full': 'kdn-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': False},
        'kdp': {'full': 'kdp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kdq': {'full': 'kdq-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'kdr': {'full': 'kdr-Latn-LT', 'region': 'LT', 'script': 'Latn', 'suppress': False},
        'kdr-Cyrl': {'full': 'kdr-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': False},
        'kdt': {'full': 'kdt-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'kdt-Khmr': {'full': 'kdt-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'kdt-Laoo': {'full': 'kdt-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'kdu': {'full': 'kdu-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'kdw': {'full': 'kdw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kdx': {'full': 'kdx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kdy': {'full': 'kdy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kdz': {'full': 'kdz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kea': {'full': 'kea-Latn-CV', 'region': 'CV', 'script': 'Latn', 'suppress': False},
        'keb': {'full': 'keb-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'kec': {'full': 'kec-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ked': {'full': 'ked-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kee': {'full': 'kee-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kef': {'full': 'kef-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'keg': {'full': 'keg-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'keh': {'full': 'keh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kei': {'full': 'kei-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kej': {'full': 'kej-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kek': {'full': 'kek-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'kel': {'full': 'kel-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kem': {'full': 'kem-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'ken': {'full': 'ken-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'keo': {'full': 'keo-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'kep': {'full': 'kep-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'keq': {'full': 'keq-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ker': {'full': 'ker-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kes': {'full': 'kes-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ket': {'full': 'ket-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'keu': {'full': 'keu-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'kev': {'full': 'kev-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kew': {'full': 'kew-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kex': {'full': 'kex-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kex-Gujr': {'full': 'kex-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'key': {'full': 'key-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'kez': {'full': 'kez-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kfa': {'full': 'kfa-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'kfb': {'full': 'kfb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfc': {'full': 'kfc-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'kfd': {'full': 'kfd-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kfe': {'full': 'kfe-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'kff-Deva': {'full': 'kff-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kff-Latn': {'full': 'kff-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kff-Orya': {'full': 'kff-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'kff-Telu': {'full': 'kff-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'kfg-Knda': {'full': 'kfg-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'kfg-Mlym': {'full': 'kfg-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'kfh': {'full': 'kfh-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'kfi': {'full': 'kfi-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'kfi-Knda': {'full': 'kfi-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'kfj': {'full': 'kfj-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'kfk': {'full': 'kfk-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfk-Takr': {'full': 'kfk-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'kfl': {'full': 'kfl-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kfm': {'full': 'kfm-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'kfn': {'full': 'kfn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kfo': {'full': 'kfo-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kfp': {'full': 'kfp-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfq': {'full': 'kfq-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfr': {'full': 'kfr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfr-Gujr': {'full': 'kfr-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'kfs': {'full': 'kfs-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kft': {'full': 'kft-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kfu': {'full': 'kfu-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kfv': {'full': 'kfv-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kfw': {'full': 'kfw-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kfx': {'full': 'kfx-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfx-Takr': {'full': 'kfx-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'kfy': {'full': 'kfy-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kfz': {'full': 'kfz-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'kg': {'full': 'kg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kga': {'full': 'kga-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kgb': {'full': 'kgb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kge': {'full': 'kge-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kgf': {'full': 'kgf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kgg': {'full': 'kgg-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'kgi': {'full': 'kgi-Zxxx-MY', 'region': 'MY', 'script': 'Zxxx', 'suppress': False},
        'kgj': {'full': 'kgj-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'kgk': {'full': 'kgk-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kgl': {'full': 'kgl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kgm': {'full': 'kgm-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kgn': {'full': 'kgn-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'kgo': {'full': 'kgo-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'kgp': {'full': 'kgp-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kgq': {'full': 'kgq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kgr': {'full': 'kgr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kgs': {'full': 'kgs-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kgt': {'full': 'kgt-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kgu': {'full': 'kgu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kgv': {'full': 'kgv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kgw': {'full': 'kgw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kgx': {'full': 'kgx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kgy': {'full': 'kgy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'kha': {'full': 'kha-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kha-Beng': {'full': 'kha-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'khb': {'full': 'khb-Talu-CN', 'region': 'CN', 'script': 'Talu', 'suppress': False},
        'khb-Lana': {'full': 'khb-Lana-CN', 'region': 'CN', 'script': 'Lana', 'suppress': False},
        'khc': {'full': 'khc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'khd': {'full': 'khd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'khe': {'full': 'khe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'khf': {'full': 'khf-Thai-LA', 'region': 'LA', 'script': 'Thai', 'suppress': False},
        'khg': {'full': 'khg-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'khh': {'full': 'khh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'khj': {'full': 'khj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'khl': {'full': 'khl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'khn': {'full': 'khn-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kho': {'full': 'kho-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'khp': {'full': 'khp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'khq': {'full': 'khq-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'khr': {'full': 'khr-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'khr-Deva': {'full': 'khr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'khs': {'full': 'khs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kht': {'full': 'kht-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'khu': {'full': 'khu-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'khv': {'full': 'khv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'khw': {'full': 'khw-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'khx': {'full': 'khx-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'khy': {'full': 'khy-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'khz': {'full': 'khz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ki': {'full': 'ki-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'kia': {'full': 'kia-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kib': {'full': 'kib-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'kic': {'full': 'kic-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kid': {'full': 'kid-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kie': {'full': 'kie-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kif': {'full': 'kif-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'kig': {'full': 'kig-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kih': {'full': 'kih-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kii': {'full': 'kii-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'kij': {'full': 'kij-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kil': {'full': 'kil-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kim': {'full': 'kim-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kio': {'full': 'kio-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kip': {'full': 'kip-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'kiq': {'full': 'kiq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kis': {'full': 'kis-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kit': {'full': 'kit-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kiu': {'full': 'kiu-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'kiv': {'full': 'kiv-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kiw': {'full': 'kiw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kix': {'full': 'kix-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kiy': {'full': 'kiy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kiz': {'full': 'kiz-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kj': {'full': 'kj-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'kj-Brai': {'full': 'kj-Brai-AO', 'region': 'AO', 'script': 'Brai', 'suppress': False},
        'kja': {'full': 'kja-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kjb': {'full': 'kjb-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'kjc': {'full': 'kjc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kjd': {'full': 'kjd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kje': {'full': 'kje-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kjf': {'full': 'kjf-Zyyy-AZ', 'region': 'AZ', 'script': 'Zyyy', 'suppress': False},
        'kjg': {'full': 'kjg-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'kjg-Latn': {'full': 'kjg-Latn-LA', 'region': 'LA', 'script': 'Latn', 'suppress': False},
        'kjg-Thai': {'full': 'kjg-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'kjh': {'full': 'kjh-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kji': {'full': 'kji-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'kjj': {'full': 'kjj-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'kjk': {'full': 'kjk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kjl': {'full': 'kjl-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'kjm': {'full': 'kjm-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'kjn': {'full': 'kjn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kjo': {'full': 'kjo-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kjp': {'full': 'kjp-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kjp-Leke': {'full': 'kjp-Leke-MM', 'region': 'MM', 'script': 'Leke', 'suppress': False},
        'kjp-Mymr-x-chekhi': {'full': 'kjp-Mymr-MM-x-chekhi', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kjp-Mymr-x-phlouyu': {'full': 'kjp-Mymr-MM-x-phlouyu', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kjp-Mymr-x-thiyon': {'full': 'kjp-Mymr-MM-x-thiyon', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kjp-Thai': {'full': 'kjp-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'kjq': {'full': 'kjq-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kjr': {'full': 'kjr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kjs': {'full': 'kjs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kjt': {'full': 'kjt-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'kju': {'full': 'kju-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kjv': {'full': 'kjv-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'kjx': {'full': 'kjx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kjy': {'full': 'kjy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kjz-Tibt': {'full': 'kjz-Tibt-BT-x-uchen', 'region': 'BT', 'script': 'Tibt', 'suppress': False},
        'kk': {'full': 'kk-Cyrl-KZ', 'region': 'KZ', 'script': 'Cyrl', 'suppress': True},
        'kk-AF': {'full': 'kk-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'kk-Brai': {'full': 'kk-Brai-KZ', 'region': 'KZ', 'script': 'Brai', 'suppress': False},
        'kk-CN': {'full': 'kk-Arab-CN', 'region': 'CN', 'script': 'Arab', 'suppress': False},
        'kk-IR': {'full': 'kk-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'kk-Latn': {'full': 'kk-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'kk-MN': {'full': 'kk-Arab-MN', 'region': 'MN', 'script': 'Arab', 'suppress': False},
        'kka': {'full': 'kka-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kkb': {'full': 'kkb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kkc': {'full': 'kkc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kkd': {'full': 'kkd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kke': {'full': 'kke-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'kke-Arab': {'full': 'kke-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'kkf': {'full': 'kkf-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kkg': {'full': 'kkg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kkh': {'full': 'kkh-Lana-MM', 'region': 'MM', 'script': 'Lana', 'suppress': False},
        'kki': {'full': 'kki-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kkj': {'full': 'kkj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kkj-TD': {'full': 'kkj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kkk': {'full': 'kkk-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'kkl': {'full': 'kkl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kkm': {'full': 'kkm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kkn': {'full': 'kkn-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'kko': {'full': 'kko-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'kkp': {'full': 'kkp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kkq': {'full': 'kkq-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kkr': {'full': 'kkr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kks': {'full': 'kks-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kkt': {'full': 'kkt-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'kku': {'full': 'kku-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kkv': {'full': 'kkv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kkw': {'full': 'kkw-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'kkx': {'full': 'kkx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kky': {'full': 'kky-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kkz': {'full': 'kkz-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'kl': {'full': 'kl-Latn-GL', 'region': 'GL', 'script': 'Latn', 'suppress': True},
        'kla': {'full': 'kla-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'klb': {'full': 'klb-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'klc': {'full': 'klc-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kld': {'full': 'kld-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kle': {'full': 'kle-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'klf': {'full': 'klf-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'klg': {'full': 'klg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'klh': {'full': 'klh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kli': {'full': 'kli-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'klj': {'full': 'klj-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'klk': {'full': 'klk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kll': {'full': 'kll-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'klm': {'full': 'klm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kln': {'full': 'kln-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'klo': {'full': 'klo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'klp': {'full': 'klp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'klq': {'full': 'klq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'klr': {'full': 'klr-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'kls': {'full': 'kls-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'kls-Arab': {'full': 'kls-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'klt': {'full': 'klt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'klu': {'full': 'klu-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'klv': {'full': 'klv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'klw': {'full': 'klw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'klx': {'full': 'klx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kly': {'full': 'kly-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'klz': {'full': 'klz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'km': {'full': 'km-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': True},
        'kma': {'full': 'kma-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'kmb': {'full': 'kmb-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'kmc': {'full': 'kmc-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'kmc-Hani': {'full': 'kmc-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'kmd': {'full': 'kmd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kme': {'full': 'kme-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kmf': {'full': 'kmf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmg': {'full': 'kmg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmh': {'full': 'kmh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmi': {'full': 'kmi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kmj': {'full': 'kmj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kmk': {'full': 'kmk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kml': {'full': 'kml-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kmm': {'full': 'kmm-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kmn': {'full': 'kmn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmo': {'full': 'kmo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmp': {'full': 'kmp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kmq': {'full': 'kmq-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'kms': {'full': 'kms-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmt': {'full': 'kmt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kmu': {'full': 'kmu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmv': {'full': 'kmv-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kmw': {'full': 'kmw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kmx': {'full': 'kmx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kmy': {'full': 'kmy-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kmz': {'full': 'kmz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'kn': {'full': 'kn-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': True},
        'kn-Brai': {'full': 'kn-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'kn-Nand': {'full': 'kn-Nand-IN', 'region': 'IN', 'script': 'Nand', 'suppress': False},
        'kna': {'full': 'kna-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'knb': {'full': 'knb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'knd': {'full': 'knd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kne': {'full': 'kne-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'knf': {'full': 'knf-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'kni': {'full': 'kni-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'knj': {'full': 'knj-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'knk': {'full': 'knk-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'knk-Arab': {'full': 'knk-Arab-SL', 'region': 'SL', 'script': 'Arab', 'suppress': False},
        'knl': {'full': 'knl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'knm': {'full': 'knm-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'knn-Knda': {'full': 'knn-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'knn-Latn': {'full': 'knn-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'kno': {'full': 'kno-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'knp': {'full': 'knp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'knq': {'full': 'knq-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'knr': {'full': 'knr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kns': {'full': 'kns-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kns-Thai': {'full': 'kns-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'knt': {'full': 'knt-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'knu': {'full': 'knu-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'knv': {'full': 'knv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'knw': {'full': 'knw-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'knx': {'full': 'knx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kny': {'full': 'kny-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'knz': {'full': 'knz-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'ko': {'full': 'ko-Kore-KR', 'region': 'KR', 'script': 'Kore', 'suppress': True},
        'ko-Brai': {'full': 'ko-Brai-KR', 'region': 'KR', 'script': 'Brai', 'suppress': False},
        'ko-KP': {'full': 'ko-Kore-KP', 'region': 'KP', 'script': 'Kore', 'suppress': True},
        'ko-Latn': {'full': 'ko-Latn-KR', 'region': 'KR', 'script': 'Latn', 'suppress': False},
        'koa': {'full': 'koa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'koc': {'full': 'koc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kod': {'full': 'kod-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'koe': {'full': 'koe-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'kof': {'full': 'kof-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kog': {'full': 'kog-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'koh': {'full': 'koh-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'koi': {'full': 'koi-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'koi-Latn': {'full': 'koi-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'koi-Perm': {'full': 'koi-Perm-RU', 'region': 'RU', 'script': 'Perm', 'suppress': False},
        'kok': {'full': 'kok-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': True},
        'kol': {'full': 'kol-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'koo': {'full': 'koo-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'kop': {'full': 'kop-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'koq': {'full': 'koq-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'kos': {'full': 'kos-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'kot': {'full': 'kot-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kou': {'full': 'kou-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kov': {'full': 'kov-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kow': {'full': 'kow-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'koy': {'full': 'koy-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'koz': {'full': 'koz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kpa': {'full': 'kpa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kpb': {'full': 'kpb-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kpc': {'full': 'kpc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'kpd': {'full': 'kpd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kpe': {'full': 'kpe-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'kpe-Kpel': {'full': 'kpe-Kpel-LR', 'region': 'LR', 'script': 'Kpel', 'suppress': False},
        'kpf': {'full': 'kpf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kpg': {'full': 'kpg-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'kph': {'full': 'kph-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'kpi': {'full': 'kpi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kpj': {'full': 'kpj-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kpk': {'full': 'kpk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kpl': {'full': 'kpl-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kpm': {'full': 'kpm-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'kpn': {'full': 'kpn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kpo': {'full': 'kpo-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'kpq': {'full': 'kpq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kpr': {'full': 'kpr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kps': {'full': 'kps-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kpt': {'full': 'kpt-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kpu': {'full': 'kpu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kpw': {'full': 'kpw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kpx': {'full': 'kpx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kpy': {'full': 'kpy-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kpz': {'full': 'kpz-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'kqa': {'full': 'kqa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqb': {'full': 'kqb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqc': {'full': 'kqc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqd': {'full': 'kqd-Syrc-IQ', 'region': 'IQ', 'script': 'Syrc', 'suppress': False},
        'kqe': {'full': 'kqe-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kqf': {'full': 'kqf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqg': {'full': 'kqg-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'kqh': {'full': 'kqh-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kqi': {'full': 'kqi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqj': {'full': 'kqj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqk': {'full': 'kqk-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'kql': {'full': 'kql-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqm': {'full': 'kqm-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kqn': {'full': 'kqn-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'kqo': {'full': 'kqo-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'kqp': {'full': 'kqp-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kqq': {'full': 'kqq-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kqr': {'full': 'kqr-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kqs': {'full': 'kqs-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'kqt': {'full': 'kqt-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kqu': {'full': 'kqu-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'kqv': {'full': 'kqv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kqw': {'full': 'kqw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kqx': {'full': 'kqx-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kqy': {'full': 'kqy-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'kqy-Latn': {'full': 'kqy-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'kqz': {'full': 'kqz-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'kr': {'full': 'kr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kr-Arab': {'full': 'kr-Arab-NG', 'region': 'NG', 'script': 'Arab', 'suppress': False},
        'kra': {'full': 'kra-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'krb': {'full': 'krb-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'krc': {'full': 'krc-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'krd': {'full': 'krd-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'kre': {'full': 'kre-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'krf': {'full': 'krf-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'krh': {'full': 'krh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kri': {'full': 'kri-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'krj': {'full': 'krj-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'krk': {'full': 'krk-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'krl': {'full': 'krl-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'krl-Cyrl': {'full': 'krl-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'krn': {'full': 'krn-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'krp': {'full': 'krp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'krr': {'full': 'krr-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'krs': {'full': 'krs-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'krt': {'full': 'krt-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'kru': {'full': 'kru-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kru-Deva-NP': {'full': 'kru-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'krv': {'full': 'krv-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'krw': {'full': 'krw-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'krx': {'full': 'krx-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'kry': {'full': 'kry-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'krz': {'full': 'krz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ks': {'full': 'ks-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'ks-Deva': {'full': 'ks-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'ks-Latn': {'full': 'ks-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'ks-Shrd': {'full': 'ks-Shrd-IN', 'region': 'IN', 'script': 'Shrd', 'suppress': False},
        'ksa': {'full': 'ksa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ksb': {'full': 'ksb-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ksc': {'full': 'ksc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ksd': {'full': 'ksd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kse': {'full': 'kse-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ksf': {'full': 'ksf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ksg': {'full': 'ksg-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ksh': {'full': 'ksh-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'ksi': {'full': 'ksi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ksj': {'full': 'ksj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ksk': {'full': 'ksk-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ksl': {'full': 'ksl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ksm': {'full': 'ksm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ksn': {'full': 'ksn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kso': {'full': 'kso-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ksp': {'full': 'ksp-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'ksq': {'full': 'ksq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ksr': {'full': 'ksr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kss': {'full': 'kss-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'kst': {'full': 'kst-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'ksu': {'full': 'ksu-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ksv': {'full': 'ksv-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ksw': {'full': 'ksw-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'ksw-Latn': {'full': 'ksw-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'ksx': {'full': 'ksx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ksy': {'full': 'ksy-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ksz': {'full': 'ksz-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kta': {'full': 'kta-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'ktb': {'full': 'ktb-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'ktb-Latn': {'full': 'ktb-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'ktc': {'full': 'ktc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ktd': {'full': 'ktd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kte': {'full': 'kte-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'ktf': {'full': 'ktf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ktg': {'full': 'ktg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kth': {'full': 'kth-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kti': {'full': 'kti-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ktj': {'full': 'ktj-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ktk': {'full': 'ktk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ktl': {'full': 'ktl-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'ktm': {'full': 'ktm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ktn': {'full': 'ktn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kto': {'full': 'kto-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ktp': {'full': 'ktp-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'ktq': {'full': 'ktq-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kts': {'full': 'kts-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ktt': {'full': 'ktt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ktu': {'full': 'ktu-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ktv': {'full': 'ktv-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'ktw': {'full': 'ktw-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ktx': {'full': 'ktx-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kty': {'full': 'kty-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ktz': {'full': 'ktz-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'ku': {'full': 'ku-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'ku-Arab': {'full': 'ku-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': False},
        'ku-Arab-TR': {'full': 'ku-Arab-TR', 'region': 'TR', 'script': 'Arab', 'suppress': False},
        'ku-Armn': {'full': 'ku-Armn-AZ', 'region': 'AZ', 'script': 'Armn', 'suppress': False},
        'ku-Cyrl': {'full': 'ku-Cyrl-IQ', 'region': 'IQ', 'script': 'Cyrl', 'suppress': False},
        'ku-Cyrl-AZ': {'full': 'ku-Cyrl-AZ', 'region': 'AZ', 'script': 'Cyrl', 'suppress': False},
        'ku-LB': {'full': 'ku-Arab-LB', 'region': 'LB', 'script': 'Arab', 'suppress': False},
        'ku-Yezi-GE': {'full': 'ku-Yezi-GE', 'region': 'GE', 'script': 'Yezi', 'suppress': False},
        'kub': {'full': 'kub-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kuc': {'full': 'kuc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kud': {'full': 'kud-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kue': {'full': 'kue-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kuf': {'full': 'kuf-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'kug': {'full': 'kug-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kuh': {'full': 'kuh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kui': {'full': 'kui-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kuj': {'full': 'kuj-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kuk': {'full': 'kuk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kul': {'full': 'kul-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kum': {'full': 'kum-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kum-Arab': {'full': 'kum-Arab-RU', 'region': 'RU', 'script': 'Arab', 'suppress': False},
        'kum-Latn': {'full': 'kum-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'kun': {'full': 'kun-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': False},
        'kuo': {'full': 'kuo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kup': {'full': 'kup-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kuq': {'full': 'kuq-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kus': {'full': 'kus-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'kut': {'full': 'kut-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'kuu': {'full': 'kuu-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kuv': {'full': 'kuv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kuw': {'full': 'kuw-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'kux': {'full': 'kux-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kuy': {'full': 'kuy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'kuz': {'full': 'kuz-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': False},
        'kv': {'full': 'kv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kv-Latn': {'full': 'kv-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'kv-Perm': {'full': 'kv-Perm-RU', 'region': 'RU', 'script': 'Perm', 'suppress': False},
        'kva': {'full': 'kva-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'kvb': {'full': 'kvb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvc': {'full': 'kvc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kvd': {'full': 'kvd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kve': {'full': 'kve-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kvf': {'full': 'kvf-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kvg': {'full': 'kvg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kvh': {'full': 'kvh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvi': {'full': 'kvi-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kvj': {'full': 'kvj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kvk': {'full': 'kvk-Zxxx-KR', 'region': 'KR', 'script': 'Zxxx', 'suppress': False},
        'kvl': {'full': 'kvl-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'kvm': {'full': 'kvm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kvn': {'full': 'kvn-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'kvo': {'full': 'kvo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvp': {'full': 'kvp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvq-Latn': {'full': 'kvq-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'kvq-Mymr': {'full': 'kvq-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kvr': {'full': 'kvr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvr-Rjng': {'full': 'kvr-Rjng-ID', 'region': 'ID', 'script': 'Rjng', 'suppress': False},
        'kvt': {'full': 'kvt-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'kvu': {'full': 'kvu-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'kvv': {'full': 'kvv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvw': {'full': 'kvw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kvx': {'full': 'kvx-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'kvy': {'full': 'kvy-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'kvz': {'full': 'kvz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kw': {'full': 'kw-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'kwa': {'full': 'kwa-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kwb': {'full': 'kwb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kwc': {'full': 'kwc-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'kwd': {'full': 'kwd-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'kwe': {'full': 'kwe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kwf': {'full': 'kwf-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'kwg': {'full': 'kwg-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kwh': {'full': 'kwh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kwi': {'full': 'kwi-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'kwj': {'full': 'kwj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kwk': {'full': 'kwk-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'kwl': {'full': 'kwl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'kwm': {'full': 'kwm-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'kwn': {'full': 'kwn-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'kwo': {'full': 'kwo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kwp': {'full': 'kwp-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kwr': {'full': 'kwr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kws': {'full': 'kws-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kwt': {'full': 'kwt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kwu': {'full': 'kwu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kwv': {'full': 'kwv-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kww': {'full': 'kww-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'kwx': {'full': 'kwx-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'kwy': {'full': 'kwy-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kwz': {'full': 'kwz-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'kxa': {'full': 'kxa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kxb': {'full': 'kxb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kxc': {'full': 'kxc-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'kxc-Latn': {'full': 'kxc-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'kxd': {'full': 'kxd-Latn-BN', 'region': 'BN', 'script': 'Latn', 'suppress': False},
        'kxd-Arab': {'full': 'kxd-Arab-BN', 'region': 'BN', 'script': 'Arab', 'suppress': False},
        'kxf': {'full': 'kxf-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kxf-Latn': {'full': 'kxf-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'kxf-Latn-x-manuma': {'full': 'kxf-Latn-MM-x-manuma', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'kxh': {'full': 'kxh-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'kxi': {'full': 'kxi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kxj': {'full': 'kxj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kxk': {'full': 'kxk-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'kxm': {'full': 'kxm-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'kxm-Khmr': {'full': 'kxm-Khmr-TH', 'region': 'TH', 'script': 'Khmr', 'suppress': False},
        'kxn': {'full': 'kxn-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kxo': {'full': 'kxo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kxp': {'full': 'kxp-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'kxp-Gujr': {'full': 'kxp-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'kxp-x-thr': {'full': 'kxp-Arab-PK-x-thr', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'kxq': {'full': 'kxq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kxr': {'full': 'kxr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kxs': {'full': 'kxs-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'kxt': {'full': 'kxt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kxu': {'full': 'kxu-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'kxv': {'full': 'kxv-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'kxw': {'full': 'kxw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kxx': {'full': 'kxx-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'kxy': {'full': 'kxy-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'kxz': {'full': 'kxz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ky': {'full': 'ky-Cyrl-KG', 'region': 'KG', 'script': 'Cyrl', 'suppress': False},
        'ky-CN': {'full': 'ky-Arab-CN', 'region': 'CN', 'script': 'Arab', 'suppress': False},
        'ky-TR': {'full': 'ky-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'kya': {'full': 'kya-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'kyb': {'full': 'kyb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kyc': {'full': 'kyc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kyd': {'full': 'kyd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kye': {'full': 'kye-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'kyf': {'full': 'kyf-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kyg': {'full': 'kyg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kyh': {'full': 'kyh-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kyi': {'full': 'kyi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kyj': {'full': 'kyj-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kyk': {'full': 'kyk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kyl': {'full': 'kyl-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'kym': {'full': 'kym-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'kyn': {'full': 'kyn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'kyo': {'full': 'kyo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kyp': {'full': 'kyp-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'kyq': {'full': 'kyq-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'kyr': {'full': 'kyr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kys': {'full': 'kys-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kyt': {'full': 'kyt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kyu': {'full': 'kyu-Kali-MM', 'region': 'MM', 'script': 'Kali', 'suppress': False},
        'kyu-Latn': {'full': 'kyu-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'kyu-Mymr': {'full': 'kyu-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'kyv': {'full': 'kyv-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'kyw-Beng': {'full': 'kyw-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'kyw-Deva': {'full': 'kyw-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'kyw-Orya': {'full': 'kyw-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'kyx': {'full': 'kyx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kyy': {'full': 'kyy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kyz': {'full': 'kyz-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kza': {'full': 'kza-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'kzb': {'full': 'kzb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzc': {'full': 'kzc-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'kzd': {'full': 'kzd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kze': {'full': 'kze-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'kzf': {'full': 'kzf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzg': {'full': 'kzg-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'kzi': {'full': 'kzi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kzk': {'full': 'kzk-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'kzl': {'full': 'kzl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzm': {'full': 'kzm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzn': {'full': 'kzn-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'kzo': {'full': 'kzo-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'kzp': {'full': 'kzp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzq': {'full': 'kzq-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'kzr': {'full': 'kzr-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'kzs': {'full': 'kzs-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'kzu': {'full': 'kzu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzv': {'full': 'kzv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzw': {'full': 'kzw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'kzx': {'full': 'kzx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'kzy': {'full': 'kzy-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'kzz': {'full': 'kzz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'la': {'full': 'la-Latn-VA', 'region': 'VA', 'script': 'Latn', 'suppress': True},
        'laa': {'full': 'laa-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'lab': {'full': 'lab-Lina-GR', 'region': 'GR', 'script': 'Lina', 'suppress': False},
        'lac': {'full': 'lac-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'lad': {'full': 'lad-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'lad-Cyrl': {'full': 'lad-Cyrl-TR', 'region': 'TR', 'script': 'Cyrl', 'suppress': False},
        'lad-Latn': {'full': 'lad-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'lae': {'full': 'lae-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'lae-Tibt': {'full': 'lae-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'laf': {'full': 'laf-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'lag': {'full': 'lag-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'lah': {'full': 'lah-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'lah-Khoj': {'full': 'lah-Khoj-PK', 'region': 'PK', 'script': 'Khoj', 'suppress': False},
        'lah-Latn': {'full': 'lah-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'lah-Mahj-IN': {'full': 'lah-Mahj-IN', 'region': 'IN', 'script': 'Mahj', 'suppress': False},
        'lah-Zzzz-PK': {'full': 'lah-Zzzz-PK', 'region': 'PK', 'script': 'Zzzz', 'suppress': False},
        'lai': {'full': 'lai-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'laj': {'full': 'laj-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lak': {'full': 'lak-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'lal': {'full': 'lal-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lam': {'full': 'lam-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'lan': {'full': 'lan-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'lap': {'full': 'lap-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'laq': {'full': 'laq-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'lar': {'full': 'lar-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'las': {'full': 'las-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'lau': {'full': 'lau-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'law': {'full': 'law-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lax-Beng': {'full': 'lax-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'lax-Latn': {'full': 'lax-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'lay': {'full': 'lay-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'laz': {'full': 'laz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lb': {'full': 'lb-Latn-LU', 'region': 'LU', 'script': 'Latn', 'suppress': True},
        'lba': {'full': 'lba-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'lbb': {'full': 'lbb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lbc': {'full': 'lbc-Lisu-CN', 'region': 'CN', 'script': 'Lisu', 'suppress': False},
        'lbe': {'full': 'lbe-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'lbf-Deva': {'full': 'lbf-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'lbf-Tibt': {'full': 'lbf-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'lbg': {'full': 'lbg-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'lbi': {'full': 'lbi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'lbj': {'full': 'lbj-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'lbl': {'full': 'lbl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'lbm': {'full': 'lbm-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'lbn-Laoo': {'full': 'lbn-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'lbn-Latn': {'full': 'lbn-Latn-LA', 'region': 'LA', 'script': 'Latn', 'suppress': False},
        'lbo': {'full': 'lbo-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'lbq': {'full': 'lbq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lbr': {'full': 'lbr-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'lbs': {'full': 'lbs-Zxxx-LY', 'region': 'LY', 'script': 'Zxxx', 'suppress': False},
        'lbt': {'full': 'lbt-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'lbu': {'full': 'lbu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lbv': {'full': 'lbv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lbw': {'full': 'lbw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lbx': {'full': 'lbx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lby': {'full': 'lby-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lbz': {'full': 'lbz-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lcc': {'full': 'lcc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lcd': {'full': 'lcd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lce': {'full': 'lce-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lcf': {'full': 'lcf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lch': {'full': 'lch-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'lcl': {'full': 'lcl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lcm': {'full': 'lcm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lcp': {'full': 'lcp-Thai-CN', 'region': 'CN', 'script': 'Thai', 'suppress': False},
        'lcq': {'full': 'lcq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lcs': {'full': 'lcs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lda': {'full': 'lda-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'ldb': {'full': 'ldb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldd': {'full': 'ldd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldg': {'full': 'ldg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldh': {'full': 'ldh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldi': {'full': 'ldi-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'ldj': {'full': 'ldj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldk': {'full': 'ldk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldl': {'full': 'ldl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldm': {'full': 'ldm-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'ldn': {'full': 'ldn-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'ldo': {'full': 'ldo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldp': {'full': 'ldp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ldq': {'full': 'ldq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'lea': {'full': 'lea-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'leb': {'full': 'leb-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'lec': {'full': 'lec-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'led': {'full': 'led-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lee': {'full': 'lee-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'lef': {'full': 'lef-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'leh': {'full': 'leh-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'lei': {'full': 'lei-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lej': {'full': 'lej-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lek': {'full': 'lek-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lel': {'full': 'lel-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lem': {'full': 'lem-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'len': {'full': 'len-Latn-HN', 'region': 'HN', 'script': 'Latn', 'suppress': False},
        'leo': {'full': 'leo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'lep': {'full': 'lep-Lepc-IN', 'region': 'IN', 'script': 'Lepc', 'suppress': False},
        'lep-Tibt': {'full': 'lep-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'leq': {'full': 'leq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ler': {'full': 'ler-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'les': {'full': 'les-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'let': {'full': 'let-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'leu': {'full': 'leu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lev': {'full': 'lev-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lew': {'full': 'lew-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lex': {'full': 'lex-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ley': {'full': 'ley-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lez': {'full': 'lez-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'lez-Aghb': {'full': 'lez-Aghb-AZ', 'region': 'AZ', 'script': 'Aghb', 'suppress': False},
        'lfa': {'full': 'lfa-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'lfn': {'full': 'lfn-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'lfn-Cyrl': {'full': 'lfn-Cyrl-001', 'region': '001', 'script': 'Cyrl', 'suppress': False},
        'lg': {'full': 'lg-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lg-Arab': {'full': 'lg-Arab-UG', 'region': 'UG', 'script': 'Arab', 'suppress': False},
        'lga': {'full': 'lga-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'lgb': {'full': 'lgb-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'lgg': {'full': 'lgg-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lgg-Arab': {'full': 'lgg-Arab-UG', 'region': 'UG', 'script': 'Arab', 'suppress': False},
        'lgh': {'full': 'lgh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'lgi': {'full': 'lgi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lgk': {'full': 'lgk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lgl': {'full': 'lgl-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'lgm': {'full': 'lgm-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lgn': {'full': 'lgn-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'lgq': {'full': 'lgq-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'lgr': {'full': 'lgr-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'lgt': {'full': 'lgt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lgu': {'full': 'lgu-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'lgz': {'full': 'lgz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lha': {'full': 'lha-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'lhh': {'full': 'lhh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lhi': {'full': 'lhi-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'lhl': {'full': 'lhl-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'lhm': {'full': 'lhm-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'lhn': {'full': 'lhn-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'lhp': {'full': 'lhp-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'lhs': {'full': 'lhs-Syrc-SY', 'region': 'SY', 'script': 'Syrc', 'suppress': False},
        'lht': {'full': 'lht-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lhu': {'full': 'lhu-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'li': {'full': 'li-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'lia': {'full': 'lia-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'lib': {'full': 'lib-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lic': {'full': 'lic-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'lid': {'full': 'lid-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lie': {'full': 'lie-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lif': {'full': 'lif-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'lif-Limb': {'full': 'lif-Limb-IN', 'region': 'IN', 'script': 'Limb', 'suppress': False},
        'lig': {'full': 'lig-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'lih': {'full': 'lih-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lij': {'full': 'lij-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'lik': {'full': 'lik-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lil': {'full': 'lil-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'lil-Dupl': {'full': 'lil-Dupl-CA', 'region': 'CA', 'script': 'Dupl', 'suppress': False},
        'lio': {'full': 'lio-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lip': {'full': 'lip-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'liq': {'full': 'liq-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'lir': {'full': 'lir-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'lis': {'full': 'lis-Lisu-CN', 'region': 'CN', 'script': 'Lisu', 'suppress': False},
        'lis-Latn': {'full': 'lis-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'liu': {'full': 'liu-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'liv': {'full': 'liv-Latn-LV', 'region': 'LV', 'script': 'Latn', 'suppress': False},
        'liw': {'full': 'liw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lix': {'full': 'lix-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'liy': {'full': 'liy-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'liz': {'full': 'liz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lja': {'full': 'lja-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lje': {'full': 'lje-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lji': {'full': 'lji-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ljl': {'full': 'ljl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ljp': {'full': 'ljp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ljp-Rjng': {'full': 'ljp-Rjng-ID', 'region': 'ID', 'script': 'Rjng', 'suppress': False},
        'ljw': {'full': 'ljw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ljx': {'full': 'ljx-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lka': {'full': 'lka-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'lkb': {'full': 'lkb-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lkc': {'full': 'lkc-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'lkd': {'full': 'lkd-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'lke': {'full': 'lke-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lkh': {'full': 'lkh-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'lki': {'full': 'lki-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'lkj': {'full': 'lkj-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'lkl': {'full': 'lkl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lkm': {'full': 'lkm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lkn': {'full': 'lkn-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lko': {'full': 'lko-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lkr': {'full': 'lkr-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lks': {'full': 'lks-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lkt': {'full': 'lkt-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'lku': {'full': 'lku-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lky': {'full': 'lky-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lla': {'full': 'lla-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'llb': {'full': 'llb-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'llc': {'full': 'llc-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'lld': {'full': 'lld-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'lle': {'full': 'lle-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'llf': {'full': 'llf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'llg': {'full': 'llg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'llh': {'full': 'llh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'lli': {'full': 'lli-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'llj': {'full': 'llj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'llk': {'full': 'llk-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'lll': {'full': 'lll-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'llm': {'full': 'llm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lln': {'full': 'lln-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'llp': {'full': 'llp-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'llq': {'full': 'llq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lls': {'full': 'lls-Zxxx-LT', 'region': 'LT', 'script': 'Zxxx', 'suppress': False},
        'llu': {'full': 'llu-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'llx': {'full': 'llx-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'lma': {'full': 'lma-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'lmb': {'full': 'lmb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lmc': {'full': 'lmc-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lmd': {'full': 'lmd-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'lme': {'full': 'lme-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'lmf': {'full': 'lmf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lmg': {'full': 'lmg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lmh': {'full': 'lmh-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'lmi': {'full': 'lmi-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lmj': {'full': 'lmj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lmk': {'full': 'lmk-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'lmk-Mymr': {'full': 'lmk-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'lml': {'full': 'lml-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lmn': {'full': 'lmn-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'lmn-Deva': {'full': 'lmn-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'lmn-Knda': {'full': 'lmn-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'lmo': {'full': 'lmo-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'lmp': {'full': 'lmp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'lmq': {'full': 'lmq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lmr': {'full': 'lmr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lmu': {'full': 'lmu-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lmv': {'full': 'lmv-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'lmw': {'full': 'lmw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'lmx': {'full': 'lmx-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'lmy': {'full': 'lmy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lmz': {'full': 'lmz-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ln': {'full': 'ln-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': True},
        'ln-AO': {'full': 'ln-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': True},
        'lna': {'full': 'lna-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'lnb': {'full': 'lnb-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'lnd': {'full': 'lnd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lng': {'full': 'lng-Zyyy-HU', 'region': 'HU', 'script': 'Zyyy', 'suppress': False},
        'lnh': {'full': 'lnh-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'lni': {'full': 'lni-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lnj': {'full': 'lnj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lnl': {'full': 'lnl-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'lnm': {'full': 'lnm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lnn': {'full': 'lnn-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lno': {'full': 'lno-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lns': {'full': 'lns-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'lnu': {'full': 'lnu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'lnw': {'full': 'lnw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lnz': {'full': 'lnz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lo': {'full': 'lo-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': True},
        'loa': {'full': 'loa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lob': {'full': 'lob-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'loc': {'full': 'loc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'loe': {'full': 'loe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lof': {'full': 'lof-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'log': {'full': 'log-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'loh': {'full': 'loh-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'loi': {'full': 'loi-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'loj': {'full': 'loj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lok': {'full': 'lok-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': False},
        'lol': {'full': 'lol-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lom': {'full': 'lom-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'lom-Loma': {'full': 'lom-Loma-LR', 'region': 'LR', 'script': 'Loma', 'suppress': False},
        'lon': {'full': 'lon-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'loo': {'full': 'loo-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lop': {'full': 'lop-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'loq': {'full': 'loq-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lor': {'full': 'lor-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'los': {'full': 'los-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lot': {'full': 'lot-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lot-Arab': {'full': 'lot-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'lou': {'full': 'lou-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'lov': {'full': 'lov-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'low': {'full': 'low-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'lox': {'full': 'lox-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'loy': {'full': 'loy-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'loy-Tibt': {'full': 'loy-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'loz': {'full': 'loz-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'lpa': {'full': 'lpa-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lpe': {'full': 'lpe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lpn': {'full': 'lpn-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'lpo': {'full': 'lpo-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'lpo-Lisu': {'full': 'lpo-Lisu-CN', 'region': 'CN', 'script': 'Lisu', 'suppress': False},
        'lpx': {'full': 'lpx-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lra': {'full': 'lra-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'lrc': {'full': 'lrc-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'lrc-IQ': {'full': 'lrc-Arab-IQ', 'region': 'IQ', 'script': 'Arab', 'suppress': False},
        'lre': {'full': 'lre-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'lrg': {'full': 'lrg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'lri': {'full': 'lri-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lrk': {'full': 'lrk-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'lrl': {'full': 'lrl-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'lrm': {'full': 'lrm-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lrn': {'full': 'lrn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lro': {'full': 'lro-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'lrr': {'full': 'lrr-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'lrt': {'full': 'lrt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lrv': {'full': 'lrv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lrz': {'full': 'lrz-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lsa': {'full': 'lsa-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'lsd': {'full': 'lsd-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'lse': {'full': 'lse-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lsg': {'full': 'lsg-Zxxx-FR', 'region': 'FR', 'script': 'Zxxx', 'suppress': False},
        'lsh': {'full': 'lsh-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'lsi': {'full': 'lsi-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'lsl': {'full': 'lsl-Zxxx-LV', 'region': 'LV', 'script': 'Zxxx', 'suppress': False},
        'lsm': {'full': 'lsm-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lsn': {'full': 'lsn-Zxxx-CN', 'region': 'CN', 'script': 'Zxxx', 'suppress': False},
        'lso': {'full': 'lso-Zxxx-LA', 'region': 'LA', 'script': 'Zxxx', 'suppress': False},
        'lsp': {'full': 'lsp-Zxxx-PA', 'region': 'PA', 'script': 'Zxxx', 'suppress': False},
        'lsr': {'full': 'lsr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lss': {'full': 'lss-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'lst': {'full': 'lst-Zxxx-TT', 'region': 'TT', 'script': 'Zxxx', 'suppress': False},
        'lsv': {'full': 'lsv-Zxxx-PE', 'region': 'PE', 'script': 'Zxxx', 'suppress': False},
        'lsy': {'full': 'lsy-Zxxx-MU', 'region': 'MU', 'script': 'Zxxx', 'suppress': False},
        'lt': {'full': 'lt-Latn-LT', 'region': 'LT', 'script': 'Latn', 'suppress': True},
        'lt-Latf': {'full': 'lt-Latf-LT', 'region': 'LT', 'script': 'Latf', 'suppress': False},
        'ltc': {'full': 'ltc-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ltg': {'full': 'ltg-Latn-LV', 'region': 'LV', 'script': 'Latn', 'suppress': False},
        'lth': {'full': 'lth-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lti': {'full': 'lti-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ltn': {'full': 'ltn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'lto': {'full': 'lto-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lts': {'full': 'lts-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'ltu': {'full': 'ltu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lu': {'full': 'lu-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lua': {'full': 'lua-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'luc': {'full': 'luc-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'lud': {'full': 'lud-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'lue': {'full': 'lue-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'luf': {'full': 'luf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'lui': {'full': 'lui-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'luj': {'full': 'luj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'luk': {'full': 'luk-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'lul': {'full': 'lul-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lum': {'full': 'lum-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'lun': {'full': 'lun-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'luo': {'full': 'luo-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lup': {'full': 'lup-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'luq': {'full': 'luq-Latn-CU', 'region': 'CU', 'script': 'Latn', 'suppress': False},
        'lur': {'full': 'lur-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lus': {'full': 'lus-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'lus-Beng': {'full': 'lus-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'lus-Brai': {'full': 'lus-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'lut': {'full': 'lut-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'luu': {'full': 'luu-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'luv': {'full': 'luv-Zyyy-OM', 'region': 'OM', 'script': 'Zyyy', 'suppress': False},
        'luw': {'full': 'luw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'luy': {'full': 'luy-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'luz': {'full': 'luz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'lv': {'full': 'lv-Latn-LV', 'region': 'LV', 'script': 'Latn', 'suppress': True},
        'lv-Brai': {'full': 'lv-Brai-LV', 'region': 'LV', 'script': 'Brai', 'suppress': False},
        'lva': {'full': 'lva-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'lvi': {'full': 'lvi-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'lvk': {'full': 'lvk-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'lvu': {'full': 'lvu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lwa': {'full': 'lwa-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'lwe': {'full': 'lwe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lwg': {'full': 'lwg-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'lwh': {'full': 'lwh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'lwl': {'full': 'lwl-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'lwm': {'full': 'lwm-Thai-CN', 'region': 'CN', 'script': 'Thai', 'suppress': False},
        'lwo': {'full': 'lwo-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'lwo-ZA': {'full': 'lwo-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'lws': {'full': 'lws-Zxxx-MW', 'region': 'MW', 'script': 'Zxxx', 'suppress': False},
        'lwt': {'full': 'lwt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'lwu': {'full': 'lwu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'lww': {'full': 'lww-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lya': {'full': 'lya-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'lyg': {'full': 'lyg-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'lyn': {'full': 'lyn-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'lzh': {'full': 'lzh-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'lzh-Hant': {'full': 'lzh-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'lzl': {'full': 'lzl-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'lzn': {'full': 'lzn-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'lzz': {'full': 'lzz-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'lzz-Geor': {'full': 'lzz-Geor-TR', 'region': 'TR', 'script': 'Geor', 'suppress': False},
        'maa': {'full': 'maa-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mab': {'full': 'mab-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mad': {'full': 'mad-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mae': {'full': 'mae-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'maf': {'full': 'maf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mag': {'full': 'mag-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mai': {'full': 'mai-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': True},
        'mai-Kthi': {'full': 'mai-Kthi-IN', 'region': 'IN', 'script': 'Kthi', 'suppress': False},
        'mai-Newa': {'full': 'mai-Newa-IN', 'region': 'IN', 'script': 'Newa', 'suppress': False},
        'mai-Tirh': {'full': 'mai-Tirh-IN', 'region': 'IN', 'script': 'Tirh', 'suppress': False},
        'maj': {'full': 'maj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mak': {'full': 'mak-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mak-Bugi': {'full': 'mak-Bugi-ID', 'region': 'ID', 'script': 'Bugi', 'suppress': False},
        'mak-Maka': {'full': 'mak-Maka-ID', 'region': 'ID', 'script': 'Maka', 'suppress': False},
        'mam': {'full': 'mam-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'man': {'full': 'man-Latn-GM', 'region': 'GM', 'script': 'Latn', 'suppress': False},
        'man-Arab': {'full': 'man-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'man-GN': {'full': 'man-Nkoo-GN', 'region': 'GN', 'script': 'Nkoo', 'suppress': False},
        'man-Latn-GN': {'full': 'man-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'maq': {'full': 'maq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mas': {'full': 'mas-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'mas-TZ': {'full': 'mas-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mat': {'full': 'mat-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mau': {'full': 'mau-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mav': {'full': 'mav-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'maw': {'full': 'maw-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'maw-Arab': {'full': 'maw-Arab-GH', 'region': 'GH', 'script': 'Arab', 'suppress': False},
        'max': {'full': 'max-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'maz': {'full': 'maz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mba': {'full': 'mba-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mbb': {'full': 'mbb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mbc': {'full': 'mbc-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mbd': {'full': 'mbd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mbe': {'full': 'mbe-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'mbf': {'full': 'mbf-Latn-SG', 'region': 'SG', 'script': 'Latn', 'suppress': False},
        'mbh': {'full': 'mbh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mbi': {'full': 'mbi-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mbj': {'full': 'mbj-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mbk': {'full': 'mbk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mbl': {'full': 'mbl-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mbm': {'full': 'mbm-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mbn': {'full': 'mbn-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'mbo': {'full': 'mbo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mbp': {'full': 'mbp-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'mbq': {'full': 'mbq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mbr': {'full': 'mbr-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'mbs': {'full': 'mbs-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mbt': {'full': 'mbt-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mbu': {'full': 'mbu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mbv': {'full': 'mbv-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'mbw': {'full': 'mbw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mbx': {'full': 'mbx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mby': {'full': 'mby-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'mbz': {'full': 'mbz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mca': {'full': 'mca-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'mcb': {'full': 'mcb-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'mcc': {'full': 'mcc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mcd': {'full': 'mcd-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'mce': {'full': 'mce-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mcf': {'full': 'mcf-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'mcg': {'full': 'mcg-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'mch': {'full': 'mch-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'mci': {'full': 'mci-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mcj': {'full': 'mcj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mck': {'full': 'mck-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'mcl': {'full': 'mcl-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'mcm': {'full': 'mcm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mcn': {'full': 'mcn-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mco': {'full': 'mco-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mcp': {'full': 'mcp-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mcq': {'full': 'mcq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mcr': {'full': 'mcr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mcs': {'full': 'mcs-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mct': {'full': 'mct-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mcu': {'full': 'mcu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mcu-Laoo-CM': {'full': 'mcu-Laoo-CM', 'region': 'CM', 'script': 'Laoo', 'suppress': False},
        'mcv': {'full': 'mcv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mcw': {'full': 'mcw-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mcx': {'full': 'mcx-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'mcy': {'full': 'mcy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mcz': {'full': 'mcz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mda': {'full': 'mda-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mdb': {'full': 'mdb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mdc': {'full': 'mdc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mdd': {'full': 'mdd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mde': {'full': 'mde-Arab-TD', 'region': 'TD', 'script': 'Arab', 'suppress': False},
        'mde-Latn': {'full': 'mde-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mdf': {'full': 'mdf-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'mdg': {'full': 'mdg-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mdh': {'full': 'mdh-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mdi': {'full': 'mdi-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mdj': {'full': 'mdj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mdk': {'full': 'mdk-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mdl': {'full': 'mdl-Zxxx-MT', 'region': 'MT', 'script': 'Zxxx', 'suppress': False},
        'mdm': {'full': 'mdm-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mdn': {'full': 'mdn-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'mdp': {'full': 'mdp-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mdq': {'full': 'mdq-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mdr': {'full': 'mdr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mdr-Bugi': {'full': 'mdr-Bugi-ID', 'region': 'ID', 'script': 'Bugi', 'suppress': False},
        'mds': {'full': 'mds-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mdt': {'full': 'mdt-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mdu': {'full': 'mdu-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mdv': {'full': 'mdv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mdw': {'full': 'mdw-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mdx': {'full': 'mdx-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'mdx-Latn': {'full': 'mdx-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'mdy': {'full': 'mdy-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'mdy-Latn': {'full': 'mdy-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'mdz': {'full': 'mdz-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mea': {'full': 'mea-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'meb': {'full': 'meb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mec': {'full': 'mec-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'med': {'full': 'med-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mee': {'full': 'mee-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mef': {'full': 'mef-Zyyy-BD', 'region': 'BD', 'script': 'Zyyy', 'suppress': False},
        'meh': {'full': 'meh-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mei': {'full': 'mei-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'mej': {'full': 'mej-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mek': {'full': 'mek-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mel': {'full': 'mel-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mem': {'full': 'mem-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'men': {'full': 'men-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': True},
        'men-Mend': {'full': 'men-Mend-SL', 'region': 'SL', 'script': 'Mend', 'suppress': False},
        'meo': {'full': 'meo-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'meo-Arab': {'full': 'meo-Arab-MY', 'region': 'MY', 'script': 'Arab', 'suppress': False},
        'mep': {'full': 'mep-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'meq': {'full': 'meq-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mer': {'full': 'mer-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'mes': {'full': 'mes-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'met': {'full': 'met-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'meu': {'full': 'meu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mev': {'full': 'mev-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'mew': {'full': 'mew-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mey': {'full': 'mey-Latn-MR', 'region': 'MR', 'script': 'Latn', 'suppress': False},
        'mey-Arab': {'full': 'mey-Arab-MR', 'region': 'MR', 'script': 'Arab', 'suppress': False},
        'mez': {'full': 'mez-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mfa': {'full': 'mfa-Arab-TH', 'region': 'TH', 'script': 'Arab', 'suppress': False},
        'mfa-Thai': {'full': 'mfa-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'mfb': {'full': 'mfb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mfc': {'full': 'mfc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mfd': {'full': 'mfd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mfe': {'full': 'mfe-Latn-MU', 'region': 'MU', 'script': 'Latn', 'suppress': False},
        'mff': {'full': 'mff-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mfg': {'full': 'mfg-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'mfh': {'full': 'mfh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mfi': {'full': 'mfi-Arab-CM', 'region': 'CM', 'script': 'Arab', 'suppress': False},
        'mfi-Latn': {'full': 'mfi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mfj': {'full': 'mfj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mfk': {'full': 'mfk-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mfl': {'full': 'mfl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mfm': {'full': 'mfm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mfn': {'full': 'mfn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mfo': {'full': 'mfo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mfp': {'full': 'mfp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mfq': {'full': 'mfq-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'mfr': {'full': 'mfr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mfs': {'full': 'mfs-Zxxx-MX', 'region': 'MX', 'script': 'Zxxx', 'suppress': False},
        'mft': {'full': 'mft-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mfu': {'full': 'mfu-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'mfv': {'full': 'mfv-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'mfw': {'full': 'mfw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mfx': {'full': 'mfx-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'mfy': {'full': 'mfy-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mfz': {'full': 'mfz-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mg': {'full': 'mg-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': True},
        'mg-Arab': {'full': 'mg-Arab-MG', 'region': 'MG', 'script': 'Arab', 'suppress': False},
        'mg-Brai': {'full': 'mg-Brai-MG', 'region': 'MG', 'script': 'Brai', 'suppress': False},
        'mga': {'full': 'mga-Latg-IE', 'region': 'IE', 'script': 'Latg', 'suppress': False},
        'mgb': {'full': 'mgb-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mgc': {'full': 'mgc-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mgd': {'full': 'mgd-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mgd-Arab': {'full': 'mgd-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'mge': {'full': 'mge-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mgf': {'full': 'mgf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mgg': {'full': 'mgg-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mgh': {'full': 'mgh-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'mgi': {'full': 'mgi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mgj': {'full': 'mgj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mgk': {'full': 'mgk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mgl': {'full': 'mgl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mgm': {'full': 'mgm-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'mgn': {'full': 'mgn-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'mgo': {'full': 'mgo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mgp': {'full': 'mgp-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'mgp-Brah-x-akkha': {'full': 'mgp-Brah-NP-x-akkha', 'region': 'NP', 'script': 'Brah', 'suppress': False},
        'mgq': {'full': 'mgq-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mgr': {'full': 'mgr-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'mgs': {'full': 'mgs-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mgt': {'full': 'mgt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mgu': {'full': 'mgu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mgv': {'full': 'mgv-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mgw': {'full': 'mgw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mgy': {'full': 'mgy-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mgz': {'full': 'mgz-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mh': {'full': 'mh-Latn-MH', 'region': 'MH', 'script': 'Latn', 'suppress': True},
        'mha': {'full': 'mha-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mhb': {'full': 'mhb-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'mhc': {'full': 'mhc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mhd': {'full': 'mhd-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mhe': {'full': 'mhe-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mhf': {'full': 'mhf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mhg': {'full': 'mhg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mhi': {'full': 'mhi-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'mhj': {'full': 'mhj-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'mhk': {'full': 'mhk-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mhl': {'full': 'mhl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mhm': {'full': 'mhm-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'mhn': {'full': 'mhn-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'mho': {'full': 'mho-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'mhp': {'full': 'mhp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mhq': {'full': 'mhq-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mhs': {'full': 'mhs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mht': {'full': 'mht-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'mhu': {'full': 'mhu-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'mhw': {'full': 'mhw-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'mhx': {'full': 'mhx-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'mhy': {'full': 'mhy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mhz': {'full': 'mhz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mi': {'full': 'mi-Latn-NZ', 'region': 'NZ', 'script': 'Latn', 'suppress': False},
        'mia': {'full': 'mia-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mib': {'full': 'mib-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mic': {'full': 'mic-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'mic-Zzzz-x-kauder': {'full': 'mic-Zzzz-CA-x-kauder', 'region': 'CA', 'script': 'Zzzz', 'suppress': False},
        'mid': {'full': 'mid-Mand-IQ', 'region': 'IQ', 'script': 'Mand', 'suppress': False},
        'mie': {'full': 'mie-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mif': {'full': 'mif-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mig': {'full': 'mig-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mih': {'full': 'mih-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mii': {'full': 'mii-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mij': {'full': 'mij-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mik': {'full': 'mik-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mil': {'full': 'mil-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mim': {'full': 'mim-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'min': {'full': 'min-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'min-Arab': {'full': 'min-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'mio': {'full': 'mio-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mip': {'full': 'mip-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'miq': {'full': 'miq-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'mir': {'full': 'mir-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mis': {'full': 'mis-Hatr-IQ', 'region': 'IQ', 'script': 'Hatr', 'suppress': False},
        'mit': {'full': 'mit-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'miu': {'full': 'miu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'miw': {'full': 'miw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mix': {'full': 'mix-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'miy': {'full': 'miy-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'miz': {'full': 'miz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mjb': {'full': 'mjb-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'mjc': {'full': 'mjc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mjd': {'full': 'mjd-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mje': {'full': 'mje-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mjg': {'full': 'mjg-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'mjh': {'full': 'mjh-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mji': {'full': 'mji-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'mjj': {'full': 'mjj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mjk': {'full': 'mjk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mjl': {'full': 'mjl-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mjl-Takr': {'full': 'mjl-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'mjm': {'full': 'mjm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mjn': {'full': 'mjn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mjo': {'full': 'mjo-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mjp': {'full': 'mjp-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mjq': {'full': 'mjq-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mjr': {'full': 'mjr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mjs': {'full': 'mjs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mjt': {'full': 'mjt-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mjt-Beng': {'full': 'mjt-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'mju': {'full': 'mju-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'mjv': {'full': 'mjv-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'mjw': {'full': 'mjw-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'mjx': {'full': 'mjx-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'mjy': {'full': 'mjy-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'mjz': {'full': 'mjz-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'mk': {'full': 'mk-Cyrl-MK', 'region': 'MK', 'script': 'Cyrl', 'suppress': True},
        'mk-Brai': {'full': 'mk-Brai-MK', 'region': 'MK', 'script': 'Brai', 'suppress': False},
        'mka': {'full': 'mka-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'mkb': {'full': 'mkb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mkc': {'full': 'mkc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mke': {'full': 'mke-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mkf': {'full': 'mkf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mkg': {'full': 'mkg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'mki': {'full': 'mki-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'mkj': {'full': 'mkj-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'mkk': {'full': 'mkk-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mkl': {'full': 'mkl-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'mkm': {'full': 'mkm-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'mkn': {'full': 'mkn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mko': {'full': 'mko-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mkp': {'full': 'mkp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mkq': {'full': 'mkq-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'mkr': {'full': 'mkr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mks': {'full': 'mks-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mkt': {'full': 'mkt-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'mku': {'full': 'mku-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'mkv': {'full': 'mkv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mkw': {'full': 'mkw-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mkx': {'full': 'mkx-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mky': {'full': 'mky-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mkz': {'full': 'mkz-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'ml': {'full': 'ml-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': True},
        'ml-Arab': {'full': 'ml-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'ml-Brai': {'full': 'ml-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'mla': {'full': 'mla-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mlb': {'full': 'mlb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mlc': {'full': 'mlc-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'mle': {'full': 'mle-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mlf': {'full': 'mlf-Thai-LA', 'region': 'LA', 'script': 'Thai', 'suppress': False},
        'mlf-Latn': {'full': 'mlf-Latn-LA', 'region': 'LA', 'script': 'Latn', 'suppress': False},
        'mlh': {'full': 'mlh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mli': {'full': 'mli-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mlj': {'full': 'mlj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mlk': {'full': 'mlk-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'mll': {'full': 'mll-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mlm': {'full': 'mlm-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'mln': {'full': 'mln-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mlo': {'full': 'mlo-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'mlp': {'full': 'mlp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mlq-Arab': {'full': 'mlq-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'mlq-Latn': {'full': 'mlq-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'mlr': {'full': 'mlr-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mls': {'full': 'mls-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'mlu': {'full': 'mlu-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mlv': {'full': 'mlv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mlw': {'full': 'mlw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mlx': {'full': 'mlx-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mlz': {'full': 'mlz-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mma': {'full': 'mma-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mmb': {'full': 'mmb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mmc': {'full': 'mmc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mmd': {'full': 'mmd-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'mmd-Hans': {'full': 'mmd-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'mmd-Hant': {'full': 'mmd-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'mme': {'full': 'mme-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mmf': {'full': 'mmf-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mmg': {'full': 'mmg-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mmh': {'full': 'mmh-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mmi': {'full': 'mmi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mmj': {'full': 'mmj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mmk': {'full': 'mmk-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'mml': {'full': 'mml-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'mmm': {'full': 'mmm-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mmn': {'full': 'mmn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mmo': {'full': 'mmo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mmp': {'full': 'mmp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mmq': {'full': 'mmq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mmr': {'full': 'mmr-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'mmt': {'full': 'mmt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mmu': {'full': 'mmu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mmv': {'full': 'mmv-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mmw': {'full': 'mmw-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mmx': {'full': 'mmx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mmy': {'full': 'mmy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mmz': {'full': 'mmz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mn': {'full': 'mn-Cyrl-MN', 'region': 'MN', 'script': 'Cyrl', 'suppress': False},
        'mn-Brai': {'full': 'mn-Brai-MN', 'region': 'MN', 'script': 'Brai', 'suppress': False},
        'mn-CN': {'full': 'mn-Mong-CN', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'mn-Mong-MN': {'full': 'mn-Mong-MN', 'region': 'MN', 'script': 'Mong', 'suppress': False},
        'mn-Phag': {'full': 'mn-Phag-CN', 'region': 'CN', 'script': 'Phag', 'suppress': False},
        'mn-Phag-MN': {'full': 'mn-Phag-MN', 'region': 'MN', 'script': 'Phag', 'suppress': False},
        'mn-Tibt': {'full': 'mn-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'mna': {'full': 'mna-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mnb': {'full': 'mnb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mnc-Mong': {'full': 'mnc-Mong-CN', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'mnc-Mong-x-manchu': {'full': 'mnc-Mong-CN-x-manchu', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'mnc-Mong-x-olmanchu': {'full': 'mnc-Mong-CN-x-olmanchu', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'mnd': {'full': 'mnd-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mne': {'full': 'mne-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mnf': {'full': 'mnf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mng': {'full': 'mng-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'mnh': {'full': 'mnh-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mni': {'full': 'mni-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'mni-Brai': {'full': 'mni-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'mni-Mtei': {'full': 'mni-Mtei-IN', 'region': 'IN', 'script': 'Mtei', 'suppress': False},
        'mnj-Arab': {'full': 'mnj-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'mnl': {'full': 'mnl-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mnm': {'full': 'mnm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mnn': {'full': 'mnn-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'mnp': {'full': 'mnp-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'mnq': {'full': 'mnq-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mnr': {'full': 'mnr-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mns': {'full': 'mns-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'mnu': {'full': 'mnu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mnv': {'full': 'mnv-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mnw': {'full': 'mnw-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'mnx': {'full': 'mnx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mny': {'full': 'mny-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'mnz': {'full': 'mnz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'moa': {'full': 'moa-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'moc': {'full': 'moc-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'mod': {'full': 'mod-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'moe': {'full': 'moe-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'mog': {'full': 'mog-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'moh': {'full': 'moh-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'moi': {'full': 'moi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'moj': {'full': 'moj-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mok': {'full': 'mok-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mom': {'full': 'mom-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'moo': {'full': 'moo-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'mop': {'full': 'mop-Latn-BZ', 'region': 'BZ', 'script': 'Latn', 'suppress': False},
        'moq': {'full': 'moq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mor': {'full': 'mor-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'mos': {'full': 'mos-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'mos-Brai': {'full': 'mos-Brai-BF', 'region': 'BF', 'script': 'Brai', 'suppress': False},
        'mot': {'full': 'mot-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'mou': {'full': 'mou-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mov': {'full': 'mov-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mow': {'full': 'mow-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'mox': {'full': 'mox-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'moy': {'full': 'moy-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'moz': {'full': 'moz-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mpa': {'full': 'mpa-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mpb': {'full': 'mpb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mpc': {'full': 'mpc-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mpd': {'full': 'mpd-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mpe': {'full': 'mpe-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'mpe-Ethi': {'full': 'mpe-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'mpg': {'full': 'mpg-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mph': {'full': 'mph-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mpi': {'full': 'mpi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mpj': {'full': 'mpj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mpk': {'full': 'mpk-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mpl': {'full': 'mpl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpm': {'full': 'mpm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mpn': {'full': 'mpn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpo': {'full': 'mpo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpp': {'full': 'mpp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpq': {'full': 'mpq-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mpr': {'full': 'mpr-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mps': {'full': 'mps-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpt': {'full': 'mpt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpu': {'full': 'mpu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mpv': {'full': 'mpv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpw': {'full': 'mpw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mpx': {'full': 'mpx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mpy': {'full': 'mpy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mpz': {'full': 'mpz-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'mqa': {'full': 'mqa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqb': {'full': 'mqb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mqc': {'full': 'mqc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqe': {'full': 'mqe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mqf': {'full': 'mqf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqg': {'full': 'mqg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqh': {'full': 'mqh-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mqi': {'full': 'mqi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqj': {'full': 'mqj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqk': {'full': 'mqk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mql': {'full': 'mql-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'mqm': {'full': 'mqm-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'mqn': {'full': 'mqn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqo': {'full': 'mqo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqp': {'full': 'mqp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqq': {'full': 'mqq-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mqr': {'full': 'mqr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqs': {'full': 'mqs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqt': {'full': 'mqt-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'mqu': {'full': 'mqu-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mqv': {'full': 'mqv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mqw': {'full': 'mqw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mqx': {'full': 'mqx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqx-Bugi': {'full': 'mqx-Bugi-ID', 'region': 'ID', 'script': 'Bugi', 'suppress': False},
        'mqy': {'full': 'mqy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mqz': {'full': 'mqz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mr': {'full': 'mr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': True},
        'mr-Brai': {'full': 'mr-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'mr-Modi': {'full': 'mr-Modi-IN', 'region': 'IN', 'script': 'Modi', 'suppress': False},
        'mra': {'full': 'mra-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'mrb': {'full': 'mrb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mrc': {'full': 'mrc-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mrd': {'full': 'mrd-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'mre': {'full': 'mre-Zxxx-US', 'region': 'US', 'script': 'Zxxx', 'suppress': False},
        'mrf': {'full': 'mrf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mrg': {'full': 'mrg-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'mrg-Beng': {'full': 'mrg-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'mrg-Deva': {'full': 'mrg-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mrh': {'full': 'mrh-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'mrj': {'full': 'mrj-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'mrk': {'full': 'mrk-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'mrl': {'full': 'mrl-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'mrm': {'full': 'mrm-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mrn': {'full': 'mrn-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mro': {'full': 'mro-Mroo-BD', 'region': 'BD', 'script': 'Mroo', 'suppress': False},
        'mro-Latn': {'full': 'mro-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'mrp': {'full': 'mrp-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mrq': {'full': 'mrq-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'mrr': {'full': 'mrr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mrs': {'full': 'mrs-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mrt': {'full': 'mrt-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mru': {'full': 'mru-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mrv': {'full': 'mrv-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'mrw': {'full': 'mrw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mrx': {'full': 'mrx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mry': {'full': 'mry-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mrz': {'full': 'mrz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ms': {'full': 'ms-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': True},
        'ms-Arab': {'full': 'ms-Arab-MY', 'region': 'MY', 'script': 'Arab', 'suppress': False},
        'ms-BN': {'full': 'ms-Latn-BN', 'region': 'BN', 'script': 'Latn', 'suppress': True},
        'ms-Brai': {'full': 'ms-Brai-MY', 'region': 'MY', 'script': 'Brai', 'suppress': False},
        'ms-CC': {'full': 'ms-Arab-CC', 'region': 'CC', 'script': 'Arab', 'suppress': False},
        'ms-ID': {'full': 'ms-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'ms-SG': {'full': 'ms-Latn-SG', 'region': 'SG', 'script': 'Latn', 'suppress': True},
        'msb': {'full': 'msb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'msc': {'full': 'msc-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'msd': {'full': 'msd-Zxxx-MX', 'region': 'MX', 'script': 'Zxxx', 'suppress': False},
        'mse': {'full': 'mse-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'msf': {'full': 'msf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'msg': {'full': 'msg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'msh': {'full': 'msh-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'msi': {'full': 'msi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'msj': {'full': 'msj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'msk': {'full': 'msk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'msl': {'full': 'msl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'msm': {'full': 'msm-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'msn': {'full': 'msn-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mso': {'full': 'mso-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'msp': {'full': 'msp-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'msq': {'full': 'msq-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'msr': {'full': 'msr-Zxxx-MN', 'region': 'MN', 'script': 'Zxxx', 'suppress': False},
        'mss': {'full': 'mss-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'msu': {'full': 'msu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'msv': {'full': 'msv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'msw': {'full': 'msw-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'msx': {'full': 'msx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'msy': {'full': 'msy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'msz': {'full': 'msz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mt': {'full': 'mt-Latn-MT', 'region': 'MT', 'script': 'Latn', 'suppress': True},
        'mt-Arab': {'full': 'mt-Arab-MT', 'region': 'MT', 'script': 'Arab', 'suppress': False},
        'mt-Brai': {'full': 'mt-Brai-MT', 'region': 'MT', 'script': 'Brai', 'suppress': False},
        'mta': {'full': 'mta-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mtb': {'full': 'mtb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'mtc': {'full': 'mtc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mtd': {'full': 'mtd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mte': {'full': 'mte-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mtf': {'full': 'mtf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mtg': {'full': 'mtg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mth': {'full': 'mth-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mti': {'full': 'mti-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mtj': {'full': 'mtj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mtk': {'full': 'mtk-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mtl': {'full': 'mtl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mtm': {'full': 'mtm-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'mtn': {'full': 'mtn-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'mto': {'full': 'mto-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mtp': {'full': 'mtp-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'mtq': {'full': 'mtq-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'mtr': {'full': 'mtr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mts': {'full': 'mts-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'mtt': {'full': 'mtt-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mtu': {'full': 'mtu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mtv': {'full': 'mtv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mtw': {'full': 'mtw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'mtx': {'full': 'mtx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mty': {'full': 'mty-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mua': {'full': 'mua-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mub': {'full': 'mub-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'muc': {'full': 'muc-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mud': {'full': 'mud-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'mue': {'full': 'mue-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'mug': {'full': 'mug-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'muh': {'full': 'muh-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mui': {'full': 'mui-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'muj': {'full': 'muj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'muk': {'full': 'muk-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'mul': {'full': 'mul-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'mum': {'full': 'mum-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'muo': {'full': 'muo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'muq': {'full': 'muq-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'mur': {'full': 'mur-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mur-Arab': {'full': 'mur-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'mus': {'full': 'mus-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'mut': {'full': 'mut-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'muu': {'full': 'muu-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'muv': {'full': 'muv-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'mux': {'full': 'mux-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'muy': {'full': 'muy-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'muz': {'full': 'muz-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'muz-Latn': {'full': 'muz-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'mva': {'full': 'mva-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mvb': {'full': 'mvb-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'mvd': {'full': 'mvd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mve-Arab': {'full': 'mve-Arab-PK-x-sindhi', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'mve-Arab-x-urdu': {'full': 'mve-Arab-PK-x-urdu', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'mvf': {'full': 'mvf-Mong-CN', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'mvf-Phag': {'full': 'mvf-Phag-CN', 'region': 'CN', 'script': 'Phag', 'suppress': False},
        'mvg': {'full': 'mvg-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mvh': {'full': 'mvh-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mvi': {'full': 'mvi-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'mvk': {'full': 'mvk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mvl': {'full': 'mvl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mvm': {'full': 'mvm-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'mvn': {'full': 'mvn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mvo': {'full': 'mvo-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'mvp': {'full': 'mvp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mvq': {'full': 'mvq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mvr': {'full': 'mvr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mvs': {'full': 'mvs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mvt': {'full': 'mvt-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mvu': {'full': 'mvu-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mvv': {'full': 'mvv-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mvw': {'full': 'mvw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mvx': {'full': 'mvx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mvy': {'full': 'mvy-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'mvz-Arab': {'full': 'mvz-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'mwa': {'full': 'mwa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mwb': {'full': 'mwb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mwc': {'full': 'mwc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mwe': {'full': 'mwe-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mwf': {'full': 'mwf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mwg': {'full': 'mwg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mwh': {'full': 'mwh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mwi': {'full': 'mwi-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mwk': {'full': 'mwk-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'mwl': {'full': 'mwl-Latn-PT', 'region': 'PT', 'script': 'Latn', 'suppress': False},
        'mwm': {'full': 'mwm-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'mwn': {'full': 'mwn-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'mwo': {'full': 'mwo-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mwp': {'full': 'mwp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'mwq': {'full': 'mwq-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'mwr': {'full': 'mwr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'mwr-Mahj': {'full': 'mwr-Mahj-IN', 'region': 'IN', 'script': 'Mahj', 'suppress': False},
        'mws': {'full': 'mws-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'mwt': {'full': 'mwt-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'mwt-Thai': {'full': 'mwt-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'mwu': {'full': 'mwu-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'mwv': {'full': 'mwv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mww': {'full': 'mww-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'mww-Hmng': {'full': 'mww-Hmng-CN', 'region': 'CN', 'script': 'Hmng', 'suppress': False},
        'mww-Laoo': {'full': 'mww-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'mww-Plrd': {'full': 'mww-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'mww-Thai': {'full': 'mww-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'mwx': {'full': 'mwx-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mwy': {'full': 'mwy-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'mwz': {'full': 'mwz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mxa': {'full': 'mxa-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxb': {'full': 'mxb-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxc': {'full': 'mxc-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': False},
        'mxd': {'full': 'mxd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mxe': {'full': 'mxe-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'mxf': {'full': 'mxf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mxg': {'full': 'mxg-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'mxh': {'full': 'mxh-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mxi': {'full': 'mxi-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'mxj': {'full': 'mxj-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'mxk': {'full': 'mxk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mxl': {'full': 'mxl-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'mxm': {'full': 'mxm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mxn': {'full': 'mxn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mxo': {'full': 'mxo-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'mxp': {'full': 'mxp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxq': {'full': 'mxq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxr': {'full': 'mxr-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mxs': {'full': 'mxs-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxt': {'full': 'mxt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxu': {'full': 'mxu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mxv': {'full': 'mxv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxw': {'full': 'mxw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mxx': {'full': 'mxx-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'mxy': {'full': 'mxy-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mxz': {'full': 'mxz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'my': {'full': 'my-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': True},
        'my-Brai': {'full': 'my-Brai-MM', 'region': 'MM', 'script': 'Brai', 'suppress': False},
        'myb': {'full': 'myb-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'myc': {'full': 'myc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'mye': {'full': 'mye-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'myf': {'full': 'myf-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'myg': {'full': 'myg-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'myh': {'full': 'myh-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'myi': {'full': 'myi-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'myj': {'full': 'myj-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'myk': {'full': 'myk-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'myl': {'full': 'myl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mym': {'full': 'mym-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'mym-Latn': {'full': 'mym-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'myo': {'full': 'myo-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'myp': {'full': 'myp-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'myr': {'full': 'myr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'mys': {'full': 'mys-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'myu': {'full': 'myu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'myv': {'full': 'myv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'myw': {'full': 'myw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'myx': {'full': 'myx-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'myy': {'full': 'myy-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'myz': {'full': 'myz-Mand-IR', 'region': 'IR', 'script': 'Mand', 'suppress': False},
        'mza': {'full': 'mza-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mzb-Arab': {'full': 'mzb-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': False},
        'mzb-Latn': {'full': 'mzb-Latn-DZ', 'region': 'DZ', 'script': 'Latn', 'suppress': False},
        'mzb-Tfng': {'full': 'mzb-Tfng-DZ', 'region': 'DZ', 'script': 'Tfng', 'suppress': False},
        'mzc': {'full': 'mzc-Zxxx-MG', 'region': 'MG', 'script': 'Zxxx', 'suppress': False},
        'mzd': {'full': 'mzd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'mze': {'full': 'mze-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mzg': {'full': 'mzg-Zxxx-VA', 'region': 'VA', 'script': 'Zxxx', 'suppress': False},
        'mzh': {'full': 'mzh-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'mzi': {'full': 'mzi-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mzj': {'full': 'mzj-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'mzk': {'full': 'mzk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mzl': {'full': 'mzl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'mzm': {'full': 'mzm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'mzn': {'full': 'mzn-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'mzo': {'full': 'mzo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mzp': {'full': 'mzp-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'mzq': {'full': 'mzq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'mzr': {'full': 'mzr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'mzs': {'full': 'mzs-Zyyy-MO', 'region': 'MO', 'script': 'Zyyy', 'suppress': False},
        'mzt': {'full': 'mzt-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'mzu': {'full': 'mzu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'mzv': {'full': 'mzv-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'mzw': {'full': 'mzw-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'mzx': {'full': 'mzx-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'mzy': {'full': 'mzy-Zxxx-MZ', 'region': 'MZ', 'script': 'Zxxx', 'suppress': False},
        'mzz': {'full': 'mzz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'na': {'full': 'na-Latn-NR', 'region': 'NR', 'script': 'Latn', 'suppress': True},
        'naa': {'full': 'naa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nab': {'full': 'nab-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'nac': {'full': 'nac-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nae': {'full': 'nae-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'naf': {'full': 'naf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nag': {'full': 'nag-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'naj': {'full': 'naj-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'nak': {'full': 'nak-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nal': {'full': 'nal-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nam': {'full': 'nam-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nan': {'full': 'nan-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'nan-Bopo': {'full': 'nan-Bopo-TW', 'region': 'TW', 'script': 'Bopo', 'suppress': False},
        'nan-Kana': {'full': 'nan-Kana-TW', 'region': 'TW', 'script': 'Kana', 'suppress': False},
        'nan-Latn': {'full': 'nan-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'nan-Latn-x-transpoj': {'full': 'nan-Latn-TW-x-transpoj', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'nao': {'full': 'nao-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'nap': {'full': 'nap-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'naq': {'full': 'naq-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'nar': {'full': 'nar-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nas': {'full': 'nas-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nat': {'full': 'nat-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'naw': {'full': 'naw-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nax': {'full': 'nax-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nay': {'full': 'nay-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'naz': {'full': 'naz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nb': {'full': 'nb-Latn-NO', 'region': 'NO', 'script': 'Latn', 'suppress': True},
        'nba': {'full': 'nba-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nbb': {'full': 'nbb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nbc': {'full': 'nbc-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nbd': {'full': 'nbd-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nbe': {'full': 'nbe-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nbg': {'full': 'nbg-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'nbh': {'full': 'nbh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nbi': {'full': 'nbi-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nbj': {'full': 'nbj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nbk': {'full': 'nbk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nbm': {'full': 'nbm-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'nbn': {'full': 'nbn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nbo': {'full': 'nbo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nbp': {'full': 'nbp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nbq': {'full': 'nbq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nbr': {'full': 'nbr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nbs': {'full': 'nbs-Zxxx-NA', 'region': 'NA', 'script': 'Zxxx', 'suppress': False},
        'nbt-Deva': {'full': 'nbt-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'nbt-Latn': {'full': 'nbt-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nbu': {'full': 'nbu-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nbv': {'full': 'nbv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nbw': {'full': 'nbw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nby': {'full': 'nby-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nca': {'full': 'nca-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ncb-Deva': {'full': 'ncb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'ncb-Latn': {'full': 'ncb-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'ncc': {'full': 'ncc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ncd': {'full': 'ncd-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'nce': {'full': 'nce-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ncf': {'full': 'ncf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ncg': {'full': 'ncg-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'nch': {'full': 'nch-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nci': {'full': 'nci-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ncj': {'full': 'ncj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nck': {'full': 'nck-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ncl': {'full': 'ncl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ncm': {'full': 'ncm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ncn': {'full': 'ncn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nco': {'full': 'nco-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ncq': {'full': 'ncq-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'ncq-Thai': {'full': 'ncq-Thai-LA', 'region': 'LA', 'script': 'Thai', 'suppress': False},
        'ncr': {'full': 'ncr-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ncs': {'full': 'ncs-Zxxx-NI', 'region': 'NI', 'script': 'Zxxx', 'suppress': False},
        'nct-Beng': {'full': 'nct-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'nct-Latn': {'full': 'nct-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'ncu': {'full': 'ncu-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ncx': {'full': 'ncx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ncz': {'full': 'ncz-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nd': {'full': 'nd-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': True},
        'nda': {'full': 'nda-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'ndb': {'full': 'ndb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ndc': {'full': 'ndc-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'ndd': {'full': 'ndd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ndf': {'full': 'ndf-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'ndg': {'full': 'ndg-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ndh': {'full': 'ndh-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ndi': {'full': 'ndi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ndj': {'full': 'ndj-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ndk': {'full': 'ndk-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ndl': {'full': 'ndl-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ndm': {'full': 'ndm-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'ndn': {'full': 'ndn-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'ndp': {'full': 'ndp-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'ndq': {'full': 'ndq-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'ndr': {'full': 'ndr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nds': {'full': 'nds-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': True},
        'nds-NL': {'full': 'nds-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': True},
        'ndt': {'full': 'ndt-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ndu': {'full': 'ndu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ndv': {'full': 'ndv-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'ndw': {'full': 'ndw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ndx': {'full': 'ndx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ndy': {'full': 'ndy-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'ndy-TD': {'full': 'ndy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'ndz': {'full': 'ndz-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'ne': {'full': 'ne-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': True},
        'ne-Brai': {'full': 'ne-Brai-NP', 'region': 'NP', 'script': 'Brai', 'suppress': False},
        'ne-IN': {'full': 'ne-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': True},
        'ne-Newa': {'full': 'ne-Newa-NP', 'region': 'NP', 'script': 'Newa', 'suppress': False},
        'nea': {'full': 'nea-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'neb': {'full': 'neb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'nec': {'full': 'nec-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ned': {'full': 'ned-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nee': {'full': 'nee-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'nef': {'full': 'nef-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'neg': {'full': 'neg-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'neh': {'full': 'neh-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'nei': {'full': 'nei-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'nej': {'full': 'nej-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nek': {'full': 'nek-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'nem': {'full': 'nem-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'nen': {'full': 'nen-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'neo': {'full': 'neo-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'neq': {'full': 'neq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ner': {'full': 'ner-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nes': {'full': 'nes-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'net': {'full': 'net-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'neu': {'full': 'neu-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'nev': {'full': 'nev-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'new': {'full': 'new-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'new-Newa': {'full': 'new-Newa-NP', 'region': 'NP', 'script': 'Newa', 'suppress': False},
        'new-Zzzz-x-ranjana': {'full': 'new-Zzzz-NP-x-ranjana', 'region': 'NP', 'script': 'Zzzz', 'suppress': False},
        'nex': {'full': 'nex-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ney': {'full': 'ney-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'nez': {'full': 'nez-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'nfa': {'full': 'nfa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nfd': {'full': 'nfd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nfl': {'full': 'nfl-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'nfr': {'full': 'nfr-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nfu': {'full': 'nfu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ng': {'full': 'ng-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'nga': {'full': 'nga-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ngb': {'full': 'ngb-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ngc': {'full': 'ngc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ngd': {'full': 'ngd-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'nge': {'full': 'nge-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ngg': {'full': 'ngg-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'ngh': {'full': 'ngh-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'ngi': {'full': 'ngi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ngj': {'full': 'ngj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ngk': {'full': 'ngk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ngl': {'full': 'ngl-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'ngm': {'full': 'ngm-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'ngn': {'full': 'ngn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ngo': {'full': 'ngo-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ngp': {'full': 'ngp-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ngq': {'full': 'ngq-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ngr': {'full': 'ngr-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ngs': {'full': 'ngs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ngt': {'full': 'ngt-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'ngu': {'full': 'ngu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ngv': {'full': 'ngv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ngw': {'full': 'ngw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ngx': {'full': 'ngx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ngy': {'full': 'ngy-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ngz': {'full': 'ngz-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'nha': {'full': 'nha-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nhb': {'full': 'nhb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'nhc': {'full': 'nhc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhd': {'full': 'nhd-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'nhe': {'full': 'nhe-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhf': {'full': 'nhf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nhg': {'full': 'nhg-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhh': {'full': 'nhh-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'nhi': {'full': 'nhi-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhk': {'full': 'nhk-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhm': {'full': 'nhm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhn': {'full': 'nhn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nho': {'full': 'nho-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nhp': {'full': 'nhp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhq': {'full': 'nhq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhr': {'full': 'nhr-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'nht': {'full': 'nht-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhu': {'full': 'nhu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nhv': {'full': 'nhv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhw': {'full': 'nhw-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhx': {'full': 'nhx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhy': {'full': 'nhy-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nhz': {'full': 'nhz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nia': {'full': 'nia-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nib': {'full': 'nib-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nid': {'full': 'nid-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nie': {'full': 'nie-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'nif': {'full': 'nif-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nig': {'full': 'nig-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nih': {'full': 'nih-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nii': {'full': 'nii-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nij': {'full': 'nij-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nik': {'full': 'nik-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'nil': {'full': 'nil-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nim': {'full': 'nim-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nin': {'full': 'nin-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nio': {'full': 'nio-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'niq': {'full': 'niq-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'nir': {'full': 'nir-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nis': {'full': 'nis-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nit': {'full': 'nit-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'niu': {'full': 'niu-Latn-NU', 'region': 'NU', 'script': 'Latn', 'suppress': True},
        'niv': {'full': 'niv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'niv-Latn': {'full': 'niv-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'niw': {'full': 'niw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nix': {'full': 'nix-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'niy': {'full': 'niy-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'niz': {'full': 'niz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nja': {'full': 'nja-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'njb': {'full': 'njb-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'njd': {'full': 'njd-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'njh': {'full': 'njh-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nji': {'full': 'nji-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'njj': {'full': 'njj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'njl': {'full': 'njl-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'njm': {'full': 'njm-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'njn': {'full': 'njn-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'njo': {'full': 'njo-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'njr': {'full': 'njr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'njs': {'full': 'njs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'njt': {'full': 'njt-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'nju': {'full': 'nju-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'njx': {'full': 'njx-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'njy': {'full': 'njy-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'njz-Beng': {'full': 'njz-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'njz-Latn': {'full': 'njz-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nka': {'full': 'nka-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'nkb': {'full': 'nkb-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nkc': {'full': 'nkc-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nkd': {'full': 'nkd-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nke': {'full': 'nke-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'nkf': {'full': 'nkf-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nkg': {'full': 'nkg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nkh': {'full': 'nkh-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nki-Beng': {'full': 'nki-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'nki-Latn': {'full': 'nki-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nkj': {'full': 'nkj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nkk': {'full': 'nkk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nkm': {'full': 'nkm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nkn': {'full': 'nkn-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nko': {'full': 'nko-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nkp': {'full': 'nkp-Zyyy-TO', 'region': 'TO', 'script': 'Zyyy', 'suppress': False},
        'nkq': {'full': 'nkq-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nkr': {'full': 'nkr-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'nks': {'full': 'nks-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nkt': {'full': 'nkt-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nku': {'full': 'nku-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'nkv': {'full': 'nkv-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'nkw': {'full': 'nkw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nkx': {'full': 'nkx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nkz': {'full': 'nkz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nl': {'full': 'nl-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': True},
        'nl-AW': {'full': 'nl-Latn-AW', 'region': 'AW', 'script': 'Latn', 'suppress': True},
        'nl-BE': {'full': 'nl-Latn-BE', 'region': 'BE', 'script': 'Latn', 'suppress': True},
        'nl-BQ': {'full': 'nl-Latn-BQ', 'region': 'BQ', 'script': 'Latn', 'suppress': True},
        'nl-Brai': {'full': 'nl-Brai-NL', 'region': 'NL', 'script': 'Brai', 'suppress': False},
        'nl-CW': {'full': 'nl-Latn-CW', 'region': 'CW', 'script': 'Latn', 'suppress': True},
        'nl-SR': {'full': 'nl-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': True},
        'nl-SX': {'full': 'nl-Latn-SX', 'region': 'SX', 'script': 'Latn', 'suppress': True},
        'nla': {'full': 'nla-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nlc': {'full': 'nlc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nle': {'full': 'nle-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'nlg': {'full': 'nlg-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'nli': {'full': 'nli-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'nlj': {'full': 'nlj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nlk': {'full': 'nlk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nll': {'full': 'nll-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'nlm': {'full': 'nlm-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'nlo': {'full': 'nlo-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nlq': {'full': 'nlq-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nlu': {'full': 'nlu-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nlv': {'full': 'nlv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nlw': {'full': 'nlw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nlx': {'full': 'nlx-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'nly': {'full': 'nly-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nlz': {'full': 'nlz-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'nma': {'full': 'nma-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nmb': {'full': 'nmb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nmc': {'full': 'nmc-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'nmd': {'full': 'nmd-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'nme': {'full': 'nme-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nmf': {'full': 'nmf-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nmg': {'full': 'nmg-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nmg-GQ': {'full': 'nmg-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'nmh': {'full': 'nmh-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nmi': {'full': 'nmi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nmj': {'full': 'nmj-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'nmk': {'full': 'nmk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nml': {'full': 'nml-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nmm': {'full': 'nmm-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'nmm-Tibt': {'full': 'nmm-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'nmn': {'full': 'nmn-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'nmo-Beng': {'full': 'nmo-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'nmo-Latn': {'full': 'nmo-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nmp': {'full': 'nmp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nmq': {'full': 'nmq-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': False},
        'nmr': {'full': 'nmr-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nms': {'full': 'nms-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nmt': {'full': 'nmt-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'nmu': {'full': 'nmu-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'nmv': {'full': 'nmv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nmw': {'full': 'nmw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nmx': {'full': 'nmx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nmy': {'full': 'nmy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'nmz': {'full': 'nmz-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'nn': {'full': 'nn-Latn-NO', 'region': 'NO', 'script': 'Latn', 'suppress': True},
        'nna': {'full': 'nna-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nnb': {'full': 'nnb-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nnc': {'full': 'nnc-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'nnd': {'full': 'nnd-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nne': {'full': 'nne-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nnf': {'full': 'nnf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nng-Beng': {'full': 'nng-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'nng-Latn': {'full': 'nng-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nnh': {'full': 'nnh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nni': {'full': 'nni-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nnj': {'full': 'nnj-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'nnk': {'full': 'nnk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nnl': {'full': 'nnl-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nnm': {'full': 'nnm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nnn': {'full': 'nnn-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'nnp-Deva': {'full': 'nnp-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'nnp-Latn': {'full': 'nnp-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nnp-Wcho': {'full': 'nnp-Wcho-IN', 'region': 'IN', 'script': 'Wcho', 'suppress': False},
        'nnq': {'full': 'nnq-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nnr': {'full': 'nnr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nnt': {'full': 'nnt-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nnu': {'full': 'nnu-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nnv': {'full': 'nnv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nnw': {'full': 'nnw-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'nny': {'full': 'nny-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nnz': {'full': 'nnz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'no': {'full': 'no-Latn-NO', 'region': 'NO', 'script': 'Latn', 'suppress': True},
        'noa': {'full': 'noa-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'noc': {'full': 'noc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nod': {'full': 'nod-Lana-TH', 'region': 'TH', 'script': 'Lana', 'suppress': False},
        'nod-Thai': {'full': 'nod-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'noe': {'full': 'noe-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'nof': {'full': 'nof-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nog': {'full': 'nog-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'noh': {'full': 'noh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'noi': {'full': 'noi-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'noj': {'full': 'noj-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'nok': {'full': 'nok-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nol': {'full': 'nol-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nom': {'full': 'nom-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'non': {'full': 'non-Runr-SE', 'region': 'SE', 'script': 'Runr', 'suppress': False},
        'nop': {'full': 'nop-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'noq': {'full': 'noq-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nos': {'full': 'nos-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'not': {'full': 'not-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'nou': {'full': 'nou-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nov': {'full': 'nov-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'now': {'full': 'now-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'noy': {'full': 'noy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'noz': {'full': 'noz-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'npa': {'full': 'npa-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'npb': {'full': 'npb-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'npg': {'full': 'npg-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nph': {'full': 'nph-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'npl': {'full': 'npl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'npn': {'full': 'npn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'npo': {'full': 'npo-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nps': {'full': 'nps-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'npu': {'full': 'npu-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'npx': {'full': 'npx-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'npy': {'full': 'npy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nqg': {'full': 'nqg-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'nqk': {'full': 'nqk-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'nql': {'full': 'nql-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nqm': {'full': 'nqm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nqn': {'full': 'nqn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nqo': {'full': 'nqo-Nkoo-GN', 'region': 'GN', 'script': 'Nkoo', 'suppress': True},
        'nqq': {'full': 'nqq-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nqy': {'full': 'nqy-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nr': {'full': 'nr-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'nr-Brai': {'full': 'nr-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'nra': {'full': 'nra-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'nrb': {'full': 'nrb-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': False},
        'nrc': {'full': 'nrc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'nre': {'full': 'nre-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nrf': {'full': 'nrf-Latn-JE', 'region': 'JE', 'script': 'Latn', 'suppress': False},
        'nrg': {'full': 'nrg-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nri': {'full': 'nri-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nrk': {'full': 'nrk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nrl': {'full': 'nrl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nrm': {'full': 'nrm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'nrn': {'full': 'nrn-Zyyy-GB', 'region': 'GB', 'script': 'Zyyy', 'suppress': False},
        'nrp': {'full': 'nrp-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'nrr': {'full': 'nrr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'nrt': {'full': 'nrt-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nru': {'full': 'nru-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'nrx': {'full': 'nrx-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nrz': {'full': 'nrz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nsa': {'full': 'nsa-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nsb': {'full': 'nsb-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'nsc': {'full': 'nsc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nsd': {'full': 'nsd-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'nse': {'full': 'nse-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'nsf': {'full': 'nsf-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'nsg': {'full': 'nsg-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nsh': {'full': 'nsh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nsi': {'full': 'nsi-Zxxx-NG', 'region': 'NG', 'script': 'Zxxx', 'suppress': False},
        'nsk': {'full': 'nsk-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'nsk-Latn': {'full': 'nsk-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'nsl': {'full': 'nsl-Zxxx-NO', 'region': 'NO', 'script': 'Zxxx', 'suppress': False},
        'nsm': {'full': 'nsm-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nsn': {'full': 'nsn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nso': {'full': 'nso-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'nso-Brai': {'full': 'nso-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'nsp': {'full': 'nsp-Zxxx-NP', 'region': 'NP', 'script': 'Zxxx', 'suppress': False},
        'nsq': {'full': 'nsq-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'nsr': {'full': 'nsr-Zxxx-CA', 'region': 'CA', 'script': 'Zxxx', 'suppress': False},
        'nss': {'full': 'nss-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nst': {'full': 'nst-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nst-x-moshang': {'full': 'nst-Latn-MM-x-moshang', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nsu': {'full': 'nsu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nsv': {'full': 'nsv-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'nsw': {'full': 'nsw-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nsx': {'full': 'nsx-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nsy': {'full': 'nsy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nsz': {'full': 'nsz-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ntd': {'full': 'ntd-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'nte': {'full': 'nte-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'ntg': {'full': 'ntg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nti': {'full': 'nti-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'ntj': {'full': 'ntj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ntk': {'full': 'ntk-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ntm': {'full': 'ntm-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'nto': {'full': 'nto-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ntp': {'full': 'ntp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ntr': {'full': 'ntr-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ntu': {'full': 'ntu-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ntw': {'full': 'ntw-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ntx': {'full': 'ntx-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nty': {'full': 'nty-Yiii-VN', 'region': 'VN', 'script': 'Yiii', 'suppress': False},
        'ntz': {'full': 'ntz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'nua': {'full': 'nua-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'nuc': {'full': 'nuc-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'nud': {'full': 'nud-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nue': {'full': 'nue-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nuf': {'full': 'nuf-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'nug': {'full': 'nug-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nuh': {'full': 'nuh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nui': {'full': 'nui-Latn-GQ', 'region': 'GQ', 'script': 'Latn', 'suppress': False},
        'nuj': {'full': 'nuj-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'nuk': {'full': 'nuk-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'nul': {'full': 'nul-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'num': {'full': 'num-Latn-TO', 'region': 'TO', 'script': 'Latn', 'suppress': False},
        'nun': {'full': 'nun-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'nuo': {'full': 'nuo-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'nup': {'full': 'nup-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'nup-Arab': {'full': 'nup-Arab-NG', 'region': 'NG', 'script': 'Arab', 'suppress': False},
        'nuq': {'full': 'nuq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nur': {'full': 'nur-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nus': {'full': 'nus-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'nut': {'full': 'nut-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'nuu': {'full': 'nuu-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nuv': {'full': 'nuv-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'nuw': {'full': 'nuw-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'nux': {'full': 'nux-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nuy': {'full': 'nuy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nuz': {'full': 'nuz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'nv': {'full': 'nv-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'nvh': {'full': 'nvh-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nvm': {'full': 'nvm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nvo': {'full': 'nvo-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nwa': {'full': 'nwa-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nwb': {'full': 'nwb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'nwc': {'full': 'nwc-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'nwe': {'full': 'nwe-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nwg': {'full': 'nwg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nwi': {'full': 'nwi-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'nwm': {'full': 'nwm-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'nwo': {'full': 'nwo-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nwr': {'full': 'nwr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nwx': {'full': 'nwx-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'nwy': {'full': 'nwy-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'nxa': {'full': 'nxa-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'nxd': {'full': 'nxd-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nxe': {'full': 'nxe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nxg': {'full': 'nxg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nxi': {'full': 'nxi-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nxk': {'full': 'nxk-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'nxl': {'full': 'nxl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'nxm': {'full': 'nxm-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'nxn': {'full': 'nxn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nxo': {'full': 'nxo-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'nxq': {'full': 'nxq-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'nxq-Lisu': {'full': 'nxq-Lisu-CN', 'region': 'CN', 'script': 'Lisu', 'suppress': False},
        'nxq-Nkgb': {'full': 'nxq-Nkgb-CN', 'region': 'CN', 'script': 'Nkgb', 'suppress': False},
        'nxr': {'full': 'nxr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'nxx': {'full': 'nxx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ny': {'full': 'ny-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': True},
        'ny-Brai': {'full': 'ny-Brai-MW', 'region': 'MW', 'script': 'Brai', 'suppress': False},
        'nyb': {'full': 'nyb-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nyc': {'full': 'nyc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nyd': {'full': 'nyd-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'nye': {'full': 'nye-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nyf': {'full': 'nyf-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'nyg': {'full': 'nyg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nyh': {'full': 'nyh-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nyi': {'full': 'nyi-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'nyj': {'full': 'nyj-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nyk': {'full': 'nyk-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'nyl': {'full': 'nyl-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'nym': {'full': 'nym-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nyn': {'full': 'nyn-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'nyo': {'full': 'nyo-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'nyp': {'full': 'nyp-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'nyq': {'full': 'nyq-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'nyr': {'full': 'nyr-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'nys': {'full': 'nys-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nyt': {'full': 'nyt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nyu': {'full': 'nyu-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'nyv': {'full': 'nyv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nyw': {'full': 'nyw-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'nyx': {'full': 'nyx-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'nyy': {'full': 'nyy-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'nza': {'full': 'nza-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'nzb': {'full': 'nzb-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'nzd': {'full': 'nzd-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'nzi': {'full': 'nzi-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'nzk': {'full': 'nzk-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'nzm': {'full': 'nzm-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'nzs': {'full': 'nzs-Zxxx-NZ', 'region': 'NZ', 'script': 'Zxxx', 'suppress': False},
        'nzu': {'full': 'nzu-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'nzy': {'full': 'nzy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'nzz': {'full': 'nzz-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'oaa': {'full': 'oaa-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'oac': {'full': 'oac-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'oar': {'full': 'oar-Syrc-SY', 'region': 'SY', 'script': 'Syrc', 'suppress': False},
        'oav': {'full': 'oav-Geor-GE', 'region': 'GE', 'script': 'Geor', 'suppress': False},
        'obi': {'full': 'obi-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'obk': {'full': 'obk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'obl': {'full': 'obl-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'obm': {'full': 'obm-Phnx-JO', 'region': 'JO', 'script': 'Phnx', 'suppress': False},
        'obo': {'full': 'obo-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'obr': {'full': 'obr-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'obt': {'full': 'obt-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'obu': {'full': 'obu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'oc': {'full': 'oc-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'oca': {'full': 'oca-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'och': {'full': 'och-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'oco': {'full': 'oco-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'ocu': {'full': 'ocu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'oda': {'full': 'oda-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'odk': {'full': 'odk-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'odt': {'full': 'odt-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'odu': {'full': 'odu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ofo': {'full': 'ofo-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ofs': {'full': 'ofs-Zyyy-NL', 'region': 'NL', 'script': 'Zyyy', 'suppress': False},
        'ofu': {'full': 'ofu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ogb': {'full': 'ogb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ogc': {'full': 'ogc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'oge': {'full': 'oge-Geok-GE', 'region': 'GE', 'script': 'Geok', 'suppress': False},
        'ogg': {'full': 'ogg-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ogo': {'full': 'ogo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ogu': {'full': 'ogu-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'oht': {'full': 'oht-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'ohu-Hung': {'full': 'ohu-Hung-HU', 'region': 'HU', 'script': 'Hung', 'suppress': False},
        'ohu-Latn': {'full': 'ohu-Latn-HU', 'region': 'HU', 'script': 'Latn', 'suppress': False},
        'oia': {'full': 'oia-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'oin': {'full': 'oin-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'oj': {'full': 'oj-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'oj-Cans': {'full': 'oj-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'ojb': {'full': 'ojb-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ojb-Cans': {'full': 'ojb-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'ojc': {'full': 'ojc-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ojp': {'full': 'ojp-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'ojs': {'full': 'ojs-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'ojs-Latn': {'full': 'ojs-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ojv': {'full': 'ojv-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ojw': {'full': 'ojw-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ojw-Cans': {'full': 'ojw-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'oka': {'full': 'oka-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'oka-Dupl': {'full': 'oka-Dupl-CA', 'region': 'CA', 'script': 'Dupl', 'suppress': False},
        'okb': {'full': 'okb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'okd': {'full': 'okd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'oke': {'full': 'oke-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'okg': {'full': 'okg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'okh': {'full': 'okh-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'oki': {'full': 'oki-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'okj': {'full': 'okj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'okk': {'full': 'okk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'okl': {'full': 'okl-Zxxx-XX', 'region': 'XX', 'script': 'Zxxx', 'suppress': False},
        'okm': {'full': 'okm-Zyyy-KR', 'region': 'KR', 'script': 'Zyyy', 'suppress': False},
        'okn': {'full': 'okn-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'oko': {'full': 'oko-Zyyy-KR', 'region': 'KR', 'script': 'Zyyy', 'suppress': False},
        'okr': {'full': 'okr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'oks': {'full': 'oks-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'oku': {'full': 'oku-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'okv': {'full': 'okv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'okx': {'full': 'okx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ola': {'full': 'ola-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'old': {'full': 'old-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ole': {'full': 'ole-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'olk': {'full': 'olk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'olm': {'full': 'olm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'olo': {'full': 'olo-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'olr': {'full': 'olr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'olt': {'full': 'olt-Latn-LT', 'region': 'LT', 'script': 'Latn', 'suppress': False},
        'olu': {'full': 'olu-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'om': {'full': 'om-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': True},
        'om-Arab': {'full': 'om-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'om-Ethi': {'full': 'om-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'om-KE': {'full': 'om-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': True},
        'oma': {'full': 'oma-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'omb': {'full': 'omb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'omc': {'full': 'omc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'omg': {'full': 'omg-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'omi': {'full': 'omi-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'omk': {'full': 'omk-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'oml': {'full': 'oml-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'omn': {'full': 'omn-Lina-XX', 'region': 'XX', 'script': 'Lina', 'suppress': False},
        'omo': {'full': 'omo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'omp': {'full': 'omp-Mtei-IN', 'region': 'IN', 'script': 'Mtei', 'suppress': False},
        'omr': {'full': 'omr-Modi-IN', 'region': 'IN', 'script': 'Modi', 'suppress': False},
        'omt': {'full': 'omt-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'omu': {'full': 'omu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'omw': {'full': 'omw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'omx': {'full': 'omx-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'ona': {'full': 'ona-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'onb': {'full': 'onb-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'one': {'full': 'one-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ong': {'full': 'ong-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'oni': {'full': 'oni-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'onj': {'full': 'onj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'onk': {'full': 'onk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'onn': {'full': 'onn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ono': {'full': 'ono-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'onp-Deva': {'full': 'onp-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'onp-Latn': {'full': 'onp-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'onr': {'full': 'onr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ons': {'full': 'ons-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ont': {'full': 'ont-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'onu': {'full': 'onu-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'onw': {'full': 'onw-Copt-SD-x-olnubian', 'region': 'SD', 'script': 'Copt', 'suppress': False},
        'onx': {'full': 'onx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ood': {'full': 'ood-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'oog': {'full': 'oog-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'oon': {'full': 'oon-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'oor': {'full': 'oor-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'oos': {'full': 'oos-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'opa': {'full': 'opa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'opk': {'full': 'opk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'opm': {'full': 'opm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'opo': {'full': 'opo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'opt': {'full': 'opt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'opy': {'full': 'opy-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'or': {'full': 'or-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': True},
        'or-Brai': {'full': 'or-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'ora': {'full': 'ora-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'orc': {'full': 'orc-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'ore': {'full': 'ore-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'org': {'full': 'org-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'orh': {'full': 'orh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'orn': {'full': 'orn-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'oro': {'full': 'oro-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'orr': {'full': 'orr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ors': {'full': 'ors-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'ort': {'full': 'ort-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'oru': {'full': 'oru-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'orv': {'full': 'orv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'orw': {'full': 'orw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'orx': {'full': 'orx-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'orz': {'full': 'orz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'os': {'full': 'os-Cyrl-GE', 'region': 'GE', 'script': 'Cyrl', 'suppress': False},
        'os-Geor': {'full': 'os-Geor-RU', 'region': 'RU', 'script': 'Geor', 'suppress': False},
        'os-Latn': {'full': 'os-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'os-RU': {'full': 'os-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'osa': {'full': 'osa-Osge-US', 'region': 'US', 'script': 'Osge', 'suppress': False},
        'osa-Latn': {'full': 'osa-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'osc': {'full': 'osc-Ital-IT', 'region': 'IT', 'script': 'Ital', 'suppress': False},
        'osc-Latn': {'full': 'osc-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'osi': {'full': 'osi-Java-ID', 'region': 'ID', 'script': 'Java', 'suppress': False},
        'oso': {'full': 'oso-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'osp': {'full': 'osp-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'ost': {'full': 'ost-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'osu': {'full': 'osu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'osx': {'full': 'osx-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'ota': {'full': 'ota-Arab-TR', 'region': 'TR', 'script': 'Arab', 'suppress': False},
        'otb': {'full': 'otb-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'otd': {'full': 'otd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ote': {'full': 'ote-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'oti': {'full': 'oti-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'otk': {'full': 'otk-Orkh-MN', 'region': 'MN', 'script': 'Orkh', 'suppress': False},
        'otl': {'full': 'otl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'otm': {'full': 'otm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'otn': {'full': 'otn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'otq': {'full': 'otq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'otr': {'full': 'otr-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ots': {'full': 'ots-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ott': {'full': 'ott-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'otu': {'full': 'otu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'otw': {'full': 'otw-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'otx': {'full': 'otx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'oty': {'full': 'oty-Gran-IN', 'region': 'IN', 'script': 'Gran', 'suppress': False},
        'otz': {'full': 'otz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'oua': {'full': 'oua-Zyyy-DZ', 'region': 'DZ', 'script': 'Zyyy', 'suppress': False},
        'oub': {'full': 'oub-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'oue': {'full': 'oue-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'oui': {'full': 'oui-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'oui-Mong': {'full': 'oui-Mong-XX', 'region': 'XX', 'script': 'Mong', 'suppress': False},
        'oum': {'full': 'oum-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ovd': {'full': 'ovd-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'owi': {'full': 'owi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'owl': {'full': 'owl-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'oyb': {'full': 'oyb-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'oyd': {'full': 'oyd-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'oym': {'full': 'oym-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'oyy': {'full': 'oyy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ozm': {'full': 'ozm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'pa': {'full': 'pa-Guru-IN', 'region': 'IN', 'script': 'Guru', 'suppress': True},
        'pa-Khoj': {'full': 'pa-Khoj-IN', 'region': 'IN', 'script': 'Khoj', 'suppress': False},
        'pa-Mahj': {'full': 'pa-Mahj-IN', 'region': 'IN', 'script': 'Mahj', 'suppress': False},
        'pa-PK': {'full': 'pa-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'pab': {'full': 'pab-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pac': {'full': 'pac-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'pac-Laoo-x-diacado': {'full': 'pac-Laoo-LA-x-diacado', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'pac-x-diacado': {'full': 'pac-Latn-VN-x-diacado', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'pad': {'full': 'pad-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pae': {'full': 'pae-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'paf': {'full': 'paf-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pag': {'full': 'pag-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'pag-Brai': {'full': 'pag-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'pah': {'full': 'pah-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pai': {'full': 'pai-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pak': {'full': 'pak-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pal': {'full': 'pal-Phli-IR', 'region': 'IR', 'script': 'Phli', 'suppress': False},
        'pal-Phlp': {'full': 'pal-Phlp-CN', 'region': 'CN', 'script': 'Phlp', 'suppress': False},
        'pam': {'full': 'pam-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'pam-Brai': {'full': 'pam-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'pao': {'full': 'pao-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pap': {'full': 'pap-Latn-AW', 'region': 'AW', 'script': 'Latn', 'suppress': False},
        'paq': {'full': 'paq-Zyyy-TJ', 'region': 'TJ', 'script': 'Zyyy', 'suppress': False},
        'par': {'full': 'par-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pas': {'full': 'pas-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pat': {'full': 'pat-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pau': {'full': 'pau-Latn-PW', 'region': 'PW', 'script': 'Latn', 'suppress': False},
        'pav': {'full': 'pav-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'paw': {'full': 'paw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pax': {'full': 'pax-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pay': {'full': 'pay-Latn-HN', 'region': 'HN', 'script': 'Latn', 'suppress': False},
        'paz': {'full': 'paz-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pbb': {'full': 'pbb-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'pbc': {'full': 'pbc-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'pbe': {'full': 'pbe-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pbf': {'full': 'pbf-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pbg': {'full': 'pbg-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'pbh': {'full': 'pbh-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'pbi': {'full': 'pbi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'pbl': {'full': 'pbl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pbm': {'full': 'pbm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pbn': {'full': 'pbn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pbo': {'full': 'pbo-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'pbp': {'full': 'pbp-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'pbr': {'full': 'pbr-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'pbs': {'full': 'pbs-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pbt': {'full': 'pbt-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'pbv': {'full': 'pbv-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'pby': {'full': 'pby-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pca': {'full': 'pca-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pcb': {'full': 'pcb-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'pcc-Hani': {'full': 'pcc-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'pcc-Latn': {'full': 'pcc-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'pcd': {'full': 'pcd-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'pce': {'full': 'pce-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'pcf': {'full': 'pcf-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'pcg-Knda': {'full': 'pcg-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'pcg-Mlym': {'full': 'pcg-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'pcg-Taml': {'full': 'pcg-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'pch': {'full': 'pch-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'pci-Deva': {'full': 'pci-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'pci-Orya': {'full': 'pci-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'pcj': {'full': 'pcj-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'pck': {'full': 'pck-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'pcl': {'full': 'pcl-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'pcm': {'full': 'pcm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pcn': {'full': 'pcn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pcp': {'full': 'pcp-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'pcw': {'full': 'pcw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pda': {'full': 'pda-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pdc': {'full': 'pdc-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pdi': {'full': 'pdi-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'pdn': {'full': 'pdn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pdo': {'full': 'pdo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pdt': {'full': 'pdt-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'pdu': {'full': 'pdu-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'pdu-Mymr': {'full': 'pdu-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'pea': {'full': 'pea-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'peb': {'full': 'peb-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'ped': {'full': 'ped-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pee': {'full': 'pee-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pef': {'full': 'pef-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'peg': {'full': 'peg-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'peh': {'full': 'peh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'pei': {'full': 'pei-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pej': {'full': 'pej-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pek': {'full': 'pek-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pel': {'full': 'pel-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pem': {'full': 'pem-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'peo': {'full': 'peo-Xpeo-IR', 'region': 'IR', 'script': 'Xpeo', 'suppress': False},
        'pep': {'full': 'pep-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'peq': {'full': 'peq-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pev': {'full': 'pev-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'pex': {'full': 'pex-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pey': {'full': 'pey-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pez': {'full': 'pez-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'pfa': {'full': 'pfa-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'pfe': {'full': 'pfe-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'pfl': {'full': 'pfl-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'pga': {'full': 'pga-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'pgd': {'full': 'pgd-Khar-PK', 'region': 'PK', 'script': 'Khar', 'suppress': False},
        'pgg': {'full': 'pgg-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'pgi': {'full': 'pgi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pgk': {'full': 'pgk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'pgl': {'full': 'pgl-Ogam-IE', 'region': 'IE', 'script': 'Ogam', 'suppress': False},
        'pgn': {'full': 'pgn-Ital-IT', 'region': 'IT', 'script': 'Ital', 'suppress': False},
        'pgs': {'full': 'pgs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pgu': {'full': 'pgu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pgz': {'full': 'pgz-Zxxx-PG', 'region': 'PG', 'script': 'Zxxx', 'suppress': False},
        'pha': {'full': 'pha-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'phd': {'full': 'phd-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'phg': {'full': 'phg-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'phh': {'full': 'phh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'phk': {'full': 'phk-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'phl': {'full': 'phl-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'phm': {'full': 'phm-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'phn': {'full': 'phn-Phnx-LB', 'region': 'LB', 'script': 'Phnx', 'suppress': False},
        'pho': {'full': 'pho-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'phq': {'full': 'phq-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'phr': {'full': 'phr-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'pht': {'full': 'pht-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'phu': {'full': 'phu-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'phv': {'full': 'phv-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'phw': {'full': 'phw-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'pi-Deva': {'full': 'pi-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'pi-Mymr': {'full': 'pi-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'pi-Sinh': {'full': 'pi-Sinh-IN', 'region': 'IN', 'script': 'Sinh', 'suppress': False},
        'pi-Thai': {'full': 'pi-Thai-IN', 'region': 'IN', 'script': 'Thai', 'suppress': False},
        'pia': {'full': 'pia-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pib': {'full': 'pib-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'pic': {'full': 'pic-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'pid': {'full': 'pid-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'pie': {'full': 'pie-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pif': {'full': 'pif-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'pig': {'full': 'pig-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'pih': {'full': 'pih-Latn-NF', 'region': 'NF', 'script': 'Latn', 'suppress': False},
        'pii': {'full': 'pii-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pij': {'full': 'pij-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'pil': {'full': 'pil-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'pim': {'full': 'pim-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pin': {'full': 'pin-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pio': {'full': 'pio-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'pip': {'full': 'pip-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pir': {'full': 'pir-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pis': {'full': 'pis-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'pit': {'full': 'pit-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'piu': {'full': 'piu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'piv': {'full': 'piv-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'piw': {'full': 'piw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'pix': {'full': 'pix-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'piy': {'full': 'piy-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'piz': {'full': 'piz-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'pjt': {'full': 'pjt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pka': {'full': 'pka-Brah-IN', 'region': 'IN', 'script': 'Brah', 'suppress': False},
        'pkb': {'full': 'pkb-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'pkc': {'full': 'pkc-Zyyy-KR', 'region': 'KR', 'script': 'Zyyy', 'suppress': False},
        'pkg': {'full': 'pkg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pkh-Deva': {'full': 'pkh-Deva-BD', 'region': 'BD', 'script': 'Deva', 'suppress': False},
        'pkh-Latn': {'full': 'pkh-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'pkn': {'full': 'pkn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pko': {'full': 'pko-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'pkp': {'full': 'pkp-Latn-CK', 'region': 'CK', 'script': 'Latn', 'suppress': False},
        'pkr': {'full': 'pkr-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'pks': {'full': 'pks-Zxxx-PK', 'region': 'PK', 'script': 'Zxxx', 'suppress': False},
        'pkt': {'full': 'pkt-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'pku': {'full': 'pku-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pl': {'full': 'pl-Latn-PL', 'region': 'PL', 'script': 'Latn', 'suppress': True},
        'pl-Brai': {'full': 'pl-Brai-PL', 'region': 'PL', 'script': 'Brai', 'suppress': False},
        'pla': {'full': 'pla-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'plb': {'full': 'plb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'plc': {'full': 'plc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'pld': {'full': 'pld-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'ple': {'full': 'ple-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'plg': {'full': 'plg-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'plh': {'full': 'plh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'plj': {'full': 'plj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'plk': {'full': 'plk-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'pll': {'full': 'pll-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'pln': {'full': 'pln-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'plo': {'full': 'plo-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'plp': {'full': 'plp-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'plq': {'full': 'plq-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'plr': {'full': 'plr-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'pls': {'full': 'pls-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'plu': {'full': 'plu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'plv': {'full': 'plv-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'plw': {'full': 'plw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ply': {'full': 'ply-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'plz': {'full': 'plz-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'pma': {'full': 'pma-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'pmb': {'full': 'pmb-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'pmd': {'full': 'pmd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pme': {'full': 'pme-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'pmf': {'full': 'pmf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pmh': {'full': 'pmh-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'pmi': {'full': 'pmi-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'pmj': {'full': 'pmj-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'pmk': {'full': 'pmk-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pml': {'full': 'pml-Zyyy-TN', 'region': 'TN', 'script': 'Zyyy', 'suppress': False},
        'pmm': {'full': 'pmm-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'pmn': {'full': 'pmn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'pmo': {'full': 'pmo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pmq': {'full': 'pmq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pmr': {'full': 'pmr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pms': {'full': 'pms-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'pmt': {'full': 'pmt-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'pmw': {'full': 'pmw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pmx': {'full': 'pmx-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'pmy': {'full': 'pmy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pmz': {'full': 'pmz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pna': {'full': 'pna-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'pnc': {'full': 'pnc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pnd': {'full': 'pnd-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'pne': {'full': 'pne-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'png': {'full': 'png-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pnh': {'full': 'pnh-Latn-CK', 'region': 'CK', 'script': 'Latn', 'suppress': False},
        'pni': {'full': 'pni-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pnj': {'full': 'pnj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pnk': {'full': 'pnk-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'pnl': {'full': 'pnl-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'pnm': {'full': 'pnm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'pnn': {'full': 'pnn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pno': {'full': 'pno-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'pnp': {'full': 'pnp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pnq': {'full': 'pnq-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'pnr': {'full': 'pnr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pns': {'full': 'pns-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pnt': {'full': 'pnt-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'pnt-Cyrl': {'full': 'pnt-Cyrl-GR', 'region': 'GR', 'script': 'Cyrl', 'suppress': False},
        'pnt-Latn': {'full': 'pnt-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'pnu': {'full': 'pnu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'pnv': {'full': 'pnv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pnw': {'full': 'pnw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'pnx': {'full': 'pnx-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'pny': {'full': 'pny-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'pnz': {'full': 'pnz-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'poc': {'full': 'poc-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'poe': {'full': 'poe-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pof': {'full': 'pof-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'pog': {'full': 'pog-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'poh': {'full': 'poh-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'poi': {'full': 'poi-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pok': {'full': 'pok-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pom': {'full': 'pom-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pon': {'full': 'pon-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'poo': {'full': 'poo-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pop': {'full': 'pop-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'poq': {'full': 'poq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pos': {'full': 'pos-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pot': {'full': 'pot-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'pov': {'full': 'pov-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': False},
        'pow': {'full': 'pow-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pox': {'full': 'pox-Zyyy-DE', 'region': 'DE', 'script': 'Zyyy', 'suppress': False},
        'poy': {'full': 'poy-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ppe': {'full': 'ppe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ppi': {'full': 'ppi-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ppk': {'full': 'ppk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ppl': {'full': 'ppl-Latn-SV', 'region': 'SV', 'script': 'Latn', 'suppress': False},
        'ppm': {'full': 'ppm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ppn': {'full': 'ppn-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ppo': {'full': 'ppo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ppp': {'full': 'ppp-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ppq': {'full': 'ppq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pps': {'full': 'pps-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ppt': {'full': 'ppt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ppu': {'full': 'ppu-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'pqa': {'full': 'pqa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pqm': {'full': 'pqm-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'pra': {'full': 'pra-Khar-PK', 'region': 'PK', 'script': 'Khar', 'suppress': False},
        'prb': {'full': 'prb-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'prc': {'full': 'prc-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'prd': {'full': 'prd-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'pre': {'full': 'pre-Latn-ST', 'region': 'ST', 'script': 'Latn', 'suppress': False},
        'prf': {'full': 'prf-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'prg': {'full': 'prg-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'prh': {'full': 'prh-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'pri': {'full': 'pri-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'prk': {'full': 'prk-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'prl': {'full': 'prl-Zxxx-PE', 'region': 'PE', 'script': 'Zxxx', 'suppress': False},
        'prm': {'full': 'prm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'prn': {'full': 'prn-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'pro': {'full': 'pro-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'prp': {'full': 'prp-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'prq': {'full': 'prq-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'prr': {'full': 'prr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'prs': {'full': 'prs-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'prt': {'full': 'prt-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'pru': {'full': 'pru-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'prw': {'full': 'prw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'prx': {'full': 'prx-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'prx-Tibt': {'full': 'prx-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'prz': {'full': 'prz-Zxxx-CO', 'region': 'CO', 'script': 'Zxxx', 'suppress': False},
        'ps': {'full': 'ps-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': True},
        'ps-PK': {'full': 'ps-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': True},
        'psa': {'full': 'psa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'psc': {'full': 'psc-Zxxx-IR', 'region': 'IR', 'script': 'Zxxx', 'suppress': False},
        'psd': {'full': 'psd-Zxxx-US', 'region': 'US', 'script': 'Zxxx', 'suppress': False},
        'pse': {'full': 'pse-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'psg': {'full': 'psg-Zxxx-MY', 'region': 'MY', 'script': 'Zxxx', 'suppress': False},
        'psh': {'full': 'psh-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'psi': {'full': 'psi-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'psl': {'full': 'psl-Zxxx-PR', 'region': 'PR', 'script': 'Zxxx', 'suppress': False},
        'psm': {'full': 'psm-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'psn': {'full': 'psn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pso': {'full': 'pso-Zxxx-PL', 'region': 'PL', 'script': 'Zxxx', 'suppress': False},
        'psp': {'full': 'psp-Zxxx-PH', 'region': 'PH', 'script': 'Zxxx', 'suppress': False},
        'psq': {'full': 'psq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'psr': {'full': 'psr-Zxxx-PT', 'region': 'PT', 'script': 'Zxxx', 'suppress': False},
        'pss': {'full': 'pss-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pst': {'full': 'pst-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'psu-Brah': {'full': 'psu-Brah-IN', 'region': 'IN', 'script': 'Brah', 'suppress': False},
        'psu-Deva': {'full': 'psu-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'psw': {'full': 'psw-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'psy': {'full': 'psy-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pt': {'full': 'pt-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': True},
        'pt-AO': {'full': 'pt-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': True},
        'pt-Brai': {'full': 'pt-Brai-PT', 'region': 'PT', 'script': 'Brai', 'suppress': False},
        'pt-CV': {'full': 'pt-Latn-CV', 'region': 'CV', 'script': 'Latn', 'suppress': True},
        'pt-GW': {'full': 'pt-Latn-GW', 'region': 'GW', 'script': 'Latn', 'suppress': True},
        'pt-LU': {'full': 'pt-Latn-LU', 'region': 'LU', 'script': 'Latn', 'suppress': True},
        'pt-MO': {'full': 'pt-Latn-MO', 'region': 'MO', 'script': 'Latn', 'suppress': True},
        'pt-MZ': {'full': 'pt-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': True},
        'pt-PT': {'full': 'pt-Latn-PT', 'region': 'PT', 'script': 'Latn', 'suppress': True},
        'pt-ST': {'full': 'pt-Latn-ST', 'region': 'ST', 'script': 'Latn', 'suppress': True},
        'pt-TL': {'full': 'pt-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': True},
        'pta': {'full': 'pta-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'pth': {'full': 'pth-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pti': {'full': 'pti-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ptn': {'full': 'ptn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pto': {'full': 'pto-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ptp': {'full': 'ptp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ptq': {'full': 'ptq-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ptr': {'full': 'ptr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ptt': {'full': 'ptt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ptu': {'full': 'ptu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ptv': {'full': 'ptv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ptw': {'full': 'ptw-Zyyy-CA', 'region': 'CA', 'script': 'Zyyy', 'suppress': False},
        'pty': {'full': 'pty-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'pua': {'full': 'pua-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pub': {'full': 'pub-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'puc': {'full': 'puc-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pud': {'full': 'pud-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pue': {'full': 'pue-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'puf': {'full': 'puf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'pug': {'full': 'pug-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'pui': {'full': 'pui-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'puj': {'full': 'puj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'puk': {'full': 'puk-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'pum': {'full': 'pum-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'puo': {'full': 'puo-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'pup': {'full': 'pup-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'puq': {'full': 'puq-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'pur': {'full': 'pur-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'put': {'full': 'put-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'puu': {'full': 'puu-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'puw': {'full': 'puw-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'pux': {'full': 'pux-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'puy': {'full': 'puy-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pwa': {'full': 'pwa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pwb': {'full': 'pwb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pwg': {'full': 'pwg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'pwi': {'full': 'pwi-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'pwm': {'full': 'pwm-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'pwn': {'full': 'pwn-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'pwo': {'full': 'pwo-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'pwr': {'full': 'pwr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'pww': {'full': 'pww-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'pxm': {'full': 'pxm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'pye': {'full': 'pye-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'pym': {'full': 'pym-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'pyn': {'full': 'pyn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'pys': {'full': 'pys-Zxxx-PY', 'region': 'PY', 'script': 'Zxxx', 'suppress': False},
        'pyu': {'full': 'pyu-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'pyu-Hani': {'full': 'pyu-Hani-TW', 'region': 'TW', 'script': 'Hani', 'suppress': False},
        'pyx': {'full': 'pyx-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'pyy': {'full': 'pyy-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'pzn': {'full': 'pzn-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'qu': {'full': 'qu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': True},
        'qu-BO': {'full': 'qu-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': True},
        'qu-EC': {'full': 'qu-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': True},
        'qua': {'full': 'qua-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'qub': {'full': 'qub-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'quc': {'full': 'quc-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'qud': {'full': 'qud-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'quf': {'full': 'quf-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qug': {'full': 'qug-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qui': {'full': 'qui-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'quk': {'full': 'quk-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qul': {'full': 'qul-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'qum': {'full': 'qum-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'qun': {'full': 'qun-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'qup': {'full': 'qup-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'quq': {'full': 'quq-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'qur': {'full': 'qur-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qus': {'full': 'qus-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'quv': {'full': 'quv-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'quw': {'full': 'quw-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qux': {'full': 'qux-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'quy': {'full': 'quy-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qva': {'full': 'qva-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvc': {'full': 'qvc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qve': {'full': 'qve-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvh': {'full': 'qvh-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvi': {'full': 'qvi-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qvj': {'full': 'qvj-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qvl': {'full': 'qvl-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvm': {'full': 'qvm-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvn': {'full': 'qvn-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvo': {'full': 'qvo-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvp': {'full': 'qvp-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvs': {'full': 'qvs-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvw': {'full': 'qvw-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qvy': {'full': 'qvy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'qvz': {'full': 'qvz-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qwa': {'full': 'qwa-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qwc': {'full': 'qwc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qwh': {'full': 'qwh-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qwm': {'full': 'qwm-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'qws': {'full': 'qws-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qwt': {'full': 'qwt-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'qxa': {'full': 'qxa-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxc': {'full': 'qxc-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxh': {'full': 'qxh-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxl': {'full': 'qxl-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qxn': {'full': 'qxn-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxo': {'full': 'qxo-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxp': {'full': 'qxp-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxq': {'full': 'qxq-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'qxr': {'full': 'qxr-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'qxs': {'full': 'qxs-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'qxt': {'full': 'qxt-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxu': {'full': 'qxu-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qxw': {'full': 'qxw-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'qya': {'full': 'qya-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'qya-Cirt': {'full': 'qya-Cirt-001', 'region': '001', 'script': 'Cirt', 'suppress': False},
        'qya-Sara': {'full': 'qya-Sara-001', 'region': '001', 'script': 'Sara', 'suppress': False},
        'qya-Teng': {'full': 'qya-Teng-001', 'region': '001', 'script': 'Teng', 'suppress': False},
        'qyp': {'full': 'qyp-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'raa': {'full': 'raa-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'rab': {'full': 'rab-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'rac': {'full': 'rac-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rad': {'full': 'rad-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'raf': {'full': 'raf-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'rag': {'full': 'rag-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'rah': {'full': 'rah-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'rah-Latn': {'full': 'rah-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'rai': {'full': 'rai-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'raj': {'full': 'raj-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'raj-Latn': {'full': 'raj-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'rak': {'full': 'rak-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ral': {'full': 'ral-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ram': {'full': 'ram-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ran': {'full': 'ran-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rao': {'full': 'rao-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rap': {'full': 'rap-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': False},
        'raq': {'full': 'raq-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'rar': {'full': 'rar-Latn-CK', 'region': 'CK', 'script': 'Latn', 'suppress': False},
        'ras': {'full': 'ras-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'rat': {'full': 'rat-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'rau': {'full': 'rau-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'rav': {'full': 'rav-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'raw': {'full': 'raw-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'raw-x-daruzerw': {'full': 'raw-Latn-MM-x-daruzerw', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'raw-x-longmin': {'full': 'raw-Latn-MM-x-longmin', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'raw-x-longmis': {'full': 'raw-Latn-MM-x-longmis', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'raw-x-tangsare': {'full': 'raw-Latn-MM-x-tangsare', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'raw-x-tangsarw': {'full': 'raw-Latn-MM-x-tangsarw', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'rax': {'full': 'rax-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ray': {'full': 'ray-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'raz': {'full': 'raz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rbb': {'full': 'rbb-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'rbk': {'full': 'rbk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'rbl': {'full': 'rbl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'rbp': {'full': 'rbp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'rcf': {'full': 'rcf-Latn-RE', 'region': 'RE', 'script': 'Latn', 'suppress': False},
        'rdb': {'full': 'rdb-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'rea': {'full': 'rea-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'reb': {'full': 'reb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ree': {'full': 'ree-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'reg': {'full': 'reg-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'rei': {'full': 'rei-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'rej': {'full': 'rej-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rej-Rjng': {'full': 'rej-Rjng-ID', 'region': 'ID', 'script': 'Rjng', 'suppress': False},
        'rel': {'full': 'rel-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'rem': {'full': 'rem-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ren': {'full': 'ren-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'rer': {'full': 'rer-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'res': {'full': 'res-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ret': {'full': 'ret-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rey': {'full': 'rey-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'rga': {'full': 'rga-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'rge': {'full': 'rge-Zyyy-GR', 'region': 'GR', 'script': 'Zyyy', 'suppress': False},
        'rgk': {'full': 'rgk-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'rgn': {'full': 'rgn-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'rgr': {'full': 'rgr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'rgs': {'full': 'rgs-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'rgu': {'full': 'rgu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rhg-Arab': {'full': 'rhg-Arab-MM', 'region': 'MM', 'script': 'Arab', 'suppress': False},
        'rhg-Latn': {'full': 'rhg-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'rhg-Rohg': {'full': 'rhg-Rohg-MM', 'region': 'MM', 'script': 'Rohg', 'suppress': False},
        'rhp': {'full': 'rhp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ria': {'full': 'ria-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'rie': {'full': 'rie-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'rif': {'full': 'rif-Tfng-MA', 'region': 'MA', 'script': 'Tfng', 'suppress': False},
        'rif-Arab': {'full': 'rif-Arab-MA', 'region': 'MA', 'script': 'Arab', 'suppress': False},
        'rif-Latn': {'full': 'rif-Latn-MA', 'region': 'MA', 'script': 'Latn', 'suppress': False},
        'rif-NL': {'full': 'rif-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'ril': {'full': 'ril-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'rim': {'full': 'rim-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'rin': {'full': 'rin-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'rir': {'full': 'rir-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rit': {'full': 'rit-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'riu': {'full': 'riu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rjg': {'full': 'rjg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rji': {'full': 'rji-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'rjs': {'full': 'rjs-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'rka': {'full': 'rka-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'rkb': {'full': 'rkb-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'rkh': {'full': 'rkh-Latn-CK', 'region': 'CK', 'script': 'Latn', 'suppress': False},
        'rki': {'full': 'rki-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'rkm': {'full': 'rkm-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'rkt': {'full': 'rkt-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'rkw': {'full': 'rkw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'rm': {'full': 'rm-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': True},
        'rma': {'full': 'rma-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'rmb': {'full': 'rmb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'rmc': {'full': 'rmc-Latn-SK', 'region': 'SK', 'script': 'Latn', 'suppress': False},
        'rmd': {'full': 'rmd-Latn-DK', 'region': 'DK', 'script': 'Latn', 'suppress': False},
        'rme': {'full': 'rme-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'rmf': {'full': 'rmf-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': False},
        'rmg': {'full': 'rmg-Zyyy-NO', 'region': 'NO', 'script': 'Zyyy', 'suppress': False},
        'rmh': {'full': 'rmh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rmi': {'full': 'rmi-Zyyy-AM', 'region': 'AM', 'script': 'Zyyy', 'suppress': False},
        'rmk': {'full': 'rmk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rml': {'full': 'rml-Latn-PL', 'region': 'PL', 'script': 'Latn', 'suppress': False},
        'rml-Cyrl': {'full': 'rml-Cyrl-BY', 'region': 'BY', 'script': 'Cyrl', 'suppress': False},
        'rmm': {'full': 'rmm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rmn': {'full': 'rmn-Latn-RS', 'region': 'RS', 'script': 'Latn', 'suppress': False},
        'rmn-Cyrl': {'full': 'rmn-Cyrl-BG', 'region': 'BG', 'script': 'Cyrl', 'suppress': False},
        'rmn-Grek': {'full': 'rmn-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'rmo': {'full': 'rmo-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': False},
        'rmp': {'full': 'rmp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rmq': {'full': 'rmq-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'rms': {'full': 'rms-Zxxx-RO', 'region': 'RO', 'script': 'Zxxx', 'suppress': False},
        'rmt': {'full': 'rmt-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'rmu': {'full': 'rmu-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'rmv': {'full': 'rmv-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'rmw': {'full': 'rmw-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'rmx': {'full': 'rmx-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'rmz': {'full': 'rmz-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'rn': {'full': 'rn-Latn-BI', 'region': 'BI', 'script': 'Latn', 'suppress': True},
        'rn-Brai': {'full': 'rn-Brai-BI', 'region': 'BI', 'script': 'Brai', 'suppress': False},
        'rnd': {'full': 'rnd-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'rng': {'full': 'rng-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'rnl': {'full': 'rnl-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'rnn': {'full': 'rnn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rnp': {'full': 'rnp-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'rnr': {'full': 'rnr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'rnw': {'full': 'rnw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ro': {'full': 'ro-Latn-RO', 'region': 'RO', 'script': 'Latn', 'suppress': True},
        'ro-Brai': {'full': 'ro-Brai-RO', 'region': 'RO', 'script': 'Brai', 'suppress': False},
        'ro-Cyrl': {'full': 'ro-Cyrl-MD', 'region': 'MD', 'script': 'Cyrl', 'suppress': False},
        'ro-Dupl': {'full': 'ro-Dupl-RO', 'region': 'RO', 'script': 'Dupl', 'suppress': False},
        'ro-MD': {'full': 'ro-Latn-MD', 'region': 'MD', 'script': 'Latn', 'suppress': True},
        'rob': {'full': 'rob-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'roc': {'full': 'roc-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'rod': {'full': 'rod-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'roe': {'full': 'roe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rof': {'full': 'rof-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'rog': {'full': 'rog-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'rol': {'full': 'rol-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'rom': {'full': 'rom-Latn-RO', 'region': 'RO', 'script': 'Latn', 'suppress': False},
        'rom-Cyrl': {'full': 'rom-Cyrl-RO', 'region': 'RO', 'script': 'Cyrl', 'suppress': False},
        'rom-Cyrl-BG': {'full': 'rom-Cyrl-BG', 'region': 'BG', 'script': 'Cyrl', 'suppress': False},
        'roo': {'full': 'roo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rop': {'full': 'rop-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ror': {'full': 'ror-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rou': {'full': 'rou-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'row': {'full': 'row-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rpn': {'full': 'rpn-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'rpt': {'full': 'rpt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rri': {'full': 'rri-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'rro': {'full': 'rro-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rrt': {'full': 'rrt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'rsb': {'full': 'rsb-Zyyy-RS', 'region': 'RS', 'script': 'Zyyy', 'suppress': False},
        'rsi': {'full': 'rsi-Zxxx-SB', 'region': 'SB', 'script': 'Zxxx', 'suppress': False},
        'rsl': {'full': 'rsl-Zxxx-RU', 'region': 'RU', 'script': 'Zxxx', 'suppress': False},
        'rsm': {'full': 'rsm-Zxxx-AU', 'region': 'AU', 'script': 'Zxxx', 'suppress': False},
        'rtc': {'full': 'rtc-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'rth': {'full': 'rth-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'rtm': {'full': 'rtm-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'rts': {'full': 'rts-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'rtw': {'full': 'rtw-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ru': {'full': 'ru-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': True},
        'ru-BY': {'full': 'ru-Cyrl-BY', 'region': 'BY', 'script': 'Cyrl', 'suppress': True},
        'ru-Brai': {'full': 'ru-Brai-RU', 'region': 'RU', 'script': 'Brai', 'suppress': False},
        'ru-KG': {'full': 'ru-Cyrl-KG', 'region': 'KG', 'script': 'Cyrl', 'suppress': True},
        'ru-KZ': {'full': 'ru-Cyrl-KZ', 'region': 'KZ', 'script': 'Cyrl', 'suppress': True},
        'ru-MD': {'full': 'ru-Cyrl-MD', 'region': 'MD', 'script': 'Cyrl', 'suppress': True},
        'ru-UA': {'full': 'ru-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': True},
        'rub': {'full': 'rub-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'ruc': {'full': 'ruc-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'rue': {'full': 'rue-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': False},
        'rue-Latn': {'full': 'rue-Latn-SK', 'region': 'SK', 'script': 'Latn', 'suppress': False},
        'ruf': {'full': 'ruf-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'rug': {'full': 'rug-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ruh': {'full': 'ruh-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'rui': {'full': 'rui-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ruk': {'full': 'ruk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ruo': {'full': 'ruo-Latn-HR', 'region': 'HR', 'script': 'Latn', 'suppress': False},
        'rup': {'full': 'rup-Latn-RO', 'region': 'RO', 'script': 'Latn', 'suppress': False},
        'rup-Grek': {'full': 'rup-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'ruq': {'full': 'ruq-Latn-GR', 'region': 'GR', 'script': 'Latn', 'suppress': False},
        'rut': {'full': 'rut-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'rut-Latn': {'full': 'rut-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'ruu': {'full': 'ruu-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'ruy': {'full': 'ruy-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ruz': {'full': 'ruz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'rw': {'full': 'rw-Latn-RW', 'region': 'RW', 'script': 'Latn', 'suppress': True},
        'rw-Brai': {'full': 'rw-Brai-RW', 'region': 'RW', 'script': 'Brai', 'suppress': False},
        'rwa': {'full': 'rwa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rwk': {'full': 'rwk-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'rwm': {'full': 'rwm-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'rwo': {'full': 'rwo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rwo-x-karo': {'full': 'rwo-Latn-PG-x-karo', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'rwr': {'full': 'rwr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'rxd': {'full': 'rxd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'rxw': {'full': 'rxw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ryn': {'full': 'ryn-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'rys': {'full': 'rys-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'ryu': {'full': 'ryu-Kana-JP', 'region': 'JP', 'script': 'Kana', 'suppress': False},
        'rzh': {'full': 'rzh-Zyyy-YE', 'region': 'YE', 'script': 'Zyyy', 'suppress': False},
        'sa': {'full': 'sa-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sa-Gran': {'full': 'sa-Gran-IN', 'region': 'IN', 'script': 'Gran', 'suppress': False},
        'sa-Mymr': {'full': 'sa-Mymr-IN', 'region': 'IN', 'script': 'Mymr', 'suppress': False},
        'sa-Nand': {'full': 'sa-Nand-IN', 'region': 'IN', 'script': 'Nand', 'suppress': False},
        'sa-Newa': {'full': 'sa-Newa-IN', 'region': 'IN', 'script': 'Newa', 'suppress': False},
        'sa-Shrd': {'full': 'sa-Shrd-IN', 'region': 'IN', 'script': 'Shrd', 'suppress': False},
        'sa-Sidd': {'full': 'sa-Sidd-IN', 'region': 'IN', 'script': 'Sidd', 'suppress': False},
        'sa-Sinh': {'full': 'sa-Sinh-IN', 'region': 'IN', 'script': 'Sinh', 'suppress': False},
        'saa': {'full': 'saa-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sab': {'full': 'sab-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': False},
        'sac': {'full': 'sac-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'sad': {'full': 'sad-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'sae': {'full': 'sae-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'saf': {'full': 'saf-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'sah': {'full': 'sah-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'saj': {'full': 'saj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sak': {'full': 'sak-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'sam': {'full': 'sam-Samr-PS', 'region': 'PS', 'script': 'Samr', 'suppress': False},
        'sam-Hebr': {'full': 'sam-Hebr-PS', 'region': 'PS', 'script': 'Hebr', 'suppress': False},
        'sam-Syrc': {'full': 'sam-Syrc-PS', 'region': 'PS', 'script': 'Syrc', 'suppress': False},
        'sao': {'full': 'sao-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'saq': {'full': 'saq-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'sar': {'full': 'sar-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'sas': {'full': 'sas-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sas-Bali': {'full': 'sas-Bali-ID', 'region': 'ID', 'script': 'Bali', 'suppress': False},
        'sat': {'full': 'sat-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'sat-Beng': {'full': 'sat-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'sat-Deva': {'full': 'sat-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'sat-Olck': {'full': 'sat-Olck-IN', 'region': 'IN', 'script': 'Olck', 'suppress': False},
        'sat-Orya': {'full': 'sat-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'sau': {'full': 'sau-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sav': {'full': 'sav-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'sav-Arab': {'full': 'sav-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'saw': {'full': 'saw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sax': {'full': 'sax-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'say': {'full': 'say-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'saz': {'full': 'saz-Saur-IN', 'region': 'IN', 'script': 'Saur', 'suppress': False},
        'saz-Deva': {'full': 'saz-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'saz-Taml': {'full': 'saz-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'saz-Telu': {'full': 'saz-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'sba': {'full': 'sba-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sbb': {'full': 'sbb-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'sbc': {'full': 'sbc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sbd': {'full': 'sbd-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'sbe': {'full': 'sbe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sbf': {'full': 'sbf-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'sbg': {'full': 'sbg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sbh': {'full': 'sbh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sbi': {'full': 'sbi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sbj': {'full': 'sbj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sbk': {'full': 'sbk-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'sbl': {'full': 'sbl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sbm': {'full': 'sbm-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'sbn': {'full': 'sbn-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'sbo': {'full': 'sbo-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'sbp': {'full': 'sbp-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'sbq': {'full': 'sbq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sbr': {'full': 'sbr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sbs': {'full': 'sbs-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'sbt': {'full': 'sbt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sbu-Deva': {'full': 'sbu-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sbu-Tibt': {'full': 'sbu-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'sbv': {'full': 'sbv-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sbw': {'full': 'sbw-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'sbx': {'full': 'sbx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sby': {'full': 'sby-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'sbz': {'full': 'sbz-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'sc': {'full': 'sc-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'scb': {'full': 'scb-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'sce': {'full': 'sce-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'sce-Arab': {'full': 'sce-Arab-CN', 'region': 'CN', 'script': 'Arab', 'suppress': False},
        'scf': {'full': 'scf-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': False},
        'scg': {'full': 'scg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sch': {'full': 'sch-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'sci': {'full': 'sci-Latn-LK', 'region': 'LK', 'script': 'Latn', 'suppress': False},
        'sck': {'full': 'sck-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sck-Beng': {'full': 'sck-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'scl': {'full': 'scl-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'scl-IN': {'full': 'scl-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': False},
        'scn': {'full': 'scn-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'sco': {'full': 'sco-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'scp': {'full': 'scp-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'scq': {'full': 'scq-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'scs': {'full': 'scs-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'scs-Cans': {'full': 'scs-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'sct': {'full': 'sct-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'scu': {'full': 'scu-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'scv': {'full': 'scv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'scw': {'full': 'scw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'scx': {'full': 'scx-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sd': {'full': 'sd-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'sd-Deva': {'full': 'sd-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sd-Guru': {'full': 'sd-Guru-IN', 'region': 'IN', 'script': 'Guru', 'suppress': False},
        'sd-Khoj': {'full': 'sd-Khoj-IN', 'region': 'IN', 'script': 'Khoj', 'suppress': False},
        'sd-Khoj-PK': {'full': 'sd-Khoj-PK', 'region': 'PK', 'script': 'Khoj', 'suppress': False},
        'sd-Sind': {'full': 'sd-Sind-IN', 'region': 'IN', 'script': 'Sind', 'suppress': False},
        'sda': {'full': 'sda-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sdb': {'full': 'sdb-Zyyy-IQ', 'region': 'IQ', 'script': 'Zyyy', 'suppress': False},
        'sdc': {'full': 'sdc-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'sde': {'full': 'sde-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'sdf': {'full': 'sdf-Zyyy-IQ', 'region': 'IQ', 'script': 'Zyyy', 'suppress': False},
        'sdg': {'full': 'sdg-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'sdh': {'full': 'sdh-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'sdj': {'full': 'sdj-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'sdk': {'full': 'sdk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sdl': {'full': 'sdl-Zxxx-SA', 'region': 'SA', 'script': 'Zxxx', 'suppress': False},
        'sdm': {'full': 'sdm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sdn': {'full': 'sdn-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'sdo': {'full': 'sdo-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'sdp': {'full': 'sdp-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'sdq': {'full': 'sdq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sdr-Beng': {'full': 'sdr-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'sdr-Deva': {'full': 'sdr-Deva-BD', 'region': 'BD', 'script': 'Deva', 'suppress': False},
        'sdr-Latn': {'full': 'sdr-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'sds': {'full': 'sds-Zyyy-TN', 'region': 'TN', 'script': 'Zyyy', 'suppress': False},
        'sdt': {'full': 'sdt-Zyyy-FR', 'region': 'FR', 'script': 'Zyyy', 'suppress': False},
        'sdu': {'full': 'sdu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sdx': {'full': 'sdx-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'sdz': {'full': 'sdz-Zyyy-NL', 'region': 'NL', 'script': 'Zyyy', 'suppress': False},
        'se': {'full': 'se-Latn-NO', 'region': 'NO', 'script': 'Latn', 'suppress': False},
        'se-Cyrl': {'full': 'se-Cyrl-NO', 'region': 'NO', 'script': 'Cyrl', 'suppress': False},
        'se-FI': {'full': 'se-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': False},
        'se-SE': {'full': 'se-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'sea': {'full': 'sea-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'seb': {'full': 'seb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'sec': {'full': 'sec-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'sed': {'full': 'sed-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'see': {'full': 'see-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'sef': {'full': 'sef-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'seg': {'full': 'seg-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'seh': {'full': 'seh-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'sei': {'full': 'sei-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'sej': {'full': 'sej-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sek': {'full': 'sek-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'sek-Cans': {'full': 'sek-Cans-CA', 'region': 'CA', 'script': 'Cans', 'suppress': False},
        'sel': {'full': 'sel-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'sen': {'full': 'sen-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'seo': {'full': 'seo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sep': {'full': 'sep-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'seq': {'full': 'seq-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'ser': {'full': 'ser-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ses': {'full': 'ses-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'set': {'full': 'set-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'seu': {'full': 'seu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sev': {'full': 'sev-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'sew': {'full': 'sew-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sey': {'full': 'sey-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'sez': {'full': 'sez-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'sfb': {'full': 'sfb-Zxxx-BE', 'region': 'BE', 'script': 'Zxxx', 'suppress': False},
        'sfe': {'full': 'sfe-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sfm': {'full': 'sfm-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'sfs': {'full': 'sfs-Zxxx-ZA', 'region': 'ZA', 'script': 'Zxxx', 'suppress': False},
        'sfw': {'full': 'sfw-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'sg': {'full': 'sg-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': True},
        'sga': {'full': 'sga-Ogam-IE', 'region': 'IE', 'script': 'Ogam', 'suppress': False},
        'sga-Latn': {'full': 'sga-Latn-IE', 'region': 'IE', 'script': 'Latn', 'suppress': False},
        'sgb': {'full': 'sgb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sgc': {'full': 'sgc-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'sgd': {'full': 'sgd-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sge': {'full': 'sge-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sgg': {'full': 'sgg-Zxxx-CH', 'region': 'CH', 'script': 'Zxxx', 'suppress': False},
        'sgh-Arab': {'full': 'sgh-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'sgh-Cyrl': {'full': 'sgh-Cyrl-TJ', 'region': 'TJ', 'script': 'Cyrl', 'suppress': False},
        'sgh-Latn': {'full': 'sgh-Latn-TJ', 'region': 'TJ', 'script': 'Latn', 'suppress': False},
        'sgi': {'full': 'sgi-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'sgj': {'full': 'sgj-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sgk': {'full': 'sgk-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'sgm': {'full': 'sgm-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'sgn-MM': {'full': 'sgn-Zxxx-MM', 'region': 'MM', 'script': 'Zxxx', 'suppress': False},
        'sgp': {'full': 'sgp-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'sgr': {'full': 'sgr-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'sgs': {'full': 'sgs-Latn-LT', 'region': 'LT', 'script': 'Latn', 'suppress': False},
        'sgt': {'full': 'sgt-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'sgu': {'full': 'sgu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sgw': {'full': 'sgw-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'sgx': {'full': 'sgx-Zxxx-SL', 'region': 'SL', 'script': 'Zxxx', 'suppress': False},
        'sgy': {'full': 'sgy-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'sgz': {'full': 'sgz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sh': {'full': 'sh-Latn-RS', 'region': 'RS', 'script': 'Latn', 'suppress': False},
        'sha': {'full': 'sha-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'shb': {'full': 'shb-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'shc': {'full': 'shc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'shd': {'full': 'shd-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'she': {'full': 'she-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'shg': {'full': 'shg-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'shh': {'full': 'shh-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'shi': {'full': 'shi-Tfng-MA', 'region': 'MA', 'script': 'Tfng', 'suppress': False},
        'shi-Arab': {'full': 'shi-Arab-MA', 'region': 'MA', 'script': 'Arab', 'suppress': False},
        'shi-Latn': {'full': 'shi-Latn-MA', 'region': 'MA', 'script': 'Latn', 'suppress': False},
        'shj': {'full': 'shj-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'shk': {'full': 'shk-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'shk-Arab': {'full': 'shk-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'shl': {'full': 'shl-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'shm': {'full': 'shm-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'shn': {'full': 'shn-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'shn-Mymr-x-taimau': {'full': 'shn-Mymr-MM-x-taimau', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'shn-Tale': {'full': 'shn-Tale-MM', 'region': 'MM', 'script': 'Tale', 'suppress': False},
        'shn-Thai': {'full': 'shn-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'sho': {'full': 'sho-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'shp': {'full': 'shp-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'shq': {'full': 'shq-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'shr': {'full': 'shr-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'shs': {'full': 'shs-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'sht': {'full': 'sht-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'shu-Arab': {'full': 'shu-Arab-TD', 'region': 'TD', 'script': 'Arab', 'suppress': False},
        'shu-Latn': {'full': 'shu-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'shv': {'full': 'shv-Zyyy-OM', 'region': 'OM', 'script': 'Zyyy', 'suppress': False},
        'shw': {'full': 'shw-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'shx': {'full': 'shx-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'shy-Arab': {'full': 'shy-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': False},
        'shy-Latn': {'full': 'shy-Latn-DZ', 'region': 'DZ', 'script': 'Latn', 'suppress': False},
        'shy-Tfng': {'full': 'shy-Tfng-DZ', 'region': 'DZ', 'script': 'Tfng', 'suppress': False},
        'shz': {'full': 'shz-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'si': {'full': 'si-Sinh-LK', 'region': 'LK', 'script': 'Sinh', 'suppress': True},
        'si-Brai': {'full': 'si-Brai-LK', 'region': 'LK', 'script': 'Brai', 'suppress': False},
        'sia': {'full': 'sia-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'sib': {'full': 'sib-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'sid': {'full': 'sid-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'sid-Ethi': {'full': 'sid-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'sie': {'full': 'sie-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'sif': {'full': 'sif-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'sig': {'full': 'sig-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'sih': {'full': 'sih-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'sii': {'full': 'sii-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'sij': {'full': 'sij-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sik': {'full': 'sik-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'sil': {'full': 'sil-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'sim': {'full': 'sim-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sip': {'full': 'sip-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'siq': {'full': 'siq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sir': {'full': 'sir-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'sis': {'full': 'sis-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'siu': {'full': 'siu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'siv': {'full': 'siv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'siw': {'full': 'siw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'six': {'full': 'six-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'siy': {'full': 'siy-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'siz': {'full': 'siz-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': False},
        'sja': {'full': 'sja-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'sjb': {'full': 'sjb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sjd': {'full': 'sjd-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'sje': {'full': 'sje-Zyyy-SE', 'region': 'SE', 'script': 'Zyyy', 'suppress': False},
        'sjg': {'full': 'sjg-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sjk': {'full': 'sjk-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sjl': {'full': 'sjl-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'sjm': {'full': 'sjm-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sjn': {'full': 'sjn-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'sjo': {'full': 'sjo-Mong-CN-x-sibe', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'sjo-Cyrl': {'full': 'sjo-Cyrl-CN', 'region': 'CN', 'script': 'Cyrl', 'suppress': False},
        'sjo-Latn': {'full': 'sjo-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'sjo-Mong-x-manchu': {'full': 'sjo-Mong-CN-x-manchu', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'sjp': {'full': 'sjp-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sjr': {'full': 'sjr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sjs': {'full': 'sjs-Zyyy-MA', 'region': 'MA', 'script': 'Zyyy', 'suppress': False},
        'sjt': {'full': 'sjt-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'sju': {'full': 'sju-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'sjw': {'full': 'sjw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'sk': {'full': 'sk-Latn-SK', 'region': 'SK', 'script': 'Latn', 'suppress': True},
        'sk-Brai': {'full': 'sk-Brai-SK', 'region': 'SK', 'script': 'Brai', 'suppress': False},
        'ska': {'full': 'ska-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'skb': {'full': 'skb-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'skc': {'full': 'skc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'skd': {'full': 'skd-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'ske': {'full': 'ske-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'skf': {'full': 'skf-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'skg': {'full': 'skg-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'skh': {'full': 'skh-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ski': {'full': 'ski-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'skj': {'full': 'skj-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'skm': {'full': 'skm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'skn': {'full': 'skn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sko': {'full': 'sko-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'skp': {'full': 'skp-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'skq': {'full': 'skq-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'skr': {'full': 'skr-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'skr-Deva': {'full': 'skr-Deva-PK', 'region': 'PK', 'script': 'Deva', 'suppress': False},
        'skr-Guru': {'full': 'skr-Guru-PK', 'region': 'PK', 'script': 'Guru', 'suppress': False},
        'skr-Khoj': {'full': 'skr-Khoj-PK', 'region': 'PK', 'script': 'Khoj', 'suppress': False},
        'sks': {'full': 'sks-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'skt': {'full': 'skt-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'sku': {'full': 'sku-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'skv': {'full': 'skv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'skw': {'full': 'skw-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'skx': {'full': 'skx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sky': {'full': 'sky-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'skz': {'full': 'skz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sl': {'full': 'sl-Latn-SI', 'region': 'SI', 'script': 'Latn', 'suppress': True},
        'sl-Brai': {'full': 'sl-Brai-SI', 'region': 'SI', 'script': 'Brai', 'suppress': False},
        'slc': {'full': 'slc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'sld': {'full': 'sld-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'sle': {'full': 'sle-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'slf': {'full': 'slf-Zxxx-CH', 'region': 'CH', 'script': 'Zxxx', 'suppress': False},
        'slg': {'full': 'slg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'slh': {'full': 'slh-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'sli': {'full': 'sli-Latn-PL', 'region': 'PL', 'script': 'Latn', 'suppress': False},
        'slj': {'full': 'slj-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'sll': {'full': 'sll-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'slm': {'full': 'slm-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sln': {'full': 'sln-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'slp': {'full': 'slp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'slq': {'full': 'slq-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'slr': {'full': 'slr-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'sls': {'full': 'sls-Zxxx-SG', 'region': 'SG', 'script': 'Zxxx', 'suppress': False},
        'slt': {'full': 'slt-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'slu': {'full': 'slu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'slw': {'full': 'slw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'slx': {'full': 'slx-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'sly': {'full': 'sly-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'slz': {'full': 'slz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sm': {'full': 'sm-Latn-WS', 'region': 'WS', 'script': 'Latn', 'suppress': True},
        'sma': {'full': 'sma-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'smb': {'full': 'smb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'smc': {'full': 'smc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'smd': {'full': 'smd-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'smf': {'full': 'smf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'smg': {'full': 'smg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'smh': {'full': 'smh-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'smj': {'full': 'smj-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': False},
        'smk': {'full': 'smk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sml': {'full': 'sml-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'smm': {'full': 'smm-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'smn': {'full': 'smn-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': False},
        'smp': {'full': 'smp-Samr-IL', 'region': 'IL', 'script': 'Samr', 'suppress': False},
        'smp-Arab': {'full': 'smp-Arab-PS', 'region': 'PS', 'script': 'Arab', 'suppress': False},
        'smp-Hebr': {'full': 'smp-Hebr-PS', 'region': 'PS', 'script': 'Hebr', 'suppress': False},
        'smq': {'full': 'smq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'smr': {'full': 'smr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sms': {'full': 'sms-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': False},
        'smt': {'full': 'smt-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'smu': {'full': 'smu-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'smv': {'full': 'smv-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'smw': {'full': 'smw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'smx': {'full': 'smx-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'smy': {'full': 'smy-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'smz': {'full': 'smz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sn': {'full': 'sn-Latn-ZW', 'region': 'ZW', 'script': 'Latn', 'suppress': False},
        'sn-Brai': {'full': 'sn-Brai-ZW', 'region': 'ZW', 'script': 'Brai', 'suppress': False},
        'snb': {'full': 'snb-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'snc': {'full': 'snc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sne': {'full': 'sne-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'snf': {'full': 'snf-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'sng': {'full': 'sng-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'sng-Brai': {'full': 'sng-Brai-CD', 'region': 'CD', 'script': 'Brai', 'suppress': False},
        'snh': {'full': 'snh-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sni': {'full': 'sni-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'snj': {'full': 'snj-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'snk': {'full': 'snk-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'snk-Arab': {'full': 'snk-Arab-ML', 'region': 'ML', 'script': 'Arab', 'suppress': False},
        'snl': {'full': 'snl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'snm': {'full': 'snm-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'snn': {'full': 'snn-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'sno': {'full': 'sno-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'snp': {'full': 'snp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'snp-x-lambau': {'full': 'snp-Latn-PG-x-lambau', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'snq': {'full': 'snq-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'snr': {'full': 'snr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sns': {'full': 'sns-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'snu': {'full': 'snu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'snv': {'full': 'snv-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'snw': {'full': 'snw-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'snx': {'full': 'snx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sny': {'full': 'sny-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'snz': {'full': 'snz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'so': {'full': 'so-Latn-SO', 'region': 'SO', 'script': 'Latn', 'suppress': True},
        'so-Arab': {'full': 'so-Arab-SO', 'region': 'SO', 'script': 'Arab', 'suppress': False},
        'so-DJ': {'full': 'so-Latn-DJ', 'region': 'DJ', 'script': 'Latn', 'suppress': True},
        'so-ET': {'full': 'so-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': True},
        'so-KE': {'full': 'so-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': True},
        'so-Osma': {'full': 'so-Osma-SO', 'region': 'SO', 'script': 'Osma', 'suppress': False},
        'soa': {'full': 'soa-Tavt-TH', 'region': 'TH', 'script': 'Tavt', 'suppress': False},
        'soa-Thai': {'full': 'soa-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'sob': {'full': 'sob-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'soc': {'full': 'soc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'sod': {'full': 'sod-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'soe': {'full': 'soe-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'sog-Mani': {'full': 'sog-Mani-XX', 'region': 'XX', 'script': 'Mani', 'suppress': False},
        'sog-Sogd': {'full': 'sog-Sogd-XX', 'region': 'XX', 'script': 'Sogd', 'suppress': False},
        'sog-Sogo': {'full': 'sog-Sogo-XX', 'region': 'XX', 'script': 'Sogo', 'suppress': False},
        'sog-Syrc': {'full': 'sog-Syrc-XX', 'region': 'XX', 'script': 'Syrc', 'suppress': False},
        'soh': {'full': 'soh-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'soi': {'full': 'soi-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'soj': {'full': 'soj-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'sok': {'full': 'sok-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sol': {'full': 'sol-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'soo': {'full': 'soo-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'sop': {'full': 'sop-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'soq': {'full': 'soq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sor': {'full': 'sor-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sos': {'full': 'sos-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'sou': {'full': 'sou-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'sov': {'full': 'sov-Latn-PW', 'region': 'PW', 'script': 'Latn', 'suppress': False},
        'sow': {'full': 'sow-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sox': {'full': 'sox-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'soy': {'full': 'soy-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'soz': {'full': 'soz-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'spb': {'full': 'spb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'spc': {'full': 'spc-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'spd': {'full': 'spd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'spe': {'full': 'spe-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'spg': {'full': 'spg-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'spi': {'full': 'spi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'spk': {'full': 'spk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'spl': {'full': 'spl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'spm': {'full': 'spm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'spn': {'full': 'spn-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'spo': {'full': 'spo-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'spp': {'full': 'spp-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'spq': {'full': 'spq-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'spr': {'full': 'spr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sps': {'full': 'sps-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'spt': {'full': 'spt-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'spu': {'full': 'spu-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'spv': {'full': 'spv-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'spx': {'full': 'spx-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sq': {'full': 'sq-Latn-AL', 'region': 'AL', 'script': 'Latn', 'suppress': True},
        'sq-Brai': {'full': 'sq-Brai-AL', 'region': 'AL', 'script': 'Brai', 'suppress': False},
        'sq-Elba': {'full': 'sq-Elba-AL', 'region': 'AL', 'script': 'Elba', 'suppress': False},
        'sq-Grek': {'full': 'sq-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'sq-MK': {'full': 'sq-Latn-MK', 'region': 'MK', 'script': 'Latn', 'suppress': True},
        'sq-XK': {'full': 'sq-Latn-XK', 'region': 'XK', 'script': 'Latn', 'suppress': True},
        'sqa': {'full': 'sqa-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'sqh': {'full': 'sqh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'sqk': {'full': 'sqk-Zxxx-AL', 'region': 'AL', 'script': 'Zxxx', 'suppress': False},
        'sqm': {'full': 'sqm-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'sqn': {'full': 'sqn-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sqo': {'full': 'sqo-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'sqq': {'full': 'sqq-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'sqr': {'full': 'sqr-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sqs': {'full': 'sqs-Zxxx-LK', 'region': 'LK', 'script': 'Zxxx', 'suppress': False},
        'sqt': {'full': 'sqt-Arab-YE', 'region': 'YE', 'script': 'Arab', 'suppress': False},
        'sqt-Latn': {'full': 'sqt-Latn-YE', 'region': 'YE', 'script': 'Latn', 'suppress': False},
        'squ': {'full': 'squ-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'sr': {'full': 'sr-Cyrl-RS', 'region': 'RS', 'script': 'Cyrl', 'suppress': False},
        'sr-BA': {'full': 'sr-Cyrl-BA', 'region': 'BA', 'script': 'Cyrl', 'suppress': False},
        'sr-Brai': {'full': 'sr-Brai-RS', 'region': 'RS', 'script': 'Brai', 'suppress': False},
        'sr-Cyrl-ME': {'full': 'sr-Cyrl-ME', 'region': 'ME', 'script': 'Cyrl', 'suppress': False},
        'sr-Latn': {'full': 'sr-Latn-RS', 'region': 'RS', 'script': 'Latn', 'suppress': False},
        'sr-Latn-BA': {'full': 'sr-Latn-BA', 'region': 'BA', 'script': 'Latn', 'suppress': False},
        'sr-Latn-XK': {'full': 'sr-Latn-XK', 'region': 'XK', 'script': 'Latn', 'suppress': False},
        'sr-ME': {'full': 'sr-Latn-ME', 'region': 'ME', 'script': 'Latn', 'suppress': False},
        'sr-RO': {'full': 'sr-Latn-RO', 'region': 'RO', 'script': 'Latn', 'suppress': False},
        'sr-RU': {'full': 'sr-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'sr-TR': {'full': 'sr-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'sr-XK': {'full': 'sr-Cyrl-XK', 'region': 'XK', 'script': 'Cyrl', 'suppress': False},
        'sra': {'full': 'sra-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'srb': {'full': 'srb-Sora-IN', 'region': 'IN', 'script': 'Sora', 'suppress': False},
        'srb-Latn': {'full': 'srb-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'srb-Orya': {'full': 'srb-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'srb-Telu': {'full': 'srb-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'sre': {'full': 'sre-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'srf': {'full': 'srf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'srg': {'full': 'srg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'srh': {'full': 'srh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'sri': {'full': 'sri-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'srk': {'full': 'srk-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'srl': {'full': 'srl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'srm': {'full': 'srm-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'srn': {'full': 'srn-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'sro': {'full': 'sro-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'srq': {'full': 'srq-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'srr': {'full': 'srr-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'srr-Arab': {'full': 'srr-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'srs': {'full': 'srs-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'srt': {'full': 'srt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sru': {'full': 'sru-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'srv': {'full': 'srv-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'srw': {'full': 'srw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'srx': {'full': 'srx-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'srx-Takr': {'full': 'srx-Takr-IN', 'region': 'IN', 'script': 'Takr', 'suppress': False},
        'sry': {'full': 'sry-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'srz': {'full': 'srz-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'ss': {'full': 'ss-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'ssb': {'full': 'ssb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ssc': {'full': 'ssc-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ssd': {'full': 'ssd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sse': {'full': 'sse-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sse-Arab': {'full': 'sse-Arab-PH', 'region': 'PH', 'script': 'Arab', 'suppress': False},
        'ssf': {'full': 'ssf-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'ssg': {'full': 'ssg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ssh': {'full': 'ssh-Arab-AE', 'region': 'AE', 'script': 'Arab', 'suppress': False},
        'ssi': {'full': 'ssi-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ssj': {'full': 'ssj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ssk': {'full': 'ssk-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ssl': {'full': 'ssl-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'ssm': {'full': 'ssm-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'ssn': {'full': 'ssn-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'sso': {'full': 'sso-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ssp': {'full': 'ssp-Zxxx-ES', 'region': 'ES', 'script': 'Zxxx', 'suppress': False},
        'ssq': {'full': 'ssq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ssr': {'full': 'ssr-Zxxx-CH', 'region': 'CH', 'script': 'Zxxx', 'suppress': False},
        'sss': {'full': 'sss-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'sss-Thai': {'full': 'sss-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'sst': {'full': 'sst-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ssu': {'full': 'ssu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ssv': {'full': 'ssv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ssx': {'full': 'ssx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ssy': {'full': 'ssy-Latn-ER', 'region': 'ER', 'script': 'Latn', 'suppress': False},
        'ssy-Ethi': {'full': 'ssy-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'ssz': {'full': 'ssz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'st': {'full': 'st-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'st-LS': {'full': 'st-Latn-LS', 'region': 'LS', 'script': 'Latn', 'suppress': True},
        'sta': {'full': 'sta-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'stb': {'full': 'stb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'std': {'full': 'std-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ste': {'full': 'ste-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'stf': {'full': 'stf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'stg': {'full': 'stg-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'sth': {'full': 'sth-Latn-IE', 'region': 'IE', 'script': 'Latn', 'suppress': False},
        'sti': {'full': 'sti-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'sti-KH': {'full': 'sti-Latn-KH', 'region': 'KH', 'script': 'Latn', 'suppress': False},
        'stj': {'full': 'stj-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'stk': {'full': 'stk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'stl': {'full': 'stl-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'stm': {'full': 'stm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'stn': {'full': 'stn-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'sto': {'full': 'sto-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'stp': {'full': 'stp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'stq': {'full': 'stq-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'str': {'full': 'str-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'sts': {'full': 'sts-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'stt': {'full': 'stt-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'stu': {'full': 'stu-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'stv': {'full': 'stv-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'stv-Arab': {'full': 'stv-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'stw': {'full': 'stw-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'sty': {'full': 'sty-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'su': {'full': 'su-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'su-Arab': {'full': 'su-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'su-Java': {'full': 'su-Java-ID', 'region': 'ID', 'script': 'Java', 'suppress': False},
        'su-Sund': {'full': 'su-Sund-ID', 'region': 'ID', 'script': 'Sund', 'suppress': False},
        'sua': {'full': 'sua-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sub': {'full': 'sub-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'suc': {'full': 'suc-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'sue': {'full': 'sue-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sug': {'full': 'sug-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'sui': {'full': 'sui-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'suj': {'full': 'suj-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'suk': {'full': 'suk-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'suq': {'full': 'suq-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'suq-Ethi': {'full': 'suq-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'sur': {'full': 'sur-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'sus': {'full': 'sus-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'sus-Arab': {'full': 'sus-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'sut': {'full': 'sut-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'suv': {'full': 'suv-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'suv-Beng': {'full': 'suv-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'suv-Deva': {'full': 'suv-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'suw': {'full': 'suw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'sux': {'full': 'sux-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'suy': {'full': 'suy-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'suz': {'full': 'suz-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'sv': {'full': 'sv-Latn-SE', 'region': 'SE', 'script': 'Latn', 'suppress': True},
        'sv-Brai': {'full': 'sv-Brai-SE', 'region': 'SE', 'script': 'Brai', 'suppress': False},
        'sv-FI': {'full': 'sv-Latn-FI', 'region': 'FI', 'script': 'Latn', 'suppress': True},
        'sva': {'full': 'sva-Geor-GE', 'region': 'GE', 'script': 'Geor', 'suppress': False},
        'sva-Cyrl': {'full': 'sva-Cyrl-GE', 'region': 'GE', 'script': 'Cyrl', 'suppress': False},
        'sva-Latn': {'full': 'sva-Latn-GE', 'region': 'GE', 'script': 'Latn', 'suppress': False},
        'svb': {'full': 'svb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'svc': {'full': 'svc-Latn-VC', 'region': 'VC', 'script': 'Latn', 'suppress': False},
        'sve': {'full': 'sve-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'svk': {'full': 'svk-Zxxx-SK', 'region': 'SK', 'script': 'Zxxx', 'suppress': False},
        'svm': {'full': 'svm-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'svs': {'full': 'svs-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'svx': {'full': 'svx-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sw': {'full': 'sw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': True},
        'sw-Arab': {'full': 'sw-Arab-TZ', 'region': 'TZ', 'script': 'Arab', 'suppress': False},
        'sw-CD': {'full': 'sw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': True},
        'sw-KE': {'full': 'sw-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': True},
        'sw-UG': {'full': 'sw-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': True},
        'swb': {'full': 'swb-Arab-YT', 'region': 'YT', 'script': 'Arab', 'suppress': False},
        'swb-Latn': {'full': 'swb-Latn-YT', 'region': 'YT', 'script': 'Latn', 'suppress': False},
        'swc': {'full': 'swc-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'swc-Arab': {'full': 'swc-Arab-CD', 'region': 'CD', 'script': 'Arab', 'suppress': False},
        'swf': {'full': 'swf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'swg': {'full': 'swg-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'swh-Arab': {'full': 'swh-Arab-TZ', 'region': 'TZ', 'script': 'Arab', 'suppress': False},
        'swh-Brai': {'full': 'swh-Brai-TZ', 'region': 'TZ', 'script': 'Brai', 'suppress': False},
        'swi': {'full': 'swi-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'swj': {'full': 'swj-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'swk': {'full': 'swk-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'swl': {'full': 'swl-Zxxx-SE', 'region': 'SE', 'script': 'Zxxx', 'suppress': False},
        'swm': {'full': 'swm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'swn': {'full': 'swn-Zyyy-LY', 'region': 'LY', 'script': 'Zyyy', 'suppress': False},
        'swo': {'full': 'swo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'swp': {'full': 'swp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'swq': {'full': 'swq-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'swr': {'full': 'swr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sws': {'full': 'sws-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'swt': {'full': 'swt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'swu': {'full': 'swu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'swv': {'full': 'swv-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'sww': {'full': 'sww-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'swx': {'full': 'swx-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'swy': {'full': 'swy-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'sxb': {'full': 'sxb-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'sxc': {'full': 'sxc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sxe': {'full': 'sxe-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'sxg': {'full': 'sxg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'sxk': {'full': 'sxk-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sxl': {'full': 'sxl-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sxm': {'full': 'sxm-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'sxn': {'full': 'sxn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'sxo': {'full': 'sxo-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'sxr': {'full': 'sxr-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'sxs': {'full': 'sxs-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'sxu': {'full': 'sxu-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'sxw': {'full': 'sxw-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'sya': {'full': 'sya-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'syb': {'full': 'syb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'syc': {'full': 'syc-Syrc-TR', 'region': 'TR', 'script': 'Syrc', 'suppress': False},
        'syi': {'full': 'syi-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'syk': {'full': 'syk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'syl': {'full': 'syl-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'syl-Latn': {'full': 'syl-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'syl-Sylo': {'full': 'syl-Sylo-BD', 'region': 'BD', 'script': 'Sylo', 'suppress': False},
        'sym': {'full': 'sym-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'syn': {'full': 'syn-Syrc-IR', 'region': 'IR', 'script': 'Syrc', 'suppress': False},
        'syo': {'full': 'syo-Latn-KH', 'region': 'KH', 'script': 'Latn', 'suppress': False},
        'syr': {'full': 'syr-Syrc-IQ', 'region': 'IQ', 'script': 'Syrc', 'suppress': False},
        'sys': {'full': 'sys-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'syw': {'full': 'syw-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'syx': {'full': 'syx-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'syy': {'full': 'syy-Zxxx-IL', 'region': 'IL', 'script': 'Zxxx', 'suppress': False},
        'sza': {'full': 'sza-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'szb': {'full': 'szb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'szc': {'full': 'szc-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'szd': {'full': 'szd-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'sze': {'full': 'sze-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'szg': {'full': 'szg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'szl': {'full': 'szl-Latn-PL', 'region': 'PL', 'script': 'Latn', 'suppress': False},
        'szn': {'full': 'szn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'szp': {'full': 'szp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'szs': {'full': 'szs-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'szs-Zxxx': {'full': 'szs-Zxxx-SB', 'region': 'SB', 'script': 'Zxxx', 'suppress': False},
        'szv': {'full': 'szv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'szw': {'full': 'szw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'szy': {'full': 'szy-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'ta': {'full': 'ta-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': True},
        'ta-Brai': {'full': 'ta-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'ta-LK': {'full': 'ta-Taml-LK', 'region': 'LK', 'script': 'Taml', 'suppress': True},
        'ta-MY': {'full': 'ta-Taml-MY', 'region': 'MY', 'script': 'Taml', 'suppress': True},
        'ta-SG': {'full': 'ta-Taml-SG', 'region': 'SG', 'script': 'Taml', 'suppress': True},
        'taa': {'full': 'taa-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tab': {'full': 'tab-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'tac': {'full': 'tac-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tad': {'full': 'tad-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tae': {'full': 'tae-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'taf': {'full': 'taf-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tag': {'full': 'tag-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'taj': {'full': 'taj-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'taj-Tibt': {'full': 'taj-Tibt-BT', 'region': 'BT', 'script': 'Tibt', 'suppress': False},
        'taj-Tibt-x-tamhig': {'full': 'taj-Tibt-BT-x-tamhig', 'region': 'BT', 'script': 'Tibt', 'suppress': False},
        'tak': {'full': 'tak-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tal': {'full': 'tal-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tan': {'full': 'tan-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tao': {'full': 'tao-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'tap': {'full': 'tap-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'taq-Latn': {'full': 'taq-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'taq-Tfng': {'full': 'taq-Tfng-ML', 'region': 'ML', 'script': 'Tfng', 'suppress': False},
        'tar': {'full': 'tar-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tas': {'full': 'tas-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tau': {'full': 'tau-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tav': {'full': 'tav-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'taw': {'full': 'taw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tax': {'full': 'tax-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'tay': {'full': 'tay-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'tay-Hans': {'full': 'tay-Hans-TW', 'region': 'TW', 'script': 'Hans', 'suppress': False},
        'tay-Hant': {'full': 'tay-Hant-TW', 'region': 'TW', 'script': 'Hant', 'suppress': False},
        'taz': {'full': 'taz-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'tba': {'full': 'tba-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tbb': {'full': 'tbb-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tbc': {'full': 'tbc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbd': {'full': 'tbd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbe': {'full': 'tbe-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tbf': {'full': 'tbf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbg': {'full': 'tbg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbh': {'full': 'tbh-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tbi': {'full': 'tbi-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'tbj': {'full': 'tbj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbk': {'full': 'tbk-Tagb-PH', 'region': 'PH', 'script': 'Tagb', 'suppress': False},
        'tbk-Latn': {'full': 'tbk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tbl': {'full': 'tbl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tbm': {'full': 'tbm-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tbn': {'full': 'tbn-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tbo': {'full': 'tbo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbp': {'full': 'tbp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tbr': {'full': 'tbr-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'tbs': {'full': 'tbs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbt': {'full': 'tbt-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tbu': {'full': 'tbu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tbv': {'full': 'tbv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tbw': {'full': 'tbw-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tbw-Tagb': {'full': 'tbw-Tagb-PH', 'region': 'PH', 'script': 'Tagb', 'suppress': False},
        'tbx': {'full': 'tbx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tby': {'full': 'tby-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tbz': {'full': 'tbz-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'tca': {'full': 'tca-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tcb': {'full': 'tcb-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tcc': {'full': 'tcc-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'tcd': {'full': 'tcd-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'tce': {'full': 'tce-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'tcf': {'full': 'tcf-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tcg': {'full': 'tcg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tch': {'full': 'tch-Latn-TC', 'region': 'TC', 'script': 'Latn', 'suppress': False},
        'tci': {'full': 'tci-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tck': {'full': 'tck-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'tcl': {'full': 'tcl-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'tcm': {'full': 'tcm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tcn': {'full': 'tcn-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'tco': {'full': 'tco-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'tcp': {'full': 'tcp-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'tcq': {'full': 'tcq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tcs': {'full': 'tcs-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tct': {'full': 'tct-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'tcu': {'full': 'tcu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tcw': {'full': 'tcw-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tcx': {'full': 'tcx-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'tcy': {'full': 'tcy-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'tcy-Zzzz-x-tulu': {'full': 'tcy-Zzzz-IN-x-tulu', 'region': 'IN', 'script': 'Zzzz', 'suppress': False},
        'tcz': {'full': 'tcz-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'tda-Arab': {'full': 'tda-Arab-NE', 'region': 'NE', 'script': 'Arab', 'suppress': False},
        'tda-Latn': {'full': 'tda-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'tda-Tfng': {'full': 'tda-Tfng-NE', 'region': 'NE', 'script': 'Tfng', 'suppress': False},
        'tdb': {'full': 'tdb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'tdb-Beng': {'full': 'tdb-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'tdb-Kthi': {'full': 'tdb-Kthi-IN', 'region': 'IN', 'script': 'Kthi', 'suppress': False},
        'tdc': {'full': 'tdc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tdd': {'full': 'tdd-Tale-CN', 'region': 'CN', 'script': 'Tale', 'suppress': False},
        'tdd-MM': {'full': 'tdd-Tale-MM', 'region': 'MM', 'script': 'Tale', 'suppress': False},
        'tde': {'full': 'tde-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'tdf': {'full': 'tdf-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'tdg': {'full': 'tdg-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'tdg-Tibt': {'full': 'tdg-Tibt-NP', 'region': 'NP', 'script': 'Tibt', 'suppress': False},
        'tdh': {'full': 'tdh-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'tdi': {'full': 'tdi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tdj': {'full': 'tdj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tdk': {'full': 'tdk-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tdl': {'full': 'tdl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tdm': {'full': 'tdm-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'tdn': {'full': 'tdn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tdo': {'full': 'tdo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tdq': {'full': 'tdq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tdr': {'full': 'tdr-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tds': {'full': 'tds-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tdt': {'full': 'tdt-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'tdv': {'full': 'tdv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tdx': {'full': 'tdx-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'tdy': {'full': 'tdy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'te': {'full': 'te-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': True},
        'te-Brai': {'full': 'te-Brai-IN', 'region': 'IN', 'script': 'Brai', 'suppress': False},
        'tea': {'full': 'tea-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'teb': {'full': 'teb-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'tec': {'full': 'tec-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'ted': {'full': 'ted-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'tee': {'full': 'tee-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tef': {'full': 'tef-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'teg': {'full': 'teg-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'teh': {'full': 'teh-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'tei': {'full': 'tei-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tek': {'full': 'tek-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tem': {'full': 'tem-Latn-SL', 'region': 'SL', 'script': 'Latn', 'suppress': True},
        'ten': {'full': 'ten-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'teo': {'full': 'teo-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'teo-KE': {'full': 'teo-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'tep': {'full': 'tep-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'teq': {'full': 'teq-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ter': {'full': 'ter-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tes': {'full': 'tes-Java-ID', 'region': 'ID', 'script': 'Java', 'suppress': False},
        'tet': {'full': 'tet-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'teu': {'full': 'teu-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'tev': {'full': 'tev-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tew': {'full': 'tew-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tew-x-sanclara': {'full': 'tew-Latn-US-x-sanclara', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tew-x-sanjuan': {'full': 'tew-Latn-US-x-sanjuan', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tex': {'full': 'tex-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'tey': {'full': 'tey-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'tez-Latn': {'full': 'tez-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'tez-Tfng': {'full': 'tez-Tfng-NE', 'region': 'NE', 'script': 'Tfng', 'suppress': False},
        'tfi': {'full': 'tfi-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'tfn': {'full': 'tfn-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tfo': {'full': 'tfo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tfr': {'full': 'tfr-Latn-PA', 'region': 'PA', 'script': 'Latn', 'suppress': False},
        'tft': {'full': 'tft-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tg': {'full': 'tg-Cyrl-TJ', 'region': 'TJ', 'script': 'Cyrl', 'suppress': False},
        'tg-Arab': {'full': 'tg-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'tg-Hebr': {'full': 'tg-Hebr-UZ', 'region': 'UZ', 'script': 'Hebr', 'suppress': False},
        'tg-Latn': {'full': 'tg-Latn-TJ', 'region': 'TJ', 'script': 'Latn', 'suppress': False},
        'tga': {'full': 'tga-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'tgb': {'full': 'tgb-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'tgc': {'full': 'tgc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tgd': {'full': 'tgd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tge': {'full': 'tge-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'tgf': {'full': 'tgf-Zyyy-BT', 'region': 'BT', 'script': 'Zyyy', 'suppress': False},
        'tgh': {'full': 'tgh-Latn-TT', 'region': 'TT', 'script': 'Latn', 'suppress': False},
        'tgi': {'full': 'tgi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tgj': {'full': 'tgj-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'tgn': {'full': 'tgn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tgo': {'full': 'tgo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tgp': {'full': 'tgp-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tgq': {'full': 'tgq-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'tgr': {'full': 'tgr-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'tgs': {'full': 'tgs-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tgt': {'full': 'tgt-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tgu': {'full': 'tgu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tgv': {'full': 'tgv-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tgw': {'full': 'tgw-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'tgx': {'full': 'tgx-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'tgy': {'full': 'tgy-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'tgz': {'full': 'tgz-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'th': {'full': 'th-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': True},
        'th-Brai': {'full': 'th-Brai-TH', 'region': 'TH', 'script': 'Brai', 'suppress': False},
        'thd': {'full': 'thd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'the': {'full': 'the-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'thf': {'full': 'thf-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'thh': {'full': 'thh-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'thi': {'full': 'thi-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'thk': {'full': 'thk-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'thl': {'full': 'thl-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'thm': {'full': 'thm-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'thn': {'full': 'thn-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'thp': {'full': 'thp-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'thp-Dupl': {'full': 'thp-Dupl-CA', 'region': 'CA', 'script': 'Dupl', 'suppress': False},
        'thq': {'full': 'thq-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'thr': {'full': 'thr-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'ths': {'full': 'ths-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'tht': {'full': 'tht-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'thu': {'full': 'thu-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'thv-Arab': {'full': 'thv-Arab-DZ', 'region': 'DZ', 'script': 'Arab', 'suppress': False},
        'thv-Latn': {'full': 'thv-Latn-DZ', 'region': 'DZ', 'script': 'Latn', 'suppress': False},
        'thv-Latn-DZ-x-ahaggar': {'full': 'thv-Latn-DZ-x-ahaggar', 'region': 'DZ', 'script': 'Latn', 'suppress': False},
        'thv-Tfng': {'full': 'thv-Tfng-DZ', 'region': 'DZ', 'script': 'Tfng', 'suppress': False},
        'thw': {'full': 'thw-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'thy': {'full': 'thy-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'thz-Latn': {'full': 'thz-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'thz-Tfng': {'full': 'thz-Tfng-NE', 'region': 'NE', 'script': 'Tfng', 'suppress': False},
        'ti': {'full': 'ti-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': True},
        'ti-Arab': {'full': 'ti-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'ti-ER': {'full': 'ti-Ethi-ER', 'region': 'ER', 'script': 'Ethi', 'suppress': True},
        'tia': {'full': 'tia-Zyyy-DZ', 'region': 'DZ', 'script': 'Zyyy', 'suppress': False},
        'tic': {'full': 'tic-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'tif': {'full': 'tif-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tig': {'full': 'tig-Ethi-ER', 'region': 'ER', 'script': 'Ethi', 'suppress': False},
        'tig-SD': {'full': 'tig-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'tih': {'full': 'tih-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'tii': {'full': 'tii-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tij': {'full': 'tij-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'tik': {'full': 'tik-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'til': {'full': 'til-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'tim': {'full': 'tim-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tin': {'full': 'tin-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'tio': {'full': 'tio-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tip': {'full': 'tip-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tiq': {'full': 'tiq-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'tis': {'full': 'tis-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tit': {'full': 'tit-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tiu': {'full': 'tiu-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tiv': {'full': 'tiv-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tiw': {'full': 'tiw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tix': {'full': 'tix-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tiy': {'full': 'tiy-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tiz': {'full': 'tiz-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'tja': {'full': 'tja-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'tjg': {'full': 'tjg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tji': {'full': 'tji-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'tjj': {'full': 'tjj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tjl': {'full': 'tjl-Mymr-MM', 'region': 'MM', 'script': 'Mymr', 'suppress': False},
        'tjm': {'full': 'tjm-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'tjn': {'full': 'tjn-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'tjo': {'full': 'tjo-Zyyy-DZ', 'region': 'DZ', 'script': 'Zyyy', 'suppress': False},
        'tjp': {'full': 'tjp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tjs': {'full': 'tjs-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'tju': {'full': 'tju-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tjw': {'full': 'tjw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tk': {'full': 'tk-Latn-TM', 'region': 'TM', 'script': 'Latn', 'suppress': False},
        'tk-Arab': {'full': 'tk-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'tk-Arab-IR': {'full': 'tk-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'tk-Cyrl': {'full': 'tk-Cyrl-TM', 'region': 'TM', 'script': 'Cyrl', 'suppress': False},
        'tka': {'full': 'tka-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tkb': {'full': 'tkb-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'tkd': {'full': 'tkd-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'tke': {'full': 'tke-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'tkf': {'full': 'tkf-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tkg': {'full': 'tkg-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'tkl': {'full': 'tkl-Latn-TK', 'region': 'TK', 'script': 'Latn', 'suppress': True},
        'tkm': {'full': 'tkm-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'tkn': {'full': 'tkn-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'tkp': {'full': 'tkp-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tkq': {'full': 'tkq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tkr': {'full': 'tkr-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'tkr-Cyrl': {'full': 'tkr-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'tks': {'full': 'tks-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'tkt': {'full': 'tkt-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'tku': {'full': 'tku-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tkv': {'full': 'tkv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tkw': {'full': 'tkw-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tkx': {'full': 'tkx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tkz': {'full': 'tkz-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tl': {'full': 'tl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': True},
        'tl-Brai': {'full': 'tl-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'tl-Tglg': {'full': 'tl-Tglg-PH', 'region': 'PH', 'script': 'Tglg', 'suppress': False},
        'tla': {'full': 'tla-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tlb': {'full': 'tlb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlc': {'full': 'tlc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tld': {'full': 'tld-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlf': {'full': 'tlf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tlg': {'full': 'tlg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlh': {'full': 'tlh-Piqd-001', 'region': '001', 'script': 'Piqd', 'suppress': False},
        'tlh-Latn': {'full': 'tlh-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'tli': {'full': 'tli-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tli-Cyrl': {'full': 'tli-Cyrl-US', 'region': 'US', 'script': 'Cyrl', 'suppress': False},
        'tlj': {'full': 'tlj-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'tlj-GH': {'full': 'tlj-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'tlk': {'full': 'tlk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tll': {'full': 'tll-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tlm': {'full': 'tlm-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tln': {'full': 'tln-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlo': {'full': 'tlo-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'tlp': {'full': 'tlp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tlq': {'full': 'tlq-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'tlr': {'full': 'tlr-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tls': {'full': 'tls-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tlt': {'full': 'tlt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlu': {'full': 'tlu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlv': {'full': 'tlv-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tlx': {'full': 'tlx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tly': {'full': 'tly-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'tly-Arab': {'full': 'tly-Arab-AZ', 'region': 'AZ', 'script': 'Arab', 'suppress': False},
        'tly-Cyrl': {'full': 'tly-Cyrl-AZ', 'region': 'AZ', 'script': 'Cyrl', 'suppress': False},
        'tma': {'full': 'tma-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'tmb': {'full': 'tmb-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tmc': {'full': 'tmc-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'tmd': {'full': 'tmd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tme': {'full': 'tme-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tmf': {'full': 'tmf-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'tmg': {'full': 'tmg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tmh': {'full': 'tmh-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': True},
        'tmh-Arab': {'full': 'tmh-Arab-NE', 'region': 'NE', 'script': 'Arab', 'suppress': False},
        'tmh-Tfng': {'full': 'tmh-Tfng-NE', 'region': 'NE', 'script': 'Tfng', 'suppress': False},
        'tmi': {'full': 'tmi-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tmj': {'full': 'tmj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tmk': {'full': 'tmk-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'tml': {'full': 'tml-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tmm': {'full': 'tmm-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tmn': {'full': 'tmn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tmo': {'full': 'tmo-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'tmq': {'full': 'tmq-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tmr': {'full': 'tmr-Syrc-IL', 'region': 'IL', 'script': 'Syrc', 'suppress': False},
        'tms': {'full': 'tms-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'tmt': {'full': 'tmt-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tmu': {'full': 'tmu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tmv': {'full': 'tmv-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tmw': {'full': 'tmw-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'tmy': {'full': 'tmy-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tmz': {'full': 'tmz-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'tn': {'full': 'tn-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'tn-BW': {'full': 'tn-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': True},
        'tna': {'full': 'tna-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'tnb': {'full': 'tnb-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tnc': {'full': 'tnc-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tnd': {'full': 'tnd-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tng': {'full': 'tng-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'tnh': {'full': 'tnh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tni': {'full': 'tni-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tnk': {'full': 'tnk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tnl': {'full': 'tnl-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tnm': {'full': 'tnm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tnn': {'full': 'tnn-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tno': {'full': 'tno-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'tnp': {'full': 'tnp-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tnq': {'full': 'tnq-Latn-PR', 'region': 'PR', 'script': 'Latn', 'suppress': False},
        'tnr': {'full': 'tnr-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'tns': {'full': 'tns-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tnt': {'full': 'tnt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tnu': {'full': 'tnu-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'tnv': {'full': 'tnv-Cakm-BD', 'region': 'BD', 'script': 'Cakm', 'suppress': False},
        'tnw': {'full': 'tnw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tnx': {'full': 'tnx-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tny': {'full': 'tny-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'tnz': {'full': 'tnz-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'to': {'full': 'to-Latn-TO', 'region': 'TO', 'script': 'Latn', 'suppress': True},
        'tob': {'full': 'tob-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'toc': {'full': 'toc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tod': {'full': 'tod-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'tof': {'full': 'tof-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tog': {'full': 'tog-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'toh': {'full': 'toh-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'toi': {'full': 'toi-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'toj': {'full': 'toj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tol': {'full': 'tol-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tom': {'full': 'tom-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'too': {'full': 'too-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'top': {'full': 'top-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'toq': {'full': 'toq-Latn-SS', 'region': 'SS', 'script': 'Latn', 'suppress': False},
        'tor': {'full': 'tor-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'tos': {'full': 'tos-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tou': {'full': 'tou-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tov': {'full': 'tov-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'tow': {'full': 'tow-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tox': {'full': 'tox-Latn-PW', 'region': 'PW', 'script': 'Latn', 'suppress': False},
        'toy': {'full': 'toy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'toz': {'full': 'toz-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'tpa': {'full': 'tpa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tpc': {'full': 'tpc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tpe-Beng': {'full': 'tpe-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'tpe-Latn': {'full': 'tpe-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'tpf': {'full': 'tpf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tpg': {'full': 'tpg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tpi': {'full': 'tpi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': True},
        'tpj': {'full': 'tpj-Latn-PY', 'region': 'PY', 'script': 'Latn', 'suppress': False},
        'tpk': {'full': 'tpk-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tpl': {'full': 'tpl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tpm': {'full': 'tpm-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'tpn': {'full': 'tpn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tpo': {'full': 'tpo-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'tpp': {'full': 'tpp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tpq': {'full': 'tpq-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'tpr': {'full': 'tpr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tpt': {'full': 'tpt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tpu': {'full': 'tpu-Khmr-KH', 'region': 'KH', 'script': 'Khmr', 'suppress': False},
        'tpv': {'full': 'tpv-Latn-MP', 'region': 'MP', 'script': 'Latn', 'suppress': False},
        'tpw': {'full': 'tpw-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'tpx': {'full': 'tpx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tpy': {'full': 'tpy-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tpz': {'full': 'tpz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tqb': {'full': 'tqb-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tql': {'full': 'tql-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tqm': {'full': 'tqm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tqn': {'full': 'tqn-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tqo': {'full': 'tqo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tqp': {'full': 'tqp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tqq': {'full': 'tqq-Zyyy-SO', 'region': 'SO', 'script': 'Zyyy', 'suppress': False},
        'tqr': {'full': 'tqr-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'tqt': {'full': 'tqt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tqu': {'full': 'tqu-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tqw': {'full': 'tqw-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'tr': {'full': 'tr-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': True},
        'tr-Arab': {'full': 'tr-Arab-TR', 'region': 'TR', 'script': 'Arab', 'suppress': False},
        'tr-Brai': {'full': 'tr-Brai-TR', 'region': 'TR', 'script': 'Brai', 'suppress': False},
        'tr-CY': {'full': 'tr-Latn-CY', 'region': 'CY', 'script': 'Latn', 'suppress': True},
        'tr-Cyrl': {'full': 'tr-Cyrl-BG', 'region': 'BG', 'script': 'Cyrl', 'suppress': False},
        'tr-Grek': {'full': 'tr-Grek-TR', 'region': 'TR', 'script': 'Grek', 'suppress': False},
        'tra': {'full': 'tra-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'trb': {'full': 'trb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'trc': {'full': 'trc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'trd': {'full': 'trd-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'tre': {'full': 'tre-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'trf': {'full': 'trf-Latn-TT', 'region': 'TT', 'script': 'Latn', 'suppress': False},
        'trg': {'full': 'trg-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'trh': {'full': 'trh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tri': {'full': 'tri-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'trj': {'full': 'trj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'trl': {'full': 'trl-Zyyy-GB', 'region': 'GB', 'script': 'Zyyy', 'suppress': False},
        'trm': {'full': 'trm-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'trn': {'full': 'trn-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'tro': {'full': 'tro-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'trp-Beng': {'full': 'trp-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'trp-Latn': {'full': 'trp-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'trq': {'full': 'trq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'trr': {'full': 'trr-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'trs': {'full': 'trs-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'trt': {'full': 'trt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tru': {'full': 'tru-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'tru-Syrc': {'full': 'tru-Syrc-TR', 'region': 'TR', 'script': 'Syrc', 'suppress': False},
        'trv': {'full': 'trv-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'trw': {'full': 'trw-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'trx': {'full': 'trx-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'try': {'full': 'try-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'trz': {'full': 'trz-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ts': {'full': 'ts-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'ts-Brai': {'full': 'ts-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'tsa': {'full': 'tsa-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'tsb': {'full': 'tsb-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'tsc': {'full': 'tsc-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'tsd': {'full': 'tsd-Grek-GR', 'region': 'GR', 'script': 'Grek', 'suppress': False},
        'tse': {'full': 'tse-Zxxx-TN', 'region': 'TN', 'script': 'Zxxx', 'suppress': False},
        'tsg': {'full': 'tsg-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'tsg-Arab': {'full': 'tsg-Arab-PH', 'region': 'PH', 'script': 'Arab', 'suppress': False},
        'tsh': {'full': 'tsh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'tsi': {'full': 'tsi-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'tsj': {'full': 'tsj-Tibt-BT', 'region': 'BT', 'script': 'Tibt', 'suppress': False},
        'tsk': {'full': 'tsk-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'tsl': {'full': 'tsl-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tsm': {'full': 'tsm-Zxxx-TR', 'region': 'TR', 'script': 'Zxxx', 'suppress': False},
        'tsp': {'full': 'tsp-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'tsq': {'full': 'tsq-Zxxx-TH', 'region': 'TH', 'script': 'Zxxx', 'suppress': False},
        'tsr': {'full': 'tsr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tss': {'full': 'tss-Zxxx-TW', 'region': 'TW', 'script': 'Zxxx', 'suppress': False},
        'tst': {'full': 'tst-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'tsu': {'full': 'tsu-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'tsv': {'full': 'tsv-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'tsw': {'full': 'tsw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tsx': {'full': 'tsx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tsy': {'full': 'tsy-Zxxx-ML', 'region': 'ML', 'script': 'Zxxx', 'suppress': False},
        'tsz': {'full': 'tsz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tt': {'full': 'tt-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'tt-Latn': {'full': 'tt-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'tta': {'full': 'tta-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'ttb': {'full': 'ttb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ttc': {'full': 'ttc-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'ttd': {'full': 'ttd-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tte': {'full': 'tte-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ttf': {'full': 'ttf-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ttg': {'full': 'ttg-Zyyy-BN', 'region': 'BN', 'script': 'Zyyy', 'suppress': False},
        'tth': {'full': 'tth-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'tti': {'full': 'tti-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ttj': {'full': 'ttj-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'ttk': {'full': 'ttk-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ttl': {'full': 'ttl-Latn-ZM', 'region': 'ZM', 'script': 'Latn', 'suppress': False},
        'ttm': {'full': 'ttm-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'ttn': {'full': 'ttn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tto': {'full': 'tto-Laoo-LA', 'region': 'LA', 'script': 'Laoo', 'suppress': False},
        'ttp': {'full': 'ttp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ttr': {'full': 'ttr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tts': {'full': 'tts-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'ttt': {'full': 'ttt-Latn-AZ', 'region': 'AZ', 'script': 'Latn', 'suppress': False},
        'ttt-Arab': {'full': 'ttt-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'ttt-Cyrl': {'full': 'ttt-Cyrl-AZ', 'region': 'AZ', 'script': 'Cyrl', 'suppress': False},
        'ttu': {'full': 'ttu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ttv': {'full': 'ttv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ttw': {'full': 'ttw-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'tty': {'full': 'tty-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ttz': {'full': 'ttz-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'tua': {'full': 'tua-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tub': {'full': 'tub-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tuc': {'full': 'tuc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tuc-x-oov': {'full': 'tuc-Latn-PG-x-oov', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tuc-x-tuam': {'full': 'tuc-Latn-PG-x-tuam', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tud': {'full': 'tud-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tue': {'full': 'tue-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tuf': {'full': 'tuf-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'tug': {'full': 'tug-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'tuh': {'full': 'tuh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tui': {'full': 'tui-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'tuj': {'full': 'tuj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tul': {'full': 'tul-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tum': {'full': 'tum-Latn-MW', 'region': 'MW', 'script': 'Latn', 'suppress': False},
        'tun': {'full': 'tun-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'tuo': {'full': 'tuo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tuq': {'full': 'tuq-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'tus': {'full': 'tus-Latn-CA', 'region': 'CA', 'script': 'Latn', 'suppress': False},
        'tuu': {'full': 'tuu-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'tuv': {'full': 'tuv-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'tux': {'full': 'tux-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'tuy': {'full': 'tuy-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'tuz': {'full': 'tuz-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'tva': {'full': 'tva-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'tvd': {'full': 'tvd-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tve': {'full': 'tve-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tvk': {'full': 'tvk-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'tvl': {'full': 'tvl-Latn-TV', 'region': 'TV', 'script': 'Latn', 'suppress': True},
        'tvm': {'full': 'tvm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tvn': {'full': 'tvn-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'tvo': {'full': 'tvo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tvs': {'full': 'tvs-Latn-KE', 'region': 'KE', 'script': 'Latn', 'suppress': False},
        'tvt': {'full': 'tvt-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'tvu': {'full': 'tvu-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'tvw': {'full': 'tvw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tvx': {'full': 'tvx-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'tvy': {'full': 'tvy-Zyyy-TL', 'region': 'TL', 'script': 'Zyyy', 'suppress': False},
        'twa': {'full': 'twa-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'twb': {'full': 'twb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'twc': {'full': 'twc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'twd': {'full': 'twd-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'twe': {'full': 'twe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'twf': {'full': 'twf-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'twg': {'full': 'twg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'twh': {'full': 'twh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'twh-Tavt': {'full': 'twh-Tavt-VN', 'region': 'VN', 'script': 'Tavt', 'suppress': False},
        'twl': {'full': 'twl-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'twm': {'full': 'twm-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'twn': {'full': 'twn-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'two': {'full': 'two-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'twp': {'full': 'twp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'twq': {'full': 'twq-Latn-NE', 'region': 'NE', 'script': 'Latn', 'suppress': False},
        'twr': {'full': 'twr-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'twt': {'full': 'twt-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'twu': {'full': 'twu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tww': {'full': 'tww-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'twx': {'full': 'twx-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'twy': {'full': 'twy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txa': {'full': 'txa-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'txb': {'full': 'txb-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'txc': {'full': 'txc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'txe': {'full': 'txe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txg-Tang': {'full': 'txg-Tang-CN', 'region': 'CN', 'script': 'Tang', 'suppress': False},
        'txh': {'full': 'txh-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'txi': {'full': 'txi-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'txj': {'full': 'txj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'txm': {'full': 'txm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txn': {'full': 'txn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txo-Beng': {'full': 'txo-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'txo-Deva': {'full': 'txo-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'txo-Toto': {'full': 'txo-Toto-IN', 'region': 'IN', 'script': 'Toto', 'suppress': False},
        'txq': {'full': 'txq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txr': {'full': 'txr-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'txs': {'full': 'txs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txt': {'full': 'txt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'txu': {'full': 'txu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'txx': {'full': 'txx-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'txy': {'full': 'txy-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'ty': {'full': 'ty-Latn-PF', 'region': 'PF', 'script': 'Latn', 'suppress': False},
        'tya': {'full': 'tya-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'tye': {'full': 'tye-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'tyh': {'full': 'tyh-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tyi': {'full': 'tyi-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'tyj': {'full': 'tyj-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tyj-Zzzz-x-taiyo': {'full': 'tyj-Zzzz-VN-x-taiyo', 'region': 'VN', 'script': 'Zzzz', 'suppress': False},
        'tyl': {'full': 'tyl-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tyn': {'full': 'tyn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'typ': {'full': 'typ-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'tyr': {'full': 'tyr-Tavt-VN', 'region': 'VN', 'script': 'Tavt', 'suppress': False},
        'tys': {'full': 'tys-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tyt-Latn': {'full': 'tyt-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tyt-Tavt': {'full': 'tyt-Tavt-VN', 'region': 'VN', 'script': 'Tavt', 'suppress': False},
        'tyu': {'full': 'tyu-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'tyv': {'full': 'tyv-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'tyx': {'full': 'tyx-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'tyz': {'full': 'tyz-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'tza': {'full': 'tza-Zxxx-TZ', 'region': 'TZ', 'script': 'Zxxx', 'suppress': False},
        'tzh': {'full': 'tzh-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tzj': {'full': 'tzj-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'tzj-x-western': {'full': 'tzj-Latn-GT-x-western', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'tzl': {'full': 'tzl-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'tzm': {'full': 'tzm-Latn-MA', 'region': 'MA', 'script': 'Latn', 'suppress': False},
        'tzm-Arab': {'full': 'tzm-Arab-MA', 'region': 'MA', 'script': 'Arab', 'suppress': False},
        'tzm-Tfng': {'full': 'tzm-Tfng-MA', 'region': 'MA', 'script': 'Tfng', 'suppress': False},
        'tzn': {'full': 'tzn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'tzo': {'full': 'tzo-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tzo-x-huixtan': {'full': 'tzo-Latn-MX-x-huixtan', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tzo-x-sanandre': {'full': 'tzo-Latn-MX-x-sanandre', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tzo-x-zinacntn': {'full': 'tzo-Latn-MX-x-zinacntn', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'tzx': {'full': 'tzx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uam': {'full': 'uam-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'uan': {'full': 'uan-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'uar': {'full': 'uar-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uba': {'full': 'uba-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ubi': {'full': 'ubi-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'ubl': {'full': 'ubl-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'ubr': {'full': 'ubr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ubu': {'full': 'ubu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ubu-x-kala': {'full': 'ubu-Latn-PG-x-kala', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ubu-x-nopenge': {'full': 'ubu-Latn-PG-x-nopenge', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uby': {'full': 'uby-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'uda': {'full': 'uda-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ude': {'full': 'ude-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'udg': {'full': 'udg-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'udi': {'full': 'udi-Cyrl-AZ', 'region': 'AZ', 'script': 'Cyrl', 'suppress': False},
        'udj': {'full': 'udj-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'udl': {'full': 'udl-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'udm': {'full': 'udm-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'udm-Latn': {'full': 'udm-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'udu': {'full': 'udu-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'ues': {'full': 'ues-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ufi': {'full': 'ufi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ug': {'full': 'ug-Arab-CN', 'region': 'CN', 'script': 'Arab', 'suppress': False},
        'ug-KZ': {'full': 'ug-Cyrl-KZ', 'region': 'KZ', 'script': 'Cyrl', 'suppress': False},
        'ug-Latn': {'full': 'ug-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'ug-MN': {'full': 'ug-Cyrl-MN', 'region': 'MN', 'script': 'Cyrl', 'suppress': False},
        'uga': {'full': 'uga-Ugar-SY', 'region': 'SY', 'script': 'Ugar', 'suppress': False},
        'ugb': {'full': 'ugb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'uge': {'full': 'uge-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'ugn': {'full': 'ugn-Zxxx-UG', 'region': 'UG', 'script': 'Zxxx', 'suppress': False},
        'ugo': {'full': 'ugo-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'ugy': {'full': 'ugy-Zxxx-UY', 'region': 'UY', 'script': 'Zxxx', 'suppress': False},
        'uha': {'full': 'uha-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'uhn': {'full': 'uhn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'uis': {'full': 'uis-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uiv': {'full': 'uiv-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'uji': {'full': 'uji-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'uk': {'full': 'uk-Cyrl-UA', 'region': 'UA', 'script': 'Cyrl', 'suppress': True},
        'uka': {'full': 'uka-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ukg': {'full': 'ukg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ukh': {'full': 'ukh-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'uki': {'full': 'uki-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'ukk': {'full': 'ukk-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'ukl': {'full': 'ukl-Zxxx-UA', 'region': 'UA', 'script': 'Zxxx', 'suppress': False},
        'ukp': {'full': 'ukp-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ukq': {'full': 'ukq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'uks': {'full': 'uks-Zxxx-BR', 'region': 'BR', 'script': 'Zxxx', 'suppress': False},
        'uku': {'full': 'uku-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ukw': {'full': 'ukw-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'uky': {'full': 'uky-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ula': {'full': 'ula-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ulb': {'full': 'ulb-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ulc': {'full': 'ulc-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'ule': {'full': 'ule-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'ulf': {'full': 'ulf-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'uli': {'full': 'uli-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'ulk': {'full': 'ulk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ull': {'full': 'ull-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'ulm': {'full': 'ulm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'uln': {'full': 'uln-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ulu': {'full': 'ulu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ulw': {'full': 'ulw-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'uma': {'full': 'uma-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'umb': {'full': 'umb-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'umc': {'full': 'umc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'umd': {'full': 'umd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'umg': {'full': 'umg-Qaax-AU', 'region': 'AU', 'script': 'Qaax', 'suppress': False},
        'umi': {'full': 'umi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'umm': {'full': 'umm-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'umn': {'full': 'umn-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'umo': {'full': 'umo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ump': {'full': 'ump-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'umr': {'full': 'umr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ums': {'full': 'ums-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'una': {'full': 'una-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'und': {'full': 'und-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'une': {'full': 'une-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ung': {'full': 'ung-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'unk': {'full': 'unk-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'unm': {'full': 'unm-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'unn': {'full': 'unn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'unr': {'full': 'unr-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'unr-Latn': {'full': 'unr-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'unr-NP': {'full': 'unr-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'unr-Orya': {'full': 'unr-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'unu': {'full': 'unu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'unx': {'full': 'unx-Beng-IN', 'region': 'IN', 'script': 'Beng', 'suppress': False},
        'unx-Deva': {'full': 'unx-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'unz': {'full': 'unz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'upi': {'full': 'upi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'upv': {'full': 'upv-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'ur': {'full': 'ur-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': True},
        'ur-Brai': {'full': 'ur-Brai-PK', 'region': 'PK', 'script': 'Brai', 'suppress': False},
        'ur-IN': {'full': 'ur-Arab-IN', 'region': 'IN', 'script': 'Arab', 'suppress': True},
        'ur-Latn': {'full': 'ur-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'ura': {'full': 'ura-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'urb': {'full': 'urb-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'urc': {'full': 'urc-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ure': {'full': 'ure-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'urf': {'full': 'urf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'urg': {'full': 'urg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'urh': {'full': 'urh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'uri': {'full': 'uri-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'urk': {'full': 'urk-Thai-TH', 'region': 'TH', 'script': 'Thai', 'suppress': False},
        'url': {'full': 'url-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'urm': {'full': 'urm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'urn': {'full': 'urn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'uro': {'full': 'uro-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'urp': {'full': 'urp-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'urr': {'full': 'urr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'urt': {'full': 'urt-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uru': {'full': 'uru-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'urv': {'full': 'urv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'urw': {'full': 'urw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'urx': {'full': 'urx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ury': {'full': 'ury-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'urz': {'full': 'urz-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'usa': {'full': 'usa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ush': {'full': 'ush-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'usi-Beng': {'full': 'usi-Beng-BD', 'region': 'BD', 'script': 'Beng', 'suppress': False},
        'usi-Latn': {'full': 'usi-Latn-BD', 'region': 'BD', 'script': 'Latn', 'suppress': False},
        'usk': {'full': 'usk-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'usp': {'full': 'usp-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'uss': {'full': 'uss-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'usu': {'full': 'usu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uta': {'full': 'uta-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ute': {'full': 'ute-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'uth': {'full': 'uth-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'utp': {'full': 'utp-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'utr': {'full': 'utr-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'utu': {'full': 'utu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uum': {'full': 'uum-Grek-GE', 'region': 'GE', 'script': 'Grek', 'suppress': False},
        'uum-Cyrl': {'full': 'uum-Cyrl-GE', 'region': 'GE', 'script': 'Cyrl', 'suppress': False},
        'uun': {'full': 'uun-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'uur': {'full': 'uur-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'uuu': {'full': 'uuu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'uve': {'full': 'uve-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'uvh': {'full': 'uvh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uvl': {'full': 'uvl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'uwa': {'full': 'uwa-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'uya': {'full': 'uya-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'uz': {'full': 'uz-Latn-UZ', 'region': 'UZ', 'script': 'Latn', 'suppress': False},
        'uz-AF': {'full': 'uz-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'uz-Brai': {'full': 'uz-Brai-UZ', 'region': 'UZ', 'script': 'Brai', 'suppress': False},
        'uz-CN': {'full': 'uz-Cyrl-CN', 'region': 'CN', 'script': 'Cyrl', 'suppress': False},
        'uz-Cyrl': {'full': 'uz-Cyrl-UZ', 'region': 'UZ', 'script': 'Cyrl', 'suppress': False},
        'uz-Sogd': {'full': 'uz-Sogd-CN', 'region': 'CN', 'script': 'Sogd', 'suppress': False},
        'uzs': {'full': 'uzs-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'vaa': {'full': 'vaa-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'vae': {'full': 'vae-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'vaf': {'full': 'vaf-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'vag': {'full': 'vag-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'vah': {'full': 'vah-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'vai': {'full': 'vai-Vaii-LR', 'region': 'LR', 'script': 'Vaii', 'suppress': False},
        'vai-Latn': {'full': 'vai-Latn-LR', 'region': 'LR', 'script': 'Latn', 'suppress': False},
        'vaj': {'full': 'vaj-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'val': {'full': 'val-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'vam': {'full': 'vam-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'van': {'full': 'van-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'vao': {'full': 'vao-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'vap': {'full': 'vap-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'var': {'full': 'var-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vas': {'full': 'vas-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'vas-Gujr': {'full': 'vas-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'vau': {'full': 'vau-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'vav': {'full': 'vav-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'vav-Gujr': {'full': 'vav-Gujr-IN', 'region': 'IN', 'script': 'Gujr', 'suppress': False},
        'vay': {'full': 'vay-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'vbb': {'full': 'vbb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vbk': {'full': 'vbk-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        've': {'full': 've-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        've-Brai': {'full': 've-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'vec': {'full': 'vec-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'ved': {'full': 'ved-Zyyy-LK', 'region': 'LK', 'script': 'Zyyy', 'suppress': False},
        'vel': {'full': 'vel-Zyyy-NL', 'region': 'NL', 'script': 'Zyyy', 'suppress': False},
        'vem': {'full': 'vem-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'veo': {'full': 'veo-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'vep': {'full': 'vep-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'ver': {'full': 'ver-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'vgr': {'full': 'vgr-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'vgt': {'full': 'vgt-Zxxx-BE', 'region': 'BE', 'script': 'Zxxx', 'suppress': False},
        'vi': {'full': 'vi-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': True},
        'vi-Brai': {'full': 'vi-Brai-VN', 'region': 'VN', 'script': 'Brai', 'suppress': False},
        'vi-Hani': {'full': 'vi-Hani-VN', 'region': 'VN', 'script': 'Hani', 'suppress': False},
        'vic': {'full': 'vic-Latn-SX', 'region': 'SX', 'script': 'Latn', 'suppress': False},
        'vid': {'full': 'vid-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'vif': {'full': 'vif-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'vig': {'full': 'vig-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'vil': {'full': 'vil-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'vin': {'full': 'vin-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'vis': {'full': 'vis-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'vit': {'full': 'vit-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'viv': {'full': 'viv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'vka': {'full': 'vka-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vki': {'full': 'vki-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'vkj': {'full': 'vkj-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'vkk': {'full': 'vkk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vkl': {'full': 'vkl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vkm': {'full': 'vkm-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'vko': {'full': 'vko-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vkp-Deva': {'full': 'vkp-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'vkp-Latn': {'full': 'vkp-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'vkt': {'full': 'vkt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vku': {'full': 'vku-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vlp': {'full': 'vlp-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'vls': {'full': 'vls-Latn-BE', 'region': 'BE', 'script': 'Latn', 'suppress': False},
        'vma': {'full': 'vma-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vmb': {'full': 'vmb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vmc': {'full': 'vmc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmd': {'full': 'vmd-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'vme': {'full': 'vme-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vmf': {'full': 'vmf-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'vmg': {'full': 'vmg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'vmh': {'full': 'vmh-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'vmi': {'full': 'vmi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vmj': {'full': 'vmj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmk': {'full': 'vmk-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'vml': {'full': 'vml-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vmm': {'full': 'vmm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmp': {'full': 'vmp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmq': {'full': 'vmq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmr': {'full': 'vmr-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'vms': {'full': 'vms-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vmu': {'full': 'vmu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'vmv': {'full': 'vmv-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'vmw': {'full': 'vmw-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'vmw-Arab': {'full': 'vmw-Arab-MZ', 'region': 'MZ', 'script': 'Arab', 'suppress': False},
        'vmx': {'full': 'vmx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmy': {'full': 'vmy-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vmz': {'full': 'vmz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'vnk': {'full': 'vnk-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'vnm': {'full': 'vnm-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'vnp': {'full': 'vnp-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'vo': {'full': 'vo-Latn-001', 'region': '001', 'script': 'Latn', 'suppress': False},
        'vor': {'full': 'vor-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'vot': {'full': 'vot-Latn-RU', 'region': 'RU', 'script': 'Latn', 'suppress': False},
        'vot-Cyrl': {'full': 'vot-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'vra': {'full': 'vra-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'vro': {'full': 'vro-Latn-EE', 'region': 'EE', 'script': 'Latn', 'suppress': False},
        'vrs': {'full': 'vrs-Latn-SB', 'region': 'SB', 'script': 'Latn', 'suppress': False},
        'vrt': {'full': 'vrt-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'vsi': {'full': 'vsi-Zxxx-MD', 'region': 'MD', 'script': 'Zxxx', 'suppress': False},
        'vsl': {'full': 'vsl-Zxxx-VE', 'region': 'VE', 'script': 'Zxxx', 'suppress': False},
        'vsv': {'full': 'vsv-Zxxx-ES', 'region': 'ES', 'script': 'Zxxx', 'suppress': False},
        'vto': {'full': 'vto-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'vum': {'full': 'vum-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'vun': {'full': 'vun-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'vut': {'full': 'vut-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'vwa': {'full': 'vwa-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'wa': {'full': 'wa-Latn-BE', 'region': 'BE', 'script': 'Latn', 'suppress': False},
        'waa': {'full': 'waa-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wab': {'full': 'wab-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wac': {'full': 'wac-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wad': {'full': 'wad-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wae': {'full': 'wae-Latn-CH', 'region': 'CH', 'script': 'Latn', 'suppress': False},
        'waf': {'full': 'waf-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wag': {'full': 'wag-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wah': {'full': 'wah-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wai': {'full': 'wai-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'waj': {'full': 'waj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wal': {'full': 'wal-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'wal-Latn': {'full': 'wal-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'wam': {'full': 'wam-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wan': {'full': 'wan-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'wao': {'full': 'wao-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'wap': {'full': 'wap-Latn-GY', 'region': 'GY', 'script': 'Latn', 'suppress': False},
        'waq': {'full': 'waq-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'war': {'full': 'war-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'war-Brai': {'full': 'war-Brai-PH', 'region': 'PH', 'script': 'Brai', 'suppress': False},
        'was': {'full': 'was-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wat': {'full': 'wat-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wau': {'full': 'wau-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wav': {'full': 'wav-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'waw': {'full': 'waw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wax': {'full': 'wax-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'way': {'full': 'way-Latn-SR', 'region': 'SR', 'script': 'Latn', 'suppress': False},
        'waz': {'full': 'waz-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wba': {'full': 'wba-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'wbb': {'full': 'wbb-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wbe': {'full': 'wbe-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wbf': {'full': 'wbf-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'wbh': {'full': 'wbh-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'wbi': {'full': 'wbi-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'wbj': {'full': 'wbj-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'wbk': {'full': 'wbk-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'wbl': {'full': 'wbl-Latn-PK', 'region': 'PK', 'script': 'Latn', 'suppress': False},
        'wbl-Arab': {'full': 'wbl-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'wbl-Cyrl': {'full': 'wbl-Cyrl-TJ', 'region': 'TJ', 'script': 'Cyrl', 'suppress': False},
        'wbm': {'full': 'wbm-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'wbp': {'full': 'wbp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wbq': {'full': 'wbq-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'wbr': {'full': 'wbr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'wbs': {'full': 'wbs-Zxxx-IN', 'region': 'IN', 'script': 'Zxxx', 'suppress': False},
        'wbt': {'full': 'wbt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wbv': {'full': 'wbv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wbw': {'full': 'wbw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wca': {'full': 'wca-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wci': {'full': 'wci-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'wdd': {'full': 'wdd-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'wdg': {'full': 'wdg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wdj': {'full': 'wdj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wdk': {'full': 'wdk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wdu': {'full': 'wdu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wdy': {'full': 'wdy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wea': {'full': 'wea-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'wec': {'full': 'wec-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'wed': {'full': 'wed-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'weg': {'full': 'weg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'weh': {'full': 'weh-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'wei': {'full': 'wei-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wem': {'full': 'wem-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'weo': {'full': 'weo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wep': {'full': 'wep-Latn-DE', 'region': 'DE', 'script': 'Latn', 'suppress': False},
        'wer': {'full': 'wer-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wes': {'full': 'wes-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'wet': {'full': 'wet-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'weu': {'full': 'weu-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'wew': {'full': 'wew-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wfg': {'full': 'wfg-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wga': {'full': 'wga-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wgb': {'full': 'wgb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wgg': {'full': 'wgg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wgi': {'full': 'wgi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wgo': {'full': 'wgo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wgu': {'full': 'wgu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wgy': {'full': 'wgy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wha': {'full': 'wha-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'whg': {'full': 'whg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'whk': {'full': 'whk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'whu': {'full': 'whu-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wib': {'full': 'wib-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'wic': {'full': 'wic-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wie': {'full': 'wie-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wif': {'full': 'wif-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wig': {'full': 'wig-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wih': {'full': 'wih-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wii': {'full': 'wii-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wij': {'full': 'wij-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wik': {'full': 'wik-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wil': {'full': 'wil-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wim': {'full': 'wim-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'win': {'full': 'win-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wir': {'full': 'wir-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wiu': {'full': 'wiu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wiv': {'full': 'wiv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wiy': {'full': 'wiy-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wja': {'full': 'wja-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'wji': {'full': 'wji-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'wka': {'full': 'wka-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'wkb': {'full': 'wkb-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'wkd': {'full': 'wkd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wkl': {'full': 'wkl-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'wkr': {'full': 'wkr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wku': {'full': 'wku-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'wkw': {'full': 'wkw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wky': {'full': 'wky-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wla': {'full': 'wla-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wlc': {'full': 'wlc-Zyyy-KM', 'region': 'KM', 'script': 'Zyyy', 'suppress': False},
        'wle-Arab': {'full': 'wle-Arab-ET', 'region': 'ET', 'script': 'Arab', 'suppress': False},
        'wlg': {'full': 'wlg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wlh': {'full': 'wlh-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'wli': {'full': 'wli-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wlk': {'full': 'wlk-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'wll': {'full': 'wll-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'wlm': {'full': 'wlm-Latn-GB', 'region': 'GB', 'script': 'Latn', 'suppress': False},
        'wlo': {'full': 'wlo-Arab-ID', 'region': 'ID', 'script': 'Arab', 'suppress': False},
        'wlr': {'full': 'wlr-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'wls': {'full': 'wls-Latn-WF', 'region': 'WF', 'script': 'Latn', 'suppress': False},
        'wlu': {'full': 'wlu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wlv': {'full': 'wlv-Latn-AR', 'region': 'AR', 'script': 'Latn', 'suppress': False},
        'wlw': {'full': 'wlw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wlx': {'full': 'wlx-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'wly': {'full': 'wly-Zyyy-NP', 'region': 'NP', 'script': 'Zyyy', 'suppress': False},
        'wma': {'full': 'wma-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'wmb': {'full': 'wmb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wmc': {'full': 'wmc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wmd': {'full': 'wmd-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wme': {'full': 'wme-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'wmh': {'full': 'wmh-Latn-TL', 'region': 'TL', 'script': 'Latn', 'suppress': False},
        'wmi': {'full': 'wmi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wmm': {'full': 'wmm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wmn': {'full': 'wmn-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'wmo': {'full': 'wmo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wms': {'full': 'wms-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wmt': {'full': 'wmt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wmw': {'full': 'wmw-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'wmw-Arab': {'full': 'wmw-Arab-MZ', 'region': 'MZ', 'script': 'Arab', 'suppress': False},
        'wmx': {'full': 'wmx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wnb': {'full': 'wnb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wnc': {'full': 'wnc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wnd': {'full': 'wnd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wne': {'full': 'wne-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'wng': {'full': 'wng-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wni': {'full': 'wni-Arab-KM', 'region': 'KM', 'script': 'Arab', 'suppress': False},
        'wni-Latn': {'full': 'wni-Latn-KM', 'region': 'KM', 'script': 'Latn', 'suppress': False},
        'wnk': {'full': 'wnk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wnm': {'full': 'wnm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wnn': {'full': 'wnn-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wno': {'full': 'wno-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wnp': {'full': 'wnp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wnu': {'full': 'wnu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wnw': {'full': 'wnw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wny': {'full': 'wny-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wo': {'full': 'wo-Latn-SN', 'region': 'SN', 'script': 'Latn', 'suppress': False},
        'wo-Arab': {'full': 'wo-Arab-SN', 'region': 'SN', 'script': 'Arab', 'suppress': False},
        'woa': {'full': 'woa-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wob': {'full': 'wob-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'woc': {'full': 'woc-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wod': {'full': 'wod-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'woe': {'full': 'woe-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'woe-Wole': {'full': 'woe-Wole-FM', 'region': 'FM', 'script': 'Wole', 'suppress': False},
        'wof': {'full': 'wof-Latn-GM', 'region': 'GM', 'script': 'Latn', 'suppress': False},
        'wof-Arab': {'full': 'wof-Arab-GM', 'region': 'GM', 'script': 'Arab', 'suppress': False},
        'wog': {'full': 'wog-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'woi': {'full': 'woi-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wok': {'full': 'wok-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'wom': {'full': 'wom-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'won': {'full': 'won-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'woo': {'full': 'woo-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wor': {'full': 'wor-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wos': {'full': 'wos-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wow': {'full': 'wow-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'woy': {'full': 'woy-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'wpc': {'full': 'wpc-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'wra': {'full': 'wra-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wrb': {'full': 'wrb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrd': {'full': 'wrd-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'wrg': {'full': 'wrg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrh': {'full': 'wrh-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wri': {'full': 'wri-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrk': {'full': 'wrk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrl': {'full': 'wrl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrm': {'full': 'wrm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrn': {'full': 'wrn-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'wro': {'full': 'wro-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrp': {'full': 'wrp-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wrr': {'full': 'wrr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrs': {'full': 'wrs-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wru': {'full': 'wru-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wrv': {'full': 'wrv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wrw': {'full': 'wrw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wrx': {'full': 'wrx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wry': {'full': 'wry-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'wrz': {'full': 'wrz-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wsa': {'full': 'wsa-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wsg': {'full': 'wsg-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'wsg-Deva': {'full': 'wsg-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'wsg-Gong': {'full': 'wsg-Gong-IN', 'region': 'IN', 'script': 'Gong', 'suppress': False},
        'wsg-Gonm': {'full': 'wsg-Gonm-IN', 'region': 'IN', 'script': 'Gonm', 'suppress': False},
        'wsi': {'full': 'wsi-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'wsk': {'full': 'wsk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wsr': {'full': 'wsr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wss': {'full': 'wss-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'wsu': {'full': 'wsu-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wsv': {'full': 'wsv-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'wtf': {'full': 'wtf-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wth': {'full': 'wth-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wti': {'full': 'wti-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'wtk': {'full': 'wtk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wtm': {'full': 'wtm-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'wtw': {'full': 'wtw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wtw-Bugi': {'full': 'wtw-Bugi-ID', 'region': 'ID', 'script': 'Bugi', 'suppress': False},
        'wua': {'full': 'wua-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wub': {'full': 'wub-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wud': {'full': 'wud-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'wuh': {'full': 'wuh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'wul': {'full': 'wul-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wum': {'full': 'wum-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'wun': {'full': 'wun-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'wur': {'full': 'wur-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wut': {'full': 'wut-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wuu': {'full': 'wuu-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'wuu-Hant': {'full': 'wuu-Hant-CN', 'region': 'CN', 'script': 'Hant', 'suppress': False},
        'wuu-Latn': {'full': 'wuu-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'wuv': {'full': 'wuv-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'wux': {'full': 'wux-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wuy': {'full': 'wuy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'wwa': {'full': 'wwa-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'wwb': {'full': 'wwb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wwo': {'full': 'wwo-Latn-VU', 'region': 'VU', 'script': 'Latn', 'suppress': False},
        'wwr': {'full': 'wwr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'www': {'full': 'www-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'wxa': {'full': 'wxa-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'wxw': {'full': 'wxw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wya': {'full': 'wya-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'wyb': {'full': 'wyb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wyi': {'full': 'wyi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'wym': {'full': 'wym-Latn-PL', 'region': 'PL', 'script': 'Latn', 'suppress': False},
        'wyr': {'full': 'wyr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'wyy': {'full': 'wyy-Latn-FJ', 'region': 'FJ', 'script': 'Latn', 'suppress': False},
        'x-bad-mru': {'full': 'x-bad-mru-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xaa': {'full': 'xaa-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'xab': {'full': 'xab-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'xac': {'full': 'xac-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'xad': {'full': 'xad-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xae': {'full': 'xae-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xag': {'full': 'xag-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xai': {'full': 'xai-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xaj': {'full': 'xaj-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xak': {'full': 'xak-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'xal': {'full': 'xal-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xal-Mong-x-todo': {'full': 'xal-Mong-CN-x-todo', 'region': 'CN', 'script': 'Mong', 'suppress': False},
        'xam': {'full': 'xam-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'xan': {'full': 'xan-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'xao': {'full': 'xao-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'xap': {'full': 'xap-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xaq': {'full': 'xaq-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xar': {'full': 'xar-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xas': {'full': 'xas-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xat': {'full': 'xat-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xau': {'full': 'xau-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xav': {'full': 'xav-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xaw': {'full': 'xaw-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'xay': {'full': 'xay-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xbb': {'full': 'xbb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xbc': {'full': 'xbc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xbd': {'full': 'xbd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xbe': {'full': 'xbe-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xbg': {'full': 'xbg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xbi': {'full': 'xbi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xbj': {'full': 'xbj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xbm': {'full': 'xbm-Latn-FR', 'region': 'FR', 'script': 'Latn', 'suppress': False},
        'xbn': {'full': 'xbn-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'xbo': {'full': 'xbo-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xbp': {'full': 'xbp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xbr': {'full': 'xbr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xbw': {'full': 'xbw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xby': {'full': 'xby-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xcb': {'full': 'xcb-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcc': {'full': 'xcc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xce': {'full': 'xce-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcg': {'full': 'xcg-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xch': {'full': 'xch-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcl': {'full': 'xcl-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcm': {'full': 'xcm-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcn': {'full': 'xcn-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xco': {'full': 'xco-Arab-XX', 'region': 'XX', 'script': 'Arab', 'suppress': False},
        'xco-Chrs': {'full': 'xco-Chrs-XX', 'region': 'XX', 'script': 'Chrs', 'suppress': False},
        'xcr': {'full': 'xcr-Cari-TR', 'region': 'TR', 'script': 'Cari', 'suppress': False},
        'xct': {'full': 'xct-Tibt-XX', 'region': 'XX', 'script': 'Tibt', 'suppress': False},
        'xcu': {'full': 'xcu-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcv': {'full': 'xcv-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcw': {'full': 'xcw-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xcy': {'full': 'xcy-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xda': {'full': 'xda-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xdc': {'full': 'xdc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xdk': {'full': 'xdk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xdm': {'full': 'xdm-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xdo': {'full': 'xdo-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'xdy': {'full': 'xdy-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xeb': {'full': 'xeb-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xed': {'full': 'xed-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'xeg': {'full': 'xeg-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'xel': {'full': 'xel-Zyyy-SD', 'region': 'SD', 'script': 'Zyyy', 'suppress': False},
        'xem': {'full': 'xem-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xep': {'full': 'xep-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xer': {'full': 'xer-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xes': {'full': 'xes-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xet': {'full': 'xet-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xeu': {'full': 'xeu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xfa': {'full': 'xfa-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xga': {'full': 'xga-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xgb': {'full': 'xgb-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'xgd': {'full': 'xgd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xgf': {'full': 'xgf-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xgg': {'full': 'xgg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xgi': {'full': 'xgi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xgl': {'full': 'xgl-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xgm': {'full': 'xgm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xgr': {'full': 'xgr-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xgu': {'full': 'xgu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xgw': {'full': 'xgw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xh': {'full': 'xh-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'xh-Brai': {'full': 'xh-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'xha': {'full': 'xha-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xhc': {'full': 'xhc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xhd': {'full': 'xhd-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xhe': {'full': 'xhe-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'xhr': {'full': 'xhr-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xht': {'full': 'xht-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'xhu': {'full': 'xhu-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xhv': {'full': 'xhv-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'xib': {'full': 'xib-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xii': {'full': 'xii-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': False},
        'xil': {'full': 'xil-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xin': {'full': 'xin-Latn-GT', 'region': 'GT', 'script': 'Latn', 'suppress': False},
        'xir': {'full': 'xir-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xis': {'full': 'xis-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'xiv': {'full': 'xiv-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xiy': {'full': 'xiy-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xjb': {'full': 'xjb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xjt': {'full': 'xjt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xka': {'full': 'xka-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'xkb': {'full': 'xkb-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'xkc': {'full': 'xkc-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'xkd': {'full': 'xkd-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xke': {'full': 'xke-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xkf-Tibt': {'full': 'xkf-Tibt-BT-x-uchen', 'region': 'BT', 'script': 'Tibt', 'suppress': False},
        'xkg': {'full': 'xkg-Latn-ML', 'region': 'ML', 'script': 'Latn', 'suppress': False},
        'xki': {'full': 'xki-Zxxx-KE', 'region': 'KE', 'script': 'Zxxx', 'suppress': False},
        'xkj': {'full': 'xkj-Arab-IR', 'region': 'IR', 'script': 'Arab', 'suppress': False},
        'xkk': {'full': 'xkk-Zyyy-KH', 'region': 'KH', 'script': 'Zyyy', 'suppress': False},
        'xkl': {'full': 'xkl-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xkn': {'full': 'xkn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xko': {'full': 'xko-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'xkp': {'full': 'xkp-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'xkq': {'full': 'xkq-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xkr': {'full': 'xkr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xks': {'full': 'xks-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xkt': {'full': 'xkt-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'xku': {'full': 'xku-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'xkv': {'full': 'xkv-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'xkw': {'full': 'xkw-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xkx': {'full': 'xkx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xky': {'full': 'xky-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'xkz': {'full': 'xkz-Latn-BT', 'region': 'BT', 'script': 'Latn', 'suppress': False},
        'xkz-Tibt-x-uchen': {'full': 'xkz-Tibt-BT-x-uchen', 'region': 'BT', 'script': 'Tibt', 'suppress': False},
        'xla': {'full': 'xla-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xlb': {'full': 'xlb-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xlc': {'full': 'xlc-Lyci-TR', 'region': 'TR', 'script': 'Lyci', 'suppress': False},
        'xld': {'full': 'xld-Lydi-TR', 'region': 'TR', 'script': 'Lydi', 'suppress': False},
        'xle': {'full': 'xle-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xlg': {'full': 'xlg-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xli': {'full': 'xli-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xln': {'full': 'xln-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xlo': {'full': 'xlo-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xlp': {'full': 'xlp-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xls': {'full': 'xls-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xlu': {'full': 'xlu-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xly': {'full': 'xly-Elym-IR', 'region': 'IR', 'script': 'Elym', 'suppress': False},
        'xma': {'full': 'xma-Zyyy-SO', 'region': 'SO', 'script': 'Zyyy', 'suppress': False},
        'xmb': {'full': 'xmb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'xmc': {'full': 'xmc-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'xmd': {'full': 'xmd-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'xme': {'full': 'xme-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xmf': {'full': 'xmf-Geor-GE', 'region': 'GE', 'script': 'Geor', 'suppress': False},
        'xmg': {'full': 'xmg-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'xmg-Zzzz-x-bagam': {'full': 'xmg-Zzzz-CM-x-bagam', 'region': 'CM', 'script': 'Zzzz', 'suppress': False},
        'xmh': {'full': 'xmh-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xmj': {'full': 'xmj-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'xmk': {'full': 'xmk-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xml': {'full': 'xml-Zxxx-MY', 'region': 'MY', 'script': 'Zxxx', 'suppress': False},
        'xmm': {'full': 'xmm-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xmn': {'full': 'xmn-Mani-CN', 'region': 'CN', 'script': 'Mani', 'suppress': False},
        'xmo': {'full': 'xmo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xmp': {'full': 'xmp-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xmq': {'full': 'xmq-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xmr': {'full': 'xmr-Merc-SD', 'region': 'SD', 'script': 'Merc', 'suppress': False},
        'xms': {'full': 'xms-Zxxx-MA', 'region': 'MA', 'script': 'Zxxx', 'suppress': False},
        'xmt': {'full': 'xmt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xmu': {'full': 'xmu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xmv': {'full': 'xmv-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'xmw': {'full': 'xmw-Latn-MG', 'region': 'MG', 'script': 'Latn', 'suppress': False},
        'xmx': {'full': 'xmx-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xmy': {'full': 'xmy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xmz': {'full': 'xmz-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xna': {'full': 'xna-Narb-SA', 'region': 'SA', 'script': 'Narb', 'suppress': False},
        'xnb': {'full': 'xnb-Zyyy-TW', 'region': 'TW', 'script': 'Zyyy', 'suppress': False},
        'xng': {'full': 'xng-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xnh': {'full': 'xnh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'xni': {'full': 'xni-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xnk': {'full': 'xnk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xnm': {'full': 'xnm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xnn': {'full': 'xnn-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'xno': {'full': 'xno-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xnr': {'full': 'xnr-Deva-IN', 'region': 'IN', 'script': 'Deva', 'suppress': False},
        'xns': {'full': 'xns-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'xnt': {'full': 'xnt-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'xnu': {'full': 'xnu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xny': {'full': 'xny-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xnz-Arab': {'full': 'xnz-Arab-EG', 'region': 'EG', 'script': 'Arab', 'suppress': False},
        'xnz-Copt': {'full': 'xnz-Copt-EG-x-olnubian', 'region': 'EG', 'script': 'Copt', 'suppress': False},
        'xnz-Latn': {'full': 'xnz-Latn-EG', 'region': 'EG', 'script': 'Latn', 'suppress': False},
        'xoc': {'full': 'xoc-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'xod': {'full': 'xod-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xog': {'full': 'xog-Latn-UG', 'region': 'UG', 'script': 'Latn', 'suppress': False},
        'xoi': {'full': 'xoi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xok': {'full': 'xok-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xom': {'full': 'xom-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'xom-Ethi': {'full': 'xom-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'xon': {'full': 'xon-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'xon-Brai': {'full': 'xon-Brai-GH', 'region': 'GH', 'script': 'Brai', 'suppress': False},
        'xoo': {'full': 'xoo-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xop': {'full': 'xop-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xor': {'full': 'xor-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xow': {'full': 'xow-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xpa': {'full': 'xpa-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpb': {'full': 'xpb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpc': {'full': 'xpc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xpd': {'full': 'xpd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpf': {'full': 'xpf-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpg': {'full': 'xpg-Grek-TR', 'region': 'TR', 'script': 'Grek', 'suppress': False},
        'xph': {'full': 'xph-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpi': {'full': 'xpi-Zyyy-GB', 'region': 'GB', 'script': 'Zyyy', 'suppress': False},
        'xpj': {'full': 'xpj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpk': {'full': 'xpk-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xpl': {'full': 'xpl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpm': {'full': 'xpm-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xpn': {'full': 'xpn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xpo': {'full': 'xpo-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xpp': {'full': 'xpp-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'xpq': {'full': 'xpq-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'xpr': {'full': 'xpr-Prti-IR', 'region': 'IR', 'script': 'Prti', 'suppress': False},
        'xps': {'full': 'xps-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'xpt': {'full': 'xpt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpu': {'full': 'xpu-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xpv': {'full': 'xpv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpw': {'full': 'xpw-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpx': {'full': 'xpx-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xpy': {'full': 'xpy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'xpz': {'full': 'xpz-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xqa': {'full': 'xqa-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'xqt': {'full': 'xqt-Zyyy-YE', 'region': 'YE', 'script': 'Zyyy', 'suppress': False},
        'xra': {'full': 'xra-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xrb': {'full': 'xrb-Latn-BF', 'region': 'BF', 'script': 'Latn', 'suppress': False},
        'xrd': {'full': 'xrd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xre': {'full': 'xre-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xrg': {'full': 'xrg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xri': {'full': 'xri-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xrm': {'full': 'xrm-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xrn': {'full': 'xrn-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xrr': {'full': 'xrr-Zyyy-IT', 'region': 'IT', 'script': 'Zyyy', 'suppress': False},
        'xrt': {'full': 'xrt-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'xru': {'full': 'xru-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xrw': {'full': 'xrw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xsa': {'full': 'xsa-Sarb-YE', 'region': 'YE', 'script': 'Sarb', 'suppress': False},
        'xsb': {'full': 'xsb-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'xsc': {'full': 'xsc-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xsd': {'full': 'xsd-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'xse': {'full': 'xse-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xsh': {'full': 'xsh-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'xsi': {'full': 'xsi-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xsm': {'full': 'xsm-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'xsn': {'full': 'xsn-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'xso': {'full': 'xso-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'xsp': {'full': 'xsp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'xsq': {'full': 'xsq-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'xsr': {'full': 'xsr-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'xsr-Tibt': {'full': 'xsr-Tibt-CN', 'region': 'CN', 'script': 'Tibt', 'suppress': False},
        'xss': {'full': 'xss-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xsu': {'full': 'xsu-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'xsv': {'full': 'xsv-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xsy': {'full': 'xsy-Latn-TW', 'region': 'TW', 'script': 'Latn', 'suppress': False},
        'xta': {'full': 'xta-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtb': {'full': 'xtb-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtc': {'full': 'xtc-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'xtd': {'full': 'xtd-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xte': {'full': 'xte-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xtg': {'full': 'xtg-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xth': {'full': 'xth-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xti': {'full': 'xti-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtj': {'full': 'xtj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtl': {'full': 'xtl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtm': {'full': 'xtm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtn': {'full': 'xtn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xto': {'full': 'xto-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'xtp': {'full': 'xtp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtq': {'full': 'xtq-Zyyy-IR', 'region': 'IR', 'script': 'Zyyy', 'suppress': False},
        'xtr': {'full': 'xtr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'xts': {'full': 'xts-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtt': {'full': 'xtt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtu': {'full': 'xtu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtv': {'full': 'xtv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xtw': {'full': 'xtw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xty': {'full': 'xty-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'xtz': {'full': 'xtz-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xua': {'full': 'xua-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'xub-Knda': {'full': 'xub-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'xub-Mlym': {'full': 'xub-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'xub-Taml': {'full': 'xub-Taml-IN', 'region': 'IN', 'script': 'Taml', 'suppress': False},
        'xud': {'full': 'xud-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xug': {'full': 'xug-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'xuj': {'full': 'xuj-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'xul': {'full': 'xul-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xum': {'full': 'xum-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'xum-Ital': {'full': 'xum-Ital-IT', 'region': 'IT', 'script': 'Ital', 'suppress': False},
        'xun': {'full': 'xun-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xuo': {'full': 'xuo-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'xup': {'full': 'xup-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'xur': {'full': 'xur-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'xut': {'full': 'xut-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xuu': {'full': 'xuu-Latn-NA', 'region': 'NA', 'script': 'Latn', 'suppress': False},
        'xve': {'full': 'xve-Ital-IT', 'region': 'IT', 'script': 'Ital', 'suppress': False},
        'xvi': {'full': 'xvi-Arab-AF', 'region': 'AF', 'script': 'Arab', 'suppress': False},
        'xvn': {'full': 'xvn-Latn-ES', 'region': 'ES', 'script': 'Latn', 'suppress': False},
        'xvo': {'full': 'xvo-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'xvs': {'full': 'xvs-Latn-IT', 'region': 'IT', 'script': 'Latn', 'suppress': False},
        'xwa': {'full': 'xwa-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xwc': {'full': 'xwc-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'xwd': {'full': 'xwd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xwe': {'full': 'xwe-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'xwg': {'full': 'xwg-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'xwj': {'full': 'xwj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xwk': {'full': 'xwk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xwl': {'full': 'xwl-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'xwo': {'full': 'xwo-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'xwr': {'full': 'xwr-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xwt': {'full': 'xwt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xww': {'full': 'xww-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xxb': {'full': 'xxb-Latn-GH', 'region': 'GH', 'script': 'Latn', 'suppress': False},
        'xxk': {'full': 'xxk-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xxm': {'full': 'xxm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xxr': {'full': 'xxr-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xxt': {'full': 'xxt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'xya': {'full': 'xya-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xyb': {'full': 'xyb-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xyj': {'full': 'xyj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xyk': {'full': 'xyk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xyl': {'full': 'xyl-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'xyt': {'full': 'xyt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xyy': {'full': 'xyy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'xzh': {'full': 'xzh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'xzm': {'full': 'xzm-Zyyy-XX', 'region': 'XX', 'script': 'Zyyy', 'suppress': False},
        'xzp': {'full': 'xzp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'yaa': {'full': 'yaa-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'yab': {'full': 'yab-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'yac': {'full': 'yac-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'yad': {'full': 'yad-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'yae': {'full': 'yae-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'yaf': {'full': 'yaf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'yag': {'full': 'yag-Latn-CL', 'region': 'CL', 'script': 'Latn', 'suppress': False},
        'yah-Cyrl': {'full': 'yah-Cyrl-TJ', 'region': 'TJ', 'script': 'Cyrl', 'suppress': False},
        'yah-Latn': {'full': 'yah-Latn-TJ', 'region': 'TJ', 'script': 'Latn', 'suppress': False},
        'yai': {'full': 'yai-Cyrl-TJ', 'region': 'TJ', 'script': 'Cyrl', 'suppress': False},
        'yaj': {'full': 'yaj-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'yak': {'full': 'yak-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'yal-Arab': {'full': 'yal-Arab-GN', 'region': 'GN', 'script': 'Arab', 'suppress': False},
        'yal-Latn': {'full': 'yal-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'yam': {'full': 'yam-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'yan': {'full': 'yan-Latn-NI', 'region': 'NI', 'script': 'Latn', 'suppress': False},
        'yao': {'full': 'yao-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'yao-Arab': {'full': 'yao-Arab-MZ', 'region': 'MZ', 'script': 'Arab', 'suppress': False},
        'yap': {'full': 'yap-Latn-FM', 'region': 'FM', 'script': 'Latn', 'suppress': False},
        'yaq': {'full': 'yaq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'yar': {'full': 'yar-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'yas': {'full': 'yas-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'yat': {'full': 'yat-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'yau': {'full': 'yau-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'yav': {'full': 'yav-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'yaw': {'full': 'yaw-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'yax': {'full': 'yax-Latn-AO', 'region': 'AO', 'script': 'Latn', 'suppress': False},
        'yay': {'full': 'yay-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yaz': {'full': 'yaz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yba': {'full': 'yba-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ybb': {'full': 'ybb-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ybe': {'full': 'ybe-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ybh': {'full': 'ybh-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'ybi': {'full': 'ybi-Deva-NP', 'region': 'NP', 'script': 'Deva', 'suppress': False},
        'ybj': {'full': 'ybj-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ybk': {'full': 'ybk-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ybl': {'full': 'ybl-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ybm': {'full': 'ybm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ybn': {'full': 'ybn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ybo': {'full': 'ybo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ybx': {'full': 'ybx-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yby': {'full': 'yby-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ych': {'full': 'ych-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ycl': {'full': 'ycl-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'ycn': {'full': 'ycn-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'ycp': {'full': 'ycp-Zyyy-LA', 'region': 'LA', 'script': 'Zyyy', 'suppress': False},
        'yda': {'full': 'yda-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yde': {'full': 'yde-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ydg': {'full': 'ydg-Arab-PK', 'region': 'PK', 'script': 'Arab', 'suppress': False},
        'ydk': {'full': 'ydk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yea-Knda': {'full': 'yea-Knda-IN', 'region': 'IN', 'script': 'Knda', 'suppress': False},
        'yea-Mlym': {'full': 'yea-Mlym-IN', 'region': 'IN', 'script': 'Mlym', 'suppress': False},
        'yec': {'full': 'yec-Zyyy-DE', 'region': 'DE', 'script': 'Zyyy', 'suppress': False},
        'yee': {'full': 'yee-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yei': {'full': 'yei-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'yej': {'full': 'yej-Grek-IL', 'region': 'IL', 'script': 'Grek', 'suppress': False},
        'yel': {'full': 'yel-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'yer': {'full': 'yer-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yes': {'full': 'yes-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yet': {'full': 'yet-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'yeu': {'full': 'yeu-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'yev': {'full': 'yev-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yey': {'full': 'yey-Latn-BW', 'region': 'BW', 'script': 'Latn', 'suppress': False},
        'yga': {'full': 'yga-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ygi': {'full': 'ygi-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ygl': {'full': 'ygl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ygm': {'full': 'ygm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ygp': {'full': 'ygp-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'ygr': {'full': 'ygr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ygs': {'full': 'ygs-Zxxx-AU', 'region': 'AU', 'script': 'Zxxx', 'suppress': False},
        'ygu': {'full': 'ygu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ygw': {'full': 'ygw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yha': {'full': 'yha-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yhd': {'full': 'yhd-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'yhl': {'full': 'yhl-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yhs': {'full': 'yhs-Zxxx-AU', 'region': 'AU', 'script': 'Zxxx', 'suppress': False},
        'yi': {'full': 'yi-Hebr-001', 'region': '001', 'script': 'Hebr', 'suppress': True},
        'yia': {'full': 'yia-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yif': {'full': 'yif-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yig': {'full': 'yig-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'yih': {'full': 'yih-Hebr-DE', 'region': 'DE', 'script': 'Hebr', 'suppress': False},
        'yii': {'full': 'yii-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yij': {'full': 'yij-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yik': {'full': 'yik-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yil': {'full': 'yil-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yim': {'full': 'yim-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'yin': {'full': 'yin-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'yip': {'full': 'yip-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yiq': {'full': 'yiq-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yir': {'full': 'yir-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'yis': {'full': 'yis-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yit': {'full': 'yit-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yiu': {'full': 'yiu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yiv': {'full': 'yiv-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yix': {'full': 'yix-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yiz': {'full': 'yiz-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yka': {'full': 'yka-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'yka-Arab': {'full': 'yka-Arab-PH', 'region': 'PH', 'script': 'Arab', 'suppress': False},
        'ykg': {'full': 'ykg-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'yki': {'full': 'yki-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ykk': {'full': 'ykk-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ykl': {'full': 'ykl-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ykm': {'full': 'ykm-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ykn': {'full': 'ykn-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yko': {'full': 'yko-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'ykr': {'full': 'ykr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ykt': {'full': 'ykt-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yku': {'full': 'yku-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yky': {'full': 'yky-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'yla': {'full': 'yla-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ylb': {'full': 'ylb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yle': {'full': 'yle-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ylg': {'full': 'ylg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yli': {'full': 'yli-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'yll': {'full': 'yll-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ylm': {'full': 'ylm-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yln': {'full': 'yln-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ylo': {'full': 'ylo-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ylr': {'full': 'ylr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ylu': {'full': 'ylu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yly': {'full': 'yly-Latn-NC', 'region': 'NC', 'script': 'Latn', 'suppress': False},
        'ymb': {'full': 'ymb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ymc': {'full': 'ymc-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ymd': {'full': 'ymd-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yme': {'full': 'yme-Latn-PE', 'region': 'PE', 'script': 'Latn', 'suppress': False},
        'ymg': {'full': 'ymg-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ymh': {'full': 'ymh-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ymi': {'full': 'ymi-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ymk': {'full': 'ymk-Latn-MZ', 'region': 'MZ', 'script': 'Latn', 'suppress': False},
        'ymk-Arab': {'full': 'ymk-Arab-MZ', 'region': 'MZ', 'script': 'Arab', 'suppress': False},
        'yml': {'full': 'yml-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ymm': {'full': 'ymm-Latn-SO', 'region': 'SO', 'script': 'Latn', 'suppress': False},
        'ymn': {'full': 'ymn-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'ymo': {'full': 'ymo-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ymp': {'full': 'ymp-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ymq': {'full': 'ymq-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ymr': {'full': 'ymr-Zyyy-IN', 'region': 'IN', 'script': 'Zyyy', 'suppress': False},
        'yms': {'full': 'yms-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'ymx': {'full': 'ymx-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ymz': {'full': 'ymz-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yna': {'full': 'yna-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'ynd': {'full': 'ynd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yne': {'full': 'yne-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yng': {'full': 'yng-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ynk': {'full': 'ynk-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'ynl': {'full': 'ynl-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ynn': {'full': 'ynn-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'yno': {'full': 'yno-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'ynq': {'full': 'ynq-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yns': {'full': 'yns-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'ynu': {'full': 'ynu-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'yo': {'full': 'yo-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yo-Arab': {'full': 'yo-Arab-NG', 'region': 'NG', 'script': 'Arab', 'suppress': False},
        'yo-BJ': {'full': 'yo-Latn-BJ', 'region': 'BJ', 'script': 'Latn', 'suppress': False},
        'yo-Brai': {'full': 'yo-Brai-NG', 'region': 'NG', 'script': 'Brai', 'suppress': False},
        'yob': {'full': 'yob-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yog': {'full': 'yog-Latn-PH', 'region': 'PH', 'script': 'Latn', 'suppress': False},
        'yoi': {'full': 'yoi-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'yok': {'full': 'yok-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'yol': {'full': 'yol-Zyyy-GB', 'region': 'GB', 'script': 'Zyyy', 'suppress': False},
        'yom': {'full': 'yom-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'yon': {'full': 'yon-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yot': {'full': 'yot-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yox': {'full': 'yox-Zyyy-JP', 'region': 'JP', 'script': 'Zyyy', 'suppress': False},
        'yoy': {'full': 'yoy-Zyyy-TH', 'region': 'TH', 'script': 'Zyyy', 'suppress': False},
        'ypa': {'full': 'ypa-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypb': {'full': 'ypb-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypg': {'full': 'ypg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yph': {'full': 'yph-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypm': {'full': 'ypm-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypn': {'full': 'ypn-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypo': {'full': 'ypo-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypp': {'full': 'ypp-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ypz': {'full': 'ypz-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yra': {'full': 'yra-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yrb': {'full': 'yrb-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yre': {'full': 'yre-Latn-CI', 'region': 'CI', 'script': 'Latn', 'suppress': False},
        'yrk': {'full': 'yrk-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'yrl': {'full': 'yrl-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'yrm': {'full': 'yrm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yrn': {'full': 'yrn-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yro': {'full': 'yro-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'yrs': {'full': 'yrs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'yrw': {'full': 'yrw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yry': {'full': 'yry-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ysc': {'full': 'ysc-Zyyy-HU', 'region': 'HU', 'script': 'Zyyy', 'suppress': False},
        'ysd': {'full': 'ysd-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'ysg': {'full': 'ysg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ysl': {'full': 'ysl-Zxxx-RS', 'region': 'RS', 'script': 'Zxxx', 'suppress': False},
        'ysn': {'full': 'ysn-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'yso': {'full': 'yso-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ysp': {'full': 'ysp-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ysr': {'full': 'ysr-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'yss': {'full': 'yss-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ysy': {'full': 'ysy-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'yta': {'full': 'yta-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ytl': {'full': 'ytl-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ytp': {'full': 'ytp-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ytw': {'full': 'ytw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yty': {'full': 'yty-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yua': {'full': 'yua-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'yub': {'full': 'yub-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yuc': {'full': 'yuc-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'yud': {'full': 'yud-Hebr-IL', 'region': 'IL', 'script': 'Hebr', 'suppress': False},
        'yue': {'full': 'yue-Hant-HK', 'region': 'HK', 'script': 'Hant', 'suppress': False},
        'yue-Brai': {'full': 'yue-Brai-HK', 'region': 'HK', 'script': 'Brai', 'suppress': False},
        'yue-CN': {'full': 'yue-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'yue-Latn': {'full': 'yue-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'yuf': {'full': 'yuf-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'yug': {'full': 'yug-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'yui': {'full': 'yui-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'yuj': {'full': 'yuj-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yuk': {'full': 'yuk-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'yul': {'full': 'yul-Latn-CF', 'region': 'CF', 'script': 'Latn', 'suppress': False},
        'yum': {'full': 'yum-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'yun': {'full': 'yun-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'yup': {'full': 'yup-Latn-CO', 'region': 'CO', 'script': 'Latn', 'suppress': False},
        'yuq': {'full': 'yuq-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'yur': {'full': 'yur-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'yut': {'full': 'yut-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yuw': {'full': 'yuw-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yux': {'full': 'yux-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'yuy': {'full': 'yuy-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yuz': {'full': 'yuz-Latn-BO', 'region': 'BO', 'script': 'Latn', 'suppress': False},
        'yva': {'full': 'yva-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'yvt': {'full': 'yvt-Latn-VE', 'region': 'VE', 'script': 'Latn', 'suppress': False},
        'ywa': {'full': 'ywa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'ywg': {'full': 'ywg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ywl': {'full': 'ywl-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ywn': {'full': 'ywn-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'ywq': {'full': 'ywq-Plrd-CN', 'region': 'CN', 'script': 'Plrd', 'suppress': False},
        'ywq-Yiii': {'full': 'ywq-Yiii-CN', 'region': 'CN', 'script': 'Yiii', 'suppress': False},
        'ywr': {'full': 'ywr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'ywt': {'full': 'ywt-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'ywu': {'full': 'ywu-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yww': {'full': 'yww-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yxa': {'full': 'yxa-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yxg': {'full': 'yxg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yxl': {'full': 'yxl-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yxm': {'full': 'yxm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yxu': {'full': 'yxu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yxy': {'full': 'yxy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yyr': {'full': 'yyr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'yyu': {'full': 'yyu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'yyz': {'full': 'yyz-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yzg': {'full': 'yzg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'yzk': {'full': 'yzk-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'za': {'full': 'za-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'za-Hani': {'full': 'za-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'za-Hans': {'full': 'za-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'zaa': {'full': 'zaa-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zab': {'full': 'zab-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zac': {'full': 'zac-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zad': {'full': 'zad-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zae': {'full': 'zae-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zaf': {'full': 'zaf-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zag': {'full': 'zag-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'zag-Arab': {'full': 'zag-Arab-SD', 'region': 'SD', 'script': 'Arab', 'suppress': False},
        'zag-Zzzz-x-beria': {'full': 'zag-Zzzz-SD-x-beria', 'region': 'SD', 'script': 'Zzzz', 'suppress': False},
        'zah': {'full': 'zah-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'zaj': {'full': 'zaj-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'zak': {'full': 'zak-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'zal': {'full': 'zal-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'zam': {'full': 'zam-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zao': {'full': 'zao-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zap': {'full': 'zap-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zaq': {'full': 'zaq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zar': {'full': 'zar-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zas': {'full': 'zas-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zat': {'full': 'zat-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zau': {'full': 'zau-Tibt-IN', 'region': 'IN', 'script': 'Tibt', 'suppress': False},
        'zav': {'full': 'zav-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zaw': {'full': 'zaw-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zax': {'full': 'zax-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zay': {'full': 'zay-Latn-ET', 'region': 'ET', 'script': 'Latn', 'suppress': False},
        'zay-Ethi': {'full': 'zay-Ethi-ET', 'region': 'ET', 'script': 'Ethi', 'suppress': False},
        'zaz': {'full': 'zaz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'zba': {'full': 'zba-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'zbc': {'full': 'zbc-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'zbe': {'full': 'zbe-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'zbl': {'full': 'zbl-Blis-001', 'region': '001', 'script': 'Blis', 'suppress': True},
        'zbt': {'full': 'zbt-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'zbw': {'full': 'zbw-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'zca': {'full': 'zca-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zch': {'full': 'zch-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zdj': {'full': 'zdj-Arab-KM', 'region': 'KM', 'script': 'Arab', 'suppress': False},
        'zdj-Latn': {'full': 'zdj-Latn-KM', 'region': 'KM', 'script': 'Latn', 'suppress': False},
        'zea': {'full': 'zea-Latn-NL', 'region': 'NL', 'script': 'Latn', 'suppress': False},
        'zeg': {'full': 'zeg-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zeh': {'full': 'zeh-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zen': {'full': 'zen-Tfng-MR', 'region': 'MR', 'script': 'Tfng', 'suppress': False},
        'zen-Arab': {'full': 'zen-Arab-MR', 'region': 'MR', 'script': 'Arab', 'suppress': False},
        'zga': {'full': 'zga-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'zgb': {'full': 'zgb-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zgh': {'full': 'zgh-Tfng-MA', 'region': 'MA', 'script': 'Tfng', 'suppress': False},
        'zgm': {'full': 'zgm-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zgn': {'full': 'zgn-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zgr': {'full': 'zgr-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zh-AU': {'full': 'zh-Hant-AU', 'region': 'AU', 'script': 'Hant', 'suppress': False},
        'zh-BN': {'full': 'zh-Hant-BN', 'region': 'BN', 'script': 'Hant', 'suppress': False},
        'zh-Bopo': {'full': 'zh-Bopo-TW', 'region': 'TW', 'script': 'Bopo', 'suppress': False},
        'zh-Brai': {'full': 'zh-Brai-CN', 'region': 'CN', 'script': 'Brai', 'suppress': False},
        'zh-CN': {'full': 'zh-Hans-CN', 'region': 'CN', 'script': 'Hans', 'suppress': False},
        'zh-GB': {'full': 'zh-Hant-GB', 'region': 'GB', 'script': 'Hant', 'suppress': False},
        'zh-GF': {'full': 'zh-Hant-GF', 'region': 'GF', 'script': 'Hant', 'suppress': False},
        'zh-HK': {'full': 'zh-Hant-HK', 'region': 'HK', 'script': 'Hant', 'suppress': False},
        'zh-Hanb': {'full': 'zh-Hanb-TW', 'region': 'TW', 'script': 'Hanb', 'suppress': False},
        'zh-Hans-HK': {'full': 'zh-Hans-HK', 'region': 'HK', 'script': 'Hans', 'suppress': False},
        'zh-Hans-MO': {'full': 'zh-Hans-MO', 'region': 'MO', 'script': 'Hans', 'suppress': False},
        'zh-ID': {'full': 'zh-Hant-ID', 'region': 'ID', 'script': 'Hant', 'suppress': False},
        'zh-Latn': {'full': 'zh-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'zh-MO': {'full': 'zh-Hant-MO', 'region': 'MO', 'script': 'Hant', 'suppress': False},
        'zh-MY': {'full': 'zh-Hant-MY', 'region': 'MY', 'script': 'Hant', 'suppress': False},
        'zh-PA': {'full': 'zh-Hant-PA', 'region': 'PA', 'script': 'Hant', 'suppress': False},
        'zh-PF': {'full': 'zh-Hant-PF', 'region': 'PF', 'script': 'Hant', 'suppress': False},
        'zh-PH': {'full': 'zh-Hant-PH', 'region': 'PH', 'script': 'Hant', 'suppress': False},
        'zh-Phag': {'full': 'zh-Phag-CN', 'region': 'CN', 'script': 'Phag', 'suppress': False},
        'zh-SG': {'full': 'zh-Hans-SG', 'region': 'SG', 'script': 'Hans', 'suppress': False},
        'zh-SR': {'full': 'zh-Hant-SR', 'region': 'SR', 'script': 'Hant', 'suppress': False},
        'zh-TH': {'full': 'zh-Hant-TH', 'region': 'TH', 'script': 'Hant', 'suppress': False},
        'zh-TW': {'full': 'zh-Hant-TW', 'region': 'TW', 'script': 'Hant', 'suppress': False},
        'zh-US': {'full': 'zh-Hant-US', 'region': 'US', 'script': 'Hant', 'suppress': False},
        'zh-VN': {'full': 'zh-Hant-VN', 'region': 'VN', 'script': 'Hant', 'suppress': False},
        'zhb': {'full': 'zhb-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'zhd-Hani': {'full': 'zhd-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zhd-Latn': {'full': 'zhd-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'zhi': {'full': 'zhi-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'zhn-Hani': {'full': 'zhn-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zhn-Latn': {'full': 'zhn-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'zhw': {'full': 'zhw-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'zhx': {'full': 'zhx-Nshu-CN', 'region': 'CN', 'script': 'Nshu', 'suppress': False},
        'zia': {'full': 'zia-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zib': {'full': 'zib-Zxxx-ZW', 'region': 'ZW', 'script': 'Zxxx', 'suppress': False},
        'zik': {'full': 'zik-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zil': {'full': 'zil-Latn-GN', 'region': 'GN', 'script': 'Latn', 'suppress': False},
        'zim': {'full': 'zim-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'zin': {'full': 'zin-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'zir': {'full': 'zir-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'ziw': {'full': 'ziw-Latn-TZ', 'region': 'TZ', 'script': 'Latn', 'suppress': False},
        'ziz': {'full': 'ziz-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'zka': {'full': 'zka-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'zkb': {'full': 'zkb-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'zkd': {'full': 'zkd-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'zkg': {'full': 'zkg-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'zkh': {'full': 'zkh-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'zkk': {'full': 'zkk-Zyyy-US', 'region': 'US', 'script': 'Zyyy', 'suppress': False},
        'zkn': {'full': 'zkn-Zyyy-MM', 'region': 'MM', 'script': 'Zyyy', 'suppress': False},
        'zko': {'full': 'zko-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'zkp': {'full': 'zkp-Latn-BR', 'region': 'BR', 'script': 'Latn', 'suppress': False},
        'zkr': {'full': 'zkr-Zyyy-CN', 'region': 'CN', 'script': 'Zyyy', 'suppress': False},
        'zkt-Kitl': {'full': 'zkt-Kitl-CN', 'region': 'CN', 'script': 'Kitl', 'suppress': False},
        'zkt-Kits': {'full': 'zkt-Kits-CN', 'region': 'CN', 'script': 'Kits', 'suppress': False},
        'zku': {'full': 'zku-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zkv': {'full': 'zkv-Zyyy-LV', 'region': 'LV', 'script': 'Zyyy', 'suppress': False},
        'zkz': {'full': 'zkz-Cyrl-RU', 'region': 'RU', 'script': 'Cyrl', 'suppress': False},
        'zlj': {'full': 'zlj-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zlj-Latn': {'full': 'zlj-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'zlm': {'full': 'zlm-Latn-TG', 'region': 'TG', 'script': 'Latn', 'suppress': False},
        'zlm-Arab': {'full': 'zlm-Arab-MY', 'region': 'MY', 'script': 'Arab', 'suppress': False},
        'zln': {'full': 'zln-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zlq': {'full': 'zlq-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zma': {'full': 'zma-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmb': {'full': 'zmb-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zmc': {'full': 'zmc-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmd': {'full': 'zmd-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zme': {'full': 'zme-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmf': {'full': 'zmf-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zmg': {'full': 'zmg-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmh': {'full': 'zmh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zmi': {'full': 'zmi-Latn-MY', 'region': 'MY', 'script': 'Latn', 'suppress': False},
        'zmj': {'full': 'zmj-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmk': {'full': 'zmk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zml': {'full': 'zml-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmm': {'full': 'zmm-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmn': {'full': 'zmn-Latn-GA', 'region': 'GA', 'script': 'Latn', 'suppress': False},
        'zmo': {'full': 'zmo-Latn-SD', 'region': 'SD', 'script': 'Latn', 'suppress': False},
        'zmp': {'full': 'zmp-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zmq': {'full': 'zmq-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zmr': {'full': 'zmr-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zms': {'full': 'zms-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zmt': {'full': 'zmt-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmu': {'full': 'zmu-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmv': {'full': 'zmv-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmw': {'full': 'zmw-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zmx': {'full': 'zmx-Latn-CG', 'region': 'CG', 'script': 'Latn', 'suppress': False},
        'zmy': {'full': 'zmy-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zmz': {'full': 'zmz-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zna': {'full': 'zna-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'zne': {'full': 'zne-Latn-CD', 'region': 'CD', 'script': 'Latn', 'suppress': False},
        'zne-Arab': {'full': 'zne-Arab-SS', 'region': 'SS', 'script': 'Arab', 'suppress': False},
        'zng': {'full': 'zng-Latn-VN', 'region': 'VN', 'script': 'Latn', 'suppress': False},
        'znk': {'full': 'znk-Latn-AU', 'region': 'AU', 'script': 'Latn', 'suppress': False},
        'zns': {'full': 'zns-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'zoc': {'full': 'zoc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zoh': {'full': 'zoh-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zom': {'full': 'zom-Latn-IN', 'region': 'IN', 'script': 'Latn', 'suppress': False},
        'zoo': {'full': 'zoo-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zoq': {'full': 'zoq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zor': {'full': 'zor-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zos': {'full': 'zos-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpa': {'full': 'zpa-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpb': {'full': 'zpb-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpc': {'full': 'zpc-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpd': {'full': 'zpd-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpe': {'full': 'zpe-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpf': {'full': 'zpf-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpg': {'full': 'zpg-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zph': {'full': 'zph-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpi': {'full': 'zpi-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpj': {'full': 'zpj-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpk': {'full': 'zpk-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpl': {'full': 'zpl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpm': {'full': 'zpm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpn': {'full': 'zpn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpo': {'full': 'zpo-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpp': {'full': 'zpp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpq': {'full': 'zpq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpr': {'full': 'zpr-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zps': {'full': 'zps-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpt': {'full': 'zpt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpu': {'full': 'zpu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpv': {'full': 'zpv-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpw': {'full': 'zpw-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpx': {'full': 'zpx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpy': {'full': 'zpy-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zpz': {'full': 'zpz-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zqe': {'full': 'zqe-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zqe-Latn': {'full': 'zqe-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'zra': {'full': 'zra-Zyyy-KR', 'region': 'KR', 'script': 'Zyyy', 'suppress': False},
        'zrg-Orya': {'full': 'zrg-Orya-IN', 'region': 'IN', 'script': 'Orya', 'suppress': False},
        'zrg-Telu': {'full': 'zrg-Telu-IN', 'region': 'IN', 'script': 'Telu', 'suppress': False},
        'zrn': {'full': 'zrn-Latn-TD', 'region': 'TD', 'script': 'Latn', 'suppress': False},
        'zro': {'full': 'zro-Latn-EC', 'region': 'EC', 'script': 'Latn', 'suppress': False},
        'zrp': {'full': 'zrp-Zyyy-FR', 'region': 'FR', 'script': 'Zyyy', 'suppress': False},
        'zrs': {'full': 'zrs-Latn-ID', 'region': 'ID', 'script': 'Latn', 'suppress': False},
        'zsa': {'full': 'zsa-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zsk': {'full': 'zsk-Zyyy-TR', 'region': 'TR', 'script': 'Zyyy', 'suppress': False},
        'zsl': {'full': 'zsl-Zxxx-ZM', 'region': 'ZM', 'script': 'Zxxx', 'suppress': False},
        'zsr': {'full': 'zsr-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zsu': {'full': 'zsu-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zte': {'full': 'zte-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztg': {'full': 'ztg-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztl': {'full': 'ztl-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztm': {'full': 'ztm-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztn': {'full': 'ztn-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztp': {'full': 'ztp-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztq': {'full': 'ztq-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zts': {'full': 'zts-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztt': {'full': 'ztt-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztu': {'full': 'ztu-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'ztx': {'full': 'ztx-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zty': {'full': 'zty-Latn-MX', 'region': 'MX', 'script': 'Latn', 'suppress': False},
        'zu': {'full': 'zu-Latn-ZA', 'region': 'ZA', 'script': 'Latn', 'suppress': True},
        'zu-Brai': {'full': 'zu-Brai-ZA', 'region': 'ZA', 'script': 'Brai', 'suppress': False},
        'zua': {'full': 'zua-Latn-NG', 'region': 'NG', 'script': 'Latn', 'suppress': False},
        'zuh': {'full': 'zuh-Latn-PG', 'region': 'PG', 'script': 'Latn', 'suppress': False},
        'zum': {'full': 'zum-Zyyy-OM', 'region': 'OM', 'script': 'Zyyy', 'suppress': False},
        'zun': {'full': 'zun-Latn-US', 'region': 'US', 'script': 'Latn', 'suppress': False},
        'zuy': {'full': 'zuy-Latn-CM', 'region': 'CM', 'script': 'Latn', 'suppress': False},
        'zwa': {'full': 'zwa-Zyyy-ET', 'region': 'ET', 'script': 'Zyyy', 'suppress': False},
        'zxx': {'full': 'zxx-Zyyy-001', 'region': '001', 'script': 'Zyyy', 'suppress': False},
        'zyg': {'full': 'zyg-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zyg-Nshu': {'full': 'zyg-Nshu-CN', 'region': 'CN', 'script': 'Nshu', 'suppress': False},
        'zyj': {'full': 'zyj-Latn-CN', 'region': 'CN', 'script': 'Latn', 'suppress': False},
        'zyj-Hani': {'full': 'zyj-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zyn': {'full': 'zyn-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False},
        'zyp': {'full': 'zyp-Latn-MM', 'region': 'MM', 'script': 'Latn', 'suppress': False},
        'zza': {'full': 'zza-Latn-TR', 'region': 'TR', 'script': 'Latn', 'suppress': False},
        'zza-Arab': {'full': 'zza-Arab-TR', 'region': 'TR', 'script': 'Arab', 'suppress': False},
        'zzj': {'full': 'zzj-Hani-CN', 'region': 'CN', 'script': 'Hani', 'suppress': False} }

    __allTags = { 'aa': 'aa',
        'aa-Latn-ET': 'aa',
        'aa-ET': 'aa',
        'aa-Latn': 'aa',
        'aa-Arab': 'aa-Arab',
        'aa-Arab-ET': 'aa-Arab',
        'aa-DJ': 'aa-DJ',
        'aa-Latn-DJ': 'aa-DJ',
        'aa-ER': 'aa-ER',
        'aa-Latn-ER': 'aa-ER',
        'aa-Ethi': 'aa-Ethi',
        'aa-Ethi-ET': 'aa-Ethi',
        'aaa': 'aaa',
        'aaa-Latn-NG': 'aaa',
        'aaa-Latn': 'aaa',
        'aaa-NG': 'aaa',
        'aab': 'aab',
        'aab-Latn-NG': 'aab',
        'aab-Latn': 'aab',
        'aab-NG': 'aab',
        'aac': 'aac',
        'aac-Latn-PG': 'aac',
        'aac-Latn': 'aac',
        'aac-PG': 'aac',
        'aad': 'aad',
        'aad-Latn-PG': 'aad',
        'aad-Latn': 'aad',
        'aad-PG': 'aad',
        'aae': 'aae',
        'aae-Latn-IT': 'aae',
        'aae-IT': 'aae',
        'aae-Latn': 'aae',
        'aae-Grek': 'aae-Grek',
        'aae-Grek-IT': 'aae-Grek',
        'aaf': 'aaf',
        'aaf-Zyyy-IN': 'aaf',
        'aaf-IN': 'aaf',
        'aaf-Zyyy': 'aaf',
        'aag': 'aag',
        'aag-Latn-PG': 'aag',
        'aag-Latn': 'aag',
        'aag-PG': 'aag',
        'aah': 'aah',
        'aah-Latn-PG': 'aah',
        'aah-Latn': 'aah',
        'aah-PG': 'aah',
        'aai': 'aai',
        'aai-Latn-PG': 'aai',
        'aai-Latn': 'aai',
        'aai-PG': 'aai',
        'aak': 'aak',
        'aak-Latn-PG': 'aak',
        'aak-Latn': 'aak',
        'aak-PG': 'aak',
        'aal': 'aal',
        'aal-Latn-CM': 'aal',
        'aal-CM': 'aal',
        'aal-Latn': 'aal',
        'aan': 'aan',
        'aan-Latn-BR': 'aan',
        'aan-BR': 'aan',
        'aan-Latn': 'aan',
        'aao': 'aao',
        'aao-Arab-DZ': 'aao',
        'aao-Arab': 'aao',
        'aao-DZ': 'aao',
        'ar-aao': 'aao',
        'ar-aao-DZ': 'aao',
        'aap': 'aap',
        'aap-Latn-BR': 'aap',
        'aap-BR': 'aap',
        'aap-Latn': 'aap',
        'aaq': 'aaq',
        'aaq-Zyyy-US': 'aaq',
        'aaq-US': 'aaq',
        'aaq-Zyyy': 'aaq',
        'aas': 'aas',
        'aas-Latn-TZ': 'aas',
        'aam': 'aas',
        'aam-Latn': 'aas',
        'aam-Latn-TZ': 'aas',
        'aam-TZ': 'aas',
        'aas-Latn': 'aas',
        'aas-TZ': 'aas',
        'aat': 'aat',
        'aat-Grek-GR': 'aat',
        'aat-GR': 'aat',
        'aat-Grek': 'aat',
        'aau': 'aau',
        'aau-Latn-PG': 'aau',
        'aau-Latn': 'aau',
        'aau-PG': 'aau',
        'aaw': 'aaw',
        'aaw-Latn-PG': 'aaw',
        'aaw-Latn': 'aaw',
        'aaw-PG': 'aaw',
        'aax': 'aax',
        'aax-Latn-ID': 'aax',
        'aax-ID': 'aax',
        'aax-Latn': 'aax',
        'aaz': 'aaz',
        'aaz-Latn-ID': 'aaz',
        'aaz-ID': 'aaz',
        'aaz-Latn': 'aaz',
        'ab': 'ab',
        'ab-Cyrl-GE': 'ab',
        'ab-Cyrl': 'ab',
        'ab-GE': 'ab',
        'ab-Geor': 'ab-Geor',
        'ab-Geor-GE': 'ab-Geor',
        'aba': 'aba',
        'aba-Latn-CI': 'aba',
        'aba-CI': 'aba',
        'aba-Latn': 'aba',
        'abb': 'abb',
        'abb-Latn-CM': 'abb',
        'abb-CM': 'abb',
        'abb-Latn': 'abb',
        'abc': 'abc',
        'abc-Latn-PH': 'abc',
        'abc-Latn': 'abc',
        'abc-PH': 'abc',
        'abd': 'abd',
        'abd-Latn-PH': 'abd',
        'abd-Latn': 'abd',
        'abd-PH': 'abd',
        'abe': 'abe',
        'abe-Latn-CA': 'abe',
        'abe-CA': 'abe',
        'abe-Latn': 'abe',
        'abf': 'abf',
        'abf-Latn-MY': 'abf',
        'abf-Latn': 'abf',
        'abf-MY': 'abf',
        'abg': 'abg',
        'abg-Latn-PG': 'abg',
        'abg-Latn': 'abg',
        'abg-PG': 'abg',
        'abh': 'abh',
        'abh-Arab-TJ': 'abh',
        'abh-Arab': 'abh',
        'abh-TJ': 'abh',
        'ar-abh': 'abh',
        'ar-abh-TJ': 'abh',
        'abi': 'abi',
        'abi-Latn-CI': 'abi',
        'abi-CI': 'abi',
        'abi-Latn': 'abi',
        'abj': 'abj',
        'abj-Zyyy-IN': 'abj',
        'abj-IN': 'abj',
        'abj-Zyyy': 'abj',
        'abl': 'abl',
        'abl-Rjng-ID': 'abl',
        'abl-ID': 'abl',
        'abl-Rjng': 'abl',
        'abm': 'abm',
        'abm-Latn-NG': 'abm',
        'abm-Latn': 'abm',
        'abm-NG': 'abm',
        'abn': 'abn',
        'abn-Latn-NG': 'abn',
        'abn-Latn': 'abn',
        'abn-NG': 'abn',
        'abo': 'abo',
        'abo-Latn-NG': 'abo',
        'abo-Latn': 'abo',
        'abo-NG': 'abo',
        'abp': 'abp',
        'abp-Latn-PH': 'abp',
        'abp-Latn': 'abp',
        'abp-PH': 'abp',
        'abq-Cyrl': 'abq-Cyrl',
        'abq-Cyrl-RU': 'abq-Cyrl',
        'abq': 'abq-Cyrl',
        'abq-RU': 'abq-Cyrl',
        'abq-Latn': 'abq-Latn',
        'abq-Latn-TR': 'abq-Latn',
        'abq-TR': 'abq-Latn',
        'abr': 'abr',
        'abr-Latn-GH': 'abr',
        'abr-GH': 'abr',
        'abr-Latn': 'abr',
        'abs': 'abs',
        'abs-Latn-ID': 'abs',
        'abs-ID': 'abs',
        'abs-Latn': 'abs',
        'abt': 'abt',
        'abt-Latn-PG': 'abt',
        'abt-Latn': 'abt',
        'abt-PG': 'abt',
        'abt-x-maprik': 'abt-x-maprik',
        'abt-Latn-PG-x-maprik': 'abt-x-maprik',
        'abt-Latn-x-maprik': 'abt-x-maprik',
        'abt-PG-x-maprik': 'abt-x-maprik',
        'abt-x-woserak': 'abt-x-woserak',
        'abt-Latn-PG-x-woserak': 'abt-x-woserak',
        'abt-Latn-x-woserak': 'abt-x-woserak',
        'abt-PG-x-woserak': 'abt-x-woserak',
        'abu': 'abu',
        'abu-Latn-CI': 'abu',
        'abu-CI': 'abu',
        'abu-Latn': 'abu',
        'abv': 'abv',
        'abv-Arab-BH': 'abv',
        'abv-Arab': 'abv',
        'abv-BH': 'abv',
        'ar-abv': 'abv',
        'ar-abv-BH': 'abv',
        'abw': 'abw',
        'abw-Latn-PG': 'abw',
        'abw-Latn': 'abw',
        'abw-PG': 'abw',
        'abx': 'abx',
        'abx-Latn-PH': 'abx',
        'abx-Latn': 'abx',
        'abx-PH': 'abx',
        'aby': 'aby',
        'aby-Latn-PG': 'aby',
        'aby-Latn': 'aby',
        'aby-PG': 'aby',
        'abz': 'abz',
        'abz-Latn-ID': 'abz',
        'abz-ID': 'abz',
        'abz-Latn': 'abz',
        'aca': 'aca',
        'aca-Latn-CO': 'aca',
        'aca-CO': 'aca',
        'aca-Latn': 'aca',
        'acb': 'acb',
        'acb-Latn-NG': 'acb',
        'acb-Latn': 'acb',
        'acb-NG': 'acb',
        'acd': 'acd',
        'acd-Latn-GH': 'acd',
        'acd-GH': 'acd',
        'acd-Latn': 'acd',
        'ace': 'ace',
        'ace-Latn-ID': 'ace',
        'ace-ID': 'ace',
        'ace-Latn': 'ace',
        'ace-Arab': 'ace-Arab',
        'ace-Arab-ID': 'ace-Arab',
        'acf': 'acf',
        'acf-Latn-LC': 'acf',
        'acf-LC': 'acf',
        'acf-Latn': 'acf',
        'ach': 'ach',
        'ach-Latn-UG': 'ach',
        'ach-Latn': 'ach',
        'ach-UG': 'ach',
        'aci': 'aci',
        'aci-Zyyy-IN': 'aci',
        'aci-IN': 'aci',
        'aci-Zyyy': 'aci',
        'ack': 'ack',
        'ack-Zyyy-IN': 'ack',
        'ack-IN': 'ack',
        'ack-Zyyy': 'ack',
        'acl': 'acl',
        'acl-Zyyy-IN': 'acl',
        'acl-IN': 'acl',
        'acl-Zyyy': 'acl',
        'acm': 'acm',
        'acm-Arab-IQ': 'acm',
        'acm-Arab': 'acm',
        'acm-IQ': 'acm',
        'ar-acm': 'acm',
        'ar-acm-IQ': 'acm',
        'acn': 'acn',
        'acn-Latn-CN': 'acn',
        'acn-CN': 'acn',
        'acn-Latn': 'acn',
        'xia': 'acn',
        'xia-CN': 'acn',
        'xia-Latn': 'acn',
        'xia-Latn-CN': 'acn',
        'acp': 'acp',
        'acp-Latn-NG': 'acp',
        'acp-Latn': 'acp',
        'acp-NG': 'acp',
        'acq': 'acq',
        'acq-Arab-YE': 'acq',
        'acq-Arab': 'acq',
        'acq-YE': 'acq',
        'ar-acq': 'acq',
        'ar-acq-YE': 'acq',
        'acr': 'acr',
        'acr-Latn-GT': 'acr',
        'acr-GT': 'acr',
        'acr-Latn': 'acr',
        'acr-x-cubulco': 'acr-x-cubulco',
        'acr-Latn-GT-x-cubulco': 'acr-x-cubulco',
        'acr-GT-x-cubulco': 'acr-x-cubulco',
        'acr-Latn-x-cubulco': 'acr-x-cubulco',
        'acr-x-rabinal': 'acr-x-rabinal',
        'acr-Latn-GT-x-rabinal': 'acr-x-rabinal',
        'acr-GT-x-rabinal': 'acr-x-rabinal',
        'acr-Latn-x-rabinal': 'acr-x-rabinal',
        'acs': 'acs',
        'acs-Latn-BR': 'acs',
        'acs-BR': 'acs',
        'acs-Latn': 'acs',
        'act': 'act',
        'act-Latn-NL': 'act',
        'act-Latn': 'act',
        'act-NL': 'act',
        'acu': 'acu',
        'acu-Latn-EC': 'acu',
        'acu-EC': 'acu',
        'acu-Latn': 'acu',
        'acv': 'acv',
        'acv-Latn-US': 'acv',
        'acv-Latn': 'acv',
        'acv-US': 'acv',
        'acw': 'acw',
        'acw-Arab-SA': 'acw',
        'acw-Arab': 'acw',
        'acw-SA': 'acw',
        'ar-acw': 'acw',
        'ar-acw-SA': 'acw',
        'acx': 'acx',
        'acx-Arab-OM': 'acx',
        'acx-Arab': 'acx',
        'acx-OM': 'acx',
        'ar-acx': 'acx',
        'ar-acx-OM': 'acx',
        'acy': 'acy',
        'acy-Latn-CY': 'acy',
        'acy-CY': 'acy',
        'acy-Latn': 'acy',
        'ar-acy': 'acy',
        'ar-acy-CY': 'acy',
        'acy-Arab': 'acy-Arab',
        'acy-Arab-CY': 'acy-Arab',
        'acy-Grek': 'acy-Grek',
        'acy-Grek-CY': 'acy-Grek',
        'acz': 'acz',
        'acz-Latn-SD': 'acz',
        'acz-Latn': 'acz',
        'acz-SD': 'acz',
        'ada': 'ada',
        'ada-Latn-GH': 'ada',
        'ada-GH': 'ada',
        'ada-Latn': 'ada',
        'adb': 'adb',
        'adb-Latn-TL': 'adb',
        'adb-Latn': 'adb',
        'adb-TL': 'adb',
        'add': 'add',
        'add-Latn-CM': 'add',
        'add-CM': 'add',
        'add-Latn': 'add',
        'ade': 'ade',
        'ade-Latn-TG': 'ade',
        'ade-Latn': 'ade',
        'ade-TG': 'ade',
        'adf': 'adf',
        'adf-Arab-OM': 'adf',
        'adf-Arab': 'adf',
        'adf-OM': 'adf',
        'ar-adf': 'adf',
        'ar-adf-OM': 'adf',
        'adg': 'adg',
        'adg-Latn-AU': 'adg',
        'adg-AU': 'adg',
        'adg-Latn': 'adg',
        'adh': 'adh',
        'adh-Latn-UG': 'adh',
        'adh-Latn': 'adh',
        'adh-UG': 'adh',
        'adi': 'adi',
        'adi-Latn-IN': 'adi',
        'adi-IN': 'adi',
        'adi-Latn': 'adi',
        'adi-Tibt': 'adi-Tibt',
        'adi-Tibt-CN': 'adi-Tibt',
        'adi-CN': 'adi-Tibt',
        'adj': 'adj',
        'adj-Latn-CI': 'adj',
        'adj-CI': 'adj',
        'adj-Latn': 'adj',
        'adl': 'adl',
        'adl-Latn-IN': 'adl',
        'adl-IN': 'adl',
        'adl-Latn': 'adl',
        'adn': 'adn',
        'adn-Latn-ID': 'adn',
        'adn-ID': 'adn',
        'adn-Latn': 'adn',
        'ado': 'ado',
        'ado-Latn-PG': 'ado',
        'ado-Latn': 'ado',
        'ado-PG': 'ado',
        'adq': 'adq',
        'adq-Latn-GH': 'adq',
        'adq-GH': 'adq',
        'adq-Latn': 'adq',
        'adr': 'adr',
        'adr-Latn-ID': 'adr',
        'adr-ID': 'adr',
        'adr-Latn': 'adr',
        'ads': 'ads',
        'ads-Latn-GH': 'ads',
        'ads-GH': 'ads',
        'ads-Latn': 'ads',
        'sgn-ads': 'ads',
        'sgn-ads-GH': 'ads',
        'ads-Zxxx': 'ads-Zxxx',
        'ads-Zxxx-GH': 'ads-Zxxx',
        'adt': 'adt',
        'adt-Latn-AU': 'adt',
        'adt-AU': 'adt',
        'adt-Latn': 'adt',
        'adu': 'adu',
        'adu-Latn-NG': 'adu',
        'adu-Latn': 'adu',
        'adu-NG': 'adu',
        'adw': 'adw',
        'adw-Latn-BR': 'adw',
        'adw-BR': 'adw',
        'adw-Latn': 'adw',
        'adx': 'adx',
        'adx-Tibt-CN': 'adx',
        'adx-CN': 'adx',
        'adx-Tibt': 'adx',
        'pcr': 'adx',
        'pcr-CN': 'adx',
        'pcr-Tibt': 'adx',
        'pcr-Tibt-CN': 'adx',
        'ady': 'ady',
        'ady-Cyrl-RU': 'ady',
        'ady-Cyrl': 'ady',
        'ady-RU': 'ady',
        'ady-Arab': 'ady-Arab',
        'ady-Arab-RU': 'ady-Arab',
        'ady-Latn': 'ady-Latn',
        'ady-Latn-TR': 'ady-Latn',
        'ady-TR': 'ady-Latn',
        'adz': 'adz',
        'adz-Latn-PG': 'adz',
        'adz-Latn': 'adz',
        'adz-PG': 'adz',
        'ae': 'ae',
        'ae-Avst-IR': 'ae',
        'ae-Avst': 'ae',
        'ae-IR': 'ae',
        'ae-Arab': 'ae-Arab',
        'ae-Arab-IR': 'ae-Arab',
        'ae-Gujr': 'ae-Gujr',
        'ae-Gujr-IR': 'ae-Gujr',
        'aea': 'aea',
        'aea-Latn-AU': 'aea',
        'aea-AU': 'aea',
        'aea-Latn': 'aea',
        'aeb': 'aeb',
        'aeb-Arab-TN': 'aeb',
        'aeb-Arab': 'aeb',
        'aeb-TN': 'aeb',
        'ar-aeb': 'aeb',
        'ar-aeb-TN': 'aeb',
        'aeb-Latn': 'aeb-Latn',
        'aeb-Latn-TN': 'aeb-Latn',
        'aec': 'aec',
        'aec-Arab-EG': 'aec',
        'aec-Arab': 'aec',
        'aec-EG': 'aec',
        'ar-aec': 'aec',
        'ar-aec-EG': 'aec',
        'aed': 'aed',
        'aed-Zxxx-AR': 'aed',
        'aed-AR': 'aed',
        'aed-Zxxx': 'aed',
        'sgn-aed': 'aed',
        'sgn-aed-AR': 'aed',
        'aee': 'aee',
        'aee-Arab-AF': 'aee',
        'aee-AF': 'aee',
        'aee-Arab': 'aee',
        'aek': 'aek',
        'aek-Latn-NC': 'aek',
        'aek-Latn': 'aek',
        'aek-NC': 'aek',
        'ael': 'ael',
        'ael-Latn-CM': 'ael',
        'ael-CM': 'ael',
        'ael-Latn': 'ael',
        'aem': 'aem',
        'aem-Latn-VN': 'aem',
        'aem-Latn': 'aem',
        'aem-VN': 'aem',
        'aen': 'aen',
        'aen-Zxxx-AM': 'aen',
        'aen-AM': 'aen',
        'aen-Zxxx': 'aen',
        'sgn-aen': 'aen',
        'sgn-aen-AM': 'aen',
        'aeq': 'aeq',
        'aeq-Arab-PK': 'aeq',
        'aeq-Arab': 'aeq',
        'aeq-PK': 'aeq',
        'aer': 'aer',
        'aer-Latn-AU': 'aer',
        'aer-AU': 'aer',
        'aer-Latn': 'aer',
        'aes': 'aes',
        'aes-Zyyy-US': 'aes',
        'aes-US': 'aes',
        'aes-Zyyy': 'aes',
        'aeu': 'aeu',
        'aeu-Latn-CN': 'aeu',
        'aeu-CN': 'aeu',
        'aeu-Latn': 'aeu',
        'aew': 'aew',
        'aew-Latn-PG': 'aew',
        'aew-Latn': 'aew',
        'aew-PG': 'aew',
        'aey': 'aey',
        'aey-Latn-PG': 'aey',
        'aey-Latn': 'aey',
        'aey-PG': 'aey',
        'aez': 'aez',
        'aez-Latn-PG': 'aez',
        'aez-Latn': 'aez',
        'aez-PG': 'aez',
        'af': 'af',
        'af-Latn-ZA': 'af',
        'af-Latn': 'af',
        'af-ZA': 'af',
        'af-Arab': 'af-Arab',
        'af-Arab-ZA': 'af-Arab',
        'af-Brai': 'af-Brai',
        'af-Brai-ZA': 'af-Brai',
        'af-NA': 'af-NA',
        'af-Latn-NA': 'af-NA',
        'afb': 'afb',
        'afb-Arab-KW': 'afb',
        'afb-Arab': 'afb',
        'afb-KW': 'afb',
        'ar-afb': 'afb',
        'ar-afb-KW': 'afb',
        'afd': 'afd',
        'afd-Latn-PG': 'afd',
        'afd-Latn': 'afd',
        'afd-PG': 'afd',
        'afe': 'afe',
        'afe-Latn-NG': 'afe',
        'afe-Latn': 'afe',
        'afe-NG': 'afe',
        'afg': 'afg',
        'afg-Zxxx-AF': 'afg',
        'afg-AF': 'afg',
        'afg-Zxxx': 'afg',
        'sgn-afg': 'afg',
        'sgn-afg-AF': 'afg',
        'afh': 'afh',
        'afh-Latn-GH': 'afh',
        'afh-GH': 'afh',
        'afh-Latn': 'afh',
        'afi': 'afi',
        'afi-Latn-PG': 'afi',
        'afi-Latn': 'afi',
        'afi-PG': 'afi',
        'afk': 'afk',
        'afk-Latn-PG': 'afk',
        'afk-Latn': 'afk',
        'afk-PG': 'afk',
        'afn': 'afn',
        'afn-Latn-NG': 'afn',
        'afn-Latn': 'afn',
        'afn-NG': 'afn',
        'afo': 'afo',
        'afo-Latn-NG': 'afo',
        'afo-Latn': 'afo',
        'afo-NG': 'afo',
        'afp': 'afp',
        'afp-Latn-PG': 'afp',
        'afp-Latn': 'afp',
        'afp-PG': 'afp',
        'afs': 'afs',
        'afs-Latn-MX': 'afs',
        'afs-Latn': 'afs',
        'afs-MX': 'afs',
        'aft': 'aft',
        'aft-Zyyy-SD': 'aft',
        'aft-SD': 'aft',
        'aft-Zyyy': 'aft',
        'afu': 'afu',
        'afu-Latn-GH': 'afu',
        'afu-GH': 'afu',
        'afu-Latn': 'afu',
        'afz': 'afz',
        'afz-Latn-ID': 'afz',
        'afz-ID': 'afz',
        'afz-Latn': 'afz',
        'aga': 'aga',
        'aga-Latn-PE': 'aga',
        'aga-Latn': 'aga',
        'aga-PE': 'aga',
        'agb': 'agb',
        'agb-Latn-NG': 'agb',
        'agb-Latn': 'agb',
        'agb-NG': 'agb',
        'agc': 'agc',
        'agc-Latn-NG': 'agc',
        'agc-Latn': 'agc',
        'agc-NG': 'agc',
        'agd': 'agd',
        'agd-Latn-PG': 'agd',
        'agd-Latn': 'agd',
        'agd-PG': 'agd',
        'age': 'age',
        'age-Latn-PG': 'age',
        'age-Latn': 'age',
        'age-PG': 'age',
        'agf': 'agf',
        'agf-Latn-ID': 'agf',
        'agf-ID': 'agf',
        'agf-Latn': 'agf',
        'agg': 'agg',
        'agg-Latn-PG': 'agg',
        'agg-Latn': 'agg',
        'agg-PG': 'agg',
        'agh': 'agh',
        'agh-Latn-CD': 'agh',
        'agh-CD': 'agh',
        'agh-Latn': 'agh',
        'agi': 'agi',
        'agi-Zyyy-IN': 'agi',
        'agi-IN': 'agi',
        'agi-Zyyy': 'agi',
        'agj': 'agj',
        'agj-Ethi-ET': 'agj',
        'agj-ET': 'agj',
        'agj-Ethi': 'agj',
        'agj-Arab': 'agj-Arab',
        'agj-Arab-ET': 'agj-Arab',
        'agk': 'agk',
        'agk-Latn-PH': 'agk',
        'agk-Latn': 'agk',
        'agk-PH': 'agk',
        'agl': 'agl',
        'agl-Latn-PG': 'agl',
        'agl-Latn': 'agl',
        'agl-PG': 'agl',
        'agm': 'agm',
        'agm-Latn-PG': 'agm',
        'agm-Latn': 'agm',
        'agm-PG': 'agm',
        'agn': 'agn',
        'agn-Latn-PH': 'agn',
        'agn-Latn': 'agn',
        'agn-PH': 'agn',
        'ago': 'ago',
        'ago-Latn-PG': 'ago',
        'ago-Latn': 'ago',
        'ago-PG': 'ago',
        'agq': 'agq',
        'agq-Latn-CM': 'agq',
        'agq-CM': 'agq',
        'agq-Latn': 'agq',
        'agr': 'agr',
        'agr-Latn-PE': 'agr',
        'agr-Latn': 'agr',
        'agr-PE': 'agr',
        'ags': 'ags',
        'ags-Latn-CM': 'ags',
        'ags-CM': 'ags',
        'ags-Latn': 'ags',
        'agt': 'agt',
        'agt-Latn-PH': 'agt',
        'agt-Latn': 'agt',
        'agt-PH': 'agt',
        'agu': 'agu',
        'agu-Latn-GT': 'agu',
        'agu-GT': 'agu',
        'agu-Latn': 'agu',
        'agv': 'agv',
        'agv-Latn-PH': 'agv',
        'agv-Latn': 'agv',
        'agv-PH': 'agv',
        'agw': 'agw',
        'agw-Latn-SB': 'agw',
        'agw-Latn': 'agw',
        'agw-SB': 'agw',
        'agx': 'agx',
        'agx-Cyrl-RU': 'agx',
        'agx-Cyrl': 'agx',
        'agx-RU': 'agx',
        'agy': 'agy',
        'agy-Latn-PH': 'agy',
        'agy-Latn': 'agy',
        'agy-PH': 'agy',
        'agz': 'agz',
        'agz-Latn-PH': 'agz',
        'agz-Latn': 'agz',
        'agz-PH': 'agz',
        'aha': 'aha',
        'aha-Latn-GH': 'aha',
        'aha-GH': 'aha',
        'aha-Latn': 'aha',
        'ahb': 'ahb',
        'ahb-Latn-VU': 'ahb',
        'ahb-Latn': 'ahb',
        'ahb-VU': 'ahb',
        'ahg': 'ahg',
        'ahg-Ethi-ET': 'ahg',
        'ahg-ET': 'ahg',
        'ahg-Ethi': 'ahg',
        'ahh': 'ahh',
        'ahh-Latn-ID': 'ahh',
        'ahh-ID': 'ahh',
        'ahh-Latn': 'ahh',
        'ahi': 'ahi',
        'ahi-Latn-CI': 'ahi',
        'ahi-CI': 'ahi',
        'ahi-Latn': 'ahi',
        'ahk': 'ahk',
        'ahk-Latn-MM': 'ahk',
        'ahk-Latn': 'ahk',
        'ahk-MM': 'ahk',
        'ahk-Latn-x-louma': 'ahk-Latn-x-louma',
        'ahk-Latn-LA-x-louma': 'ahk-Latn-x-louma',
        'ahk-LA-x-louma': 'ahk-Latn-x-louma',
        'ahk-Mymr': 'ahk-Mymr',
        'ahk-Mymr-MM': 'ahk-Mymr',
        'ahk-TH': 'ahk-TH',
        'ahk-Latn-TH': 'ahk-TH',
        'ahk-Thai': 'ahk-Thai',
        'ahk-Thai-TH': 'ahk-Thai',
        'ahl': 'ahl',
        'ahl-Latn-TG': 'ahl',
        'ahl-Latn': 'ahl',
        'ahl-TG': 'ahl',
        'ahm': 'ahm',
        'ahm-Latn-CI': 'ahm',
        'ahm-CI': 'ahm',
        'ahm-Latn': 'ahm',
        'ahn': 'ahn',
        'ahn-Latn-NG': 'ahn',
        'ahn-Latn': 'ahn',
        'ahn-NG': 'ahn',
        'aho': 'aho',
        'aho-Ahom-IN': 'aho',
        'aho-Ahom': 'aho',
        'aho-IN': 'aho',
        'ahp': 'ahp',
        'ahp-Latn-CI': 'ahp',
        'ahp-CI': 'ahp',
        'ahp-Latn': 'ahp',
        'ahr': 'ahr',
        'ahr-Zyyy-IN': 'ahr',
        'ahr-IN': 'ahr',
        'ahr-Zyyy': 'ahr',
        'ahs': 'ahs',
        'ahs-Latn-NG': 'ahs',
        'ahs-Latn': 'ahs',
        'ahs-NG': 'ahs',
        'aht': 'aht',
        'aht-Latn-US': 'aht',
        'aht-Latn': 'aht',
        'aht-US': 'aht',
        'aia': 'aia',
        'aia-Latn-SB': 'aia',
        'aia-Latn': 'aia',
        'aia-SB': 'aia',
        'aib': 'aib',
        'aib-Zyyy-CN': 'aib',
        'aib-CN': 'aib',
        'aib-Zyyy': 'aib',
        'aic': 'aic',
        'aic-Latn-PG': 'aic',
        'aic-Latn': 'aic',
        'aic-PG': 'aic',
        'aid': 'aid',
        'aid-Latn-AU': 'aid',
        'aid-AU': 'aid',
        'aid-Latn': 'aid',
        'aie': 'aie',
        'aie-Latn-PG': 'aie',
        'aie-Latn': 'aie',
        'aie-PG': 'aie',
        'aif': 'aif',
        'aif-Latn-PG': 'aif',
        'aif-Latn': 'aif',
        'aif-PG': 'aif',
        'aig': 'aig',
        'aig-Latn-AG': 'aig',
        'aig-AG': 'aig',
        'aig-Latn': 'aig',
        'aih': 'aih',
        'aih-Zyyy-CN': 'aih',
        'aih-CN': 'aih',
        'aih-Zyyy': 'aih',
        'aii-Cyrl': 'aii-Cyrl',
        'aii-Cyrl-RU': 'aii-Cyrl',
        'aii-RU': 'aii-Cyrl',
        'aii-Syrc': 'aii-Syrc',
        'aii-Syrc-IQ': 'aii-Syrc',
        'aii-IQ': 'aii-Syrc',
        'aij': 'aij',
        'aij-Hebr-IL': 'aij',
        'aij-Hebr': 'aij',
        'aij-IL': 'aij',
        'aik': 'aik',
        'aik-Latn-NG': 'aik',
        'aik-Latn': 'aik',
        'aik-NG': 'aik',
        'ail': 'ail',
        'ail-Latn-PG': 'ail',
        'ail-Latn': 'ail',
        'ail-PG': 'ail',
        'aim': 'aim',
        'aim-Latn-IN': 'aim',
        'aim-IN': 'aim',
        'aim-Latn': 'aim',
        'ain': 'ain',
        'ain-Kana-JP': 'ain',
        'ain-JP': 'ain',
        'ain-Kana': 'ain',
        'ain-Latn': 'ain-Latn',
        'ain-Latn-JP': 'ain-Latn',
        'aio': 'aio',
        'aio-Mymr-IN': 'aio',
        'aio-IN': 'aio',
        'aio-Mymr': 'aio',
        'aip': 'aip',
        'aip-Latn-ID': 'aip',
        'aip-ID': 'aip',
        'aip-Latn': 'aip',
        'aiq': 'aiq',
        'aiq-Arab-AF': 'aiq',
        'aiq-AF': 'aiq',
        'aiq-Arab': 'aiq',
        'air': 'air',
        'air-Latn-ID': 'air',
        'air-ID': 'air',
        'air-Latn': 'air',
        'ait': 'ait',
        'ait-Latn-BR': 'ait',
        'ait-BR': 'ait',
        'ait-Latn': 'ait',
        'aiw-Arab': 'aiw-Arab',
        'aiw-Arab-ET': 'aiw-Arab',
        'aiw-Ethi': 'aiw-Ethi',
        'aiw-Ethi-ET': 'aiw-Ethi',
        'aiw-Latn': 'aiw-Latn',
        'aiw-Latn-ET': 'aiw-Latn',
        'aix': 'aix',
        'aix-Latn-PG': 'aix',
        'aix-Latn': 'aix',
        'aix-PG': 'aix',
        'aiy': 'aiy',
        'aiy-Latn-CF': 'aiy',
        'aiy-CF': 'aiy',
        'aiy-Latn': 'aiy',
        'aja': 'aja',
        'aja-Latn-SS': 'aja',
        'aja-Latn': 'aja',
        'aja-SS': 'aja',
        'ajg': 'ajg',
        'ajg-Latn-BJ': 'ajg',
        'ajg-BJ': 'ajg',
        'ajg-Latn': 'ajg',
        'aji': 'aji',
        'aji-Latn-NC': 'aji',
        'aji-Latn': 'aji',
        'aji-NC': 'aji',
        'ajn': 'ajn',
        'ajn-Latn-AU': 'ajn',
        'ajn-AU': 'ajn',
        'ajn-Latn': 'ajn',
        'ajp': 'ajp',
        'ajp-Arab-JO': 'ajp',
        'ajp-Arab': 'ajp',
        'ajp-JO': 'ajp',
        'ar-ajp': 'ajp',
        'ar-ajp-JO': 'ajp',
        'ajt': 'ajt',
        'ajt-Arab-TN': 'ajt',
        'ajt-Arab': 'ajt',
        'ajt-TN': 'ajt',
        'ajt-Hebr': 'ajt-Hebr',
        'ajt-Hebr-IL': 'ajt-Hebr',
        'ajt-IL': 'ajt-Hebr',
        'aju-Arab': 'aju-Arab',
        'aju-Arab-MA': 'aju-Arab',
        'aju-MA': 'aju-Arab',
        'ajw': 'ajw',
        'ajw-Latn-NG': 'ajw',
        'ajw-Latn': 'ajw',
        'ajw-NG': 'ajw',
        'ajz': 'ajz',
        'ajz-Latn-IN': 'ajz',
        'ajz-IN': 'ajz',
        'ajz-Latn': 'ajz',
        'ak': 'ak',
        'ak-Latn-GH': 'ak',
        'ak-GH': 'ak',
        'ak-Latn': 'ak',
        'fat': 'ak',
        'fat-GH': 'ak',
        'fat-Latn': 'ak',
        'fat-Latn-GH': 'ak',
        'tw': 'ak',
        'tw-GH': 'ak',
        'tw-Latn': 'ak',
        'tw-Latn-GH': 'ak',
        'ak-Arab': 'ak-Arab',
        'ak-Arab-GH': 'ak-Arab',
        'akb': 'akb',
        'akb-Latn-ID': 'akb',
        'akb-ID': 'akb',
        'akb-Latn': 'akb',
        'akb-Batk': 'akb-Batk',
        'akb-Batk-ID': 'akb-Batk',
        'akc': 'akc',
        'akc-Latn-ID': 'akc',
        'akc-ID': 'akc',
        'akc-Latn': 'akc',
        'akd': 'akd',
        'akd-Latn-NG': 'akd',
        'akd-Latn': 'akd',
        'akd-NG': 'akd',
        'ake': 'ake',
        'ake-Latn-GY': 'ake',
        'ake-GY': 'ake',
        'ake-Latn': 'ake',
        'akf': 'akf',
        'akf-Latn-NG': 'akf',
        'akf-Latn': 'akf',
        'akf-NG': 'akf',
        'akg': 'akg',
        'akg-Latn-ID': 'akg',
        'akg-ID': 'akg',
        'akg-Latn': 'akg',
        'akh': 'akh',
        'akh-Latn-PG': 'akh',
        'akh-Latn': 'akh',
        'akh-PG': 'akh',
        'aki': 'aki',
        'aki-Latn-PG': 'aki',
        'aki-Latn': 'aki',
        'aki-PG': 'aki',
        'akj': 'akj',
        'akj-Zyyy-IN': 'akj',
        'akj-IN': 'akj',
        'akj-Zyyy': 'akj',
        'akk': 'akk',
        'akk-Xsux-IQ': 'akk',
        'akk-IQ': 'akk',
        'akk-Xsux': 'akk',
        'akl': 'akl',
        'akl-Latn-PH': 'akl',
        'akl-Latn': 'akl',
        'akl-PH': 'akl',
        'akm': 'akm',
        'akm-Zyyy-IN': 'akm',
        'akm-IN': 'akm',
        'akm-Zyyy': 'akm',
        'ako': 'ako',
        'ako-Latn-SR': 'ako',
        'ako-Latn': 'ako',
        'ako-SR': 'ako',
        'akp': 'akp',
        'akp-Latn-GH': 'akp',
        'akp-GH': 'akp',
        'akp-Latn': 'akp',
        'akq': 'akq',
        'akq-Latn-PG': 'akq',
        'akq-Latn': 'akq',
        'akq-PG': 'akq',
        'akr': 'akr',
        'akr-Latn-VU': 'akr',
        'akr-Latn': 'akr',
        'akr-VU': 'akr',
        'aks': 'aks',
        'aks-Latn-TG': 'aks',
        'aks-Latn': 'aks',
        'aks-TG': 'aks',
        'akt': 'akt',
        'akt-Latn-PG': 'akt',
        'akt-Latn': 'akt',
        'akt-PG': 'akt',
        'aku': 'aku',
        'aku-Latn-CM': 'aku',
        'aku-CM': 'aku',
        'aku-Latn': 'aku',
        'akv': 'akv',
        'akv-Cyrl-RU': 'akv',
        'akv-Cyrl': 'akv',
        'akv-RU': 'akv',
        'akw': 'akw',
        'akw-Latn-CG': 'akw',
        'akw-CG': 'akw',
        'akw-Latn': 'akw',
        'akx': 'akx',
        'akx-Zyyy-IN': 'akx',
        'akx-IN': 'akx',
        'akx-Zyyy': 'akx',
        'aky': 'aky',
        'aky-Zyyy-IN': 'aky',
        'aky-IN': 'aky',
        'aky-Zyyy': 'aky',
        'akz': 'akz',
        'akz-Latn-US': 'akz',
        'akz-Latn': 'akz',
        'akz-US': 'akz',
        'ala': 'ala',
        'ala-Latn-NG': 'ala',
        'ala-Latn': 'ala',
        'ala-NG': 'ala',
        'alc': 'alc',
        'alc-Latn-CL': 'alc',
        'alc-CL': 'alc',
        'alc-Latn': 'alc',
        'ald': 'ald',
        'ald-Latn-CI': 'ald',
        'ald-CI': 'ald',
        'ald-Latn': 'ald',
        'ale': 'ale',
        'ale-Latn-US': 'ale',
        'ale-Latn': 'ale',
        'ale-US': 'ale',
        'ale-Cyrs': 'ale-Cyrs',
        'ale-Cyrs-US': 'ale-Cyrs',
        'alf': 'alf',
        'alf-Latn-NG': 'alf',
        'alf-Latn': 'alf',
        'alf-NG': 'alf',
        'alh': 'alh',
        'alh-Latn-AU': 'alh',
        'alh-AU': 'alh',
        'alh-Latn': 'alh',
        'ali': 'ali',
        'ali-Latn-PG': 'ali',
        'ali-Latn': 'ali',
        'ali-PG': 'ali',
        'alj': 'alj',
        'alj-Latn-PH': 'alj',
        'alj-Latn': 'alj',
        'alj-PH': 'alj',
        'alk': 'alk',
        'alk-Zyyy-LA': 'alk',
        'alk-LA': 'alk',
        'alk-Zyyy': 'alk',
        'all': 'all',
        'all-Mlym-IN': 'all',
        'all-IN': 'all',
        'all-Mlym': 'all',
        'alm': 'alm',
        'alm-Latn-VU': 'alm',
        'alm-Latn': 'alm',
        'alm-VU': 'alm',
        'aln': 'aln',
        'aln-Latn-XK': 'aln',
        'aln-Latn': 'aln',
        'aln-XK': 'aln',
        'aln-Brai': 'aln-Brai',
        'aln-Brai-AL': 'aln-Brai',
        'aln-AL': 'aln-Brai',
        'alo': 'alo',
        'alo-Latn-ID': 'alo',
        'alo-ID': 'alo',
        'alo-Latn': 'alo',
        'alp': 'alp',
        'alp-Latn-ID': 'alp',
        'alp-ID': 'alp',
        'alp-Latn': 'alp',
        'alq': 'alq',
        'alq-Latn-CA': 'alq',
        'alq-CA': 'alq',
        'alq-Latn': 'alq',
        'alr': 'alr',
        'alr-Cyrl-RU': 'alr',
        'alr-Cyrl': 'alr',
        'alr-RU': 'alr',
        'alt': 'alt',
        'alt-Cyrl-RU': 'alt',
        'alt-Cyrl': 'alt',
        'alt-RU': 'alt',
        'alt-Mong': 'alt-Mong',
        'alt-Mong-RU': 'alt-Mong',
        'alu': 'alu',
        'alu-Latn-SB': 'alu',
        'alu-Latn': 'alu',
        'alu-SB': 'alu',
        'alw': 'alw',
        'alw-Ethi-ET': 'alw',
        'alw-ET': 'alw',
        'alw-Ethi': 'alw',
        'alx': 'alx',
        'alx-Latn-PG': 'alx',
        'alx-Latn': 'alx',
        'alx-PG': 'alx',
        'aly': 'aly',
        'aly-Latn-AU': 'aly',
        'aly-AU': 'aly',
        'aly-Latn': 'aly',
        'alz': 'alz',
        'alz-Latn-CD': 'alz',
        'alz-CD': 'alz',
        'alz-Latn': 'alz',
        'am': 'am',
        'am-Ethi-ET': 'am',
        'am-ET': 'am',
        'am-Ethi': 'am',
        'am-Arab': 'am-Arab',
        'am-Arab-ET': 'am-Arab',
        'am-Brai': 'am-Brai',
        'am-Brai-ET': 'am-Brai',
        'ama': 'ama',
        'ama-Latn-BR': 'ama',
        'ama-BR': 'ama',
        'ama-Latn': 'ama',
        'amb': 'amb',
        'amb-Latn-NG': 'amb',
        'amb-Latn': 'amb',
        'amb-NG': 'amb',
        'amc': 'amc',
        'amc-Latn-PE': 'amc',
        'amc-Latn': 'amc',
        'amc-PE': 'amc',
        'ame': 'ame',
        'ame-Latn-PE': 'ame',
        'ame-Latn': 'ame',
        'ame-PE': 'ame',
        'amf-Ethi': 'amf-Ethi',
        'amf-Ethi-ET': 'amf-Ethi',
        'amf-Latn': 'amf-Latn',
        'amf-Latn-ET': 'amf-Latn',
        'amg': 'amg',
        'amg-Latn-AU': 'amg',
        'amg-AU': 'amg',
        'amg-Latn': 'amg',
        'ami': 'ami',
        'ami-Latn-TW': 'ami',
        'ami-Latn': 'ami',
        'ami-TW': 'ami',
        'ami-Zyyy-TW': 'ami-Zyyy-TW',
        'ais': 'ami-Zyyy-TW',
        'ais-TW': 'ami-Zyyy-TW',
        'ais-Zyyy': 'ami-Zyyy-TW',
        'ais-Zyyy-TW': 'ami-Zyyy-TW',
        'amj': 'amj',
        'amj-Latn-TD': 'amj',
        'amj-Latn': 'amj',
        'amj-TD': 'amj',
        'amk': 'amk',
        'amk-Latn-ID': 'amk',
        'amk-ID': 'amk',
        'amk-Latn': 'amk',
        'aml': 'aml',
        'aml-Zyyy-BD': 'aml',
        'aml-BD': 'aml',
        'aml-Zyyy': 'aml',
        'amm': 'amm',
        'amm-Latn-PG': 'amm',
        'amm-Latn': 'amm',
        'amm-PG': 'amm',
        'amn': 'amn',
        'amn-Latn-PG': 'amn',
        'amn-Latn': 'amn',
        'amn-PG': 'amn',
        'amo': 'amo',
        'amo-Latn-NG': 'amo',
        'amo-Latn': 'amo',
        'amo-NG': 'amo',
        'amp': 'amp',
        'amp-Latn-PG': 'amp',
        'amp-Latn': 'amp',
        'amp-PG': 'amp',
        'amq': 'amq',
        'amq-Latn-ID': 'amq',
        'amq-ID': 'amq',
        'amq-Latn': 'amq',
        'amr': 'amr',
        'amr-Latn-PE': 'amr',
        'amr-Latn': 'amr',
        'amr-PE': 'amr',
        'ams': 'ams',
        'ams-Zyyy-JP': 'ams',
        'ams-JP': 'ams',
        'ams-Zyyy': 'ams',
        'amt': 'amt',
        'amt-Latn-PG': 'amt',
        'amt-Latn': 'amt',
        'amt-PG': 'amt',
        'amu': 'amu',
        'amu-Latn-MX': 'amu',
        'amu-Latn': 'amu',
        'amu-MX': 'amu',
        'amv': 'amv',
        'amv-Latn-ID': 'amv',
        'amv-ID': 'amv',
        'amv-Latn': 'amv',
        'amw-Arab': 'amw-Arab',
        'amw-Arab-SY': 'amw-Arab',
        'amw-Armi': 'amw-Armi',
        'amw-Armi-SY': 'amw-Armi',
        'amw-Latn': 'amw-Latn',
        'amw-Latn-SY': 'amw-Latn',
        'amw-Syrj': 'amw-Syrj',
        'amw-Syrj-SY': 'amw-Syrj',
        'amx': 'amx',
        'amx-Latn-AU': 'amx',
        'amx-AU': 'amx',
        'amx-Latn': 'amx',
        'amy': 'amy',
        'amy-Latn-AU': 'amy',
        'amy-AU': 'amy',
        'amy-Latn': 'amy',
        'amz': 'amz',
        'amz-Latn-AU': 'amz',
        'amz-AU': 'amz',
        'amz-Latn': 'amz',
        'an': 'an',
        'an-Latn-ES': 'an',
        'an-ES': 'an',
        'an-Latn': 'an',
        'ana': 'ana',
        'ana-Latn-CO': 'ana',
        'ana-CO': 'ana',
        'ana-Latn': 'ana',
        'anb': 'anb',
        'anb-Latn-PE': 'anb',
        'anb-Latn': 'anb',
        'anb-PE': 'anb',
        'anc': 'anc',
        'anc-Latn-NG': 'anc',
        'anc-Latn': 'anc',
        'anc-NG': 'anc',
        'and': 'and',
        'and-Latn-ID': 'and',
        'and-ID': 'and',
        'and-Latn': 'and',
        'ane': 'ane',
        'ane-Latn-NC': 'ane',
        'ane-Latn': 'ane',
        'ane-NC': 'ane',
        'anf': 'anf',
        'anf-Latn-GH': 'anf',
        'anf-GH': 'anf',
        'anf-Latn': 'anf',
        'ang': 'ang',
        'ang-Latn-GB': 'ang',
        'ang-GB': 'ang',
        'ang-Latn': 'ang',
        'anh': 'anh',
        'anh-Latn-PG': 'anh',
        'anh-Latn': 'anh',
        'anh-PG': 'anh',
        'ani': 'ani',
        'ani-Cyrl-RU': 'ani',
        'ani-Cyrl': 'ani',
        'ani-RU': 'ani',
        'anj': 'anj',
        'anj-Latn-PG': 'anj',
        'anj-Latn': 'anj',
        'anj-PG': 'anj',
        'ank': 'ank',
        'ank-Latn-NG': 'ank',
        'ank-Latn': 'ank',
        'ank-NG': 'ank',
        'anl': 'anl',
        'anl-Latn-MM': 'anl',
        'anl-Latn': 'anl',
        'anl-MM': 'anl',
        'anm': 'anm',
        'anm-Latn-IN': 'anm',
        'anm-IN': 'anm',
        'anm-Latn': 'anm',
        'ann': 'ann',
        'ann-Latn-NG': 'ann',
        'ann-Latn': 'ann',
        'ann-NG': 'ann',
        'ano': 'ano',
        'ano-Latn-CO': 'ano',
        'ano-CO': 'ano',
        'ano-Latn': 'ano',
        'anp': 'anp',
        'anp-Deva-IN': 'anp',
        'anp-Deva': 'anp',
        'anp-IN': 'anp',
        'anq': 'anq',
        'anq-Zyyy-IN': 'anq',
        'anq-IN': 'anq',
        'anq-Zyyy': 'anq',
        'anr': 'anr',
        'anr-Deva-IN': 'anr',
        'anr-Deva': 'anr',
        'anr-IN': 'anr',
        'ans': 'ans',
        'ans-Latn-CO': 'ans',
        'ans-CO': 'ans',
        'ans-Latn': 'ans',
        'ant': 'ant',
        'ant-Latn-AU': 'ant',
        'ant-AU': 'ant',
        'ant-Latn': 'ant',
        'anu': 'anu',
        'anu-Ethi-ET': 'anu',
        'anu-ET': 'anu',
        'anu-Ethi': 'anu',
        'anu-Arab': 'anu-Arab',
        'anu-Arab-SS': 'anu-Arab',
        'anu-Latn': 'anu-Latn',
        'anu-Latn-SS': 'anu-Latn',
        'anv': 'anv',
        'anv-Latn-CM': 'anv',
        'anv-CM': 'anv',
        'anv-Latn': 'anv',
        'anw': 'anw',
        'anw-Latn-NG': 'anw',
        'anw-Latn': 'anw',
        'anw-NG': 'anw',
        'anx': 'anx',
        'anx-Latn-PG': 'anx',
        'anx-Latn': 'anx',
        'anx-PG': 'anx',
        'any': 'any',
        'any-Latn-CI': 'any',
        'any-CI': 'any',
        'any-Latn': 'any',
        'anz': 'anz',
        'anz-Latn-PG': 'anz',
        'anz-Latn': 'anz',
        'anz-PG': 'anz',
        'aoa': 'aoa',
        'aoa-Latn-ST': 'aoa',
        'aoa-Latn': 'aoa',
        'aoa-ST': 'aoa',
        'aob': 'aob',
        'aob-Latn-PG': 'aob',
        'aob-Latn': 'aob',
        'aob-PG': 'aob',
        'aoc': 'aoc',
        'aoc-Latn-VE': 'aoc',
        'aoc-Latn': 'aoc',
        'aoc-VE': 'aoc',
        'aod': 'aod',
        'aod-Latn-PG': 'aod',
        'aod-Latn': 'aod',
        'aod-PG': 'aod',
        'aoe': 'aoe',
        'aoe-Latn-PG': 'aoe',
        'aoe-Latn': 'aoe',
        'aoe-PG': 'aoe',
        'aof': 'aof',
        'aof-Latn-PG': 'aof',
        'aof-Latn': 'aof',
        'aof-PG': 'aof',
        'aog': 'aog',
        'aog-Latn-PG': 'aog',
        'aog-Latn': 'aog',
        'aog-PG': 'aog',
        'myd': 'aog',
        'myd-Latn': 'aog',
        'myd-Latn-PG': 'aog',
        'myd-PG': 'aog',
        'aoh': 'aoh',
        'aoh-Latn-CO': 'aoh',
        'aoh-CO': 'aoh',
        'aoh-Latn': 'aoh',
        'aoi': 'aoi',
        'aoi-Latn-AU': 'aoi',
        'aoi-AU': 'aoi',
        'aoi-Latn': 'aoi',
        'aoj': 'aoj',
        'aoj-Latn-PG': 'aoj',
        'aoj-Latn': 'aoj',
        'aoj-PG': 'aoj',
        'aoj-x-balif': 'aoj-x-balif',
        'aoj-Latn-PG-x-balif': 'aoj-x-balif',
        'aoj-Latn-x-balif': 'aoj-x-balif',
        'aoj-PG-x-balif': 'aoj-x-balif',
        'aoj-x-filifita': 'aoj-x-filifita',
        'aoj-Latn-PG-x-filifita': 'aoj-x-filifita',
        'aoj-Latn-x-filifita': 'aoj-x-filifita',
        'aoj-PG-x-filifita': 'aoj-x-filifita',
        'aok': 'aok',
        'aok-Latn-NC': 'aok',
        'aok-Latn': 'aok',
        'aok-NC': 'aok',
        'aol': 'aol',
        'aol-Latn-ID': 'aol',
        'aol-ID': 'aol',
        'aol-Latn': 'aol',
        'aom': 'aom',
        'aom-Latn-PG': 'aom',
        'aom-Latn': 'aom',
        'aom-PG': 'aom',
        'aon': 'aon',
        'aon-Latn-PG': 'aon',
        'aon-Latn': 'aon',
        'aon-PG': 'aon',
        'aor': 'aor',
        'aor-Latn-VU': 'aor',
        'aor-Latn': 'aor',
        'aor-VU': 'aor',
        'aos': 'aos',
        'aos-Latn-ID': 'aos',
        'aos-ID': 'aos',
        'aos-Latn': 'aos',
        'aot': 'aot',
        'aot-Zyyy-IN': 'aot',
        'aot-IN': 'aot',
        'aot-Zyyy': 'aot',
        'aou': 'aou',
        'aou-Zyyy-CN': 'aou',
        'aou-CN': 'aou',
        'aou-Zyyy': 'aou',
        'aox': 'aox',
        'aox-Latn-GY': 'aox',
        'aox-GY': 'aox',
        'aox-Latn': 'aox',
        'aoz': 'aoz',
        'aoz-Latn-ID': 'aoz',
        'aoz-ID': 'aoz',
        'aoz-Latn': 'aoz',
        'apb': 'apb',
        'apb-Latn-SB': 'apb',
        'apb-Latn': 'apb',
        'apb-SB': 'apb',
        'apc': 'apc',
        'apc-Arab-SY': 'apc',
        'apc-Arab': 'apc',
        'apc-SY': 'apc',
        'ar-apc': 'apc',
        'ar-apc-SY': 'apc',
        'apd': 'apd',
        'apd-Arab-TG': 'apd',
        'apd-Arab': 'apd',
        'apd-TG': 'apd',
        'ar-apd': 'apd',
        'ar-apd-TG': 'apd',
        'apd-Latn': 'apd-Latn',
        'apd-Latn-SD': 'apd-Latn',
        'apd-SD': 'apd-Latn',
        'ar-apd-SD': 'apd-Latn',
        'ape': 'ape',
        'ape-Latn-PG': 'ape',
        'ape-Latn': 'ape',
        'ape-PG': 'ape',
        'ape-x-coastal': 'ape-x-coastal',
        'ape-Latn-PG-x-coastal': 'ape-x-coastal',
        'ape-Latn-x-coastal': 'ape-x-coastal',
        'ape-PG-x-coastal': 'ape-x-coastal',
        'ape-x-mountain': 'ape-x-mountain',
        'ape-Latn-PG-x-mountain': 'ape-x-mountain',
        'ape-Latn-x-mountain': 'ape-x-mountain',
        'ape-PG-x-mountain': 'ape-x-mountain',
        'apf': 'apf',
        'apf-Latn-PH': 'apf',
        'apf-Latn': 'apf',
        'apf-PH': 'apf',
        'apg': 'apg',
        'apg-Latn-ID': 'apg',
        'apg-ID': 'apg',
        'apg-Latn': 'apg',
        'aph': 'aph',
        'aph-Deva-NP': 'aph',
        'aph-Deva': 'aph',
        'aph-NP': 'aph',
        'api': 'api',
        'api-Latn-BR': 'api',
        'api-BR': 'api',
        'api-Latn': 'api',
        'apj': 'apj',
        'apj-Latn-US': 'apj',
        'apj-Latn': 'apj',
        'apj-US': 'apj',
        'apk': 'apk',
        'apk-Latn-US': 'apk',
        'apk-Latn': 'apk',
        'apk-US': 'apk',
        'apl': 'apl',
        'apl-Latn-US': 'apl',
        'apl-Latn': 'apl',
        'apl-US': 'apl',
        'apm': 'apm',
        'apm-Latn-US': 'apm',
        'apm-Latn': 'apm',
        'apm-US': 'apm',
        'apn': 'apn',
        'apn-Latn-BR': 'apn',
        'apn-BR': 'apn',
        'apn-Latn': 'apn',
        'apo': 'apo',
        'apo-Latn-PG': 'apo',
        'apo-Latn': 'apo',
        'apo-PG': 'apo',
        'app': 'app',
        'app-Latn-VU': 'app',
        'app-Latn': 'app',
        'app-VU': 'app',
        'apq': 'apq',
        'apq-Zyyy-IN': 'apq',
        'apq-IN': 'apq',
        'apq-Zyyy': 'apq',
        'apr': 'apr',
        'apr-Latn-PG': 'apr',
        'apr-Latn': 'apr',
        'apr-PG': 'apr',
        'aps': 'aps',
        'aps-Latn-PG': 'aps',
        'aps-Latn': 'aps',
        'aps-PG': 'aps',
        'apt': 'apt',
        'apt-Latn-IN': 'apt',
        'apt-IN': 'apt',
        'apt-Latn': 'apt',
        'apu': 'apu',
        'apu-Latn-BR': 'apu',
        'apu-BR': 'apu',
        'apu-Latn': 'apu',
        'apv': 'apv',
        'apv-Latn-BR': 'apv',
        'apv-BR': 'apv',
        'apv-Latn': 'apv',
        'apw': 'apw',
        'apw-Latn-US': 'apw',
        'apw-Latn': 'apw',
        'apw-US': 'apw',
        'apx': 'apx',
        'apx-Latn-ID': 'apx',
        'apx-ID': 'apx',
        'apx-Latn': 'apx',
        'apy': 'apy',
        'apy-Latn-BR': 'apy',
        'apy-BR': 'apy',
        'apy-Latn': 'apy',
        'apz': 'apz',
        'apz-Latn-PG': 'apz',
        'apz-Latn': 'apz',
        'apz-PG': 'apz',
        'aqc': 'aqc',
        'aqc-Cyrl-RU': 'aqc',
        'aqc-Cyrl': 'aqc',
        'aqc-RU': 'aqc',
        'aqd': 'aqd',
        'aqd-Latn-ML': 'aqd',
        'aqd-Latn': 'aqd',
        'aqd-ML': 'aqd',
        'aqg': 'aqg',
        'aqg-Latn-NG': 'aqg',
        'aqg-Latn': 'aqg',
        'aqg-NG': 'aqg',
        'aqm': 'aqm',
        'aqm-Latn-ID': 'aqm',
        'aqm-ID': 'aqm',
        'aqm-Latn': 'aqm',
        'aqn': 'aqn',
        'aqn-Latn-PH': 'aqn',
        'aqn-Latn': 'aqn',
        'aqn-PH': 'aqn',
        'aqp': 'aqp',
        'aqp-Zyyy-US': 'aqp',
        'aqp-US': 'aqp',
        'aqp-Zyyy': 'aqp',
        'aqr': 'aqr',
        'aqr-Latn-NC': 'aqr',
        'aqr-Latn': 'aqr',
        'aqr-NC': 'aqr',
        'aqt': 'aqt',
        'aqt-Latn-PY': 'aqt',
        'aqt-Latn': 'aqt',
        'aqt-PY': 'aqt',
        'aqz': 'aqz',
        'aqz-Latn-BR': 'aqz',
        'aqz-BR': 'aqz',
        'aqz-Latn': 'aqz',
        'ar': 'ar',
        'ar-Arab-EG': 'ar',
        'ar-Arab': 'ar',
        'ar-EG': 'ar',
        'ar-AE': 'ar-AE',
        'ar-Arab-AE': 'ar-AE',
        'ar-Brai': 'ar-Brai',
        'ar-Brai-SA': 'ar-Brai',
        'arb-Brai': 'ar-Brai',
        'arb-Brai-SA': 'ar-Brai',
        'ar-DJ': 'ar-DJ',
        'ar-Arab-DJ': 'ar-DJ',
        'ar-DZ': 'ar-DZ',
        'ar-Arab-DZ': 'ar-DZ',
        'ar-EH': 'ar-EH',
        'ar-Arab-EH': 'ar-EH',
        'ar-ER': 'ar-ER',
        'ar-Arab-ER': 'ar-ER',
        'ar-IL': 'ar-IL',
        'ar-Arab-IL': 'ar-IL',
        'ar-IQ': 'ar-IQ',
        'ar-Arab-IQ': 'ar-IQ',
        'ar-JO': 'ar-JO',
        'ar-Arab-JO': 'ar-JO',
        'ar-KM': 'ar-KM',
        'ar-Arab-KM': 'ar-KM',
        'ar-LB': 'ar-LB',
        'ar-Arab-LB': 'ar-LB',
        'ar-LY': 'ar-LY',
        'ar-Arab-LY': 'ar-LY',
        'ar-MA': 'ar-MA',
        'ar-Arab-MA': 'ar-MA',
        'ar-MR': 'ar-MR',
        'ar-Arab-MR': 'ar-MR',
        'ar-PS': 'ar-PS',
        'ar-Arab-PS': 'ar-PS',
        'ar-SA': 'ar-SA',
        'ar-Arab-SA': 'ar-SA',
        'ar-arb': 'ar-SA',
        'ar-arb-SA': 'ar-SA',
        'arb': 'ar-SA',
        'arb-Arab': 'ar-SA',
        'arb-Arab-SA': 'ar-SA',
        'arb-SA': 'ar-SA',
        'ar-SO': 'ar-SO',
        'ar-Arab-SO': 'ar-SO',
        'ar-SS': 'ar-SS',
        'ar-Arab-SS': 'ar-SS',
        'ar-SY': 'ar-SY',
        'ar-Arab-SY': 'ar-SY',
        'ar-Syrc': 'ar-Syrc',
        'ar-Syrc-SA': 'ar-Syrc',
        'ar-TN': 'ar-TN',
        'ar-Arab-TN': 'ar-TN',
        'arc': 'arc',
        'arc-Armi-IR': 'arc',
        'arc-Armi': 'arc',
        'arc-IR': 'arc',
        'arc-Nbat': 'arc-Nbat',
        'arc-Nbat-JO': 'arc-Nbat',
        'arc-JO': 'arc-Nbat',
        'arc-Palm': 'arc-Palm',
        'arc-Palm-SY': 'arc-Palm',
        'arc-SY': 'arc-Palm',
        'arc-Syrc': 'arc-Syrc',
        'arc-Syrc-XX': 'arc-Syrc',
        'arc-XX': 'arc-Syrc',
        'ard': 'ard',
        'ard-Latn-AU': 'ard',
        'ard-AU': 'ard',
        'ard-Latn': 'ard',
        'are': 'are',
        'are-Latn-AU': 'are',
        'are-AU': 'are',
        'are-Latn': 'are',
        'arh': 'arh',
        'arh-Latn-CO': 'arh',
        'arh-CO': 'arh',
        'arh-Latn': 'arh',
        'ari': 'ari',
        'ari-Latn-US': 'ari',
        'ari-Latn': 'ari',
        'ari-US': 'ari',
        'arj': 'arj',
        'arj-Latn-BR': 'arj',
        'arj-BR': 'arj',
        'arj-Latn': 'arj',
        'ark': 'ark',
        'ark-Latn-BR': 'ark',
        'ark-BR': 'ark',
        'ark-Latn': 'ark',
        'arl': 'arl',
        'arl-Latn-PE': 'arl',
        'arl-Latn': 'arl',
        'arl-PE': 'arl',
        'arn': 'arn',
        'arn-Latn-CL': 'arn',
        'arn-CL': 'arn',
        'arn-Latn': 'arn',
        'aro': 'aro',
        'aro-Latn-BO': 'aro',
        'aro-BO': 'aro',
        'aro-Latn': 'aro',
        'arp': 'arp',
        'arp-Latn-US': 'arp',
        'arp-Latn': 'arp',
        'arp-US': 'arp',
        'arq': 'arq',
        'arq-Arab-DZ': 'arq',
        'ar-arq': 'arq',
        'ar-arq-DZ': 'arq',
        'arq-Arab': 'arq',
        'arq-DZ': 'arq',
        'arr': 'arr',
        'arr-Latn-BR': 'arr',
        'arr-BR': 'arr',
        'arr-Latn': 'arr',
        'ars': 'ars',
        'ars-Arab-SA': 'ars',
        'ar-ars': 'ars',
        'ar-ars-SA': 'ars',
        'ars-Arab': 'ars',
        'ars-SA': 'ars',
        'aru': 'aru',
        'aru-Latn-BR': 'aru',
        'aru-BR': 'aru',
        'aru-Latn': 'aru',
        'arv': 'arv',
        'arv-Zyyy-ET': 'arv',
        'arv-ET': 'arv',
        'arv-Zyyy': 'arv',
        'arw': 'arw',
        'arw-Latn-SR': 'arw',
        'arw-Latn': 'arw',
        'arw-SR': 'arw',
        'arx': 'arx',
        'arx-Latn-BR': 'arx',
        'arx-BR': 'arx',
        'arx-Latn': 'arx',
        'ary': 'ary',
        'ary-Arab-MA': 'ary',
        'ar-ary': 'ary',
        'ar-ary-MA': 'ary',
        'ary-Arab': 'ary',
        'ary-MA': 'ary',
        'arz': 'arz',
        'arz-Arab-EG': 'arz',
        'ar-arz': 'arz',
        'ar-arz-EG': 'arz',
        'arz-Arab': 'arz',
        'arz-EG': 'arz',
        'arz-Brai': 'arz-Brai',
        'arz-Brai-EG': 'arz-Brai',
        'as': 'as',
        'as-Beng-IN': 'as',
        'as-Beng': 'as',
        'as-IN': 'as',
        'asa': 'asa',
        'asa-Latn-TZ': 'asa',
        'asa-Latn': 'asa',
        'asa-TZ': 'asa',
        'asb': 'asb',
        'asb-Latn-CA': 'asb',
        'asb-CA': 'asb',
        'asb-Latn': 'asb',
        'asc': 'asc',
        'asc-Latn-ID': 'asc',
        'asc-ID': 'asc',
        'asc-Latn': 'asc',
        'ase': 'ase',
        'ase-Sgnw-US': 'ase',
        'ase-Sgnw': 'ase',
        'ase-US': 'ase',
        'sgn-ase': 'ase',
        'sgn-ase-US': 'ase',
        'ase-Zxxx': 'ase-Zxxx',
        'ase-Zxxx-US': 'ase-Zxxx',
        'asf': 'asf',
        'asf-Zxxx-AU': 'asf',
        'asf-AU': 'asf',
        'asf-Zxxx': 'asf',
        'sgn-asf': 'asf',
        'sgn-asf-AU': 'asf',
        'asg': 'asg',
        'asg-Latn-NG': 'asg',
        'asg-Latn': 'asg',
        'asg-NG': 'asg',
        'ash': 'ash',
        'ash-Latn-PE': 'ash',
        'ash-Latn': 'ash',
        'ash-PE': 'ash',
        'asi': 'asi',
        'asi-Latn-ID': 'asi',
        'asi-ID': 'asi',
        'asi-Latn': 'asi',
        'asj': 'asj',
        'asj-Latn-CM': 'asj',
        'asj-CM': 'asj',
        'asj-Latn': 'asj',
        'ask': 'ask',
        'ask-Arab-AF': 'ask',
        'ask-AF': 'ask',
        'ask-Arab': 'ask',
        'asl': 'asl',
        'asl-Latn-ID': 'asl',
        'asl-ID': 'asl',
        'asl-Latn': 'asl',
        'asn': 'asn',
        'asn-Latn-BR': 'asn',
        'asn-BR': 'asn',
        'asn-Latn': 'asn',
        'aso': 'aso',
        'aso-Latn-PG': 'aso',
        'aso-Latn': 'aso',
        'aso-PG': 'aso',
        'asp': 'asp',
        'asp-Zxxx-DZ': 'asp',
        'asp-DZ': 'asp',
        'asp-Zxxx': 'asp',
        'sgn-asp': 'asp',
        'sgn-asp-DZ': 'asp',
        'asq': 'asq',
        'asq-Zxxx-AT': 'asq',
        'asq-AT': 'asq',
        'asq-Zxxx': 'asq',
        'sgn-asq': 'asq',
        'sgn-asq-AT': 'asq',
        'asr-Deva': 'asr-Deva',
        'asr-Deva-IN': 'asr-Deva',
        'asr-IN': 'asr-Deva',
        'ass': 'ass',
        'ass-Latn-CM': 'ass',
        'ass-CM': 'ass',
        'ass-Latn': 'ass',
        'ast': 'ast',
        'ast-Latn-ES': 'ast',
        'ast-ES': 'ast',
        'ast-Latn': 'ast',
        'asu': 'asu',
        'asu-Latn-BR': 'asu',
        'asu-BR': 'asu',
        'asu-Latn': 'asu',
        'asv': 'asv',
        'asv-Latn-CD': 'asv',
        'asv-CD': 'asv',
        'asv-Latn': 'asv',
        'asw': 'asw',
        'asw-Zxxx-AU': 'asw',
        'asw-AU': 'asw',
        'asw-Zxxx': 'asw',
        'sgn-asw': 'asw',
        'sgn-asw-AU': 'asw',
        'asx': 'asx',
        'asx-Latn-PG': 'asx',
        'asx-Latn': 'asx',
        'asx-PG': 'asx',
        'asy': 'asy',
        'asy-Latn-ID': 'asy',
        'asy-ID': 'asy',
        'asy-Latn': 'asy',
        'asz': 'asz',
        'asz-Latn-ID': 'asz',
        'asz-ID': 'asz',
        'asz-Latn': 'asz',
        'ata': 'ata',
        'ata-Latn-PG': 'ata',
        'ata-Latn': 'ata',
        'ata-PG': 'ata',
        'atb': 'atb',
        'atb-Latn-CN': 'atb',
        'atb-CN': 'atb',
        'atb-Latn': 'atb',
        'atb-Lisu': 'atb-Lisu',
        'atb-Lisu-CN': 'atb-Lisu',
        'atc': 'atc',
        'atc-Latn-PE': 'atc',
        'atc-Latn': 'atc',
        'atc-PE': 'atc',
        'atd': 'atd',
        'atd-Latn-PH': 'atd',
        'atd-Latn': 'atd',
        'atd-PH': 'atd',
        'ate': 'ate',
        'ate-Latn-PG': 'ate',
        'ate-Latn': 'ate',
        'ate-PG': 'ate',
        'atg': 'atg',
        'atg-Latn-NG': 'atg',
        'atg-Latn': 'atg',
        'atg-NG': 'atg',
        'ati': 'ati',
        'ati-Latn-CI': 'ati',
        'ati-CI': 'ati',
        'ati-Latn': 'ati',
        'atj': 'atj',
        'atj-Latn-CA': 'atj',
        'atj-CA': 'atj',
        'atj-Latn': 'atj',
        'atk': 'atk',
        'atk-Latn-PH': 'atk',
        'atk-Latn': 'atk',
        'atk-PH': 'atk',
        'atl': 'atl',
        'atl-Latn-PH': 'atl',
        'atl-Latn': 'atl',
        'atl-PH': 'atl',
        'atm': 'atm',
        'atm-Latn-PH': 'atm',
        'atm-Latn': 'atm',
        'atm-PH': 'atm',
        'atn': 'atn',
        'atn-Arab-IR': 'atn',
        'atn-Arab': 'atn',
        'atn-IR': 'atn',
        'ato': 'ato',
        'ato-Latn-CM': 'ato',
        'ato-CM': 'ato',
        'ato-Latn': 'ato',
        'atp': 'atp',
        'atp-Latn-PH': 'atp',
        'atp-Latn': 'atp',
        'atp-PH': 'atp',
        'atq': 'atq',
        'atq-Latn-ID': 'atq',
        'atq-ID': 'atq',
        'atq-Latn': 'atq',
        'atr': 'atr',
        'atr-Latn-BR': 'atr',
        'atr-BR': 'atr',
        'atr-Latn': 'atr',
        'ats': 'ats',
        'ats-Latn-US': 'ats',
        'ats-Latn': 'ats',
        'ats-US': 'ats',
        'att': 'att',
        'att-Latn-PH': 'att',
        'att-Latn': 'att',
        'att-PH': 'att',
        'atu': 'atu',
        'atu-Latn-SS': 'atu',
        'atu-Latn': 'atu',
        'atu-SS': 'atu',
        'atv': 'atv',
        'atv-Cyrl-RU': 'atv',
        'atv-Cyrl': 'atv',
        'atv-RU': 'atv',
        'atw': 'atw',
        'atw-Latn-US': 'atw',
        'atw-Latn': 'atw',
        'atw-US': 'atw',
        'atx': 'atx',
        'atx-Latn-BR': 'atx',
        'atx-BR': 'atx',
        'atx-Latn': 'atx',
        'aty': 'aty',
        'aty-Latn-VU': 'aty',
        'aty-Latn': 'aty',
        'aty-VU': 'aty',
        'atz': 'atz',
        'atz-Latn-PH': 'atz',
        'atz-Latn': 'atz',
        'atz-PH': 'atz',
        'aua': 'aua',
        'aua-Latn-SB': 'aua',
        'aua-Latn': 'aua',
        'aua-SB': 'aua',
        'aub': 'aub',
        'aub-Zyyy-CN': 'aub',
        'aub-CN': 'aub',
        'aub-Zyyy': 'aub',
        'auc': 'auc',
        'auc-Latn-EC': 'auc',
        'auc-EC': 'auc',
        'auc-Latn': 'auc',
        'aud': 'aud',
        'aud-Latn-SB': 'aud',
        'aud-Latn': 'aud',
        'aud-SB': 'aud',
        'aug': 'aug',
        'aug-Latn-BJ': 'aug',
        'aug-BJ': 'aug',
        'aug-Latn': 'aug',
        'auh': 'auh',
        'auh-Latn-ZM': 'auh',
        'auh-Latn': 'auh',
        'auh-ZM': 'auh',
        'aui': 'aui',
        'aui-Latn-PG': 'aui',
        'aui-Latn': 'aui',
        'aui-PG': 'aui',
        'auj': 'auj',
        'auj-Zyyy-LY': 'auj',
        'auj-LY': 'auj',
        'auj-Zyyy': 'auj',
        'auk': 'auk',
        'auk-Latn-PG': 'auk',
        'auk-Latn': 'auk',
        'auk-PG': 'auk',
        'aul': 'aul',
        'aul-Latn-VU': 'aul',
        'aul-Latn': 'aul',
        'aul-VU': 'aul',
        'aum': 'aum',
        'aum-Latn-NG': 'aum',
        'aum-Latn': 'aum',
        'aum-NG': 'aum',
        'aun': 'aun',
        'aun-Latn-PG': 'aun',
        'aun-Latn': 'aun',
        'aun-PG': 'aun',
        'auo': 'auo',
        'auo-Latn-NG': 'auo',
        'auo-Latn': 'auo',
        'auo-NG': 'auo',
        'aup': 'aup',
        'aup-Latn-PG': 'aup',
        'aup-Latn': 'aup',
        'aup-PG': 'aup',
        'auq': 'auq',
        'auq-Latn-ID': 'auq',
        'auq-ID': 'auq',
        'auq-Latn': 'auq',
        'aur': 'aur',
        'aur-Latn-PG': 'aur',
        'aur-Latn': 'aur',
        'aur-PG': 'aur',
        'aut': 'aut',
        'aut-Latn-PF': 'aut',
        'aut-Latn': 'aut',
        'aut-PF': 'aut',
        'auu': 'auu',
        'auu-Latn-ID': 'auu',
        'auu-ID': 'auu',
        'auu-Latn': 'auu',
        'auw': 'auw',
        'auw-Latn-ID': 'auw',
        'auw-ID': 'auw',
        'auw-Latn': 'auw',
        'aux': 'aux',
        'aux-Latn-BR': 'aux',
        'aux-BR': 'aux',
        'aux-Latn': 'aux',
        'auy': 'auy',
        'auy-Latn-PG': 'auy',
        'auy-Latn': 'auy',
        'auy-PG': 'auy',
        'auz': 'auz',
        'auz-Arab-UZ': 'auz',
        'ar-auz': 'auz',
        'ar-auz-UZ': 'auz',
        'auz-Arab': 'auz',
        'auz-UZ': 'auz',
        'av': 'av',
        'av-Cyrl-RU': 'av',
        'av-Cyrl': 'av',
        'av-RU': 'av',
        'avb': 'avb',
        'avb-Latn-PG': 'avb',
        'avb-Latn': 'avb',
        'avb-PG': 'avb',
        'avd': 'avd',
        'avd-Zyyy-IR': 'avd',
        'avd-IR': 'avd',
        'avd-Zyyy': 'avd',
        'avi': 'avi',
        'avi-Latn-CI': 'avi',
        'avi-CI': 'avi',
        'avi-Latn': 'avi',
        'avk': 'avk',
        'avk-Latn-001': 'avk',
        'avk-001': 'avk',
        'avk-Latn': 'avk',
        'avl': 'avl',
        'avl-Arab-EG': 'avl',
        'ar-avl': 'avl',
        'ar-avl-EG': 'avl',
        'avl-Arab': 'avl',
        'avl-EG': 'avl',
        'avm': 'avm',
        'avm-Latn-AU': 'avm',
        'avm-AU': 'avm',
        'avm-Latn': 'avm',
        'avn': 'avn',
        'avn-Latn-GH': 'avn',
        'avn-GH': 'avn',
        'avn-Latn': 'avn',
        'avo': 'avo',
        'avo-Latn-BR': 'avo',
        'avo-BR': 'avo',
        'avo-Latn': 'avo',
        'avs': 'avs',
        'avs-Latn-PE': 'avs',
        'avs-Latn': 'avs',
        'avs-PE': 'avs',
        'avt': 'avt',
        'avt-Latn-PG': 'avt',
        'avt-Latn': 'avt',
        'avt-PG': 'avt',
        'avu': 'avu',
        'avu-Latn-SS': 'avu',
        'avu-Latn': 'avu',
        'avu-SS': 'avu',
        'avu-SD': 'avu-SD',
        'avu-Latn-SD': 'avu-SD',
        'avv': 'avv',
        'avv-Latn-BR': 'avv',
        'avv-BR': 'avv',
        'avv-Latn': 'avv',
        'awa': 'awa',
        'awa-Deva-IN': 'awa',
        'awa-Deva': 'awa',
        'awa-IN': 'awa',
        'awb': 'awb',
        'awb-Latn-PG': 'awb',
        'awb-Latn': 'awb',
        'awb-PG': 'awb',
        'awc': 'awc',
        'awc-Latn-NG': 'awc',
        'awc-Latn': 'awc',
        'awc-NG': 'awc',
        'awe': 'awe',
        'awe-Latn-BR': 'awe',
        'awe-BR': 'awe',
        'awe-Latn': 'awe',
        'awg': 'awg',
        'awg-Latn-AU': 'awg',
        'awg-AU': 'awg',
        'awg-Latn': 'awg',
        'awh': 'awh',
        'awh-Latn-ID': 'awh',
        'awh-ID': 'awh',
        'awh-Latn': 'awh',
        'awi': 'awi',
        'awi-Latn-PG': 'awi',
        'awi-Latn': 'awi',
        'awi-PG': 'awi',
        'awk': 'awk',
        'awk-Latn-AU': 'awk',
        'awk-AU': 'awk',
        'awk-Latn': 'awk',
        'awm': 'awm',
        'awm-Latn-PG': 'awm',
        'awm-Latn': 'awm',
        'awm-PG': 'awm',
        'awn': 'awn',
        'awn-Ethi-ET': 'awn',
        'awn-ET': 'awn',
        'awn-Ethi': 'awn',
        'awo': 'awo',
        'awo-Latn-NG': 'awo',
        'awo-Latn': 'awo',
        'awo-NG': 'awo',
        'awr': 'awr',
        'awr-Latn-ID': 'awr',
        'awr-ID': 'awr',
        'awr-Latn': 'awr',
        'aws': 'aws',
        'aws-Latn-ID': 'aws',
        'aws-ID': 'aws',
        'aws-Latn': 'aws',
        'awt': 'awt',
        'awt-Latn-BR': 'awt',
        'awt-BR': 'awt',
        'awt-Latn': 'awt',
        'awu': 'awu',
        'awu-Latn-ID': 'awu',
        'awu-ID': 'awu',
        'awu-Latn': 'awu',
        'awv': 'awv',
        'awv-Latn-ID': 'awv',
        'awv-ID': 'awv',
        'awv-Latn': 'awv',
        'aww': 'aww',
        'aww-Latn-PG': 'aww',
        'aww-Latn': 'aww',
        'aww-PG': 'aww',
        'awx': 'awx',
        'awx-Latn-PG': 'awx',
        'awx-Latn': 'awx',
        'awx-PG': 'awx',
        'awy': 'awy',
        'awy-Latn-ID': 'awy',
        'awy-ID': 'awy',
        'awy-Latn': 'awy',
        'axb': 'axb',
        'axb-Latn-AR': 'axb',
        'axb-AR': 'axb',
        'axb-Latn': 'axb',
        'axe': 'axe',
        'axe-Latn-AU': 'axe',
        'axe-AU': 'axe',
        'axe-Latn': 'axe',
        'axg': 'axg',
        'axg-Latn-BR': 'axg',
        'axg-BR': 'axg',
        'axg-Latn': 'axg',
        'axk': 'axk',
        'axk-Latn-CF': 'axk',
        'axk-CF': 'axk',
        'axk-Latn': 'axk',
        'axl': 'axl',
        'axl-Latn-AU': 'axl',
        'axl-AU': 'axl',
        'axl-Latn': 'axl',
        'axm': 'axm',
        'axm-Zyyy-AM': 'axm',
        'axm-AM': 'axm',
        'axm-Zyyy': 'axm',
        'axx': 'axx',
        'axx-Latn-NC': 'axx',
        'axx-Latn': 'axx',
        'axx-NC': 'axx',
        'ay': 'ay',
        'ay-Latn-BO': 'ay',
        'ay-BO': 'ay',
        'ay-Latn': 'ay',
        'ayr': 'ay',
        'ayr-BO': 'ay',
        'ayr-Latn': 'ay',
        'ayr-Latn-BO': 'ay',
        'aya': 'aya',
        'aya-Latn-PG': 'aya',
        'aya-Latn': 'aya',
        'aya-PG': 'aya',
        'ayb': 'ayb',
        'ayb-Latn-BJ': 'ayb',
        'ayb-BJ': 'ayb',
        'ayb-Latn': 'ayb',
        'ayc': 'ayc',
        'ayc-Latn-PE': 'ayc',
        'ayc-Latn': 'ayc',
        'ayc-PE': 'ayc',
        'ayd': 'ayd',
        'ayd-Latn-AU': 'ayd',
        'ayd-AU': 'ayd',
        'ayd-Latn': 'ayd',
        'aye': 'aye',
        'aye-Latn-NG': 'aye',
        'aye-Latn': 'aye',
        'aye-NG': 'aye',
        'ayg': 'ayg',
        'ayg-Latn-TG': 'ayg',
        'ayg-Latn': 'ayg',
        'ayg-TG': 'ayg',
        'ayh': 'ayh',
        'ayh-Arab-YE': 'ayh',
        'ar-ayh': 'ayh',
        'ar-ayh-YE': 'ayh',
        'ayh-Arab': 'ayh',
        'ayh-YE': 'ayh',
        'ayi': 'ayi',
        'ayi-Latn-NG': 'ayi',
        'ayi-Latn': 'ayi',
        'ayi-NG': 'ayi',
        'ayk': 'ayk',
        'ayk-Latn-NG': 'ayk',
        'ayk-Latn': 'ayk',
        'ayk-NG': 'ayk',
        'ayl': 'ayl',
        'ayl-Arab-LY': 'ayl',
        'ar-ayl': 'ayl',
        'ar-ayl-LY': 'ayl',
        'ayl-Arab': 'ayl',
        'ayl-LY': 'ayl',
        'ayn': 'ayn',
        'ayn-Arab-YE': 'ayn',
        'ar-ayn': 'ayn',
        'ar-ayn-YE': 'ayn',
        'ayn-Arab': 'ayn',
        'ayn-YE': 'ayn',
        'ayo': 'ayo',
        'ayo-Latn-PY': 'ayo',
        'ayo-Latn': 'ayo',
        'ayo-PY': 'ayo',
        'ayp': 'ayp',
        'ayp-Arab-IQ': 'ayp',
        'ar-ayp': 'ayp',
        'ar-ayp-IQ': 'ayp',
        'ayp-Arab': 'ayp',
        'ayp-IQ': 'ayp',
        'ayq': 'ayq',
        'ayq-Latn-PG': 'ayq',
        'ayq-Latn': 'ayq',
        'ayq-PG': 'ayq',
        'ays': 'ays',
        'ays-Latn-PH': 'ays',
        'ays-Latn': 'ays',
        'ays-PH': 'ays',
        'ayt': 'ayt',
        'ayt-Latn-PH': 'ayt',
        'ayt-Latn': 'ayt',
        'ayt-PH': 'ayt',
        'ayu': 'ayu',
        'ayu-Latn-NG': 'ayu',
        'ayu-Latn': 'ayu',
        'ayu-NG': 'ayu',
        'ayy': 'ayy',
        'ayy-Latn-PH': 'ayy',
        'ayy-Latn': 'ayy',
        'ayy-PH': 'ayy',
        'ayz': 'ayz',
        'ayz-Latn-ID': 'ayz',
        'ayz-ID': 'ayz',
        'ayz-Latn': 'ayz',
        'az': 'az',
        'az-Latn-AZ': 'az',
        'az-AZ': 'az',
        'az-Latn': 'az',
        'azj': 'az',
        'azj-AZ': 'az',
        'azj-Latn': 'az',
        'azj-Latn-AZ': 'az',
        'az-Brai': 'az-Brai',
        'az-Brai-IR': 'az-Brai',
        'azj-Brai': 'az-Brai',
        'azj-Brai-IR': 'az-Brai',
        'az-Cyrl-AZ': 'az-Cyrl-AZ',
        'az-IQ': 'az-IQ',
        'az-Arab-IQ': 'az-IQ',
        'az-IR': 'az-IR',
        'az-Arab-IR': 'az-IR',
        'az-Arab': 'az-IR',
        'azj-Arab': 'az-IR',
        'azj-Arab-IR': 'az-IR',
        'az-RU': 'az-RU',
        'az-Cyrl-RU': 'az-RU',
        'az-Cyrl': 'az-RU',
        'azj-Cyrl': 'az-RU',
        'azj-Cyrl-RU': 'az-RU',
        'aza': 'aza',
        'aza-Zyyy-CN': 'aza',
        'aza-CN': 'aza',
        'aza-Zyyy': 'aza',
        'azb': 'azb',
        'azb-Arab-IR': 'azb',
        'azb-Arab': 'azb',
        'azb-IR': 'azb',
        'azb-Cyrl': 'azb-Cyrl',
        'azb-Cyrl-AZ': 'azb-Cyrl',
        'azb-AZ': 'azb-Cyrl',
        'azd': 'azd',
        'azd-Latn-MX': 'azd',
        'azd-Latn': 'azd',
        'azd-MX': 'azd',
        'azg': 'azg',
        'azg-Latn-MX': 'azg',
        'azg-Latn': 'azg',
        'azg-MX': 'azg',
        'azm': 'azm',
        'azm-Latn-MX': 'azm',
        'azm-Latn': 'azm',
        'azm-MX': 'azm',
        'azn': 'azn',
        'azn-Latn-MX': 'azn',
        'azn-Latn': 'azn',
        'azn-MX': 'azn',
        'azo': 'azo',
        'azo-Latn-CM': 'azo',
        'azo-CM': 'azo',
        'azo-Latn': 'azo',
        'azt': 'azt',
        'azt-Latn-PH': 'azt',
        'azt-Latn': 'azt',
        'azt-PH': 'azt',
        'azz': 'azz',
        'azz-Latn-MX': 'azz',
        'azz-Latn': 'azz',
        'azz-MX': 'azz',
        'ba': 'ba',
        'ba-Cyrl-RU': 'ba',
        'ba-Cyrl': 'ba',
        'ba-RU': 'ba',
        'baa': 'baa',
        'baa-Latn-SB': 'baa',
        'baa-Latn': 'baa',
        'baa-SB': 'baa',
        'bab': 'bab',
        'bab-Latn-GW': 'bab',
        'bab-GW': 'bab',
        'bab-Latn': 'bab',
        'bac': 'bac',
        'bac-Latn-ID': 'bac',
        'bac-ID': 'bac',
        'bac-Latn': 'bac',
        'bae': 'bae',
        'bae-Latn-VE': 'bae',
        'bae-Latn': 'bae',
        'bae-VE': 'bae',
        'baf': 'baf',
        'baf-Latn-CM': 'baf',
        'baf-CM': 'baf',
        'baf-Latn': 'baf',
        'bag': 'bag',
        'bag-Latn-CM': 'bag',
        'bag-CM': 'bag',
        'bag-Latn': 'bag',
        'bah': 'bah',
        'bah-Latn-BS': 'bah',
        'bah-BS': 'bah',
        'bah-Latn': 'bah',
        'baj': 'baj',
        'baj-Latn-ID': 'baj',
        'baj-ID': 'baj',
        'baj-Latn': 'baj',
        'bal': 'bal',
        'bal-Arab-PK': 'bal',
        'bal-Arab': 'bal',
        'bal-PK': 'bal',
        'bcc': 'bal',
        'bcc-Arab': 'bal',
        'bcc-Arab-PK': 'bal',
        'bcc-PK': 'bal',
        'bal-Latn': 'bal-Latn',
        'bal-Latn-PK': 'bal-Latn',
        'bcc-Latn': 'bal-Latn',
        'bcc-Latn-PK': 'bal-Latn',
        'ban': 'ban',
        'ban-Latn-ID': 'ban',
        'ban-ID': 'ban',
        'ban-Latn': 'ban',
        'ban-Bali': 'ban-Bali',
        'ban-Bali-ID': 'ban-Bali',
        'ban-Java': 'ban-Java',
        'ban-Java-ID': 'ban-Java',
        'bao': 'bao',
        'bao-Latn-CO': 'bao',
        'bao-CO': 'bao',
        'bao-Latn': 'bao',
        'bap': 'bap',
        'bap-Deva-NP': 'bap',
        'bap-Deva': 'bap',
        'bap-NP': 'bap',
        'bar': 'bar',
        'bar-Latn-AT': 'bar',
        'bar-AT': 'bar',
        'bar-Latn': 'bar',
        'bas': 'bas',
        'bas-Latn-CM': 'bas',
        'bas-CM': 'bas',
        'bas-Latn': 'bas',
        'bau': 'bau',
        'bau-Latn-NG': 'bau',
        'bau-Latn': 'bau',
        'bau-NG': 'bau',
        'bav': 'bav',
        'bav-Latn-CM': 'bav',
        'bav-CM': 'bav',
        'bav-Latn': 'bav',
        'baw': 'baw',
        'baw-Latn-CM': 'baw',
        'baw-CM': 'baw',
        'baw-Latn': 'baw',
        'bax': 'bax',
        'bax-Bamu-CM': 'bax',
        'bax-Bamu': 'bax',
        'bax-CM': 'bax',
        'bax-Latn': 'bax-Latn',
        'bax-Latn-CM': 'bax-Latn',
        'bay': 'bay',
        'bay-Latn-ID': 'bay',
        'bay-ID': 'bay',
        'bay-Latn': 'bay',
        'bba': 'bba',
        'bba-Latn-BJ': 'bba',
        'bba-BJ': 'bba',
        'bba-Latn': 'bba',
        'bbb': 'bbb',
        'bbb-Latn-PG': 'bbb',
        'bbb-Latn': 'bbb',
        'bbb-PG': 'bbb',
        'bbc': 'bbc',
        'bbc-Latn-ID': 'bbc',
        'bbc-ID': 'bbc',
        'bbc-Latn': 'bbc',
        'bbc-Batk': 'bbc-Batk',
        'bbc-Batk-ID': 'bbc-Batk',
        'bbd': 'bbd',
        'bbd-Latn-PG': 'bbd',
        'bbd-Latn': 'bbd',
        'bbd-PG': 'bbd',
        'bbe': 'bbe',
        'bbe-Latn-CD': 'bbe',
        'bbe-CD': 'bbe',
        'bbe-Latn': 'bbe',
        'bbf': 'bbf',
        'bbf-Latn-PG': 'bbf',
        'bbf-Latn': 'bbf',
        'bbf-PG': 'bbf',
        'bbg': 'bbg',
        'bbg-Latn-GA': 'bbg',
        'bbg-GA': 'bbg',
        'bbg-Latn': 'bbg',
        'bbh': 'bbh',
        'bbh-Zyyy-CN': 'bbh',
        'bbh-CN': 'bbh',
        'bbh-Zyyy': 'bbh',
        'bbi': 'bbi',
        'bbi-Latn-CM': 'bbi',
        'bbi-CM': 'bbi',
        'bbi-Latn': 'bbi',
        'bbj': 'bbj',
        'bbj-Latn-CM': 'bbj',
        'bbj-CM': 'bbj',
        'bbj-Latn': 'bbj',
        'bbk': 'bbk',
        'bbk-Latn-CM': 'bbk',
        'bbk-CM': 'bbk',
        'bbk-Latn': 'bbk',
        'bbl': 'bbl',
        'bbl-Zyyy-GE': 'bbl',
        'bbl-GE': 'bbl',
        'bbl-Zyyy': 'bbl',
        'bbm': 'bbm',
        'bbm-Latn-CD': 'bbm',
        'bbm-CD': 'bbm',
        'bbm-Latn': 'bbm',
        'bbn': 'bbn',
        'bbn-Latn-PG': 'bbn',
        'bbn-Latn': 'bbn',
        'bbn-PG': 'bbn',
        'bbo': 'bbo',
        'bbo-Latn-BF': 'bbo',
        'bbo-BF': 'bbo',
        'bbo-Latn': 'bbo',
        'bbp': 'bbp',
        'bbp-Latn-CF': 'bbp',
        'bbp-CF': 'bbp',
        'bbp-Latn': 'bbp',
        'bbq': 'bbq',
        'bbq-Latn-CM': 'bbq',
        'bbq-CM': 'bbq',
        'bbq-Latn': 'bbq',
        'bbr': 'bbr',
        'bbr-Latn-PG': 'bbr',
        'bbr-Latn': 'bbr',
        'bbr-PG': 'bbr',
        'bbs': 'bbs',
        'bbs-Latn-NG': 'bbs',
        'bbs-Latn': 'bbs',
        'bbs-NG': 'bbs',
        'bbt': 'bbt',
        'bbt-Latn-NG': 'bbt',
        'bbt-Latn': 'bbt',
        'bbt-NG': 'bbt',
        'bbu': 'bbu',
        'bbu-Latn-NG': 'bbu',
        'bbu-Latn': 'bbu',
        'bbu-NG': 'bbu',
        'bbv': 'bbv',
        'bbv-Latn-PG': 'bbv',
        'bbv-Latn': 'bbv',
        'bbv-PG': 'bbv',
        'bbw': 'bbw',
        'bbw-Latn-CM': 'bbw',
        'bbw-CM': 'bbw',
        'bbw-Latn': 'bbw',
        'bbx': 'bbx',
        'bbx-Latn-CM': 'bbx',
        'bbx-CM': 'bbx',
        'bbx-Latn': 'bbx',
        'bby': 'bby',
        'bby-Latn-CM': 'bby',
        'bby-CM': 'bby',
        'bby-Latn': 'bby',
        'bbz': 'bbz',
        'bbz-Latn-TD': 'bbz',
        'ar-bbz': 'bbz',
        'ar-bbz-TD': 'bbz',
        'bbz-Latn': 'bbz',
        'bbz-TD': 'bbz',
        'bca': 'bca',
        'bca-Latn-CN': 'bca',
        'bca-CN': 'bca',
        'bca-Latn': 'bca',
        'bca-Hani': 'bca-Hani',
        'bca-Hani-CN': 'bca-Hani',
        'bcb': 'bcb',
        'bcb-Latn-SN': 'bcb',
        'bcb-Latn': 'bcb',
        'bcb-SN': 'bcb',
        'bcd': 'bcd',
        'bcd-Latn-ID': 'bcd',
        'bcd-ID': 'bcd',
        'bcd-Latn': 'bcd',
        'bce': 'bce',
        'bce-Latn-CM': 'bce',
        'bce-CM': 'bce',
        'bce-Latn': 'bce',
        'bcf': 'bcf',
        'bcf-Latn-PG': 'bcf',
        'bcf-Latn': 'bcf',
        'bcf-PG': 'bcf',
        'bcg': 'bcg',
        'bcg-Latn-GN': 'bcg',
        'bcg-GN': 'bcg',
        'bcg-Latn': 'bcg',
        'bgm': 'bcg',
        'bgm-GN': 'bcg',
        'bgm-Latn': 'bcg',
        'bgm-Latn-GN': 'bcg',
        'bch': 'bch',
        'bch-Latn-PG': 'bch',
        'bch-Latn': 'bch',
        'bch-PG': 'bch',
        'bci': 'bci',
        'bci-Latn-CI': 'bci',
        'bci-CI': 'bci',
        'bci-Latn': 'bci',
        'bcj': 'bcj',
        'bcj-Latn-AU': 'bcj',
        'bcj-AU': 'bcj',
        'bcj-Latn': 'bcj',
        'bck': 'bck',
        'bck-Latn-AU': 'bck',
        'bck-AU': 'bck',
        'bck-Latn': 'bck',
        'bcm': 'bcm',
        'bcm-Latn-PG': 'bcm',
        'bcm-Latn': 'bcm',
        'bcm-PG': 'bcm',
        'bcn': 'bcn',
        'bcn-Latn-NG': 'bcn',
        'bcn-Latn': 'bcn',
        'bcn-NG': 'bcn',
        'bco': 'bco',
        'bco-Latn-PG': 'bco',
        'bco-Latn': 'bco',
        'bco-PG': 'bco',
        'bcp': 'bcp',
        'bcp-Latn-CD': 'bcp',
        'bcp-CD': 'bcp',
        'bcp-Latn': 'bcp',
        'bcq': 'bcq',
        'bcq-Ethi-ET': 'bcq',
        'bcq-ET': 'bcq',
        'bcq-Ethi': 'bcq',
        'bcq-Latn': 'bcq-Latn',
        'bcq-Latn-ET': 'bcq-Latn',
        'bcr': 'bcr',
        'bcr-Latn-CA': 'bcr',
        'bcr-CA': 'bcr',
        'bcr-Latn': 'bcr',
        'bcs': 'bcs',
        'bcs-Latn-NG': 'bcs',
        'bcs-Latn': 'bcs',
        'bcs-NG': 'bcs',
        'bct': 'bct',
        'bct-Latn-CD': 'bct',
        'bct-CD': 'bct',
        'bct-Latn': 'bct',
        'bcu': 'bcu',
        'bcu-Latn-PG': 'bcu',
        'bcu-Latn': 'bcu',
        'bcu-PG': 'bcu',
        'bcv': 'bcv',
        'bcv-Latn-NG': 'bcv',
        'bcv-Latn': 'bcv',
        'bcv-NG': 'bcv',
        'bcw': 'bcw',
        'bcw-Latn-CM': 'bcw',
        'bcw-CM': 'bcw',
        'bcw-Latn': 'bcw',
        'bcy': 'bcy',
        'bcy-Latn-NG': 'bcy',
        'bcy-Latn': 'bcy',
        'bcy-NG': 'bcy',
        'bcz': 'bcz',
        'bcz-Latn-SN': 'bcz',
        'bcz-Latn': 'bcz',
        'bcz-SN': 'bcz',
        'bda': 'bda',
        'bda-Latn-SN': 'bda',
        'bda-Latn': 'bda',
        'bda-SN': 'bda',
        'bdb': 'bdb',
        'bdb-Latn-ID': 'bdb',
        'bdb-ID': 'bdb',
        'bdb-Latn': 'bdb',
        'bdc': 'bdc',
        'bdc-Latn-CO': 'bdc',
        'bdc-CO': 'bdc',
        'bdc-Latn': 'bdc',
        'bdd': 'bdd',
        'bdd-Latn-PG': 'bdd',
        'bdd-Latn': 'bdd',
        'bdd-PG': 'bdd',
        'bde': 'bde',
        'bde-Latn-NG': 'bde',
        'bde-Latn': 'bde',
        'bde-NG': 'bde',
        'bdf': 'bdf',
        'bdf-Latn-PG': 'bdf',
        'bdf-Latn': 'bdf',
        'bdf-PG': 'bdf',
        'bdg': 'bdg',
        'bdg-Latn-MY': 'bdg',
        'bdg-Latn': 'bdg',
        'bdg-MY': 'bdg',
        'bdh': 'bdh',
        'bdh-Latn-SS': 'bdh',
        'bdh-Latn': 'bdh',
        'bdh-SS': 'bdh',
        'bdi': 'bdi',
        'bdi-Latn-SD': 'bdi',
        'bdi-Latn': 'bdi',
        'bdi-SD': 'bdi',
        'bdj': 'bdj',
        'bdj-Latn-SS': 'bdj',
        'bdj-Latn': 'bdj',
        'bdj-SS': 'bdj',
        'bdk': 'bdk',
        'bdk-Latn-AZ': 'bdk',
        'bdk-AZ': 'bdk',
        'bdk-Latn': 'bdk',
        'bdl': 'bdl',
        'bdl-Latn-ID': 'bdl',
        'bdl-ID': 'bdl',
        'bdl-Latn': 'bdl',
        'bdm': 'bdm',
        'bdm-Latn-TD': 'bdm',
        'bdm-Latn': 'bdm',
        'bdm-TD': 'bdm',
        'bdn': 'bdn',
        'bdn-Latn-CM': 'bdn',
        'bdn-CM': 'bdn',
        'bdn-Latn': 'bdn',
        'bdo': 'bdo',
        'bdo-Latn-TD': 'bdo',
        'bdo-Latn': 'bdo',
        'bdo-TD': 'bdo',
        'bdp': 'bdp',
        'bdp-Latn-TZ': 'bdp',
        'bdp-Latn': 'bdp',
        'bdp-TZ': 'bdp',
        'bdq': 'bdq',
        'bdq-Latn-VN': 'bdq',
        'bdq-Latn': 'bdq',
        'bdq-VN': 'bdq',
        'bdr': 'bdr',
        'bdr-Latn-MY': 'bdr',
        'bdr-Latn': 'bdr',
        'bdr-MY': 'bdr',
        'bds': 'bds',
        'bds-Latn-TZ': 'bds',
        'bds-Latn': 'bds',
        'bds-TZ': 'bds',
        'bdt': 'bdt',
        'bdt-Latn-CF': 'bdt',
        'bdt-CF': 'bdt',
        'bdt-Latn': 'bdt',
        'bdu': 'bdu',
        'bdu-Latn-CM': 'bdu',
        'bdu-CM': 'bdu',
        'bdu-Latn': 'bdu',
        'bdv': 'bdv',
        'bdv-Orya-IN': 'bdv',
        'bdv-IN': 'bdv',
        'bdv-Orya': 'bdv',
        'bdw': 'bdw',
        'bdw-Latn-ID': 'bdw',
        'bdw-ID': 'bdw',
        'bdw-Latn': 'bdw',
        'bdx': 'bdx',
        'bdx-Latn-ID': 'bdx',
        'bdx-ID': 'bdx',
        'bdx-Latn': 'bdx',
        'bdy': 'bdy',
        'bdy-Latn-AU': 'bdy',
        'bdy-AU': 'bdy',
        'bdy-Latn': 'bdy',
        'bdz': 'bdz',
        'bdz-Arab-PK': 'bdz',
        'bdz-Arab': 'bdz',
        'bdz-PK': 'bdz',
        'be': 'be',
        'be-Cyrl-BY': 'be',
        'be-BY': 'be',
        'be-Cyrl': 'be',
        'be-Brai': 'be-Brai',
        'be-Brai-BY': 'be-Brai',
        'be-Latn': 'be-Latn',
        'be-Latn-BY': 'be-Latn',
        'bea': 'bea',
        'bea-Latn-CA': 'bea',
        'bea-CA': 'bea',
        'bea-Latn': 'bea',
        'bea-Cans': 'bea-Cans',
        'bea-Cans-CA': 'bea-Cans',
        'beb': 'beb',
        'beb-Latn-CM': 'beb',
        'beb-CM': 'beb',
        'beb-Latn': 'beb',
        'bec': 'bec',
        'bec-Latn-CM': 'bec',
        'bec-CM': 'bec',
        'bec-Latn': 'bec',
        'bed': 'bed',
        'bed-Latn-ID': 'bed',
        'bed-ID': 'bed',
        'bed-Latn': 'bed',
        'bee': 'bee',
        'bee-Deva-IN': 'bee',
        'bee-Deva': 'bee',
        'bee-IN': 'bee',
        'bef': 'bef',
        'bef-Latn-PG': 'bef',
        'bef-Latn': 'bef',
        'bef-PG': 'bef',
        'beg': 'beg',
        'beg-Zyyy-BN': 'beg',
        'beg-BN': 'beg',
        'beg-Zyyy': 'beg',
        'beh': 'beh',
        'beh-Latn-BJ': 'beh',
        'beh-BJ': 'beh',
        'beh-Latn': 'beh',
        'bei': 'bei',
        'bei-Latn-ID': 'bei',
        'bei-ID': 'bei',
        'bei-Latn': 'bei',
        'bej': 'bej',
        'bej-Arab-SD': 'bej',
        'bej-Arab': 'bej',
        'bej-SD': 'bej',
        'bej-Latn': 'bej-Latn',
        'bej-Latn-ER': 'bej-Latn',
        'bej-ER': 'bej-Latn',
        'bek': 'bek',
        'bek-Latn-PG': 'bek',
        'bek-Latn': 'bek',
        'bek-PG': 'bek',
        'bem': 'bem',
        'bem-Latn-ZM': 'bem',
        'bem-Latn': 'bem',
        'bem-ZM': 'bem',
        'bmy': 'bem',
        'bmy-Latn': 'bem',
        'bmy-Latn-ZM': 'bem',
        'bmy-ZM': 'bem',
        'bem-Brai': 'bem-Brai',
        'bem-Brai-ZM': 'bem-Brai',
        'beo': 'beo',
        'beo-Latn-PG': 'beo',
        'beo-Latn': 'beo',
        'beo-PG': 'beo',
        'bep': 'bep',
        'bep-Latn-ID': 'bep',
        'bep-ID': 'bep',
        'bep-Latn': 'bep',
        'beq': 'beq',
        'beq-Latn-CG': 'beq',
        'beq-CG': 'beq',
        'beq-Latn': 'beq',
        'bes': 'bes',
        'bes-Latn-TD': 'bes',
        'bes-Latn': 'bes',
        'bes-TD': 'bes',
        'bet': 'bet',
        'bet-Latn-CI': 'bet',
        'bet-CI': 'bet',
        'bet-Latn': 'bet',
        'beu': 'beu',
        'beu-Latn-ID': 'beu',
        'beu-ID': 'beu',
        'beu-Latn': 'beu',
        'bev': 'bev',
        'bev-Latn-CI': 'bev',
        'bev-CI': 'bev',
        'bev-Latn': 'bev',
        'bew': 'bew',
        'bew-Latn-ID': 'bew',
        'bew-ID': 'bew',
        'bew-Latn': 'bew',
        'bex': 'bex',
        'bex-Latn-SS': 'bex',
        'bex-Latn': 'bex',
        'bex-SS': 'bex',
        'bex-Arab': 'bex-Arab',
        'bex-Arab-SS': 'bex-Arab',
        'bey': 'bey',
        'bey-Latn-PG': 'bey',
        'bey-Latn': 'bey',
        'bey-PG': 'bey',
        'bez': 'bez',
        'bez-Latn-TZ': 'bez',
        'bez-Latn': 'bez',
        'bez-TZ': 'bez',
        'bfa': 'bfa',
        'bfa-Latn-SS': 'bfa',
        'bfa-Latn': 'bfa',
        'bfa-SS': 'bfa',
        'bfa-Arab': 'bfa-Arab',
        'bfa-Arab-SS': 'bfa-Arab',
        'bfb': 'bfb',
        'bfb-Deva-IN': 'bfb',
        'bfb-Deva': 'bfb',
        'bfb-IN': 'bfb',
        'bfc': 'bfc',
        'bfc-Latn-CN': 'bfc',
        'bfc-CN': 'bfc',
        'bfc-Latn': 'bfc',
        'bfd': 'bfd',
        'bfd-Latn-CM': 'bfd',
        'bfd-CM': 'bfd',
        'bfd-Latn': 'bfd',
        'bfe': 'bfe',
        'bfe-Latn-ID': 'bfe',
        'bfe-ID': 'bfe',
        'bfe-Latn': 'bfe',
        'bff': 'bff',
        'bff-Latn-CF': 'bff',
        'bff-CF': 'bff',
        'bff-Latn': 'bff',
        'bfg': 'bfg',
        'bfg-Latn-ID': 'bfg',
        'bfg-ID': 'bfg',
        'bfg-Latn': 'bfg',
        'bfh': 'bfh',
        'bfh-Latn-PG': 'bfh',
        'bfh-Latn': 'bfh',
        'bfh-PG': 'bfh',
        'bfi': 'bfi',
        'bfi-Zxxx-GB': 'bfi',
        'bfi-GB': 'bfi',
        'bfi-Zxxx': 'bfi',
        'sgn-bfi': 'bfi',
        'sgn-bfi-GB': 'bfi',
        'bfi-x-stokoe': 'bfi-x-stokoe',
        'bfi-Zzzz-GB-x-stokoe': 'bfi-x-stokoe',
        'bfi-GB-x-stokoe': 'bfi-x-stokoe',
        'bfi-Zzzz-x-stokoe': 'bfi-x-stokoe',
        'sgn-bfi-GB-x-stokoe': 'bfi-x-stokoe',
        'sgn-bfi-x-stokoe': 'bfi-x-stokoe',
        'bfj': 'bfj',
        'bfj-Latn-CM': 'bfj',
        'bfj-CM': 'bfj',
        'bfj-Latn': 'bfj',
        'bfk': 'bfk',
        'bfk-Zxxx-TH': 'bfk',
        'bfk-TH': 'bfk',
        'bfk-Zxxx': 'bfk',
        'sgn-bfk': 'bfk',
        'sgn-bfk-TH': 'bfk',
        'bfl': 'bfl',
        'bfl-Latn-CF': 'bfl',
        'bfl-CF': 'bfl',
        'bfl-Latn': 'bfl',
        'bfm': 'bfm',
        'bfm-Latn-CM': 'bfm',
        'bfm-CM': 'bfm',
        'bfm-Latn': 'bfm',
        'bfn': 'bfn',
        'bfn-Latn-TL': 'bfn',
        'bfn-Latn': 'bfn',
        'bfn-TL': 'bfn',
        'bfo': 'bfo',
        'bfo-Latn-BF': 'bfo',
        'bfo-BF': 'bfo',
        'bfo-Latn': 'bfo',
        'bfp': 'bfp',
        'bfp-Latn-CM': 'bfp',
        'bfp-CM': 'bfp',
        'bfp-Latn': 'bfp',
        'bfq': 'bfq',
        'bfq-Taml-IN': 'bfq',
        'bfq-IN': 'bfq',
        'bfq-Taml': 'bfq',
        'bfq-Knda': 'bfq-Knda',
        'bfq-Knda-IN': 'bfq-Knda',
        'bfq-Latn': 'bfq-Latn',
        'bfq-Latn-IN': 'bfq-Latn',
        'bfq-x-badaga': 'bfq-x-badaga',
        'bfq-Zzzz-IN-x-badaga': 'bfq-x-badaga',
        'bfq-IN-x-badaga': 'bfq-x-badaga',
        'bfq-Zzzz-x-badaga': 'bfq-x-badaga',
        'bfr': 'bfr',
        'bfr-Zyyy-IN': 'bfr',
        'bfr-IN': 'bfr',
        'bfr-Zyyy': 'bfr',
        'bfs': 'bfs',
        'bfs-Latn-CN': 'bfs',
        'bfs-CN': 'bfs',
        'bfs-Latn': 'bfs',
        'bfs-Hani': 'bfs-Hani',
        'bfs-Hani-CN': 'bfs-Hani',
        'bft': 'bft',
        'bft-Arab-PK': 'bft',
        'bft-Arab': 'bft',
        'bft-PK': 'bft',
        'bft-Tibt': 'bft-Tibt',
        'bft-Tibt-PK': 'bft-Tibt',
        'bft-x-baltia': 'bft-x-baltia',
        'bft-Zzzz-PK-x-baltia': 'bft-x-baltia',
        'bft-PK-x-baltia': 'bft-x-baltia',
        'bft-Zzzz-x-baltia': 'bft-x-baltia',
        'bfu': 'bfu',
        'bfu-Tibt-IN': 'bfu',
        'bfu-IN': 'bfu',
        'bfu-Tibt': 'bfu',
        'bfu-Takr': 'bfu-Takr',
        'bfu-Takr-IN': 'bfu-Takr',
        'bfw': 'bfw',
        'bfw-Orya-IN': 'bfw',
        'bfw-IN': 'bfw',
        'bfw-Orya': 'bfw',
        'bfx': 'bfx',
        'bfx-Latn-PH': 'bfx',
        'bfx-Latn': 'bfx',
        'bfx-PH': 'bfx',
        'bfy': 'bfy',
        'bfy-Deva-IN': 'bfy',
        'bfy-Deva': 'bfy',
        'bfy-IN': 'bfy',
        'ppa': 'bfy',
        'ppa-Deva': 'bfy',
        'ppa-Deva-IN': 'bfy',
        'ppa-IN': 'bfy',
        'bfz': 'bfz',
        'bfz-Deva-IN': 'bfz',
        'bfz-Deva': 'bfz',
        'bfz-IN': 'bfz',
        'bg': 'bg',
        'bg-Cyrl-BG': 'bg',
        'bg-BG': 'bg',
        'bg-Cyrl': 'bg',
        'bg-Brai': 'bg-Brai',
        'bg-Brai-BG': 'bg-Brai',
        'bg-Latn': 'bg-Latn',
        'bg-Latn-BG': 'bg-Latn',
        'bga': 'bga',
        'bga-Latn-NG': 'bga',
        'bga-Latn': 'bga',
        'bga-NG': 'bga',
        'bgb': 'bgb',
        'bgb-Latn-ID': 'bgb',
        'bgb-ID': 'bgb',
        'bgb-Latn': 'bgb',
        'bgc': 'bgc',
        'bgc-Deva-IN': 'bgc',
        'bgc-Deva': 'bgc',
        'bgc-IN': 'bgc',
        'bgd': 'bgd',
        'bgd-Deva-IN': 'bgd',
        'bgd-Deva': 'bgd',
        'bgd-IN': 'bgd',
        'bge': 'bge',
        'bge-Zyyy-IN': 'bge',
        'bge-IN': 'bge',
        'bge-Zyyy': 'bge',
        'bgf': 'bgf',
        'bgf-Latn-CM': 'bgf',
        'bgf-CM': 'bgf',
        'bgf-Latn': 'bgf',
        'bgg': 'bgg',
        'bgg-Latn-IN': 'bgg',
        'bgg-IN': 'bgg',
        'bgg-Latn': 'bgg',
        'bgi': 'bgi',
        'bgi-Latn-PH': 'bgi',
        'bgi-Latn': 'bgi',
        'bgi-PH': 'bgi',
        'bgj': 'bgj',
        'bgj-Latn-CM': 'bgj',
        'bgj-CM': 'bgj',
        'bgj-Latn': 'bgj',
        'bgk': 'bgk',
        'bgk-Zyyy-LA': 'bgk',
        'bgk-LA': 'bgk',
        'bgk-Zyyy': 'bgk',
        'bgl': 'bgl',
        'bgl-Zyyy-LA': 'bgl',
        'bgl-LA': 'bgl',
        'bgl-Zyyy': 'bgl',
        'bgn': 'bgn',
        'bgn-Arab-PK': 'bgn',
        'bgn-Arab': 'bgn',
        'bgn-PK': 'bgn',
        'bgn-Cyrl': 'bgn-Cyrl',
        'bgn-Cyrl-TM': 'bgn-Cyrl',
        'bgn-TM': 'bgn-Cyrl',
        'bgo': 'bgo',
        'bgo-Latn-GN': 'bgo',
        'bgo-GN': 'bgo',
        'bgo-Latn': 'bgo',
        'bgp': 'bgp',
        'bgp-Arab-PK': 'bgp',
        'bgp-Arab': 'bgp',
        'bgp-PK': 'bgp',
        'bgq': 'bgq',
        'bgq-Deva-IN': 'bgq',
        'bgq-Deva': 'bgq',
        'bgq-IN': 'bgq',
        'bgr': 'bgr',
        'bgr-Latn-IN': 'bgr',
        'bgr-IN': 'bgr',
        'bgr-Latn': 'bgr',
        'bgs': 'bgs',
        'bgs-Latn-PH': 'bgs',
        'bgs-Latn': 'bgs',
        'bgs-PH': 'bgs',
        'bgt': 'bgt',
        'bgt-Latn-SB': 'bgt',
        'bgt-Latn': 'bgt',
        'bgt-SB': 'bgt',
        'bgu': 'bgu',
        'bgu-Latn-NG': 'bgu',
        'bgu-Latn': 'bgu',
        'bgu-NG': 'bgu',
        'bgv': 'bgv',
        'bgv-Latn-ID': 'bgv',
        'bgv-ID': 'bgv',
        'bgv-Latn': 'bgv',
        'bgw': 'bgw',
        'bgw-Deva-IN': 'bgw',
        'bgw-Deva': 'bgw',
        'bgw-IN': 'bgw',
        'bgx': 'bgx',
        'bgx-Grek-TR': 'bgx',
        'bgx-Grek': 'bgx',
        'bgx-TR': 'bgx',
        'bgx-Latn': 'bgx-Latn',
        'bgx-Latn-TR': 'bgx-Latn',
        'bgy': 'bgy',
        'bgy-Latn-ID': 'bgy',
        'bgy-ID': 'bgy',
        'bgy-Latn': 'bgy',
        'bgz': 'bgz',
        'bgz-Latn-ID': 'bgz',
        'bgz-ID': 'bgz',
        'bgz-Latn': 'bgz',
        'bha': 'bha',
        'bha-Deva-IN': 'bha',
        'bha-Deva': 'bha',
        'bha-IN': 'bha',
        'bhb': 'bhb',
        'bhb-Deva-IN': 'bhb',
        'bhb-Deva': 'bhb',
        'bhb-IN': 'bhb',
        'bhb-Gujr': 'bhb-Gujr',
        'bhb-Gujr-IN': 'bhb-Gujr',
        'bhc': 'bhc',
        'bhc-Latn-ID': 'bhc',
        'bhc-ID': 'bhc',
        'bhc-Latn': 'bhc',
        'bhd-Arab': 'bhd-Arab',
        'bhd-Arab-IN': 'bhd-Arab',
        'bhd-Deva': 'bhd-Deva',
        'bhd-Deva-IN': 'bhd-Deva',
        'bhe': 'bhe',
        'bhe-Arab-PK': 'bhe',
        'bhe-Arab': 'bhe',
        'bhe-PK': 'bhe',
        'bhf': 'bhf',
        'bhf-Latn-PG': 'bhf',
        'bhf-Latn': 'bhf',
        'bhf-PG': 'bhf',
        'bhg': 'bhg',
        'bhg-Latn-PG': 'bhg',
        'bhg-Latn': 'bhg',
        'bhg-PG': 'bhg',
        'bhh': 'bhh',
        'bhh-Cyrl-IL': 'bhh',
        'bhh-Cyrl': 'bhh',
        'bhh-IL': 'bhh',
        'bhh-Hebr': 'bhh-Hebr',
        'bhh-Hebr-IL': 'bhh-Hebr',
        'bhh-Latn': 'bhh-Latn',
        'bhh-Latn-IL': 'bhh-Latn',
        'bhi': 'bhi',
        'bhi-Deva-IN': 'bhi',
        'bhi-Deva': 'bhi',
        'bhi-IN': 'bhi',
        'bhj': 'bhj',
        'bhj-Deva-NP': 'bhj',
        'bhj-Deva': 'bhj',
        'bhj-NP': 'bhj',
        'bhl': 'bhl',
        'bhl-Latn-PG': 'bhl',
        'bhl-Latn': 'bhl',
        'bhl-PG': 'bhl',
        'bhm': 'bhm',
        'bhm-Arab-OM': 'bhm',
        'bhm-Arab': 'bhm',
        'bhm-OM': 'bhm',
        'bhn': 'bhn',
        'bhn-Syrc-GE': 'bhn',
        'bhn-GE': 'bhn',
        'bhn-Syrc': 'bhn',
        'bho': 'bho',
        'bho-Deva-IN': 'bho',
        'bh-Deva': 'bho',
        'bh-Deva-IN': 'bho',
        'bho-Deva': 'bho',
        'bho-IN': 'bho',
        'bho-Kthi': 'bho-Kthi',
        'bho-Kthi-IN': 'bho-Kthi',
        'bh': 'bho-Kthi',
        'bh-IN': 'bho-Kthi',
        'bh-Kthi': 'bho-Kthi',
        'bh-Kthi-IN': 'bho-Kthi',
        'bhp': 'bhp',
        'bhp-Latn-ID': 'bhp',
        'bhp-ID': 'bhp',
        'bhp-Latn': 'bhp',
        'bhq': 'bhq',
        'bhq-Latn-ID': 'bhq',
        'bhq-ID': 'bhq',
        'bhq-Latn': 'bhq',
        'bhr': 'bhr',
        'bhr-Latn-MG': 'bhr',
        'bhr-Latn': 'bhr',
        'bhr-MG': 'bhr',
        'bhs': 'bhs',
        'bhs-Latn-CM': 'bhs',
        'bhs-CM': 'bhs',
        'bhs-Latn': 'bhs',
        'bht': 'bht',
        'bht-Zyyy-IN': 'bht',
        'bht-IN': 'bht',
        'bht-Zyyy': 'bht',
        'bhu': 'bhu',
        'bhu-Deva-IN': 'bhu',
        'bhu-Deva': 'bhu',
        'bhu-IN': 'bhu',
        'bhv': 'bhv',
        'bhv-Latn-ID': 'bhv',
        'bhv-ID': 'bhv',
        'bhv-Latn': 'bhv',
        'bhw': 'bhw',
        'bhw-Latn-ID': 'bhw',
        'bhw-ID': 'bhw',
        'bhw-Latn': 'bhw',
        'bhx': 'bhx',
        'bhx-Zyyy-IN': 'bhx',
        'bhx-IN': 'bhx',
        'bhx-Zyyy': 'bhx',
        'bhy': 'bhy',
        'bhy-Latn-CD': 'bhy',
        'bhy-CD': 'bhy',
        'bhy-Latn': 'bhy',
        'bhz': 'bhz',
        'bhz-Latn-ID': 'bhz',
        'bhz-ID': 'bhz',
        'bhz-Latn': 'bhz',
        'bi': 'bi',
        'bi-Latn-VU': 'bi',
        'bi-Latn': 'bi',
        'bi-VU': 'bi',
        'bia': 'bia',
        'bia-Latn-AU': 'bia',
        'bia-AU': 'bia',
        'bia-Latn': 'bia',
        'bib': 'bib',
        'bib-Latn-BF': 'bib',
        'bib-BF': 'bib',
        'bib-Latn': 'bib',
        'bic': 'bic',
        'bic-Latn-PG': 'bic',
        'bic-Latn': 'bic',
        'bic-PG': 'bic',
        'bid': 'bid',
        'bid-Latn-TD': 'bid',
        'bid-Latn': 'bid',
        'bid-TD': 'bid',
        'bie': 'bie',
        'bie-Latn-PG': 'bie',
        'bie-Latn': 'bie',
        'bie-PG': 'bie',
        'bif': 'bif',
        'bif-Latn-GW': 'bif',
        'bif-GW': 'bif',
        'bif-Latn': 'bif',
        'big': 'big',
        'big-Latn-PG': 'big',
        'big-Latn': 'big',
        'big-PG': 'big',
        'bij': 'bij',
        'bij-Latn-NG': 'bij',
        'bij-Latn': 'bij',
        'bij-NG': 'bij',
        'bik': 'bik',
        'bik-Latn-PH': 'bik',
        'bcl': 'bik',
        'bcl-Latn': 'bik',
        'bcl-Latn-PH': 'bik',
        'bcl-PH': 'bik',
        'bhk': 'bik',
        'bhk-Latn': 'bik',
        'bhk-Latn-PH': 'bik',
        'bhk-PH': 'bik',
        'bik-Latn': 'bik',
        'bik-PH': 'bik',
        'bik-Brai': 'bik-Brai',
        'bik-Brai-PH': 'bik-Brai',
        'bcl-Brai': 'bik-Brai',
        'bcl-Brai-PH': 'bik-Brai',
        'bil': 'bil',
        'bil-Latn-NG': 'bil',
        'bil-Latn': 'bil',
        'bil-NG': 'bil',
        'bim': 'bim',
        'bim-Latn-GH': 'bim',
        'bim-GH': 'bim',
        'bim-Latn': 'bim',
        'bin': 'bin',
        'bin-Latn-NG': 'bin',
        'bin-Latn': 'bin',
        'bin-NG': 'bin',
        'bio': 'bio',
        'bio-Latn-PG': 'bio',
        'bio-Latn': 'bio',
        'bio-PG': 'bio',
        'bip': 'bip',
        'bip-Latn-CD': 'bip',
        'bip-CD': 'bip',
        'bip-Latn': 'bip',
        'biq': 'biq',
        'biq-Latn-PG': 'biq',
        'biq-Latn': 'biq',
        'biq-PG': 'biq',
        'bir': 'bir',
        'bir-Latn-PG': 'bir',
        'bir-Latn': 'bir',
        'bir-PG': 'bir',
        'bit': 'bit',
        'bit-Latn-PG': 'bit',
        'bit-Latn': 'bit',
        'bit-PG': 'bit',
        'biu': 'biu',
        'biu-Latn-IN': 'biu',
        'biu-IN': 'biu',
        'biu-Latn': 'biu',
        'biv': 'biv',
        'biv-Latn-GH': 'biv',
        'biv-GH': 'biv',
        'biv-Latn': 'biv',
        'biw': 'biw',
        'biw-Latn-CM': 'biw',
        'biw-CM': 'biw',
        'biw-Latn': 'biw',
        'bix': 'bix',
        'bix-Zyyy-IN': 'bix',
        'bix-IN': 'bix',
        'bix-Zyyy': 'bix',
        'biy': 'biy',
        'biy-Deva-IN': 'biy',
        'biy-Deva': 'biy',
        'biy-IN': 'biy',
        'biz': 'biz',
        'biz-Latn-CD': 'biz',
        'biz-CD': 'biz',
        'biz-Latn': 'biz',
        'bja': 'bja',
        'bja-Latn-CD': 'bja',
        'bja-CD': 'bja',
        'bja-Latn': 'bja',
        'bjb': 'bjb',
        'bjb-Latn-AU': 'bjb',
        'bjb-AU': 'bjb',
        'bjb-Latn': 'bjb',
        'bjc': 'bjc',
        'bjc-Latn-PG': 'bjc',
        'bjc-Latn': 'bjc',
        'bjc-PG': 'bjc',
        'bje': 'bje',
        'bje-Zyyy-CN': 'bje',
        'bje-CN': 'bje',
        'bje-Zyyy': 'bje',
        'bjf': 'bjf',
        'bjf-Syrc-IL': 'bjf',
        'bjf-IL': 'bjf',
        'bjf-Syrc': 'bjf',
        'bjg': 'bjg',
        'bjg-Latn-GW': 'bjg',
        'bjg-GW': 'bjg',
        'bjg-Latn': 'bjg',
        'bjh': 'bjh',
        'bjh-Latn-PG': 'bjh',
        'bjh-Latn': 'bjh',
        'bjh-PG': 'bjh',
        'bji': 'bji',
        'bji-Ethi-ET': 'bji',
        'bji-ET': 'bji',
        'bji-Ethi': 'bji',
        'bjj': 'bjj',
        'bjj-Deva-IN': 'bjj',
        'bjj-Deva': 'bjj',
        'bjj-IN': 'bjj',
        'bjk': 'bjk',
        'bjk-Latn-PG': 'bjk',
        'bjk-Latn': 'bjk',
        'bjk-PG': 'bjk',
        'bjl': 'bjl',
        'bjl-Latn-PG': 'bjl',
        'bjl-Latn': 'bjl',
        'bjl-PG': 'bjl',
        'bjm': 'bjm',
        'bjm-Zyyy-IQ': 'bjm',
        'bjm-IQ': 'bjm',
        'bjm-Zyyy': 'bjm',
        'bjn': 'bjn',
        'bjn-Latn-ID': 'bjn',
        'bjn-ID': 'bjn',
        'bjn-Latn': 'bjn',
        'ms-bjn': 'bjn',
        'ms-bjn-ID': 'bjn',
        'bjn-Arab': 'bjn-Arab',
        'bjn-Arab-ID': 'bjn-Arab',
        'bjo': 'bjo',
        'bjo-Latn-CF': 'bjo',
        'bjo-CF': 'bjo',
        'bjo-Latn': 'bjo',
        'bjp': 'bjp',
        'bjp-Latn-PG': 'bjp',
        'bjp-Latn': 'bjp',
        'bjp-PG': 'bjp',
        'bjr': 'bjr',
        'bjr-Latn-PG': 'bjr',
        'bjr-Latn': 'bjr',
        'bjr-PG': 'bjr',
        'bjs': 'bjs',
        'bjs-Latn-BB': 'bjs',
        'bjs-BB': 'bjs',
        'bjs-Latn': 'bjs',
        'bjt': 'bjt',
        'bjt-Latn-SN': 'bjt',
        'bjt-Latn': 'bjt',
        'bjt-SN': 'bjt',
        'bjt-Arab': 'bjt-Arab',
        'bjt-Arab-SN': 'bjt-Arab',
        'bju': 'bju',
        'bju-Latn-CM': 'bju',
        'bju-CM': 'bju',
        'bju-Latn': 'bju',
        'bjv': 'bjv',
        'bjv-Latn-TD': 'bjv',
        'bjv-Latn': 'bjv',
        'bjv-TD': 'bjv',
        'bjw': 'bjw',
        'bjw-Latn-CI': 'bjw',
        'bjw-CI': 'bjw',
        'bjw-Latn': 'bjw',
        'bjx': 'bjx',
        'bjx-Latn-PH': 'bjx',
        'bjx-Latn': 'bjx',
        'bjx-PH': 'bjx',
        'bjy': 'bjy',
        'bjy-Latn-AU': 'bjy',
        'bjy-AU': 'bjy',
        'bjy-Latn': 'bjy',
        'bjz': 'bjz',
        'bjz-Latn-PG': 'bjz',
        'bjz-Latn': 'bjz',
        'bjz-PG': 'bjz',
        'bka': 'bka',
        'bka-Latn-NG': 'bka',
        'bka-Latn': 'bka',
        'bka-NG': 'bka',
        'bkc': 'bkc',
        'bkc-Latn-CM': 'bkc',
        'bkc-CM': 'bkc',
        'bkc-Latn': 'bkc',
        'bkd': 'bkd',
        'bkd-Latn-PH': 'bkd',
        'bkd-Latn': 'bkd',
        'bkd-PH': 'bkd',
        'bkf': 'bkf',
        'bkf-Latn-CD': 'bkf',
        'bkf-CD': 'bkf',
        'bkf-Latn': 'bkf',
        'bkg': 'bkg',
        'bkg-Latn-CF': 'bkg',
        'bkg-CF': 'bkg',
        'bkg-Latn': 'bkg',
        'bkh': 'bkh',
        'bkh-Latn-CM': 'bkh',
        'bkh-CM': 'bkh',
        'bkh-Latn': 'bkh',
        'bki': 'bki',
        'bki-Latn-VU': 'bki',
        'bki-Latn': 'bki',
        'bki-VU': 'bki',
        'bkj': 'bkj',
        'bkj-Latn-CF': 'bkj',
        'bkj-CF': 'bkj',
        'bkj-Latn': 'bkj',
        'bkk-x-baltia': 'bkk-x-baltia',
        'bkk-Zzzz-IN-x-baltia': 'bkk-x-baltia',
        'bkk-IN-x-baltia': 'bkk-x-baltia',
        'bkk-Zzzz-x-baltia': 'bkk-x-baltia',
        'bkl': 'bkl',
        'bkl-Latn-ID': 'bkl',
        'bkl-ID': 'bkl',
        'bkl-Latn': 'bkl',
        'bkm': 'bkm',
        'bkm-Latn-CM': 'bkm',
        'bkm-CM': 'bkm',
        'bkm-Latn': 'bkm',
        'bkn': 'bkn',
        'bkn-Latn-ID': 'bkn',
        'bkn-ID': 'bkn',
        'bkn-Latn': 'bkn',
        'bko': 'bko',
        'bko-Latn-CM': 'bko',
        'bko-CM': 'bko',
        'bko-Latn': 'bko',
        'bkp': 'bkp',
        'bkp-Latn-CD': 'bkp',
        'bkp-CD': 'bkp',
        'bkp-Latn': 'bkp',
        'bkq': 'bkq',
        'bkq-Latn-BR': 'bkq',
        'bkq-BR': 'bkq',
        'bkq-Latn': 'bkq',
        'bkr': 'bkr',
        'bkr-Latn-ID': 'bkr',
        'bkr-ID': 'bkr',
        'bkr-Latn': 'bkr',
        'bks': 'bks',
        'bks-Latn-PH': 'bks',
        'bks-Latn': 'bks',
        'bks-PH': 'bks',
        'bkt': 'bkt',
        'bkt-Latn-CD': 'bkt',
        'bkt-CD': 'bkt',
        'bkt-Latn': 'bkt',
        'bku': 'bku',
        'bku-Latn-PH': 'bku',
        'bku-Latn': 'bku',
        'bku-PH': 'bku',
        'bku-Buhd': 'bku-Buhd',
        'bku-Buhd-PH': 'bku-Buhd',
        'bkv': 'bkv',
        'bkv-Latn-NG': 'bkv',
        'bkv-Latn': 'bkv',
        'bkv-NG': 'bkv',
        'bkw': 'bkw',
        'bkw-Latn-CG': 'bkw',
        'bkw-CG': 'bkw',
        'bkw-Latn': 'bkw',
        'bkx': 'bkx',
        'bkx-Latn-TL': 'bkx',
        'bkx-Latn': 'bkx',
        'bkx-TL': 'bkx',
        'bky': 'bky',
        'bky-Latn-NG': 'bky',
        'bky-Latn': 'bky',
        'bky-NG': 'bky',
        'bkz': 'bkz',
        'bkz-Latn-ID': 'bkz',
        'bkz-ID': 'bkz',
        'bkz-Latn': 'bkz',
        'bla': 'bla',
        'bla-Latn-CA': 'bla',
        'bla-CA': 'bla',
        'bla-Latn': 'bla',
        'bla-Cans': 'bla-Cans',
        'bla-Cans-CA': 'bla-Cans',
        'blb': 'blb',
        'blb-Latn-SB': 'blb',
        'blb-Latn': 'blb',
        'blb-SB': 'blb',
        'blc': 'blc',
        'blc-Latn-CA': 'blc',
        'blc-CA': 'blc',
        'blc-Latn': 'blc',
        'bld': 'bld',
        'bld-Latn-ID': 'bld',
        'bld-ID': 'bld',
        'bld-Latn': 'bld',
        'ble': 'ble',
        'ble-Latn-GW': 'ble',
        'ble-GW': 'ble',
        'ble-Latn': 'ble',
        'blf': 'blf',
        'blf-Latn-ID': 'blf',
        'blf-ID': 'blf',
        'blf-Latn': 'blf',
        'blg': 'blg',
        'blg-Latn-MY': 'blg',
        'blg-Latn': 'blg',
        'blg-MY': 'blg',
        'blh': 'blh',
        'blh-Latn-LR': 'blh',
        'blh-LR': 'blh',
        'blh-Latn': 'blh',
        'bli': 'bli',
        'bli-Latn-CD': 'bli',
        'bli-CD': 'bli',
        'bli-Latn': 'bli',
        'blj': 'blj',
        'blj-Latn-ID': 'blj',
        'blj-ID': 'blj',
        'blj-Latn': 'blj',
        'blk': 'blk',
        'blk-Mymr-MM': 'blk',
        'blk-MM': 'blk',
        'blk-Mymr': 'blk',
        'bll': 'bll',
        'bll-Zyyy-US': 'bll',
        'bll-US': 'bll',
        'bll-Zyyy': 'bll',
        'blm': 'blm',
        'blm-Latn-SS': 'blm',
        'blm-Latn': 'blm',
        'blm-SS': 'blm',
        'bln': 'bln',
        'bln-Latn-PH': 'bln',
        'bln-Latn': 'bln',
        'bln-PH': 'bln',
        'blo': 'blo',
        'blo-Latn-BJ': 'blo',
        'blo-BJ': 'blo',
        'blo-Latn': 'blo',
        'blp': 'blp',
        'blp-Latn-SB': 'blp',
        'blp-Latn': 'blp',
        'blp-SB': 'blp',
        'blq': 'blq',
        'blq-Latn-PG': 'blq',
        'blq-Latn': 'blq',
        'blq-PG': 'blq',
        'blr': 'blr',
        'blr-Latn-CN': 'blr',
        'blr-CN': 'blr',
        'blr-Latn': 'blr',
        'blr-Latn-x-pangpung': 'blr-Latn-x-pangpung',
        'blr-Latn-MM-x-pangpung': 'blr-Latn-x-pangpung',
        'blr-MM-x-pangpung': 'blr-Latn-x-pangpung',
        'blr-Tale': 'blr-Tale',
        'blr-Tale-CN': 'blr-Tale',
        'blr-Thai': 'blr-Thai',
        'blr-Thai-TH': 'blr-Thai',
        'blr-TH': 'blr-Thai',
        'bls': 'bls',
        'bls-Latn-ID': 'bls',
        'bls-ID': 'bls',
        'bls-Latn': 'bls',
        'blt': 'blt',
        'blt-Tavt-VN': 'blt',
        'blt-Tavt': 'blt',
        'blt-VN': 'blt',
        'blt-Laoo': 'blt-Laoo',
        'blt-Laoo-LA': 'blt-Laoo',
        'blt-LA': 'blt-Laoo',
        'blt-Latn': 'blt-Latn',
        'blt-Latn-VN': 'blt-Latn',
        'blv': 'blv',
        'blv-Latn-AO': 'blv',
        'blv-AO': 'blv',
        'blv-Latn': 'blv',
        'blw': 'blw',
        'blw-Latn-PH': 'blw',
        'blw-Latn': 'blw',
        'blw-PH': 'blw',
        'blx': 'blx',
        'blx-Latn-PH': 'blx',
        'blx-Latn': 'blx',
        'blx-PH': 'blx',
        'bly': 'bly',
        'bly-Latn-BJ': 'bly',
        'bly-BJ': 'bly',
        'bly-Latn': 'bly',
        'blz': 'blz',
        'blz-Latn-ID': 'blz',
        'blz-ID': 'blz',
        'blz-Latn': 'blz',
        'bm': 'bm',
        'bm-Latn-ML': 'bm',
        'bm-Latn': 'bm',
        'bm-ML': 'bm',
        'bm-Arab': 'bm-Arab',
        'bm-Arab-ML': 'bm-Arab',
        'bm-Nkoo': 'bm-Nkoo',
        'bm-Nkoo-ML': 'bm-Nkoo',
        'bma': 'bma',
        'bma-Latn-NG': 'bma',
        'bma-Latn': 'bma',
        'bma-NG': 'bma',
        'bmb': 'bmb',
        'bmb-Latn-CD': 'bmb',
        'bmb-CD': 'bmb',
        'bmb-Latn': 'bmb',
        'bmc': 'bmc',
        'bmc-Latn-PG': 'bmc',
        'bmc-Latn': 'bmc',
        'bmc-PG': 'bmc',
        'bmd': 'bmd',
        'bmd-Latn-GN': 'bmd',
        'bmd-GN': 'bmd',
        'bmd-Latn': 'bmd',
        'bme': 'bme',
        'bme-Latn-CF': 'bme',
        'bme-CF': 'bme',
        'bme-Latn': 'bme',
        'bmf': 'bmf',
        'bmf-Latn-SL': 'bmf',
        'bmf-Latn': 'bmf',
        'bmf-SL': 'bmf',
        'krm': 'bmf',
        'krm-Latn': 'bmf',
        'krm-Latn-SL': 'bmf',
        'krm-SL': 'bmf',
        'bmg': 'bmg',
        'bmg-Latn-CD': 'bmg',
        'bmg-CD': 'bmg',
        'bmg-Latn': 'bmg',
        'bmh': 'bmh',
        'bmh-Latn-PG': 'bmh',
        'bmh-Latn': 'bmh',
        'bmh-PG': 'bmh',
        'bmi': 'bmi',
        'bmi-Latn-TD': 'bmi',
        'bmi-Latn': 'bmi',
        'bmi-TD': 'bmi',
        'bmj': 'bmj',
        'bmj-Deva-NP': 'bmj',
        'bmj-Deva': 'bmj',
        'bmj-NP': 'bmj',
        'bmk': 'bmk',
        'bmk-Latn-PG': 'bmk',
        'bmk-Latn': 'bmk',
        'bmk-PG': 'bmk',
        'bml': 'bml',
        'bml-Latn-CD': 'bml',
        'bml-CD': 'bml',
        'bml-Latn': 'bml',
        'bmm': 'bmm',
        'bmm-Latn-MG': 'bmm',
        'bmm-Latn': 'bmm',
        'bmm-MG': 'bmm',
        'bmn': 'bmn',
        'bmn-Latn-PG': 'bmn',
        'bmn-Latn': 'bmn',
        'bmn-PG': 'bmn',
        'bmo': 'bmo',
        'bmo-Latn-CM': 'bmo',
        'bmo-CM': 'bmo',
        'bmo-Latn': 'bmo',
        'bmp': 'bmp',
        'bmp-Latn-PG': 'bmp',
        'bmp-Latn': 'bmp',
        'bmp-PG': 'bmp',
        'bmq': 'bmq',
        'bmq-Latn-ML': 'bmq',
        'bmq-Latn': 'bmq',
        'bmq-ML': 'bmq',
        'bmr': 'bmr',
        'bmr-Latn-CO': 'bmr',
        'bmr-CO': 'bmr',
        'bmr-Latn': 'bmr',
        'bms': 'bms',
        'bms-Latn-NE': 'bms',
        'bms-Latn': 'bms',
        'bms-NE': 'bms',
        'bmt': 'bmt',
        'bmt-Zyyy-CN': 'bmt',
        'bmt-CN': 'bmt',
        'bmt-Zyyy': 'bmt',
        'bmu': 'bmu',
        'bmu-Latn-PG': 'bmu',
        'bmu-Latn': 'bmu',
        'bmu-PG': 'bmu',
        'bmv': 'bmv',
        'bmv-Latn-CM': 'bmv',
        'bmv-CM': 'bmv',
        'bmv-Latn': 'bmv',
        'bmw': 'bmw',
        'bmw-Latn-CG': 'bmw',
        'bmw-CG': 'bmw',
        'bmw-Latn': 'bmw',
        'bmx': 'bmx',
        'bmx-Latn-PG': 'bmx',
        'bmx-Latn': 'bmx',
        'bmx-PG': 'bmx',
        'bmz': 'bmz',
        'bmz-Latn-PG': 'bmz',
        'bmz-Latn': 'bmz',
        'bmz-PG': 'bmz',
        'bn': 'bn',
        'bn-Beng-BD': 'bn',
        'bn-BD': 'bn',
        'bn-Beng': 'bn',
        'bn-Brai': 'bn-Brai',
        'bn-Brai-BD': 'bn-Brai',
        'bn-IN': 'bn-IN',
        'bn-Beng-IN': 'bn-IN',
        'bn-Newa': 'bn-Newa',
        'bn-Newa-NP': 'bn-Newa',
        'bn-NP': 'bn-Newa',
        'bna': 'bna',
        'bna-Latn-ID': 'bna',
        'bna-ID': 'bna',
        'bna-Latn': 'bna',
        'bnb': 'bnb',
        'bnb-Latn-MY': 'bnb',
        'bnb-Latn': 'bnb',
        'bnb-MY': 'bnb',
        'bnc': 'bnc',
        'bnc-Latn-PH': 'bnc',
        'bkb': 'bnc',
        'bkb-Latn': 'bnc',
        'bkb-Latn-PH': 'bnc',
        'bkb-PH': 'bnc',
        'bnc-Latn': 'bnc',
        'bnc-PH': 'bnc',
        'lbk': 'bnc',
        'lbk-Latn': 'bnc',
        'lbk-Latn-PH': 'bnc',
        'lbk-PH': 'bnc',
        'bnd': 'bnd',
        'bnd-Latn-ID': 'bnd',
        'bnd-ID': 'bnd',
        'bnd-Latn': 'bnd',
        'bne': 'bne',
        'bne-Latn-ID': 'bne',
        'bne-ID': 'bne',
        'bne-Latn': 'bne',
        'bnf': 'bnf',
        'bnf-Latn-ID': 'bnf',
        'bnf-ID': 'bnf',
        'bnf-Latn': 'bnf',
        'bng': 'bng',
        'bng-Latn-GQ': 'bng',
        'bng-GQ': 'bng',
        'bng-Latn': 'bng',
        'bni': 'bni',
        'bni-Latn-CD': 'bni',
        'bni-CD': 'bni',
        'bni-Latn': 'bni',
        'bnj': 'bnj',
        'bnj-Latn-PH': 'bnj',
        'bnj-Latn': 'bnj',
        'bnj-PH': 'bnj',
        'bnk': 'bnk',
        'bnk-Latn-VU': 'bnk',
        'bnk-Latn': 'bnk',
        'bnk-VU': 'bnk',
        'bnl': 'bnl',
        'bnl-Zyyy-SO': 'bnl',
        'bnl-SO': 'bnl',
        'bnl-Zyyy': 'bnl',
        'bnm': 'bnm',
        'bnm-Latn-GQ': 'bnm',
        'bnm-GQ': 'bnm',
        'bnm-Latn': 'bnm',
        'bnn': 'bnn',
        'bnn-Latn-TW': 'bnn',
        'bnn-Latn': 'bnn',
        'bnn-TW': 'bnn',
        'bno': 'bno',
        'bno-Latn-PH': 'bno',
        'bno-Latn': 'bno',
        'bno-PH': 'bno',
        'bnp': 'bnp',
        'bnp-Latn-PG': 'bnp',
        'bnp-Latn': 'bnp',
        'bnp-PG': 'bnp',
        'bnq': 'bnq',
        'bnq-Latn-ID': 'bnq',
        'bnq-ID': 'bnq',
        'bnq-Latn': 'bnq',
        'bnr': 'bnr',
        'bnr-Latn-VU': 'bnr',
        'bnr-Latn': 'bnr',
        'bnr-VU': 'bnr',
        'bns': 'bns',
        'bns-Deva-IN': 'bns',
        'bns-Deva': 'bns',
        'bns-IN': 'bns',
        'bnu': 'bnu',
        'bnu-Latn-ID': 'bnu',
        'bnu-ID': 'bnu',
        'bnu-Latn': 'bnu',
        'bnv': 'bnv',
        'bnv-Latn-ID': 'bnv',
        'bnv-ID': 'bnv',
        'bnv-Latn': 'bnv',
        'bnw': 'bnw',
        'bnw-Latn-PG': 'bnw',
        'bnw-Latn': 'bnw',
        'bnw-PG': 'bnw',
        'bnx': 'bnx',
        'bnx-Latn-CD': 'bnx',
        'bnx-CD': 'bnx',
        'bnx-Latn': 'bnx',
        'bny': 'bny',
        'bny-Latn-MY': 'bny',
        'bny-Latn': 'bny',
        'bny-MY': 'bny',
        'bnz': 'bnz',
        'bnz-Latn-CM': 'bnz',
        'bnz-CM': 'bnz',
        'bnz-Latn': 'bnz',
        'bo': 'bo',
        'bo-Tibt-CN': 'bo',
        'bo-CN': 'bo',
        'bo-Tibt': 'bo',
        'bo-IN': 'bo-IN',
        'bo-Tibt-IN': 'bo-IN',
        'bo-Latn': 'bo-Latn',
        'bo-Latn-CN': 'bo-Latn',
        'bo-Marc': 'bo-Marc',
        'bo-Marc-CN': 'bo-Marc',
        'bo-Phag': 'bo-Phag',
        'bo-Phag-CN': 'bo-Phag',
        'boa': 'boa',
        'boa-Latn-PE': 'boa',
        'boa-Latn': 'boa',
        'boa-PE': 'boa',
        'bob': 'bob',
        'bob-Latn-KE': 'bob',
        'bob-KE': 'bob',
        'bob-Latn': 'bob',
        'boe': 'boe',
        'boe-Latn-CM': 'boe',
        'boe-CM': 'boe',
        'boe-Latn': 'boe',
        'bof': 'bof',
        'bof-Latn-BF': 'bof',
        'bof-BF': 'bof',
        'bof-Latn': 'bof',
        'bog': 'bog',
        'bog-Zxxx-ML': 'bog',
        'bog-ML': 'bog',
        'bog-Zxxx': 'bog',
        'sgn-bog': 'bog',
        'sgn-bog-ML': 'bog',
        'boh': 'boh',
        'boh-Latn-CD': 'boh',
        'boh-CD': 'boh',
        'boh-Latn': 'boh',
        'boi': 'boi',
        'boi-Zyyy-US': 'boi',
        'boi-US': 'boi',
        'boi-Zyyy': 'boi',
        'boj': 'boj',
        'boj-Latn-PG': 'boj',
        'boj-Latn': 'boj',
        'boj-PG': 'boj',
        'bok': 'bok',
        'bok-Latn-CG': 'bok',
        'bok-CG': 'bok',
        'bok-Latn': 'bok',
        'bol': 'bol',
        'bol-Latn-NG': 'bol',
        'bol-Latn': 'bol',
        'bol-NG': 'bol',
        'bom': 'bom',
        'bom-Latn-NG': 'bom',
        'bom-Latn': 'bom',
        'bom-NG': 'bom',
        'bon': 'bon',
        'bon-Latn-PG': 'bon',
        'bon-Latn': 'bon',
        'bon-PG': 'bon',
        'boo': 'boo',
        'boo-Latn-ML': 'boo',
        'boo-Latn': 'boo',
        'boo-ML': 'boo',
        'bop': 'bop',
        'bop-Latn-PG': 'bop',
        'bop-Latn': 'bop',
        'bop-PG': 'bop',
        'boq': 'boq',
        'boq-Latn-PG': 'boq',
        'boq-Latn': 'boq',
        'boq-PG': 'boq',
        'bor': 'bor',
        'bor-Latn-BR': 'bor',
        'bor-BR': 'bor',
        'bor-Latn': 'bor',
        'bot': 'bot',
        'bot-Latn-SS': 'bot',
        'bot-Latn': 'bot',
        'bot-SS': 'bot',
        'bou': 'bou',
        'bou-Latn-TZ': 'bou',
        'bou-Latn': 'bou',
        'bou-TZ': 'bou',
        'bov': 'bov',
        'bov-Latn-GH': 'bov',
        'bov-GH': 'bov',
        'bov-Latn': 'bov',
        'bow': 'bow',
        'bow-Latn-PG': 'bow',
        'bow-Latn': 'bow',
        'bow-PG': 'bow',
        'box': 'box',
        'box-Latn-BF': 'box',
        'box-BF': 'box',
        'box-Latn': 'box',
        'boy': 'boy',
        'boy-Latn-CF': 'boy',
        'boy-CF': 'boy',
        'boy-Latn': 'boy',
        'boz': 'boz',
        'boz-Latn-ML': 'boz',
        'boz-Latn': 'boz',
        'boz-ML': 'boz',
        'boz-Arab': 'boz-Arab',
        'boz-Arab-ML': 'boz-Arab',
        'bpa': 'bpa',
        'bpa-Latn-VU': 'bpa',
        'bpa-Latn': 'bpa',
        'bpa-VU': 'bpa',
        'bpb': 'bpb',
        'bpb-Latn-CO': 'bpb',
        'bpb-CO': 'bpb',
        'bpb-Latn': 'bpb',
        'bpd': 'bpd',
        'bpd-Latn-CF': 'bpd',
        'bpd-CF': 'bpd',
        'bpd-Latn': 'bpd',
        'bpg': 'bpg',
        'bpg-Latn-ID': 'bpg',
        'bpg-ID': 'bpg',
        'bpg-Latn': 'bpg',
        'bph': 'bph',
        'bph-Cyrl-RU': 'bph',
        'bph-Cyrl': 'bph',
        'bph-RU': 'bph',
        'bpi': 'bpi',
        'bpi-Latn-PG': 'bpi',
        'bpi-Latn': 'bpi',
        'bpi-PG': 'bpi',
        'bpj': 'bpj',
        'bpj-Latn-CD': 'bpj',
        'bpj-CD': 'bpj',
        'bpj-Latn': 'bpj',
        'bpk': 'bpk',
        'bpk-Latn-NC': 'bpk',
        'bpk-Latn': 'bpk',
        'bpk-NC': 'bpk',
        'bpl': 'bpl',
        'bpl-Latn-AU': 'bpl',
        'bpl-AU': 'bpl',
        'bpl-Latn': 'bpl',
        'bpm': 'bpm',
        'bpm-Latn-PG': 'bpm',
        'bpm-Latn': 'bpm',
        'bpm-PG': 'bpm',
        'bpn': 'bpn',
        'bpn-Zyyy-CN': 'bpn',
        'bpn-CN': 'bpn',
        'bpn-Zyyy': 'bpn',
        'bpo': 'bpo',
        'bpo-Latn-ID': 'bpo',
        'bpo-ID': 'bpo',
        'bpo-Latn': 'bpo',
        'bpp': 'bpp',
        'bpp-Latn-ID': 'bpp',
        'bpp-ID': 'bpp',
        'bpp-Latn': 'bpp',
        'nxu': 'bpp',
        'nxu-ID': 'bpp',
        'nxu-Latn': 'bpp',
        'nxu-Latn-ID': 'bpp',
        'bpq': 'bpq',
        'bpq-Latn-ID': 'bpq',
        'bpq-ID': 'bpq',
        'bpq-Latn': 'bpq',
        'bpr': 'bpr',
        'bpr-Latn-PH': 'bpr',
        'bpr-Latn': 'bpr',
        'bpr-PH': 'bpr',
        'bps': 'bps',
        'bps-Latn-PH': 'bps',
        'bps-Latn': 'bps',
        'bps-PH': 'bps',
        'bpt': 'bpt',
        'bpt-Latn-AU': 'bpt',
        'bpt-AU': 'bpt',
        'bpt-Latn': 'bpt',
        'bpu': 'bpu',
        'bpu-Latn-PG': 'bpu',
        'bpu-Latn': 'bpu',
        'bpu-PG': 'bpu',
        'bpv': 'bpv',
        'bpv-Latn-ID': 'bpv',
        'bpv-ID': 'bpv',
        'bpv-Latn': 'bpv',
        'bpw': 'bpw',
        'bpw-Latn-PG': 'bpw',
        'bpw-Latn': 'bpw',
        'bpw-PG': 'bpw',
        'bpx': 'bpx',
        'bpx-Deva-IN': 'bpx',
        'bpx-Deva': 'bpx',
        'bpx-IN': 'bpx',
        'bpy': 'bpy',
        'bpy-Beng-IN': 'bpy',
        'bpy-Beng': 'bpy',
        'bpy-IN': 'bpy',
        'bpz': 'bpz',
        'bpz-Latn-ID': 'bpz',
        'bpz-ID': 'bpz',
        'bpz-Latn': 'bpz',
        'bqa': 'bqa',
        'bqa-Latn-BJ': 'bqa',
        'bqa-BJ': 'bqa',
        'bqa-Latn': 'bqa',
        'bqb': 'bqb',
        'bqb-Latn-ID': 'bqb',
        'bqb-ID': 'bqb',
        'bqb-Latn': 'bqb',
        'bqc': 'bqc',
        'bqc-Latn-BJ': 'bqc',
        'bqc-BJ': 'bqc',
        'bqc-Latn': 'bqc',
        'bqd': 'bqd',
        'bqd-Latn-CM': 'bqd',
        'bqd-CM': 'bqd',
        'bqd-Latn': 'bqd',
        'bqf': 'bqf',
        'bqf-Latn-GN': 'bqf',
        'bqf-GN': 'bqf',
        'bqf-Latn': 'bqf',
        'bqf-Arab': 'bqf-Arab',
        'bqf-Arab-GN': 'bqf-Arab',
        'bqg': 'bqg',
        'bqg-Latn-TG': 'bqg',
        'bqg-Latn': 'bqg',
        'bqg-TG': 'bqg',
        'bqh': 'bqh',
        'bqh-Zyyy-CN': 'bqh',
        'bqh-CN': 'bqh',
        'bqh-Zyyy': 'bqh',
        'bqi': 'bqi',
        'bqi-Arab-IR': 'bqi',
        'bqi-Arab': 'bqi',
        'bqi-IR': 'bqi',
        'bqj': 'bqj',
        'bqj-Latn-SN': 'bqj',
        'bqj-Latn': 'bqj',
        'bqj-SN': 'bqj',
        'bqk': 'bqk',
        'bqk-Latn-CF': 'bqk',
        'bqk-CF': 'bqk',
        'bqk-Latn': 'bqk',
        'bql': 'bql',
        'bql-Latn-PG': 'bql',
        'bql-Latn': 'bql',
        'bql-PG': 'bql',
        'bqm': 'bqm',
        'bqm-Latn-CM': 'bqm',
        'bqm-CM': 'bqm',
        'bqm-Latn': 'bqm',
        'bqn': 'bqn',
        'bqn-Zxxx-BG': 'bqn',
        'bqn-BG': 'bqn',
        'bqn-Zxxx': 'bqn',
        'sgn-bqn': 'bqn',
        'sgn-bqn-BG': 'bqn',
        'bqo': 'bqo',
        'bqo-Latn-CM': 'bqo',
        'bqo-CM': 'bqo',
        'bqo-Latn': 'bqo',
        'bqp': 'bqp',
        'bqp-Latn-NG': 'bqp',
        'bqp-Latn': 'bqp',
        'bqp-NG': 'bqp',
        'bqq': 'bqq',
        'bqq-Latn-ID': 'bqq',
        'bqq-ID': 'bqq',
        'bqq-Latn': 'bqq',
        'bqr': 'bqr',
        'bqr-Latn-ID': 'bqr',
        'bqr-ID': 'bqr',
        'bqr-Latn': 'bqr',
        'bqs': 'bqs',
        'bqs-Latn-PG': 'bqs',
        'bqs-Latn': 'bqs',
        'bqs-PG': 'bqs',
        'bqt': 'bqt',
        'bqt-Latn-CM': 'bqt',
        'bqt-CM': 'bqt',
        'bqt-Latn': 'bqt',
        'bqu': 'bqu',
        'bqu-Latn-CD': 'bqu',
        'bqu-CD': 'bqu',
        'bqu-Latn': 'bqu',
        'bqv': 'bqv',
        'bqv-Latn-CI': 'bqv',
        'bqv-CI': 'bqv',
        'bqv-Latn': 'bqv',
        'bqw': 'bqw',
        'bqw-Latn-NG': 'bqw',
        'bqw-Latn': 'bqw',
        'bqw-NG': 'bqw',
        'bqx': 'bqx',
        'bqx-Latn-NG': 'bqx',
        'bqx-Latn': 'bqx',
        'bqx-NG': 'bqx',
        'bqy': 'bqy',
        'bqy-Zxxx-ID': 'bqy',
        'bqy-ID': 'bqy',
        'bqy-Zxxx': 'bqy',
        'sgn-bqy': 'bqy',
        'sgn-bqy-ID': 'bqy',
        'bqz': 'bqz',
        'bqz-Latn-CM': 'bqz',
        'bqz-CM': 'bqz',
        'bqz-Latn': 'bqz',
        'br': 'br',
        'br-Latn-FR': 'br',
        'br-FR': 'br',
        'br-Latn': 'br',
        'bra': 'bra',
        'bra-Deva-IN': 'bra',
        'bra-Deva': 'bra',
        'bra-IN': 'bra',
        'brb': 'brb',
        'brb-Khmr-KH': 'brb',
        'brb-KH': 'brb',
        'brb-Khmr': 'brb',
        'brb-Laoo': 'brb-Laoo',
        'brb-Laoo-LA': 'brb-Laoo',
        'brb-LA': 'brb-Laoo',
        'brb-Latn': 'brb-Latn',
        'brb-Latn-VN': 'brb-Latn',
        'brb-VN': 'brb-Latn',
        'brc': 'brc',
        'brc-Latn-GY': 'brc',
        'brc-GY': 'brc',
        'brc-Latn': 'brc',
        'brd': 'brd',
        'brd-Deva-NP': 'brd',
        'brd-Deva': 'brd',
        'brd-NP': 'brd',
        'brf': 'brf',
        'brf-Latn-CD': 'brf',
        'brf-CD': 'brf',
        'brf-Latn': 'brf',
        'brg': 'brg',
        'brg-Latn-BO': 'brg',
        'brg-BO': 'brg',
        'brg-Latn': 'brg',
        'brh': 'brh',
        'brh-Arab-PK': 'brh',
        'brh-Arab': 'brh',
        'brh-PK': 'brh',
        'brh-Latn': 'brh-Latn',
        'brh-Latn-PK': 'brh-Latn',
        'bri': 'bri',
        'bri-Latn-CM': 'bri',
        'bri-CM': 'bri',
        'bri-Latn': 'bri',
        'brj': 'brj',
        'brj-Latn-VU': 'brj',
        'brj-Latn': 'brj',
        'brj-VU': 'brj',
        'brk': 'brk',
        'brk-Arab-SD': 'brk',
        'brk-Arab': 'brk',
        'brk-SD': 'brk',
        'brl': 'brl',
        'brl-Latn-BW': 'brl',
        'brl-BW': 'brl',
        'brl-Latn': 'brl',
        'brm': 'brm',
        'brm-Latn-CD': 'brm',
        'brm-CD': 'brm',
        'brm-Latn': 'brm',
        'brn': 'brn',
        'brn-Latn-CR': 'brn',
        'brn-CR': 'brn',
        'brn-Latn': 'brn',
        'bro': 'bro',
        'bro-Zyyy-BT': 'bro',
        'bro-BT': 'bro',
        'bro-Zyyy': 'bro',
        'brp': 'brp',
        'brp-Latn-ID': 'brp',
        'brp-ID': 'brp',
        'brp-Latn': 'brp',
        'brq': 'brq',
        'brq-Latn-PG': 'brq',
        'brq-Latn': 'brq',
        'brq-PG': 'brq',
        'brr': 'brr',
        'brr-Latn-SB': 'brr',
        'brr-Latn': 'brr',
        'brr-SB': 'brr',
        'brs': 'brs',
        'brs-Latn-ID': 'brs',
        'brs-ID': 'brs',
        'brs-Latn': 'brs',
        'brt': 'brt',
        'brt-Latn-NG': 'brt',
        'brt-Latn': 'brt',
        'brt-NG': 'brt',
        'bru': 'bru',
        'bru-Latn-VN': 'bru',
        'bru-Latn': 'bru',
        'bru-VN': 'bru',
        'bru-Laoo': 'bru-Laoo',
        'bru-Laoo-LA': 'bru-Laoo',
        'bru-Thai': 'bru-Thai',
        'bru-Thai-LA': 'bru-Thai',
        'brv': 'brv',
        'brv-Laoo-LA': 'brv',
        'brv-LA': 'brv',
        'brv-Laoo': 'brv',
        'brv-Thai-x-donglng': 'brv-Thai-x-donglng',
        'brv-Thai-TH-x-donglng': 'brv-Thai-x-donglng',
        'brv-TH-x-donglng': 'brv-Thai-x-donglng',
        'brv-Thai-x-khongchm': 'brv-Thai-x-khongchm',
        'brv-Thai-TH-x-khongchm': 'brv-Thai-x-khongchm',
        'brv-TH-x-khongchm': 'brv-Thai-x-khongchm',
        'brv-Thai-x-sakonnkn': 'brv-Thai-x-sakonnkn',
        'brv-Thai-TH-x-sakonnkn': 'brv-Thai-x-sakonnkn',
        'brv-TH-x-sakonnkn': 'brv-Thai-x-sakonnkn',
        'brw': 'brw',
        'brw-Zyyy-IN': 'brw',
        'brw-IN': 'brw',
        'brw-Zyyy': 'brw',
        'brx': 'brx',
        'brx-Deva-IN': 'brx',
        'brx-Deva': 'brx',
        'brx-IN': 'brx',
        'brx-Beng': 'brx-Beng',
        'brx-Beng-IN': 'brx-Beng',
        'brx-Latn': 'brx-Latn',
        'brx-Latn-IN': 'brx-Latn',
        'bry': 'bry',
        'bry-Latn-PG': 'bry',
        'bry-Latn': 'bry',
        'bry-PG': 'bry',
        'brz': 'brz',
        'brz-Latn-PG': 'brz',
        'brz-Latn': 'brz',
        'brz-PG': 'brz',
        'bs': 'bs',
        'bs-Latn-BA': 'bs',
        'bs-BA': 'bs',
        'bs-Latn': 'bs',
        'bs-Cyrl': 'bs-Cyrl',
        'bs-Cyrl-BA': 'bs-Cyrl',
        'bsa': 'bsa',
        'bsa-Latn-ID': 'bsa',
        'bsa-ID': 'bsa',
        'bsa-Latn': 'bsa',
        'bsb': 'bsb',
        'bsb-Latn-BN': 'bsb',
        'bsb-BN': 'bsb',
        'bsb-Latn': 'bsb',
        'bsc': 'bsc',
        'bsc-Latn-SN': 'bsc',
        'bsc-Latn': 'bsc',
        'bsc-SN': 'bsc',
        'bse': 'bse',
        'bse-Latn-CM': 'bse',
        'bse-CM': 'bse',
        'bse-Latn': 'bse',
        'bsf': 'bsf',
        'bsf-Latn-NG': 'bsf',
        'bsf-Latn': 'bsf',
        'bsf-NG': 'bsf',
        'bsg': 'bsg',
        'bsg-Zyyy-IR': 'bsg',
        'bsg-IR': 'bsg',
        'bsg-Zyyy': 'bsg',
        'bsh': 'bsh',
        'bsh-Arab-AF': 'bsh',
        'bsh-AF': 'bsh',
        'bsh-Arab': 'bsh',
        'bsi': 'bsi',
        'bsi-Latn-CM': 'bsi',
        'bsi-CM': 'bsi',
        'bsi-Latn': 'bsi',
        'bsj': 'bsj',
        'bsj-Latn-NG': 'bsj',
        'bsj-Latn': 'bsj',
        'bsj-NG': 'bsj',
        'bsk': 'bsk',
        'bsk-Arab-PK': 'bsk',
        'bsk-Arab': 'bsk',
        'bsk-PK': 'bsk',
        'bsk-Latn': 'bsk-Latn',
        'bsk-Latn-PK': 'bsk-Latn',
        'bsl': 'bsl',
        'bsl-Latn-NG': 'bsl',
        'bsl-Latn': 'bsl',
        'bsl-NG': 'bsl',
        'bsm': 'bsm',
        'bsm-Latn-ID': 'bsm',
        'bsm-ID': 'bsm',
        'bsm-Latn': 'bsm',
        'bsn': 'bsn',
        'bsn-Latn-CO': 'bsn',
        'bsn-CO': 'bsn',
        'bsn-Latn': 'bsn',
        'bso': 'bso',
        'bso-Latn-TD': 'bso',
        'bso-Latn': 'bso',
        'bso-TD': 'bso',
        'bsp': 'bsp',
        'bsp-Latn-GN': 'bsp',
        'bsp-GN': 'bsp',
        'bsp-Latn': 'bsp',
        'bsq': 'bsq',
        'bsq-Bass-LR': 'bsq',
        'bsq-Bass': 'bsq',
        'bsq-LR': 'bsq',
        'bsq-Latn': 'bsq-Latn',
        'bsq-Latn-LR': 'bsq-Latn',
        'bsr': 'bsr',
        'bsr-Latn-NG': 'bsr',
        'bsr-Latn': 'bsr',
        'bsr-NG': 'bsr',
        'bss': 'bss',
        'bss-Latn-CM': 'bss',
        'bss-CM': 'bss',
        'bss-Latn': 'bss',
        'bst': 'bst',
        'bst-Ethi-ET': 'bst',
        'bst-ET': 'bst',
        'bst-Ethi': 'bst',
        'bst-Latn': 'bst-Latn',
        'bst-Latn-ET': 'bst-Latn',
        'bsu': 'bsu',
        'bsu-Latn-ID': 'bsu',
        'bsu-ID': 'bsu',
        'bsu-Latn': 'bsu',
        'bsv': 'bsv',
        'bsv-Latn-GN': 'bsv',
        'bsv-GN': 'bsv',
        'bsv-Latn': 'bsv',
        'bsv-Arab': 'bsv-Arab',
        'bsv-Arab-GN': 'bsv-Arab',
        'bsw': 'bsw',
        'bsw-Zyyy-ET': 'bsw',
        'bsw-ET': 'bsw',
        'bsw-Zyyy': 'bsw',
        'bsx': 'bsx',
        'bsx-Latn-NG': 'bsx',
        'bsx-Latn': 'bsx',
        'bsx-NG': 'bsx',
        'bsy': 'bsy',
        'bsy-Latn-MY': 'bsy',
        'bsy-Latn': 'bsy',
        'bsy-MY': 'bsy',
        'bta': 'bta',
        'bta-Latn-NG': 'bta',
        'bta-Latn': 'bta',
        'bta-NG': 'bta',
        'btb': 'btb',
        'btb-Latn-CM': 'btb',
        'btb-CM': 'btb',
        'btb-Latn': 'btb',
        'btc': 'btc',
        'btc-Latn-CM': 'btc',
        'btc-CM': 'btc',
        'btc-Latn': 'btc',
        'btd': 'btd',
        'btd-Batk-ID': 'btd',
        'btd-Batk': 'btd',
        'btd-ID': 'btd',
        'bte': 'bte',
        'bte-Latn-NG': 'bte',
        'bte-Latn': 'bte',
        'bte-NG': 'bte',
        'btf': 'btf',
        'btf-Latn-TD': 'btf',
        'btf-Latn': 'btf',
        'btf-TD': 'btf',
        'btg': 'btg',
        'btg-Latn-CI': 'btg',
        'btg-CI': 'btg',
        'btg-Latn': 'btg',
        'bth': 'bth',
        'bth-Latn-MY': 'bth',
        'bth-Latn': 'bth',
        'bth-MY': 'bth',
        'bti': 'bti',
        'bti-Latn-ID': 'bti',
        'bti-ID': 'bti',
        'bti-Latn': 'bti',
        'btj': 'btj',
        'btj-Latn-ID': 'btj',
        'btj-ID': 'btj',
        'btj-Latn': 'btj',
        'ms-btj': 'btj',
        'ms-btj-ID': 'btj',
        'btm': 'btm',
        'btm-Batk-ID': 'btm',
        'btm-Batk': 'btm',
        'btm-ID': 'btm',
        'btn': 'btn',
        'btn-Latn-PH': 'btn',
        'btn-Latn': 'btn',
        'btn-PH': 'btn',
        'bto': 'bto',
        'bto-Latn-PH': 'bto',
        'bto-Latn': 'bto',
        'bto-PH': 'bto',
        'btp': 'btp',
        'btp-Latn-PG': 'btp',
        'btp-Latn': 'btp',
        'btp-PG': 'btp',
        'btq': 'btq',
        'btq-Latn-MY': 'btq',
        'btq-Latn': 'btq',
        'btq-MY': 'btq',
        'btr': 'btr',
        'btr-Latn-VU': 'btr',
        'btr-Latn': 'btr',
        'btr-VU': 'btr',
        'bts': 'bts',
        'bts-Latn-ID': 'bts',
        'bts-ID': 'bts',
        'bts-Latn': 'bts',
        'bts-Batk': 'bts-Batk',
        'bts-Batk-ID': 'bts-Batk',
        'btt': 'btt',
        'btt-Latn-NG': 'btt',
        'btt-Latn': 'btt',
        'btt-NG': 'btt',
        'btu': 'btu',
        'btu-Latn-NG': 'btu',
        'btu-Latn': 'btu',
        'btu-NG': 'btu',
        'btv': 'btv',
        'btv-Deva-PK': 'btv',
        'btv-Deva': 'btv',
        'btv-PK': 'btv',
        'btw': 'btw',
        'btw-Latn-PH': 'btw',
        'btw-Latn': 'btw',
        'btw-PH': 'btw',
        'btx': 'btx',
        'btx-Latn-ID': 'btx',
        'btx-ID': 'btx',
        'btx-Latn': 'btx',
        'btx-Batk': 'btx-Batk',
        'btx-Batk-ID': 'btx-Batk',
        'bty': 'bty',
        'bty-Latn-ID': 'bty',
        'bty-ID': 'bty',
        'bty-Latn': 'bty',
        'btz': 'btz',
        'btz-Latn-ID': 'btz',
        'btz-ID': 'btz',
        'btz-Latn': 'btz',
        'bua': 'bua',
        'bua-Cyrl-RU': 'bua',
        'bua-Cyrl': 'bua',
        'bua-RU': 'bua',
        'bxr': 'bua',
        'bxr-Cyrl': 'bua',
        'bxr-Cyrl-RU': 'bua',
        'bxr-RU': 'bua',
        'bub': 'bub',
        'bub-Latn-TD': 'bub',
        'bub-Latn': 'bub',
        'bub-TD': 'bub',
        'buc': 'buc',
        'buc-Latn-YT': 'buc',
        'buc-Latn': 'buc',
        'buc-YT': 'buc',
        'bud': 'bud',
        'bud-Latn-TG': 'bud',
        'bud-Latn': 'bud',
        'bud-TG': 'bud',
        'bud-Brai': 'bud-Brai',
        'bud-Brai-TG': 'bud-Brai',
        'bue': 'bue',
        'bue-Latn-CA': 'bue',
        'bue-CA': 'bue',
        'bue-Latn': 'bue',
        'buf': 'buf',
        'buf-Latn-CD': 'buf',
        'buf-CD': 'buf',
        'buf-Latn': 'buf',
        'bug': 'bug',
        'bug-Latn-ID': 'bug',
        'bug-ID': 'bug',
        'bug-Latn': 'bug',
        'bug-Bugi': 'bug-Bugi',
        'bug-Bugi-ID': 'bug-Bugi',
        'buh': 'buh',
        'buh-Latn-CN': 'buh',
        'buh-CN': 'buh',
        'buh-Latn': 'buh',
        'bui': 'bui',
        'bui-Latn-CG': 'bui',
        'bui-CG': 'bui',
        'bui-Latn': 'bui',
        'buj': 'buj',
        'buj-Latn-NG': 'buj',
        'buj-Latn': 'buj',
        'buj-NG': 'buj',
        'buk': 'buk',
        'buk-Latn-PG': 'buk',
        'buk-Latn': 'buk',
        'buk-PG': 'buk',
        'bum': 'bum',
        'bum-Latn-CM': 'bum',
        'bum-CM': 'bum',
        'bum-Latn': 'bum',
        'bun': 'bun',
        'bun-Latn-SL': 'bun',
        'bun-Latn': 'bun',
        'bun-SL': 'bun',
        'buo': 'buo',
        'buo-Latn-PG': 'buo',
        'buo-Latn': 'buo',
        'buo-PG': 'buo',
        'bup': 'bup',
        'bup-Latn-ID': 'bup',
        'bup-ID': 'bup',
        'bup-Latn': 'bup',
        'buq': 'buq',
        'buq-Latn-PG': 'buq',
        'buq-Latn': 'buq',
        'buq-PG': 'buq',
        'bus': 'bus',
        'bus-Latn-NG': 'bus',
        'bus-Latn': 'bus',
        'bus-NG': 'bus',
        'but': 'but',
        'but-Latn-PG': 'but',
        'but-Latn': 'but',
        'but-PG': 'but',
        'buu': 'buu',
        'buu-Latn-CD': 'buu',
        'buu-CD': 'buu',
        'buu-Latn': 'buu',
        'buv': 'buv',
        'buv-Latn-PG': 'buv',
        'buv-Latn': 'buv',
        'buv-PG': 'buv',
        'buw': 'buw',
        'buw-Latn-GA': 'buw',
        'buw-GA': 'buw',
        'buw-Latn': 'buw',
        'bux': 'bux',
        'bux-Latn-NG': 'bux',
        'bux-Latn': 'bux',
        'bux-NG': 'bux',
        'buy': 'buy',
        'buy-Latn-SL': 'buy',
        'buy-Latn': 'buy',
        'buy-SL': 'buy',
        'buz': 'buz',
        'buz-Latn-NG': 'buz',
        'buz-Latn': 'buz',
        'buz-NG': 'buz',
        'bva': 'bva',
        'bva-Latn-TD': 'bva',
        'bva-Latn': 'bva',
        'bva-TD': 'bva',
        'bvb': 'bvb',
        'bvb-Latn-GQ': 'bvb',
        'bvb-GQ': 'bvb',
        'bvb-Latn': 'bvb',
        'bvc': 'bvc',
        'bvc-Latn-SB': 'bvc',
        'bvc-Latn': 'bvc',
        'bvc-SB': 'bvc',
        'bvd': 'bvd',
        'bvd-Latn-SB': 'bvd',
        'bvd-Latn': 'bvd',
        'bvd-SB': 'bvd',
        'bve': 'bve',
        'bve-Latn-ID': 'bve',
        'bve-ID': 'bve',
        'bve-Latn': 'bve',
        'ms-bve': 'bve',
        'ms-bve-ID': 'bve',
        'bvf': 'bvf',
        'bvf-Latn-TD': 'bvf',
        'bvf-Latn': 'bvf',
        'bvf-TD': 'bvf',
        'bvg': 'bvg',
        'bvg-Latn-CM': 'bvg',
        'bvg-CM': 'bvg',
        'bvg-Latn': 'bvg',
        'bvh': 'bvh',
        'bvh-Latn-NG': 'bvh',
        'bvh-Latn': 'bvh',
        'bvh-NG': 'bvh',
        'bvi': 'bvi',
        'bvi-Latn-SS': 'bvi',
        'bvi-Latn': 'bvi',
        'bvi-SS': 'bvi',
        'bvj': 'bvj',
        'bvj-Latn-NG': 'bvj',
        'bvj-Latn': 'bvj',
        'bvj-NG': 'bvj',
        'bvk': 'bvk',
        'bvk-Latn-ID': 'bvk',
        'bvk-ID': 'bvk',
        'bvk-Latn': 'bvk',
        'bvl': 'bvl',
        'bvl-Zxxx-BO': 'bvl',
        'bvl-BO': 'bvl',
        'bvl-Zxxx': 'bvl',
        'sgn-bvl': 'bvl',
        'sgn-bvl-BO': 'bvl',
        'bvm': 'bvm',
        'bvm-Latn-CM': 'bvm',
        'bvm-CM': 'bvm',
        'bvm-Latn': 'bvm',
        'bvn': 'bvn',
        'bvn-Latn-PG': 'bvn',
        'bvn-Latn': 'bvn',
        'bvn-PG': 'bvn',
        'bvo': 'bvo',
        'bvo-Latn-TD': 'bvo',
        'bvo-Latn': 'bvo',
        'bvo-TD': 'bvo',
        'bvp': 'bvp',
        'bvp-Zyyy-CN': 'bvp',
        'bvp-CN': 'bvp',
        'bvp-Zyyy': 'bvp',
        'bvq': 'bvq',
        'bvq-Latn-CF': 'bvq',
        'bvq-CF': 'bvq',
        'bvq-Latn': 'bvq',
        'bvr': 'bvr',
        'bvr-Latn-AU': 'bvr',
        'bvr-AU': 'bvr',
        'bvr-Latn': 'bvr',
        'bvt': 'bvt',
        'bvt-Latn-ID': 'bvt',
        'bvt-ID': 'bvt',
        'bvt-Latn': 'bvt',
        'bvu': 'bvu',
        'bvu-Latn-ID': 'bvu',
        'bvu-ID': 'bvu',
        'bvu-Latn': 'bvu',
        'ms-bvu': 'bvu',
        'ms-bvu-ID': 'bvu',
        'bvv': 'bvv',
        'bvv-Latn-VE': 'bvv',
        'bvv-Latn': 'bvv',
        'bvv-VE': 'bvv',
        'bvw': 'bvw',
        'bvw-Latn-NG': 'bvw',
        'bvw-Latn': 'bvw',
        'bvw-NG': 'bvw',
        'bvx': 'bvx',
        'bvx-Latn-CG': 'bvx',
        'bvx-CG': 'bvx',
        'bvx-Latn': 'bvx',
        'bvy': 'bvy',
        'bvy-Latn-PH': 'bvy',
        'bvy-Latn': 'bvy',
        'bvy-PH': 'bvy',
        'bvz': 'bvz',
        'bvz-Latn-ID': 'bvz',
        'bvz-ID': 'bvz',
        'bvz-Latn': 'bvz',
        'bwa': 'bwa',
        'bwa-Latn-NC': 'bwa',
        'bwa-Latn': 'bwa',
        'bwa-NC': 'bwa',
        'bwb': 'bwb',
        'bwb-Latn-FJ': 'bwb',
        'bwb-FJ': 'bwb',
        'bwb-Latn': 'bwb',
        'bwc': 'bwc',
        'bwc-Latn-ZM': 'bwc',
        'bwc-Latn': 'bwc',
        'bwc-ZM': 'bwc',
        'bwd': 'bwd',
        'bwd-Latn-PG': 'bwd',
        'bwd-Latn': 'bwd',
        'bwd-PG': 'bwd',
        'bwe': 'bwe',
        'bwe-Mymr-MM': 'bwe',
        'bwe-MM': 'bwe',
        'bwe-Mymr': 'bwe',
        'bwe-Latn': 'bwe-Latn',
        'bwe-Latn-MM': 'bwe-Latn',
        'bwf': 'bwf',
        'bwf-Latn-PG': 'bwf',
        'bwf-Latn': 'bwf',
        'bwf-PG': 'bwf',
        'bwg': 'bwg',
        'bwg-Latn-MZ': 'bwg',
        'bwg-Latn': 'bwg',
        'bwg-MZ': 'bwg',
        'bwh': 'bwh',
        'bwh-Latn-CM': 'bwh',
        'bwh-CM': 'bwh',
        'bwh-Latn': 'bwh',
        'bwi': 'bwi',
        'bwi-Latn-VE': 'bwi',
        'bwi-Latn': 'bwi',
        'bwi-VE': 'bwi',
        'bwj': 'bwj',
        'bwj-Latn-BF': 'bwj',
        'bwj-BF': 'bwj',
        'bwj-Latn': 'bwj',
        'bwk': 'bwk',
        'bwk-Latn-PG': 'bwk',
        'bwk-Latn': 'bwk',
        'bwk-PG': 'bwk',
        'bwl': 'bwl',
        'bwl-Latn-CD': 'bwl',
        'bwl-CD': 'bwl',
        'bwl-Latn': 'bwl',
        'bwm': 'bwm',
        'bwm-Latn-PG': 'bwm',
        'bwm-Latn': 'bwm',
        'bwm-PG': 'bwm',
        'bwn': 'bwn',
        'bwn-Zyyy-CN': 'bwn',
        'bwn-CN': 'bwn',
        'bwn-Zyyy': 'bwn',
        'bwo': 'bwo',
        'bwo-Latn-ET': 'bwo',
        'bwo-ET': 'bwo',
        'bwo-Latn': 'bwo',
        'bwo-Ethi': 'bwo-Ethi',
        'bwo-Ethi-ET': 'bwo-Ethi',
        'bwp': 'bwp',
        'bwp-Latn-ID': 'bwp',
        'bwp-ID': 'bwp',
        'bwp-Latn': 'bwp',
        'bwq': 'bwq',
        'bwq-Latn-BF': 'bwq',
        'bwq-BF': 'bwq',
        'bwq-Latn': 'bwq',
        'bwr': 'bwr',
        'bwr-Latn-NG': 'bwr',
        'bwr-Latn': 'bwr',
        'bwr-NG': 'bwr',
        'bws': 'bws',
        'bws-Latn-CD': 'bws',
        'bws-CD': 'bws',
        'bws-Latn': 'bws',
        'bwt': 'bwt',
        'bwt-Latn-CM': 'bwt',
        'bwt-CM': 'bwt',
        'bwt-Latn': 'bwt',
        'bwu': 'bwu',
        'bwu-Latn-GH': 'bwu',
        'bwu-GH': 'bwu',
        'bwu-Latn': 'bwu',
        'bww': 'bww',
        'bww-Latn-CD': 'bww',
        'bww-CD': 'bww',
        'bww-Latn': 'bww',
        'bwx': 'bwx',
        'bwx-Latn-CN': 'bwx',
        'bwx-CN': 'bwx',
        'bwx-Latn': 'bwx',
        'bwy': 'bwy',
        'bwy-Latn-BF': 'bwy',
        'bwy-BF': 'bwy',
        'bwy-Latn': 'bwy',
        'bwz': 'bwz',
        'bwz-Latn-CG': 'bwz',
        'bwz-CG': 'bwz',
        'bwz-Latn': 'bwz',
        'bxa': 'bxa',
        'bxa-Latn-SB': 'bxa',
        'bxa-Latn': 'bxa',
        'bxa-SB': 'bxa',
        'bxb': 'bxb',
        'bxb-Latn-SS': 'bxb',
        'bxb-Latn': 'bxb',
        'bxb-SS': 'bxb',
        'bxc': 'bxc',
        'bxc-Latn-GQ': 'bxc',
        'bxc-GQ': 'bxc',
        'bxc-Latn': 'bxc',
        'bxd': 'bxd',
        'bxd-Zyyy-CN': 'bxd',
        'bxd-CN': 'bxd',
        'bxd-Zyyy': 'bxd',
        'bxe': 'bxe',
        'bxe-Zyyy-ET': 'bxe',
        'bxe-ET': 'bxe',
        'bxe-Zyyy': 'bxe',
        'bxf': 'bxf',
        'bxf-Latn-PG': 'bxf',
        'bxf-Latn': 'bxf',
        'bxf-PG': 'bxf',
        'bxg': 'bxg',
        'bxg-Latn-CD': 'bxg',
        'bxg-CD': 'bxg',
        'bxg-Latn': 'bxg',
        'bxh': 'bxh',
        'bxh-Latn-PG': 'bxh',
        'bxh-Latn': 'bxh',
        'bxh-PG': 'bxh',
        'bxi': 'bxi',
        'bxi-Latn-AU': 'bxi',
        'bxi-AU': 'bxi',
        'bxi-Latn': 'bxi',
        'bxj': 'bxj',
        'bxj-Latn-AU': 'bxj',
        'bxj-AU': 'bxj',
        'bxj-Latn': 'bxj',
        'bxl': 'bxl',
        'bxl-Latn-BF': 'bxl',
        'bxl-BF': 'bxl',
        'bxl-Latn': 'bxl',
        'bxm': 'bxm',
        'bxm-Cyrl-MN': 'bxm',
        'bxm-Cyrl': 'bxm',
        'bxm-MN': 'bxm',
        'bxm-Latn': 'bxm-Latn',
        'bxm-Latn-MN': 'bxm-Latn',
        'bxm-Mong': 'bxm-Mong',
        'bxm-Mong-MN': 'bxm-Mong',
        'bxn': 'bxn',
        'bxn-Latn-AU': 'bxn',
        'bxn-AU': 'bxn',
        'bxn-Latn': 'bxn',
        'bxo': 'bxo',
        'bxo-Latn-NG': 'bxo',
        'bxo-Latn': 'bxo',
        'bxo-NG': 'bxo',
        'bxp': 'bxp',
        'bxp-Latn-CM': 'bxp',
        'bxp-CM': 'bxp',
        'bxp-Latn': 'bxp',
        'bxq': 'bxq',
        'bxq-Latn-NG': 'bxq',
        'bxq-Latn': 'bxq',
        'bxq-NG': 'bxq',
        'bxs': 'bxs',
        'bxs-Latn-CM': 'bxs',
        'bxs-CM': 'bxs',
        'bxs-Latn': 'bxs',
        'bxu': 'bxu',
        'bxu-Zyyy-CN': 'bxu',
        'bxu-CN': 'bxu',
        'bxu-Zyyy': 'bxu',
        'bxv': 'bxv',
        'bxv-Latn-TD': 'bxv',
        'bxv-Latn': 'bxv',
        'bxv-TD': 'bxv',
        'bxw': 'bxw',
        'bxw-Latn-ML': 'bxw',
        'bxw-Latn': 'bxw',
        'bxw-ML': 'bxw',
        'bxz': 'bxz',
        'bxz-Latn-PG': 'bxz',
        'bxz-Latn': 'bxz',
        'bxz-PG': 'bxz',
        'bya': 'bya',
        'bya-Latn-PH': 'bya',
        'bya-Latn': 'bya',
        'bya-PH': 'bya',
        'byb': 'byb',
        'byb-Latn-CM': 'byb',
        'byb-CM': 'byb',
        'byb-Latn': 'byb',
        'byc': 'byc',
        'byc-Latn-NG': 'byc',
        'byc-Latn': 'byc',
        'byc-NG': 'byc',
        'byd': 'byd',
        'byd-Latn-ID': 'byd',
        'byd-ID': 'byd',
        'byd-Latn': 'byd',
        'bye': 'bye',
        'bye-Latn-PG': 'bye',
        'bye-Latn': 'bye',
        'bye-PG': 'bye',
        'byf': 'byf',
        'byf-Latn-NG': 'byf',
        'byf-Latn': 'byf',
        'byf-NG': 'byf',
        'byg': 'byg',
        'byg-Zyyy-SD': 'byg',
        'byg-SD': 'byg',
        'byg-Zyyy': 'byg',
        'byh': 'byh',
        'byh-Deva-NP': 'byh',
        'byh-Deva': 'byh',
        'byh-NP': 'byh',
        'byi': 'byi',
        'byi-Latn-CD': 'byi',
        'byi-CD': 'byi',
        'byi-Latn': 'byi',
        'byj': 'byj',
        'byj-Latn-NG': 'byj',
        'byj-Latn': 'byj',
        'byj-NG': 'byj',
        'byk': 'byk',
        'byk-Zyyy-CN': 'byk',
        'byk-CN': 'byk',
        'byk-Zyyy': 'byk',
        'byl': 'byl',
        'byl-Latn-ID': 'byl',
        'byl-ID': 'byl',
        'byl-Latn': 'byl',
        'bym': 'bym',
        'bym-Latn-AU': 'bym',
        'bym-AU': 'bym',
        'bym-Latn': 'bym',
        'byn': 'byn',
        'byn-Ethi-ER': 'byn',
        'byn-ER': 'byn',
        'byn-Ethi': 'byn',
        'byn-Latn': 'byn-Latn',
        'byn-Latn-ER': 'byn-Latn',
        'byo': 'byo',
        'byo-Zyyy-CN': 'byo',
        'byo-CN': 'byo',
        'byo-Zyyy': 'byo',
        'byp': 'byp',
        'byp-Latn-NG': 'byp',
        'byp-Latn': 'byp',
        'byp-NG': 'byp',
        'byq': 'byq',
        'byq-Zyyy-TW': 'byq',
        'byq-TW': 'byq',
        'byq-Zyyy': 'byq',
        'byr': 'byr',
        'byr-Latn-PG': 'byr',
        'byr-Latn': 'byr',
        'byr-PG': 'byr',
        'bys': 'bys',
        'bys-Latn-NG': 'bys',
        'bys-Latn': 'bys',
        'bys-NG': 'bys',
        'byt': 'byt',
        'byt-Zyyy-SD': 'byt',
        'byt-SD': 'byt',
        'byt-Zyyy': 'byt',
        'byv': 'byv',
        'byv-Latn-CM': 'byv',
        'byv-CM': 'byv',
        'byv-Latn': 'byv',
        'byw': 'byw',
        'byw-Deva-NP': 'byw',
        'byw-Deva': 'byw',
        'byw-NP': 'byw',
        'byx': 'byx',
        'byx-Latn-PG': 'byx',
        'byx-Latn': 'byx',
        'byx-PG': 'byx',
        'byz': 'byz',
        'byz-Latn-PG': 'byz',
        'byz-Latn': 'byz',
        'byz-PG': 'byz',
        'bza': 'bza',
        'bza-Latn-LR': 'bza',
        'bza-LR': 'bza',
        'bza-Latn': 'bza',
        'bzb': 'bzb',
        'bzb-Latn-ID': 'bzb',
        'bzb-ID': 'bzb',
        'bzb-Latn': 'bzb',
        'bzc': 'bzc',
        'bzc-Latn-MG': 'bzc',
        'bzc-Latn': 'bzc',
        'bzc-MG': 'bzc',
        'bzd': 'bzd',
        'bzd-Latn-CR': 'bzd',
        'bzd-CR': 'bzd',
        'bzd-Latn': 'bzd',
        'bze': 'bze',
        'bze-Latn-ML': 'bze',
        'bze-Latn': 'bze',
        'bze-ML': 'bze',
        'bze-Arab': 'bze-Arab',
        'bze-Arab-ML': 'bze-Arab',
        'bzf': 'bzf',
        'bzf-Latn-PG': 'bzf',
        'bzf-Latn': 'bzf',
        'bzf-PG': 'bzf',
        'bzg': 'bzg',
        'bzg-Zyyy-TW': 'bzg',
        'bzg-TW': 'bzg',
        'bzg-Zyyy': 'bzg',
        'bzh': 'bzh',
        'bzh-Latn-PG': 'bzh',
        'bzh-Latn': 'bzh',
        'bzh-PG': 'bzh',
        'bzi': 'bzi',
        'bzi-Thai-TH': 'bzi',
        'bzi-TH': 'bzi',
        'bzi-Thai': 'bzi',
        'bzj': 'bzj',
        'bzj-Latn-BZ': 'bzj',
        'bzj-BZ': 'bzj',
        'bzj-Latn': 'bzj',
        'bzk': 'bzk',
        'bzk-Latn-NI': 'bzk',
        'bzk-Latn': 'bzk',
        'bzk-NI': 'bzk',
        'bzl': 'bzl',
        'bzl-Latn-ID': 'bzl',
        'bzl-ID': 'bzl',
        'bzl-Latn': 'bzl',
        'bzm': 'bzm',
        'bzm-Latn-CD': 'bzm',
        'bzm-CD': 'bzm',
        'bzm-Latn': 'bzm',
        'bzn': 'bzn',
        'bzn-Latn-ID': 'bzn',
        'bzn-ID': 'bzn',
        'bzn-Latn': 'bzn',
        'bzo': 'bzo',
        'bzo-Latn-CD': 'bzo',
        'bzo-CD': 'bzo',
        'bzo-Latn': 'bzo',
        'bzp': 'bzp',
        'bzp-Latn-ID': 'bzp',
        'bzp-ID': 'bzp',
        'bzp-Latn': 'bzp',
        'bzq': 'bzq',
        'bzq-Latn-ID': 'bzq',
        'bzq-ID': 'bzq',
        'bzq-Latn': 'bzq',
        'bzr': 'bzr',
        'bzr-Latn-AU': 'bzr',
        'bzr-AU': 'bzr',
        'bzr-Latn': 'bzr',
        'bzs': 'bzs',
        'bzs-Zxxx-BR': 'bzs',
        'bzs-BR': 'bzs',
        'bzs-Zxxx': 'bzs',
        'sgn-bzs': 'bzs',
        'sgn-bzs-BR': 'bzs',
        'bzt': 'bzt',
        'bzt-Zyyy-001': 'bzt',
        'bzt-001': 'bzt',
        'bzt-Zyyy': 'bzt',
        'bzu': 'bzu',
        'bzu-Latn-ID': 'bzu',
        'bzu-ID': 'bzu',
        'bzu-Latn': 'bzu',
        'bzv': 'bzv',
        'bzv-Latn-CM': 'bzv',
        'bzv-CM': 'bzv',
        'bzv-Latn': 'bzv',
        'bzw': 'bzw',
        'bzw-Latn-NG': 'bzw',
        'bzw-Latn': 'bzw',
        'bzw-NG': 'bzw',
        'bzx': 'bzx',
        'bzx-Latn-ML': 'bzx',
        'bzx-Latn': 'bzx',
        'bzx-ML': 'bzx',
        'bzy': 'bzy',
        'bzy-Latn-NG': 'bzy',
        'bzy-Latn': 'bzy',
        'bzy-NG': 'bzy',
        'bzz': 'bzz',
        'bzz-Latn-NG': 'bzz',
        'bzz-Latn': 'bzz',
        'bzz-NG': 'bzz',
        'ca': 'ca',
        'ca-Latn-ES': 'ca',
        'ca-ES': 'ca',
        'ca-Latn': 'ca',
        'ca-FR': 'ca-FR',
        'ca-Latn-FR': 'ca-FR',
        'ca-valencia': 'ca-valencia',
        'ca-Latn-ES-valencia': 'ca-valencia',
        'ca-ES-valencia': 'ca-valencia',
        'ca-Latn-valencia': 'ca-valencia',
        'caa': 'caa',
        'caa-Latn-GT': 'caa',
        'caa-GT': 'caa',
        'caa-Latn': 'caa',
        'cab': 'cab',
        'cab-Latn-HN': 'cab',
        'cab-HN': 'cab',
        'cab-Latn': 'cab',
        'cac': 'cac',
        'cac-Latn-GT': 'cac',
        'cac-GT': 'cac',
        'cac-Latn': 'cac',
        'cad': 'cad',
        'cad-Latn-US': 'cad',
        'cad-Latn': 'cad',
        'cad-US': 'cad',
        'cae': 'cae',
        'cae-Latn-SN': 'cae',
        'cae-Latn': 'cae',
        'cae-SN': 'cae',
        'caf': 'caf',
        'caf-Latn-CA': 'caf',
        'caf-CA': 'caf',
        'caf-Latn': 'caf',
        'caf-Cans': 'caf-Cans',
        'caf-Cans-CA': 'caf-Cans',
        'cag': 'cag',
        'cag-Latn-PY': 'cag',
        'cag-Latn': 'cag',
        'cag-PY': 'cag',
        'cah': 'cah',
        'cah-Latn-PE': 'cah',
        'cah-Latn': 'cah',
        'cah-PE': 'cah',
        'caj': 'caj',
        'caj-Latn-AR': 'caj',
        'caj-AR': 'caj',
        'caj-Latn': 'caj',
        'cak': 'cak',
        'cak-Latn-GT': 'cak',
        'cak-GT': 'cak',
        'cak-Latn': 'cak',
        'cal': 'cal',
        'cal-Latn-MP': 'cal',
        'cal-Latn': 'cal',
        'cal-MP': 'cal',
        'cam': 'cam',
        'cam-Latn-NC': 'cam',
        'cam-Latn': 'cam',
        'cam-NC': 'cam',
        'can': 'can',
        'can-Latn-PG': 'can',
        'can-Latn': 'can',
        'can-PG': 'can',
        'cao': 'cao',
        'cao-Latn-BO': 'cao',
        'cao-BO': 'cao',
        'cao-Latn': 'cao',
        'cap': 'cap',
        'cap-Latn-BO': 'cap',
        'cap-BO': 'cap',
        'cap-Latn': 'cap',
        'caq': 'caq',
        'caq-Latn-IN': 'caq',
        'caq-IN': 'caq',
        'caq-Latn': 'caq',
        'car': 'car',
        'car-Latn-VE': 'car',
        'car-Latn': 'car',
        'car-VE': 'car',
        'cas': 'cas',
        'cas-Latn-BO': 'cas',
        'cas-BO': 'cas',
        'cas-Latn': 'cas',
        'cav': 'cav',
        'cav-Latn-BO': 'cav',
        'cav-BO': 'cav',
        'cav-Latn': 'cav',
        'caw': 'caw',
        'caw-Latn-BO': 'caw',
        'caw-BO': 'caw',
        'caw-Latn': 'caw',
        'cax': 'cax',
        'cax-Latn-BO': 'cax',
        'cax-BO': 'cax',
        'cax-Latn': 'cax',
        'xba': 'cax',
        'xba-BO': 'cax',
        'xba-Latn': 'cax',
        'xba-Latn-BO': 'cax',
        'cay': 'cay',
        'cay-Latn-CA': 'cay',
        'cay-CA': 'cay',
        'cay-Latn': 'cay',
        'caz': 'caz',
        'caz-Latn-BO': 'caz',
        'caz-BO': 'caz',
        'caz-Latn': 'caz',
        'cbb': 'cbb',
        'cbb-Latn-CO': 'cbb',
        'cbb-CO': 'cbb',
        'cbb-Latn': 'cbb',
        'cbc': 'cbc',
        'cbc-Latn-CO': 'cbc',
        'cbc-CO': 'cbc',
        'cbc-Latn': 'cbc',
        'cbd': 'cbd',
        'cbd-Latn-CO': 'cbd',
        'cbd-CO': 'cbd',
        'cbd-Latn': 'cbd',
        'cbg': 'cbg',
        'cbg-Latn-CO': 'cbg',
        'cbg-CO': 'cbg',
        'cbg-Latn': 'cbg',
        'cbi': 'cbi',
        'cbi-Latn-EC': 'cbi',
        'cbi-EC': 'cbi',
        'cbi-Latn': 'cbi',
        'cbj': 'cbj',
        'cbj-Latn-BJ': 'cbj',
        'cbj-BJ': 'cbj',
        'cbj-Latn': 'cbj',
        'cbk': 'cbk',
        'cbk-Latn-PH': 'cbk',
        'cbk-Latn': 'cbk',
        'cbk-PH': 'cbk',
        'cbk-Brai': 'cbk-Brai',
        'cbk-Brai-PH': 'cbk-Brai',
        'cbl': 'cbl',
        'cbl-Latn-MM': 'cbl',
        'cbl-Latn': 'cbl',
        'cbl-MM': 'cbl',
        'cbn': 'cbn',
        'cbn-Thai-TH': 'cbn',
        'cbn-TH': 'cbn',
        'cbn-Thai': 'cbn',
        'cbo': 'cbo',
        'cbo-Latn-NG': 'cbo',
        'cbo-Latn': 'cbo',
        'cbo-NG': 'cbo',
        'cbq': 'cbq',
        'cbq-Latn-NG': 'cbq',
        'cbq-Latn': 'cbq',
        'cbq-NG': 'cbq',
        'cbr': 'cbr',
        'cbr-Latn-PE': 'cbr',
        'cbr-Latn': 'cbr',
        'cbr-PE': 'cbr',
        'cbs': 'cbs',
        'cbs-Latn-PE': 'cbs',
        'cbs-Latn': 'cbs',
        'cbs-PE': 'cbs',
        'cbt': 'cbt',
        'cbt-Latn-PE': 'cbt',
        'cbt-Latn': 'cbt',
        'cbt-PE': 'cbt',
        'cbu': 'cbu',
        'cbu-Latn-PE': 'cbu',
        'cbu-Latn': 'cbu',
        'cbu-PE': 'cbu',
        'cbv': 'cbv',
        'cbv-Latn-CO': 'cbv',
        'cbv-CO': 'cbv',
        'cbv-Latn': 'cbv',
        'cbw': 'cbw',
        'cbw-Latn-PH': 'cbw',
        'cbw-Latn': 'cbw',
        'cbw-PH': 'cbw',
        'cby': 'cby',
        'cby-Latn-CO': 'cby',
        'cby-CO': 'cby',
        'cby-Latn': 'cby',
        'cca': 'cca',
        'cca-Latn-CO': 'cca',
        'cca-CO': 'cca',
        'cca-Latn': 'cca',
        'ccc': 'ccc',
        'ccc-Latn-PE': 'ccc',
        'ccc-Latn': 'ccc',
        'ccc-PE': 'ccc',
        'ccd': 'ccd',
        'ccd-Latn-BR': 'ccd',
        'ccd-BR': 'ccd',
        'ccd-Latn': 'ccd',
        'cce': 'cce',
        'cce-Latn-MZ': 'cce',
        'cce-Latn': 'cce',
        'cce-MZ': 'cce',
        'ccg': 'ccg',
        'ccg-Latn-NG': 'ccg',
        'ccg-Latn': 'ccg',
        'ccg-NG': 'ccg',
        'cch': 'cch',
        'cch-Latn-NG': 'cch',
        'cch-Latn': 'cch',
        'cch-NG': 'cch',
        'ccj': 'ccj',
        'ccj-Latn-GW': 'ccj',
        'ccj-GW': 'ccj',
        'ccj-Latn': 'ccj',
        'ccl': 'ccl',
        'ccl-Latn-TZ': 'ccl',
        'ccl-Latn': 'ccl',
        'ccl-TZ': 'ccl',
        'ccm': 'ccm',
        'ccm-Latn-MY': 'ccm',
        'ccm-Latn': 'ccm',
        'ccm-MY': 'ccm',
        'cco': 'cco',
        'cco-Latn-MX': 'cco',
        'cco-Latn': 'cco',
        'cco-MX': 'cco',
        'ccp': 'ccp',
        'ccp-Cakm-BD': 'ccp',
        'ccp-BD': 'ccp',
        'ccp-Cakm': 'ccp',
        'ccp-Beng': 'ccp-Beng',
        'ccp-Beng-IN': 'ccp-Beng',
        'ccp-IN': 'ccp-Beng',
        'ccp-Latn': 'ccp-Latn',
        'ccp-Latn-BD': 'ccp-Latn',
        'ccr': 'ccr',
        'ccr-Latn-SV': 'ccr',
        'ccr-Latn': 'ccr',
        'ccr-SV': 'ccr',
        'cda': 'cda',
        'cda-Zyyy-CN': 'cda',
        'cda-CN': 'cda',
        'cda-Zyyy': 'cda',
        'cde': 'cde',
        'cde-Telu-IN': 'cde',
        'cde-IN': 'cde',
        'cde-Telu': 'cde',
        'cdf': 'cdf',
        'cdf-Latn-IN': 'cdf',
        'cdf-IN': 'cdf',
        'cdf-Latn': 'cdf',
        'cdf-Beng': 'cdf-Beng',
        'cdf-Beng-IN': 'cdf-Beng',
        'cdg': 'cdg',
        'cdg-Zyyy-IN': 'cdg',
        'cdg-IN': 'cdg',
        'cdg-Zyyy': 'cdg',
        'cdh': 'cdh',
        'cdh-Deva-IN': 'cdh',
        'cdh-Deva': 'cdh',
        'cdh-IN': 'cdh',
        'cdh-Takr': 'cdh-Takr',
        'cdh-Takr-IN': 'cdh-Takr',
        'cdi': 'cdi',
        'cdi-Gujr-IN': 'cdi',
        'cdi-Gujr': 'cdi',
        'cdi-IN': 'cdi',
        'cdj': 'cdj',
        'cdj-Deva-IN': 'cdj',
        'cdj-Deva': 'cdj',
        'cdj-IN': 'cdj',
        'cdm': 'cdm',
        'cdm-Deva-NP': 'cdm',
        'cdm-Deva': 'cdm',
        'cdm-NP': 'cdm',
        'cdm-Latn': 'cdm-Latn',
        'cdm-Latn-NP': 'cdm-Latn',
        'cdn': 'cdn',
        'cdn-Zyyy-IN': 'cdn',
        'cdn-IN': 'cdn',
        'cdn-Zyyy': 'cdn',
        'cdo-Hans': 'cdo-Hans',
        'cdo-Hans-CN': 'cdo-Hans',
        'cdo-Hant': 'cdo-Hant',
        'cdo-Hant-CN': 'cdo-Hant',
        'cdo-Latn': 'cdo-Latn',
        'cdo-Latn-CN': 'cdo-Latn',
        'cdr': 'cdr',
        'cdr-Latn-NG': 'cdr',
        'cdr-Latn': 'cdr',
        'cdr-NG': 'cdr',
        'cds': 'cds',
        'cds-Zxxx-TD': 'cds',
        'cds-TD': 'cds',
        'cds-Zxxx': 'cds',
        'sgn-cds': 'cds',
        'sgn-cds-TD': 'cds',
        'cdy': 'cdy',
        'cdy-Zyyy-CN': 'cdy',
        'cdy-CN': 'cdy',
        'cdy-Zyyy': 'cdy',
        'cdz': 'cdz',
        'cdz-Beng-IN': 'cdz',
        'cdz-Beng': 'cdz',
        'cdz-IN': 'cdz',
        'ce': 'ce',
        'ce-Cyrl-RU': 'ce',
        'ce-Cyrl': 'ce',
        'ce-RU': 'ce',
        'ce-Arab': 'ce-Arab',
        'ce-Arab-RU': 'ce-Arab',
        'ce-Latn': 'ce-Latn',
        'ce-Latn-RU': 'ce-Latn',
        'cea': 'cea',
        'cea-Zyyy-US': 'cea',
        'cea-US': 'cea',
        'cea-Zyyy': 'cea',
        'ceb': 'ceb',
        'ceb-Latn-PH': 'ceb',
        'ceb-Latn': 'ceb',
        'ceb-PH': 'ceb',
        'ceb-Brai': 'ceb-Brai',
        'ceb-Brai-PH': 'ceb-Brai',
        'ceg': 'ceg',
        'ceg-Latn-PY': 'ceg',
        'ceg-Latn': 'ceg',
        'ceg-PY': 'ceg',
        'cek': 'cek',
        'cek-Latn-MM': 'cek',
        'cek-Latn': 'cek',
        'cek-MM': 'cek',
        'cek-x-asang': 'cek-x-asang',
        'cek-Latn-MM-x-asang': 'cek-x-asang',
        'cek-Latn-x-asang': 'cek-x-asang',
        'cek-MM-x-asang': 'cek-x-asang',
        'cek-x-hnise': 'cek-x-hnise',
        'cek-Latn-MM-x-hnise': 'cek-x-hnise',
        'cek-Latn-x-hnise': 'cek-x-hnise',
        'cek-MM-x-hnise': 'cek-x-hnise',
        'cek-x-kanise': 'cek-x-kanise',
        'cek-Latn-MM-x-kanise': 'cek-x-kanise',
        'cek-Latn-x-kanise': 'cek-x-kanise',
        'cek-MM-x-kanise': 'cek-x-kanise',
        'cek-x-khawngtu': 'cek-x-khawngtu',
        'cek-Latn-MM-x-khawngtu': 'cek-x-khawngtu',
        'cek-Latn-x-khawngtu': 'cek-x-khawngtu',
        'cek-MM-x-khawngtu': 'cek-x-khawngtu',
        'cek-x-khongtu': 'cek-x-khongtu',
        'cek-Latn-MM-x-khongtu': 'cek-x-khongtu',
        'cek-Latn-x-khongtu': 'cek-x-khongtu',
        'cek-MM-x-khongtu': 'cek-x-khongtu',
        'cek-x-lemi': 'cek-x-lemi',
        'cek-Latn-MM-x-lemi': 'cek-x-lemi',
        'cek-Latn-x-lemi': 'cek-x-lemi',
        'cek-MM-x-lemi': 'cek-x-lemi',
        'cek-x-likhy': 'cek-x-likhy',
        'cek-Latn-MM-x-likhy': 'cek-x-likhy',
        'cek-Latn-x-likhy': 'cek-x-likhy',
        'cek-MM-x-likhy': 'cek-x-likhy',
        'cek-x-rengcaa': 'cek-x-rengcaa',
        'cek-Latn-MM-x-rengcaa': 'cek-x-rengcaa',
        'cek-Latn-x-rengcaa': 'cek-x-rengcaa',
        'cek-MM-x-rengcaa': 'cek-x-rengcaa',
        'cek-x-taaw': 'cek-x-taaw',
        'cek-Latn-MM-x-taaw': 'cek-x-taaw',
        'cek-Latn-x-taaw': 'cek-x-taaw',
        'cek-MM-x-taaw': 'cek-x-taaw',
        'cen': 'cen',
        'cen-Latn-NG': 'cen',
        'cen-Latn': 'cen',
        'cen-NG': 'cen',
        'cet': 'cet',
        'cet-Latn-NG': 'cet',
        'cet-Latn': 'cet',
        'cet-NG': 'cet',
        'cey': 'cey',
        'cey-Latn-MM': 'cey',
        'cey-Latn': 'cey',
        'cey-MM': 'cey',
        'cfa': 'cfa',
        'cfa-Latn-NG': 'cfa',
        'cfa-Latn': 'cfa',
        'cfa-NG': 'cfa',
        'cfd': 'cfd',
        'cfd-Latn-NG': 'cfd',
        'cfd-Latn': 'cfd',
        'cfd-NG': 'cfd',
        'cfg': 'cfg',
        'cfg-Latn-NG': 'cfg',
        'cfg-Latn': 'cfg',
        'cfg-NG': 'cfg',
        'cfm': 'cfm',
        'cfm-Latn-MM': 'cfm',
        'cfm-Latn': 'cfm',
        'cfm-MM': 'cfm',
        'cfm-Beng': 'cfm-Beng',
        'cfm-Beng-IN': 'cfm-Beng',
        'cfm-IN': 'cfm-Beng',
        'cfm-Latn-x-khuals': 'cfm-Latn-x-khuals',
        'cfm-Latn-MM-x-khuals': 'cfm-Latn-x-khuals',
        'cfm-MM-x-khuals': 'cfm-Latn-x-khuals',
        'cfm-Latn-x-lente': 'cfm-Latn-x-lente',
        'cfm-Latn-MM-x-lente': 'cfm-Latn-x-lente',
        'cfm-MM-x-lente': 'cfm-Latn-x-lente',
        'cfm-Latn-x-zannia': 'cfm-Latn-x-zannia',
        'cfm-Latn-MM-x-zannia': 'cfm-Latn-x-zannia',
        'cfm-MM-x-zannia': 'cfm-Latn-x-zannia',
        'cga': 'cga',
        'cga-Latn-PG': 'cga',
        'cga-Latn': 'cga',
        'cga-PG': 'cga',
        'cgc': 'cgc',
        'cgc-Latn-PH': 'cgc',
        'cgc-Latn': 'cgc',
        'cgc-PH': 'cgc',
        'cgg': 'cgg',
        'cgg-Latn-UG': 'cgg',
        'cgg-Latn': 'cgg',
        'cgg-UG': 'cgg',
        'cgk': 'cgk',
        'cgk-Zyyy-BT': 'cgk',
        'cgk-BT': 'cgk',
        'cgk-Zyyy': 'cgk',
        'ch': 'ch',
        'ch-Latn-GU': 'ch',
        'ch-GU': 'ch',
        'ch-Latn': 'ch',
        'chb': 'chb',
        'chb-Latn-CO': 'chb',
        'chb-CO': 'chb',
        'chb-Latn': 'chb',
        'chc': 'chc',
        'chc-Zyyy-US': 'chc',
        'chc-US': 'chc',
        'chc-Zyyy': 'chc',
        'chd': 'chd',
        'chd-Latn-MX': 'chd',
        'chd-Latn': 'chd',
        'chd-MX': 'chd',
        'chf': 'chf',
        'chf-Latn-MX': 'chf',
        'chf-Latn': 'chf',
        'chf-MX': 'chf',
        'chg': 'chg',
        'chg-Zyyy-TM': 'chg',
        'chg-TM': 'chg',
        'chg-Zyyy': 'chg',
        'chh': 'chh',
        'chh-Latn-US': 'chh',
        'chh-Latn': 'chh',
        'chh-US': 'chh',
        'chj': 'chj',
        'chj-Latn-MX': 'chj',
        'chj-Latn': 'chj',
        'chj-MX': 'chj',
        'chk': 'chk',
        'chk-Latn-FM': 'chk',
        'chk-FM': 'chk',
        'chk-Latn': 'chk',
        'chl': 'chl',
        'chl-Latn-US': 'chl',
        'chl-Latn': 'chl',
        'chl-US': 'chl',
        'chm': 'chm',
        'chm-Cyrl-RU': 'chm',
        'chm-Cyrl': 'chm',
        'chm-RU': 'chm',
        'mhr': 'chm',
        'mhr-Cyrl': 'chm',
        'mhr-Cyrl-RU': 'chm',
        'mhr-RU': 'chm',
        'chm-Latn': 'chm-Latn',
        'chm-Latn-RU': 'chm-Latn',
        'mhr-Latn': 'chm-Latn',
        'mhr-Latn-RU': 'chm-Latn',
        'chn': 'chn',
        'chn-Latn-US': 'chn',
        'chn-Latn': 'chn',
        'chn-US': 'chn',
        'chn-Dupl': 'chn-Dupl',
        'chn-Dupl-US': 'chn-Dupl',
        'cho': 'cho',
        'cho-Latn-US': 'cho',
        'cho-Latn': 'cho',
        'cho-US': 'cho',
        'chp': 'chp',
        'chp-Latn-CA': 'chp',
        'chp-CA': 'chp',
        'chp-Latn': 'chp',
        'chp-Cans': 'chp-Cans',
        'chp-Cans-CA': 'chp-Cans',
        'chq': 'chq',
        'chq-Latn-MX': 'chq',
        'chq-Latn': 'chq',
        'chq-MX': 'chq',
        'chr': 'chr',
        'chr-Cher-US': 'chr',
        'chr-Cher': 'chr',
        'chr-US': 'chr',
        'chr-Latn': 'chr-Latn',
        'chr-Latn-US': 'chr-Latn',
        'cht': 'cht',
        'cht-Latn-PE': 'cht',
        'cht-Latn': 'cht',
        'cht-PE': 'cht',
        'chw': 'chw',
        'chw-Latn-MZ': 'chw',
        'chw-Latn': 'chw',
        'chw-MZ': 'chw',
        'chx': 'chx',
        'chx-Deva-NP': 'chx',
        'chx-Deva': 'chx',
        'chx-NP': 'chx',
        'chy': 'chy',
        'chy-Latn-US': 'chy',
        'chy-Latn': 'chy',
        'chy-US': 'chy',
        'chz': 'chz',
        'chz-Latn-MX': 'chz',
        'chz-Latn': 'chz',
        'chz-MX': 'chz',
        'cia': 'cia',
        'cia-Latn-ID': 'cia',
        'cia-ID': 'cia',
        'cia-Latn': 'cia',
        'cia-Arab': 'cia-Arab',
        'cia-Arab-ID': 'cia-Arab',
        'cia-Hang': 'cia-Hang',
        'cia-Hang-ID': 'cia-Hang',
        'cib': 'cib',
        'cib-Latn-BJ': 'cib',
        'cib-BJ': 'cib',
        'cib-Latn': 'cib',
        'cic': 'cic',
        'cic-Latn-US': 'cic',
        'cic-Latn': 'cic',
        'cic-US': 'cic',
        'cid': 'cid',
        'cid-Zyyy-US': 'cid',
        'cid-US': 'cid',
        'cid-Zyyy': 'cid',
        'cie': 'cie',
        'cie-Latn-NG': 'cie',
        'cie-Latn': 'cie',
        'cie-NG': 'cie',
        'cih': 'cih',
        'cih-Deva-IN': 'cih',
        'cih-Deva': 'cih',
        'cih-IN': 'cih',
        'cik': 'cik',
        'cik-Zyyy-IN': 'cik',
        'cik-IN': 'cik',
        'cik-Zyyy': 'cik',
        'cim': 'cim',
        'cim-Latn-IT': 'cim',
        'cim-IT': 'cim',
        'cim-Latn': 'cim',
        'cin': 'cin',
        'cin-Latn-BR': 'cin',
        'cin-BR': 'cin',
        'cin-Latn': 'cin',
        'cip': 'cip',
        'cip-Latn-MX': 'cip',
        'cip-Latn': 'cip',
        'cip-MX': 'cip',
        'cir': 'cir',
        'cir-Latn-NC': 'cir',
        'cir-Latn': 'cir',
        'cir-NC': 'cir',
        'meg': 'cir',
        'meg-Latn': 'cir',
        'meg-Latn-NC': 'cir',
        'meg-NC': 'cir',
        'ciw': 'ciw',
        'ciw-Latn-US': 'ciw',
        'ciw-Latn': 'ciw',
        'ciw-US': 'ciw',
        'ciw-Cans': 'ciw-Cans',
        'ciw-Cans-US': 'ciw-Cans',
        'ciy': 'ciy',
        'ciy-Latn-VE': 'ciy',
        'ciy-Latn': 'ciy',
        'ciy-VE': 'ciy',
        'cja': 'cja',
        'cja-Arab-KH': 'cja',
        'cja-Arab': 'cja',
        'cja-KH': 'cja',
        'cja-Cham': 'cja-Cham',
        'cja-Cham-KH': 'cja-Cham',
        'cja-Latn': 'cja-Latn',
        'cja-Latn-KH': 'cja-Latn',
        'cje': 'cje',
        'cje-Latn-VN': 'cje',
        'cje-Latn': 'cje',
        'cje-VN': 'cje',
        'cjh': 'cjh',
        'cjh-Zyyy-US': 'cjh',
        'cjh-US': 'cjh',
        'cjh-Zyyy': 'cjh',
        'cji': 'cji',
        'cji-Cyrl-RU': 'cji',
        'cji-Cyrl': 'cji',
        'cji-RU': 'cji',
        'cjk': 'cjk',
        'cjk-Latn-AO': 'cjk',
        'cjk-AO': 'cjk',
        'cjk-Latn': 'cjk',
        'cjm': 'cjm',
        'cjm-Cham-VN': 'cjm',
        'cjm-Cham': 'cjm',
        'cjm-VN': 'cjm',
        'cjm-Arab': 'cjm-Arab',
        'cjm-Arab-VN': 'cjm-Arab',
        'cjm-Latn': 'cjm-Latn',
        'cjm-Latn-VN': 'cjm-Latn',
        'cjn': 'cjn',
        'cjn-Latn-PG': 'cjn',
        'cjn-Latn': 'cjn',
        'cjn-PG': 'cjn',
        'cjo': 'cjo',
        'cjo-Latn-PE': 'cjo',
        'cjo-Latn': 'cjo',
        'cjo-PE': 'cjo',
        'cjp': 'cjp',
        'cjp-Latn-CR': 'cjp',
        'cjp-CR': 'cjp',
        'cjp-Latn': 'cjp',
        'cjs': 'cjs',
        'cjs-Latn-RU': 'cjs',
        'cjs-Latn': 'cjs',
        'cjs-RU': 'cjs',
        'cjs-Cyrl': 'cjs-Cyrl',
        'cjs-Cyrl-RU': 'cjs-Cyrl',
        'cjv': 'cjv',
        'cjv-Latn-PG': 'cjv',
        'cjv-Latn': 'cjv',
        'cjv-PG': 'cjv',
        'cjy-Hans': 'cjy-Hans',
        'cjy-Hans-CN': 'cjy-Hans',
        'cjy-Hant': 'cjy-Hant',
        'cjy-Hant-CN': 'cjy-Hant',
        'ckb': 'ckb',
        'ckb-Arab-IQ': 'ckb',
        'ckb-Arab': 'ckb',
        'ckb-IQ': 'ckb',
        'ckb-IR': 'ckb-IR',
        'ckb-Arab-IR': 'ckb-IR',
        'ckb-Latn': 'ckb-Latn',
        'ckb-Latn-IQ': 'ckb-Latn',
        'ckh': 'ckh',
        'ckh-Zyyy-BD': 'ckh',
        'ckh-BD': 'ckh',
        'ckh-Zyyy': 'ckh',
        'ckl': 'ckl',
        'ckl-Latn-NG': 'ckl',
        'ckl-Latn': 'ckl',
        'ckl-NG': 'ckl',
        'ckm': 'ckm',
        'ckm-Latn-HR': 'ckm',
        'ckm-HR': 'ckm',
        'ckm-Latn': 'ckm',
        'ckm-Glag': 'ckm-Glag',
        'ckm-Glag-HR': 'ckm-Glag',
        'ckn': 'ckn',
        'ckn-Latn-MM': 'ckn',
        'ckn-Latn': 'ckn',
        'ckn-MM': 'ckn',
        'cko': 'cko',
        'cko-Latn-GH': 'cko',
        'cko-GH': 'cko',
        'cko-Latn': 'cko',
        'ckq': 'ckq',
        'ckq-Latn-TD': 'ckq',
        'ckq-Latn': 'ckq',
        'ckq-TD': 'ckq',
        'ckr': 'ckr',
        'ckr-Latn-PG': 'ckr',
        'ckr-Latn': 'ckr',
        'ckr-PG': 'ckr',
        'cks': 'cks',
        'cks-Latn-NC': 'cks',
        'cks-Latn': 'cks',
        'cks-NC': 'cks',
        'ckt': 'ckt',
        'ckt-Cyrl-RU': 'ckt',
        'ckt-Cyrl': 'ckt',
        'ckt-RU': 'ckt',
        'cku': 'cku',
        'cku-Latn-US': 'cku',
        'cku-Latn': 'cku',
        'cku-US': 'cku',
        'ckv': 'ckv',
        'ckv-Latn-TW': 'ckv',
        'ckv-Latn': 'ckv',
        'ckv-TW': 'ckv',
        'ckx': 'ckx',
        'ckx-Latn-CM': 'ckx',
        'ckx-CM': 'ckx',
        'ckx-Latn': 'ckx',
        'cky': 'cky',
        'cky-Latn-NG': 'cky',
        'cky-Latn': 'cky',
        'cky-NG': 'cky',
        'ckz': 'ckz',
        'ckz-Latn-GT': 'ckz',
        'ckz-GT': 'ckz',
        'ckz-Latn': 'ckz',
        'cla': 'cla',
        'cla-Latn-NG': 'cla',
        'cla-Latn': 'cla',
        'cla-NG': 'cla',
        'clc': 'clc',
        'clc-Latn-CA': 'clc',
        'clc-CA': 'clc',
        'clc-Latn': 'clc',
        'cle': 'cle',
        'cle-Latn-MX': 'cle',
        'cle-Latn': 'cle',
        'cle-MX': 'cle',
        'clh': 'clh',
        'clh-Arab-PK': 'clh',
        'clh-Arab': 'clh',
        'clh-PK': 'clh',
        'cli': 'cli',
        'cli-Latn-GH': 'cli',
        'cli-GH': 'cli',
        'cli-Latn': 'cli',
        'clj': 'clj',
        'clj-Latn-MM': 'clj',
        'clj-Latn': 'clj',
        'clj-MM': 'clj',
        'clk': 'clk',
        'clk-Latn-IN': 'clk',
        'clk-IN': 'clk',
        'clk-Latn': 'clk',
        'clk-Tibt': 'clk-Tibt',
        'clk-Tibt-CN': 'clk-Tibt',
        'clk-CN': 'clk-Tibt',
        'cll': 'cll',
        'cll-Latn-GH': 'cll',
        'cll-GH': 'cll',
        'cll-Latn': 'cll',
        'clm': 'clm',
        'clm-Latn-US': 'clm',
        'clm-Latn': 'clm',
        'clm-US': 'clm',
        'clo': 'clo',
        'clo-Latn-MX': 'clo',
        'clo-Latn': 'clo',
        'clo-MX': 'clo',
        'clt': 'clt',
        'clt-Latn-MM': 'clt',
        'clt-Latn': 'clt',
        'clt-MM': 'clt',
        'clu': 'clu',
        'clu-Latn-PH': 'clu',
        'clu-Latn': 'clu',
        'clu-PH': 'clu',
        'clw': 'clw',
        'clw-Cyrl-RU': 'clw',
        'clw-Cyrl': 'clw',
        'clw-RU': 'clw',
        'cly': 'cly',
        'cly-Latn-MX': 'cly',
        'cly-Latn': 'cly',
        'cly-MX': 'cly',
        'cma': 'cma',
        'cma-Latn-VN': 'cma',
        'cma-Latn': 'cma',
        'cma-VN': 'cma',
        'cme': 'cme',
        'cme-Latn-BF': 'cme',
        'cme-BF': 'cme',
        'cme-Latn': 'cme',
        'cmg-Soyo': 'cmg-Soyo',
        'cmg-Soyo-MN': 'cmg-Soyo',
        'cmg-MN': 'cmg-Soyo',
        'cmi': 'cmi',
        'cmi-Latn-CO': 'cmi',
        'cmi-CO': 'cmi',
        'cmi-Latn': 'cmi',
        'cml': 'cml',
        'cml-Latn-ID': 'cml',
        'cml-ID': 'cml',
        'cml-Latn': 'cml',
        'cmm': 'cmm',
        'cmm-Zyyy-US': 'cmm',
        'cmm-US': 'cmm',
        'cmm-Zyyy': 'cmm',
        'cmo-Khmr': 'cmo-Khmr',
        'cmo-Khmr-KH': 'cmo-Khmr',
        'cmo-Latn': 'cmo-Latn',
        'cmo-Latn-VN': 'cmo-Latn',
        'cmo-VN': 'cmo-Latn',
        'cmo-Latn-KH': 'cmo-Latn-KH',
        'cmr': 'cmr',
        'cmr-Latn-MM': 'cmr',
        'cka': 'cmr',
        'cka-Latn': 'cmr',
        'cka-Latn-MM': 'cmr',
        'cka-MM': 'cmr',
        'cmr-Latn': 'cmr',
        'cmr-MM': 'cmr',
        'cms': 'cms',
        'cms-Latn-IT': 'cms',
        'cms-IT': 'cms',
        'cms-Latn': 'cms',
        'cmt': 'cmt',
        'cmt-Latn-ZA': 'cmt',
        'cmt-Latn': 'cmt',
        'cmt-ZA': 'cmt',
        'cna': 'cna',
        'cna-Tibt-IN': 'cna',
        'cna-IN': 'cna',
        'cna-Tibt': 'cna',
        'cnb': 'cnb',
        'cnb-Latn-MM': 'cnb',
        'cnb-Latn': 'cnb',
        'cnb-MM': 'cnb',
        'cnc': 'cnc',
        'cnc-Latn-VN': 'cnc',
        'cnc-Latn': 'cnc',
        'cnc-VN': 'cnc',
        'cng': 'cng',
        'cng-Latn-CN': 'cng',
        'cng-CN': 'cng',
        'cng-Latn': 'cng',
        'cnh': 'cnh',
        'cnh-Latn-MM': 'cnh',
        'cnh-Latn': 'cnh',
        'cnh-MM': 'cnh',
        'cni': 'cni',
        'cni-Latn-PE': 'cni',
        'cni-Latn': 'cni',
        'cni-PE': 'cni',
        'cnk': 'cnk',
        'cnk-Latn-MM': 'cnk',
        'cnk-Latn': 'cnk',
        'cnk-MM': 'cnk',
        'cnl': 'cnl',
        'cnl-Latn-MX': 'cnl',
        'cnl-Latn': 'cnl',
        'cnl-MX': 'cnl',
        'cno': 'cno',
        'cno-Zyyy-LA': 'cno',
        'cno-LA': 'cno',
        'cno-Zyyy': 'cno',
        'cnp-Hans': 'cnp-Hans',
        'cnp-Hans-CN': 'cnp-Hans',
        'cnp-Hant': 'cnp-Hant',
        'cnp-Hant-CN': 'cnp-Hant',
        'cnr': 'cnr',
        'cnr-Cyrl-ME': 'cnr',
        'cnr-Cyrl': 'cnr',
        'cnr-ME': 'cnr',
        'cnr-Latn': 'cnr-Latn',
        'cnr-Latn-ME': 'cnr-Latn',
        'cns': 'cns',
        'cns-Latn-ID': 'cns',
        'cns-ID': 'cns',
        'cns-Latn': 'cns',
        'cnt': 'cnt',
        'cnt-Latn-MX': 'cnt',
        'cnt-Latn': 'cnt',
        'cnt-MX': 'cnt',
        'cnu': 'cnu',
        'cnu-Zyyy-DZ': 'cnu',
        'cnu-DZ': 'cnu',
        'cnu-Zyyy': 'cnu',
        'cnw': 'cnw',
        'cnw-Latn-MM': 'cnw',
        'cnw-Latn': 'cnw',
        'cnw-MM': 'cnw',
        'cnx': 'cnx',
        'cnx-Latn-GB': 'cnx',
        'cnx-GB': 'cnx',
        'cnx-Latn': 'cnx',
        'co': 'co',
        'co-Latn-FR': 'co',
        'co-FR': 'co',
        'co-Latn': 'co',
        'coa': 'coa',
        'coa-Latn-AU': 'coa',
        'coa-AU': 'coa',
        'coa-Latn': 'coa',
        'ms-coa': 'coa',
        'ms-coa-AU': 'coa',
        'cob': 'cob',
        'cob-Latn-MX': 'cob',
        'cob-Latn': 'cob',
        'cob-MX': 'cob',
        'coc': 'coc',
        'coc-Latn-MX': 'coc',
        'coc-Latn': 'coc',
        'coc-MX': 'coc',
        'cod': 'cod',
        'cod-Latn-PE': 'cod',
        'cod-Latn': 'cod',
        'cod-PE': 'cod',
        'coe': 'coe',
        'coe-Latn-CO': 'coe',
        'coe-CO': 'coe',
        'coe-Latn': 'coe',
        'cof': 'cof',
        'cof-Latn-EC': 'cof',
        'cof-EC': 'cof',
        'cof-Latn': 'cof',
        'cog': 'cog',
        'cog-Thai-TH': 'cog',
        'cog-TH': 'cog',
        'cog-Thai': 'cog',
        'coh': 'coh',
        'coh-Latn-KE': 'coh',
        'coh-KE': 'coh',
        'coh-Latn': 'coh',
        'coj': 'coj',
        'coj-Latn-MX': 'coj',
        'coj-Latn': 'coj',
        'coj-MX': 'coj',
        'cok': 'cok',
        'cok-Latn-MX': 'cok',
        'cok-Latn': 'cok',
        'cok-MX': 'cok',
        'col': 'col',
        'col-Latn-US': 'col',
        'col-Latn': 'col',
        'col-US': 'col',
        'com': 'com',
        'com-Latn-US': 'com',
        'com-Latn': 'com',
        'com-US': 'com',
        'con': 'con',
        'con-Latn-EC': 'con',
        'con-EC': 'con',
        'con-Latn': 'con',
        'coo': 'coo',
        'coo-Latn-CA': 'coo',
        'coo-CA': 'coo',
        'coo-Latn': 'coo',
        'cop': 'cop',
        'cop-Copt-EG': 'cop',
        'cop-Copt': 'cop',
        'cop-EG': 'cop',
        'cop-Arab': 'cop-Arab',
        'cop-Arab-EG': 'cop-Arab',
        'cop-Grek': 'cop-Grek',
        'cop-Grek-EG': 'cop-Grek',
        'coq': 'coq',
        'coq-Zyyy-US': 'coq',
        'coq-US': 'coq',
        'coq-Zyyy': 'coq',
        'cot': 'cot',
        'cot-Latn-PE': 'cot',
        'cot-Latn': 'cot',
        'cot-PE': 'cot',
        'cou': 'cou',
        'cou-Latn-SN': 'cou',
        'cou-Latn': 'cou',
        'cou-SN': 'cou',
        'cov': 'cov',
        'cov-Zyyy-CN': 'cov',
        'cov-CN': 'cov',
        'cov-Zyyy': 'cov',
        'cow': 'cow',
        'cow-Zyyy-US': 'cow',
        'cow-US': 'cow',
        'cow-Zyyy': 'cow',
        'cox': 'cox',
        'cox-Latn-PE': 'cox',
        'cox-Latn': 'cox',
        'cox-PE': 'cox',
        'coz': 'coz',
        'coz-Latn-MX': 'coz',
        'coz-Latn': 'coz',
        'coz-MX': 'coz',
        'cpa': 'cpa',
        'cpa-Latn-MX': 'cpa',
        'cpa-Latn': 'cpa',
        'cpa-MX': 'cpa',
        'cpb': 'cpb',
        'cpb-Latn-PE': 'cpb',
        'cpb-Latn': 'cpb',
        'cpb-PE': 'cpb',
        'cpc': 'cpc',
        'cpc-Latn-PE': 'cpc',
        'cpc-Latn': 'cpc',
        'cpc-PE': 'cpc',
        'cpg': 'cpg',
        'cpg-Grek-GR': 'cpg',
        'cpg-GR': 'cpg',
        'cpg-Grek': 'cpg',
        'cpi': 'cpi',
        'cpi-Latn-NR': 'cpi',
        'cpi-Latn': 'cpi',
        'cpi-NR': 'cpi',
        'cpn': 'cpn',
        'cpn-Latn-GH': 'cpn',
        'cpn-GH': 'cpn',
        'cpn-Latn': 'cpn',
        'cpo': 'cpo',
        'cpo-Latn-BF': 'cpo',
        'cpo-BF': 'cpo',
        'cpo-Latn': 'cpo',
        'cps': 'cps',
        'cps-Latn-PH': 'cps',
        'cps-Latn': 'cps',
        'cps-PH': 'cps',
        'cpu': 'cpu',
        'cpu-Latn-PE': 'cpu',
        'cpu-Latn': 'cpu',
        'cpu-PE': 'cpu',
        'cpx': 'cpx',
        'cpx-Latn-CN': 'cpx',
        'cpx-CN': 'cpx',
        'cpx-Latn': 'cpx',
        'zh-cpx': 'cpx',
        'zh-cpx-CN': 'cpx',
        'cpy': 'cpy',
        'cpy-Latn-PE': 'cpy',
        'cpy-Latn': 'cpy',
        'cpy-PE': 'cpy',
        'cqd': 'cqd',
        'cqd-Latn-CN': 'cqd',
        'cqd-CN': 'cqd',
        'cqd-Latn': 'cqd',
        'cr': 'cr',
        'cr-Cans-CA': 'cr',
        'cr-CA': 'cr',
        'cr-Cans': 'cr',
        'cwd': 'cr',
        'cwd-CA': 'cr',
        'cwd-Cans': 'cr',
        'cwd-Cans-CA': 'cr',
        'cr-Latn': 'cr-Latn',
        'cr-Latn-CA': 'cr-Latn',
        'cwd-Latn': 'cr-Latn',
        'cwd-Latn-CA': 'cr-Latn',
        'cra': 'cra',
        'cra-Zyyy-ET': 'cra',
        'cra-ET': 'cra',
        'cra-Zyyy': 'cra',
        'crb': 'crb',
        'crb-Latn-VC': 'crb',
        'crb-Latn': 'crb',
        'crb-VC': 'crb',
        'crc': 'crc',
        'crc-Latn-VU': 'crc',
        'crc-Latn': 'crc',
        'crc-VU': 'crc',
        'crd': 'crd',
        'crd-Latn-US': 'crd',
        'crd-Latn': 'crd',
        'crd-US': 'crd',
        'crf': 'crf',
        'crf-Latn-CO': 'crf',
        'crf-CO': 'crf',
        'crf-Latn': 'crf',
        'crg': 'crg',
        'crg-Latn-US': 'crg',
        'crg-Latn': 'crg',
        'crg-US': 'crg',
        'crh': 'crh',
        'crh-Cyrl-UA': 'crh',
        'crh-Cyrl': 'crh',
        'crh-UA': 'crh',
        'crh-Arab': 'crh-Arab',
        'crh-Arab-UZ': 'crh-Arab',
        'crh-UZ': 'crh-Arab',
        'crh-Latn': 'crh-Latn',
        'crh-Latn-UA': 'crh-Latn',
        'cri': 'cri',
        'cri-Latn-ST': 'cri',
        'cri-Latn': 'cri',
        'cri-ST': 'cri',
        'crj': 'crj',
        'crj-Cans-CA': 'crj',
        'crj-CA': 'crj',
        'crj-Cans': 'crj',
        'crj-Latn': 'crj-Latn',
        'crj-Latn-CA': 'crj-Latn',
        'crk': 'crk',
        'crk-Cans-CA': 'crk',
        'crk-CA': 'crk',
        'crk-Cans': 'crk',
        'crk-Latn': 'crk-Latn',
        'crk-Latn-CA': 'crk-Latn',
        'crl': 'crl',
        'crl-Cans-CA': 'crl',
        'crl-CA': 'crl',
        'crl-Cans': 'crl',
        'crl-Latn': 'crl-Latn',
        'crl-Latn-CA': 'crl-Latn',
        'crm': 'crm',
        'crm-Cans-CA': 'crm',
        'crm-CA': 'crm',
        'crm-Cans': 'crm',
        'crn': 'crn',
        'crn-Latn-MX': 'crn',
        'crn-Latn': 'crn',
        'crn-MX': 'crn',
        'cro': 'cro',
        'cro-Latn-US': 'cro',
        'cro-Latn': 'cro',
        'cro-US': 'cro',
        'crq': 'crq',
        'crq-Latn-AR': 'crq',
        'crq-AR': 'crq',
        'crq-Latn': 'crq',
        'crr': 'crr',
        'crr-Zyyy-US': 'crr',
        'crr-US': 'crr',
        'crr-Zyyy': 'crr',
        'crs': 'crs',
        'crs-Latn-SC': 'crs',
        'crs-Latn': 'crs',
        'crs-SC': 'crs',
        'crt': 'crt',
        'crt-Latn-AR': 'crt',
        'crt-AR': 'crt',
        'crt-Latn': 'crt',
        'crv': 'crv',
        'crv-Zyyy-IN': 'crv',
        'crv-IN': 'crv',
        'crv-Zyyy': 'crv',
        'crw': 'crw',
        'crw-Latn-VN': 'crw',
        'crw-Latn': 'crw',
        'crw-VN': 'crw',
        'crx': 'crx',
        'crx-Latn-CA': 'crx',
        'crx-CA': 'crx',
        'crx-Latn': 'crx',
        'crx-Cans': 'crx-Cans',
        'crx-Cans-CA': 'crx-Cans',
        'cry': 'cry',
        'cry-Latn-NG': 'cry',
        'cry-Latn': 'cry',
        'cry-NG': 'cry',
        'crz': 'crz',
        'crz-Zyyy-US': 'crz',
        'crz-US': 'crz',
        'crz-Zyyy': 'crz',
        'cs': 'cs',
        'cs-Latn-CZ': 'cs',
        'cs-CZ': 'cs',
        'cs-Latn': 'cs',
        'cs-Brai': 'cs-Brai',
        'cs-Brai-CZ': 'cs-Brai',
        'csa': 'csa',
        'csa-Latn-MX': 'csa',
        'csa-Latn': 'csa',
        'csa-MX': 'csa',
        'csb': 'csb',
        'csb-Latn-PL': 'csb',
        'csb-Latn': 'csb',
        'csb-PL': 'csb',
        'csc': 'csc',
        'csc-Zxxx-ES': 'csc',
        'csc-ES': 'csc',
        'csc-Zxxx': 'csc',
        'sgn-csc': 'csc',
        'sgn-csc-ES': 'csc',
        'csd': 'csd',
        'csd-Zxxx-TH': 'csd',
        'csd-TH': 'csd',
        'csd-Zxxx': 'csd',
        'sgn-csd': 'csd',
        'sgn-csd-TH': 'csd',
        'cse': 'cse',
        'cse-Zxxx-CZ': 'cse',
        'cse-CZ': 'cse',
        'cse-Zxxx': 'cse',
        'sgn-cse': 'cse',
        'sgn-cse-CZ': 'cse',
        'csf': 'csf',
        'csf-Zxxx-CU': 'csf',
        'csf-CU': 'csf',
        'csf-Zxxx': 'csf',
        'sgn-csf': 'csf',
        'sgn-csf-CU': 'csf',
        'csg': 'csg',
        'csg-Zxxx-CL': 'csg',
        'csg-CL': 'csg',
        'csg-Zxxx': 'csg',
        'sgn-csg': 'csg',
        'sgn-csg-CL': 'csg',
        'csh': 'csh',
        'csh-Mymr-MM': 'csh',
        'csh-MM': 'csh',
        'csh-Mymr': 'csh',
        'csh-Latn': 'csh-Latn',
        'csh-Latn-MM': 'csh-Latn',
        'csi': 'csi',
        'csi-Zyyy-US': 'csi',
        'csi-US': 'csi',
        'csi-Zyyy': 'csi',
        'csj': 'csj',
        'csj-Latn-MM': 'csj',
        'csj-Latn': 'csj',
        'csj-MM': 'csj',
        'csk': 'csk',
        'csk-Latn-SN': 'csk',
        'csk-Latn': 'csk',
        'csk-SN': 'csk',
        'csl': 'csl',
        'csl-Zxxx-CN': 'csl',
        'csl-CN': 'csl',
        'csl-Zxxx': 'csl',
        'sgn-csl': 'csl',
        'sgn-csl-CN': 'csl',
        'csm': 'csm',
        'csm-Latn-US': 'csm',
        'csm-Latn': 'csm',
        'csm-US': 'csm',
        'csn': 'csn',
        'csn-Zxxx-CO': 'csn',
        'csn-CO': 'csn',
        'csn-Zxxx': 'csn',
        'sgn-csn': 'csn',
        'sgn-csn-CO': 'csn',
        'cso': 'cso',
        'cso-Latn-MX': 'cso',
        'cso-Latn': 'cso',
        'cso-MX': 'cso',
        'csp-Hans': 'csp-Hans',
        'csp-Hans-CN': 'csp-Hans',
        'csp-Hant': 'csp-Hant',
        'csp-Hant-CN': 'csp-Hant',
        'csq': 'csq',
        'csq-Zxxx-HR': 'csq',
        'csq-HR': 'csq',
        'csq-Zxxx': 'csq',
        'sgn-csq': 'csq',
        'sgn-csq-HR': 'csq',
        'csr': 'csr',
        'csr-Zxxx-CR': 'csr',
        'csr-CR': 'csr',
        'csr-Zxxx': 'csr',
        'sgn-csr': 'csr',
        'sgn-csr-CR': 'csr',
        'css': 'css',
        'css-Zyyy-US': 'css',
        'css-US': 'css',
        'css-Zyyy': 'css',
        'cst': 'cst',
        'cst-Latn-US': 'cst',
        'cst-Latn': 'cst',
        'cst-US': 'cst',
        'csv': 'csv',
        'csv-Latn-MM': 'csv',
        'csv-Latn': 'csv',
        'csv-MM': 'csv',
        'csw': 'csw',
        'csw-Cans-CA': 'csw',
        'csw-CA': 'csw',
        'csw-Cans': 'csw',
        'csy': 'csy',
        'csy-Latn-MM': 'csy',
        'csy-Latn': 'csy',
        'csy-MM': 'csy',
        'csz': 'csz',
        'csz-Latn-US': 'csz',
        'csz-Latn': 'csz',
        'csz-US': 'csz',
        'cta': 'cta',
        'cta-Latn-MX': 'cta',
        'cta-Latn': 'cta',
        'cta-MX': 'cta',
        'ctc': 'ctc',
        'ctc-Latn-US': 'ctc',
        'ctc-Latn': 'ctc',
        'ctc-US': 'ctc',
        'ctd': 'ctd',
        'ctd-Pauc-MM': 'ctd',
        'ctd-MM': 'ctd',
        'ctd-Pauc': 'ctd',
        'ctd-Latn': 'ctd-Latn',
        'ctd-Latn-MM': 'ctd-Latn',
        'cte': 'cte',
        'cte-Latn-MX': 'cte',
        'cte-Latn': 'cte',
        'cte-MX': 'cte',
        'ctg': 'ctg',
        'ctg-Beng-BD': 'ctg',
        'ctg-BD': 'ctg',
        'ctg-Beng': 'ctg',
        'ctg-Arab': 'ctg-Arab',
        'ctg-Arab-BD': 'ctg-Arab',
        'ctg-Latn': 'ctg-Latn',
        'ctg-Latn-BD': 'ctg-Latn',
        'cth': 'cth',
        'cth-Latn-MM': 'cth',
        'cth-Latn': 'cth',
        'cth-MM': 'cth',
        'ctl': 'ctl',
        'ctl-Latn-MX': 'ctl',
        'ctl-Latn': 'ctl',
        'ctl-MX': 'ctl',
        'ctm': 'ctm',
        'ctm-Zyyy-US': 'ctm',
        'ctm-US': 'ctm',
        'ctm-Zyyy': 'ctm',
        'ctn': 'ctn',
        'ctn-Deva-NP': 'ctn',
        'ctn-Deva': 'ctn',
        'ctn-NP': 'ctn',
        'cto': 'cto',
        'cto-Latn-CO': 'cto',
        'cto-CO': 'cto',
        'cto-Latn': 'cto',
        'ctp': 'ctp',
        'ctp-Latn-MX': 'ctp',
        'ctp-Latn': 'ctp',
        'ctp-MX': 'ctp',
        'cts': 'cts',
        'cts-Latn-PH': 'cts',
        'cts-Latn': 'cts',
        'cts-PH': 'cts',
        'ctt': 'ctt',
        'ctt-Taml-IN': 'ctt',
        'ctt-IN': 'ctt',
        'ctt-Taml': 'ctt',
        'ctu': 'ctu',
        'ctu-Latn-MX': 'ctu',
        'ctu-Latn': 'ctu',
        'ctu-MX': 'ctu',
        'ctu-x-tila': 'ctu-x-tila',
        'ctu-Latn-MX-x-tila': 'ctu-x-tila',
        'ctu-Latn-x-tila': 'ctu-x-tila',
        'ctu-MX-x-tila': 'ctu-x-tila',
        'ctu-x-tumbala': 'ctu-x-tumbala',
        'ctu-Latn-MX-x-tumbala': 'ctu-x-tumbala',
        'ctu-Latn-x-tumbala': 'ctu-x-tumbala',
        'ctu-MX-x-tumbala': 'ctu-x-tumbala',
        'ctz': 'ctz',
        'ctz-Latn-MX': 'ctz',
        'ctz-Latn': 'ctz',
        'ctz-MX': 'ctz',
        'cu': 'cu',
        'cu-Cyrl-RU': 'cu',
        'cu-Cyrl': 'cu',
        'cu-RU': 'cu',
        'cu-Cyrs': 'cu-Cyrs',
        'cu-Cyrs-RU': 'cu-Cyrs',
        'cu-Glag': 'cu-Glag',
        'cu-Glag-BG': 'cu-Glag',
        'cu-BG': 'cu-Glag',
        'cua': 'cua',
        'cua-Latn-VN': 'cua',
        'cua-Latn': 'cua',
        'cua-VN': 'cua',
        'cub': 'cub',
        'cub-Latn-CO': 'cub',
        'cub-CO': 'cub',
        'cub-Latn': 'cub',
        'cuc': 'cuc',
        'cuc-Latn-MX': 'cuc',
        'cuc-Latn': 'cuc',
        'cuc-MX': 'cuc',
        'cug': 'cug',
        'cug-Latn-CM': 'cug',
        'cug-CM': 'cug',
        'cug-Latn': 'cug',
        'cuh': 'cuh',
        'cuh-Latn-KE': 'cuh',
        'cuh-KE': 'cuh',
        'cuh-Latn': 'cuh',
        'cui': 'cui',
        'cui-Latn-CO': 'cui',
        'cui-CO': 'cui',
        'cui-Latn': 'cui',
        'cuj': 'cuj',
        'cuj-Latn-PE': 'cuj',
        'cuj-Latn': 'cuj',
        'cuj-PE': 'cuj',
        'cuk': 'cuk',
        'cuk-Latn-PA': 'cuk',
        'cuk-Latn': 'cuk',
        'cuk-PA': 'cuk',
        'cul': 'cul',
        'cul-Latn-BR': 'cul',
        'cul-BR': 'cul',
        'cul-Latn': 'cul',
        'cuo': 'cuo',
        'cuo-Latn-VE': 'cuo',
        'cuo-Latn': 'cuo',
        'cuo-VE': 'cuo',
        'cup': 'cup',
        'cup-Zyyy-US': 'cup',
        'cup-US': 'cup',
        'cup-Zyyy': 'cup',
        'cuq': 'cuq',
        'cuq-Zyyy-CN': 'cuq',
        'cuq-CN': 'cuq',
        'cuq-Zyyy': 'cuq',
        'cur': 'cur',
        'cur-Zyyy-NP': 'cur',
        'cur-NP': 'cur',
        'cur-Zyyy': 'cur',
        'cut': 'cut',
        'cut-Latn-MX': 'cut',
        'cut-Latn': 'cut',
        'cut-MX': 'cut',
        'cuu': 'cuu',
        'cuu-Lana-CN': 'cuu',
        'cuu-CN': 'cuu',
        'cuu-Lana': 'cuu',
        'cuv': 'cuv',
        'cuv-Latn-CM': 'cuv',
        'cuv-CM': 'cuv',
        'cuv-Latn': 'cuv',
        'cuw': 'cuw',
        'cuw-Zyyy-NP': 'cuw',
        'cuw-NP': 'cuw',
        'cuw-Zyyy': 'cuw',
        'cux': 'cux',
        'cux-Latn-MX': 'cux',
        'cux-Latn': 'cux',
        'cux-MX': 'cux',
        'cuy': 'cuy',
        'cuy-Latn-XX': 'cuy',
        'cuy-Latn': 'cuy',
        'cuy-XX': 'cuy',
        'cv': 'cv',
        'cv-Cyrl-RU': 'cv',
        'cv-Cyrl': 'cv',
        'cv-RU': 'cv',
        'cvg': 'cvg',
        'cvg-Latn-IN': 'cvg',
        'cvg-IN': 'cvg',
        'cvg-Latn': 'cvg',
        'cvg-Tibt': 'cvg-Tibt',
        'cvg-Tibt-IN': 'cvg-Tibt',
        'cvn': 'cvn',
        'cvn-Latn-MX': 'cvn',
        'cvn-Latn': 'cvn',
        'cvn-MX': 'cvn',
        'cwa': 'cwa',
        'cwa-Latn-TZ': 'cwa',
        'cwa-Latn': 'cwa',
        'cwa-TZ': 'cwa',
        'cwb': 'cwb',
        'cwb-Latn-MZ': 'cwb',
        'cwb-Latn': 'cwb',
        'cwb-MZ': 'cwb',
        'cwe': 'cwe',
        'cwe-Latn-TZ': 'cwe',
        'cwe-Latn': 'cwe',
        'cwe-TZ': 'cwe',
        'cwg': 'cwg',
        'cwg-Latn-MY': 'cwg',
        'cwg-Latn': 'cwg',
        'cwg-MY': 'cwg',
        'cwt': 'cwt',
        'cwt-Latn-SN': 'cwt',
        'cwt-Latn': 'cwt',
        'cwt-SN': 'cwt',
        'cy': 'cy',
        'cy-Latn-GB': 'cy',
        'cy-GB': 'cy',
        'cy-Latn': 'cy',
        'cy-Brai': 'cy-Brai',
        'cy-Brai-GB': 'cy-Brai',
        'cya': 'cya',
        'cya-Latn-MX': 'cya',
        'cya-Latn': 'cya',
        'cya-MX': 'cya',
        'cyb': 'cyb',
        'cyb-Latn-BO': 'cyb',
        'cyb-BO': 'cyb',
        'cyb-Latn': 'cyb',
        'cyo': 'cyo',
        'cyo-Latn-PH': 'cyo',
        'cyo-Latn': 'cyo',
        'cyo-PH': 'cyo',
        'czh-Hans': 'czh-Hans',
        'czh-Hans-CN': 'czh-Hans',
        'czh-Hant': 'czh-Hant',
        'czh-Hant-CN': 'czh-Hant',
        'czk': 'czk',
        'czk-Zyyy-CZ': 'czk',
        'czk-CZ': 'czk',
        'czk-Zyyy': 'czk',
        'czn': 'czn',
        'czn-Latn-MX': 'czn',
        'czn-Latn': 'czn',
        'czn-MX': 'czn',
        'czo': 'czo',
        'czo-Zyyy-CN': 'czo',
        'czo-CN': 'czo',
        'czo-Zyyy': 'czo',
        'zh-czo': 'czo',
        'zh-czo-CN': 'czo',
        'czt': 'czt',
        'czt-Latn-MM': 'czt',
        'czt-Latn': 'czt',
        'czt-MM': 'czt',
        'da': 'da',
        'da-Latn-DK': 'da',
        'da-DK': 'da',
        'da-Latn': 'da',
        'da-Brai': 'da-Brai',
        'da-Brai-DK': 'da-Brai',
        'daa': 'daa',
        'daa-Latn-TD': 'daa',
        'daa-Latn': 'daa',
        'daa-TD': 'daa',
        'dac': 'dac',
        'dac-Latn-PG': 'dac',
        'dac-Latn': 'dac',
        'dac-PG': 'dac',
        'dad': 'dad',
        'dad-Latn-PG': 'dad',
        'dad-Latn': 'dad',
        'dad-PG': 'dad',
        'dae': 'dae',
        'dae-Latn-CM': 'dae',
        'dae-CM': 'dae',
        'dae-Latn': 'dae',
        'dag': 'dag',
        'dag-Latn-GH': 'dag',
        'dag-GH': 'dag',
        'dag-Latn': 'dag',
        'dag-Arab': 'dag-Arab',
        'dag-Arab-GH': 'dag-Arab',
        'dah': 'dah',
        'dah-Latn-PG': 'dah',
        'dah-Latn': 'dah',
        'dah-PG': 'dah',
        'dai': 'dai',
        'dai-Latn-TD': 'dai',
        'dai-Latn': 'dai',
        'dai-TD': 'dai',
        'daj': 'daj',
        'daj-Latn-SD': 'daj',
        'daj-Latn': 'daj',
        'daj-SD': 'daj',
        'dak': 'dak',
        'dak-Latn-US': 'dak',
        'dak-Latn': 'dak',
        'dak-US': 'dak',
        'dal': 'dal',
        'dal-Latn-KE': 'dal',
        'dal-KE': 'dal',
        'dal-Latn': 'dal',
        'dam': 'dam',
        'dam-Latn-NG': 'dam',
        'dam-Latn': 'dam',
        'dam-NG': 'dam',
        'dao': 'dao',
        'dao-Latn-MM': 'dao',
        'dao-Latn': 'dao',
        'dao-MM': 'dao',
        'dao-x-khengdai': 'dao-x-khengdai',
        'dao-Latn-MM-x-khengdai': 'dao-x-khengdai',
        'dao-Latn-x-khengdai': 'dao-x-khengdai',
        'dao-MM-x-khengdai': 'dao-x-khengdai',
        'dao-x-matlic': 'dao-x-matlic',
        'dao-Latn-MM-x-matlic': 'dao-x-matlic',
        'dao-Latn-x-matlic': 'dao-x-matlic',
        'dao-MM-x-matlic': 'dao-x-matlic',
        'dao-x-mattui': 'dao-x-mattui',
        'dao-Latn-MM-x-mattui': 'dao-x-mattui',
        'dao-Latn-x-mattui': 'dao-x-mattui',
        'dao-MM-x-mattui': 'dao-x-mattui',
        'dao-x-yindu': 'dao-x-yindu',
        'dao-Latn-MM-x-yindu': 'dao-x-yindu',
        'dao-Latn-x-yindu': 'dao-x-yindu',
        'dao-MM-x-yindu': 'dao-x-yindu',
        'daq': 'daq',
        'daq-Deva-IN': 'daq',
        'daq-Deva': 'daq',
        'daq-IN': 'daq',
        'dar': 'dar',
        'dar-Cyrl-RU': 'dar',
        'dar-Cyrl': 'dar',
        'dar-RU': 'dar',
        'das': 'das',
        'das-Latn-CI': 'das',
        'das-CI': 'das',
        'das-Latn': 'das',
        'dau': 'dau',
        'dau-Latn-TD': 'dau',
        'dau-Latn': 'dau',
        'dau-TD': 'dau',
        'dav': 'dav',
        'dav-Latn-KE': 'dav',
        'dav-KE': 'dav',
        'dav-Latn': 'dav',
        'daw': 'daw',
        'daw-Latn-PH': 'daw',
        'daw-Latn': 'daw',
        'daw-PH': 'daw',
        'dax': 'dax',
        'dax-Latn-AU': 'dax',
        'dax-AU': 'dax',
        'dax-Latn': 'dax',
        'daz': 'daz',
        'daz-Latn-ID': 'daz',
        'daz-ID': 'daz',
        'daz-Latn': 'daz',
        'dba': 'dba',
        'dba-Latn-ML': 'dba',
        'dba-Latn': 'dba',
        'dba-ML': 'dba',
        'dbb': 'dbb',
        'dbb-Latn-NG': 'dbb',
        'dbb-Latn': 'dbb',
        'dbb-NG': 'dbb',
        'dbd': 'dbd',
        'dbd-Latn-NG': 'dbd',
        'dbd-Latn': 'dbd',
        'dbd-NG': 'dbd',
        'dbe': 'dbe',
        'dbe-Latn-ID': 'dbe',
        'dbe-ID': 'dbe',
        'dbe-Latn': 'dbe',
        'dbf': 'dbf',
        'dbf-Latn-ID': 'dbf',
        'dbf-ID': 'dbf',
        'dbf-Latn': 'dbf',
        'dbg': 'dbg',
        'dbg-Latn-ML': 'dbg',
        'dbg-Latn': 'dbg',
        'dbg-ML': 'dbg',
        'dbi': 'dbi',
        'dbi-Latn-NG': 'dbi',
        'dbi-Latn': 'dbi',
        'dbi-NG': 'dbi',
        'dbj': 'dbj',
        'dbj-Latn-MY': 'dbj',
        'dbj-Latn': 'dbj',
        'dbj-MY': 'dbj',
        'dbj-Arab': 'dbj-Arab',
        'dbj-Arab-MY': 'dbj-Arab',
        'dbl': 'dbl',
        'dbl-Latn-AU': 'dbl',
        'dbl-AU': 'dbl',
        'dbl-Latn': 'dbl',
        'dbm': 'dbm',
        'dbm-Latn-NG': 'dbm',
        'dbm-Latn': 'dbm',
        'dbm-NG': 'dbm',
        'dbn': 'dbn',
        'dbn-Latn-ID': 'dbn',
        'dbn-ID': 'dbn',
        'dbn-Latn': 'dbn',
        'dbo': 'dbo',
        'dbo-Latn-NG': 'dbo',
        'dbo-Latn': 'dbo',
        'dbo-NG': 'dbo',
        'dbp': 'dbp',
        'dbp-Latn-NG': 'dbp',
        'dbp-Latn': 'dbp',
        'dbp-NG': 'dbp',
        'dbq': 'dbq',
        'dbq-Latn-CM': 'dbq',
        'dbq-CM': 'dbq',
        'dbq-Latn': 'dbq',
        'dbr': 'dbr',
        'dbr-Zyyy-SO': 'dbr',
        'dbr-SO': 'dbr',
        'dbr-Zyyy': 'dbr',
        'dbt': 'dbt',
        'dbt-Latn-ML': 'dbt',
        'dbt-Latn': 'dbt',
        'dbt-ML': 'dbt',
        'dwl': 'dbt',
        'dwl-Latn': 'dbt',
        'dwl-Latn-ML': 'dbt',
        'dwl-ML': 'dbt',
        'dbu': 'dbu',
        'dbu-Latn-ML': 'dbu',
        'dbu-Latn': 'dbu',
        'dbu-ML': 'dbu',
        'dbv': 'dbv',
        'dbv-Latn-NG': 'dbv',
        'dbv-Latn': 'dbv',
        'dbv-NG': 'dbv',
        'dbw': 'dbw',
        'dbw-Latn-ML': 'dbw',
        'dbw-Latn': 'dbw',
        'dbw-ML': 'dbw',
        'dby': 'dby',
        'dby-Latn-PG': 'dby',
        'dby-Latn': 'dby',
        'dby-PG': 'dby',
        'dcc': 'dcc',
        'dcc-Arab-IN': 'dcc',
        'dcc-Arab': 'dcc',
        'dcc-IN': 'dcc',
        'dcc-Deva': 'dcc-Deva',
        'dcc-Deva-IN': 'dcc-Deva',
        'dcr': 'dcr',
        'dcr-Latn-VI': 'dcr',
        'dcr-Latn': 'dcr',
        'dcr-VI': 'dcr',
        'dda': 'dda',
        'dda-Latn-AU': 'dda',
        'dda-AU': 'dda',
        'dda-Latn': 'dda',
        'ddd': 'ddd',
        'ddd-Latn-SS': 'ddd',
        'ddd-Latn': 'ddd',
        'ddd-SS': 'ddd',
        'dde': 'dde',
        'dde-Latn-CG': 'dde',
        'dde-CG': 'dde',
        'dde-Latn': 'dde',
        'ddg': 'ddg',
        'ddg-Latn-TL': 'ddg',
        'ddg-Latn': 'ddg',
        'ddg-TL': 'ddg',
        'ddi': 'ddi',
        'ddi-Latn-PG': 'ddi',
        'ddi-Latn': 'ddi',
        'ddi-PG': 'ddi',
        'ddj': 'ddj',
        'ddj-Latn-AU': 'ddj',
        'ddj-AU': 'ddj',
        'ddj-Latn': 'ddj',
        'ddn': 'ddn',
        'ddn-Latn-BJ': 'ddn',
        'ddn-BJ': 'ddn',
        'ddn-Latn': 'ddn',
        'ddo': 'ddo',
        'ddo-Cyrl-RU': 'ddo',
        'ddo-Cyrl': 'ddo',
        'ddo-RU': 'ddo',
        'ddr': 'ddr',
        'ddr-Latn-AU': 'ddr',
        'ddr-AU': 'ddr',
        'ddr-Latn': 'ddr',
        'dds': 'dds',
        'dds-Latn-ML': 'dds',
        'dds-Latn': 'dds',
        'dds-ML': 'dds',
        'ddw': 'ddw',
        'ddw-Latn-ID': 'ddw',
        'ddw-ID': 'ddw',
        'ddw-Latn': 'ddw',
        'de': 'de',
        'de-Latn-DE': 'de',
        'de-DE': 'de',
        'de-Latn': 'de',
        'de-AT': 'de-AT',
        'de-Latn-AT': 'de-AT',
        'de-Brai': 'de-Brai',
        'de-Brai-DE': 'de-Brai',
        'de-CH': 'de-CH',
        'de-Latn-CH': 'de-CH',
        'de-Dupl': 'de-Dupl',
        'de-Dupl-DE': 'de-Dupl',
        'de-IT': 'de-IT',
        'de-Latn-IT': 'de-IT',
        'de-LI': 'de-LI',
        'de-Latn-LI': 'de-LI',
        'de-LU': 'de-LU',
        'de-Latn-LU': 'de-LU',
        'de-Latf': 'de-Latf',
        'de-Latf-DE': 'de-Latf',
        'de-Runr': 'de-Runr',
        'de-Runr-DE': 'de-Runr',
        'dec': 'dec',
        'dec-Latn-SD': 'dec',
        'dec-Latn': 'dec',
        'dec-SD': 'dec',
        'ded': 'ded',
        'ded-Latn-PG': 'ded',
        'ded-Latn': 'ded',
        'ded-PG': 'ded',
        'dee': 'dee',
        'dee-Latn-LR': 'dee',
        'dee-LR': 'dee',
        'dee-Latn': 'dee',
        'def': 'def',
        'def-Arab-IR': 'def',
        'def-Arab': 'def',
        'def-IR': 'def',
        'deg': 'deg',
        'deg-Latn-NG': 'deg',
        'deg-Latn': 'deg',
        'deg-NG': 'deg',
        'deh': 'deh',
        'deh-Arab-PK': 'deh',
        'deh-Arab': 'deh',
        'deh-PK': 'deh',
        'dei': 'dei',
        'dei-Latn-ID': 'dei',
        'dei-ID': 'dei',
        'dei-Latn': 'dei',
        'dek': 'dek',
        'dek-Latn-CM': 'dek',
        'dek-CM': 'dek',
        'dek-Latn': 'dek',
        'del': 'del',
        'del-Latn-US': 'del',
        'del-Latn': 'del',
        'del-US': 'del',
        'del-Latn-CA': 'del-Latn-CA',
        'umu': 'del-Latn-CA',
        'umu-CA': 'del-Latn-CA',
        'umu-Latn': 'del-Latn-CA',
        'umu-Latn-CA': 'del-Latn-CA',
        'dem': 'dem',
        'dem-Latn-ID': 'dem',
        'dem-ID': 'dem',
        'dem-Latn': 'dem',
        'den': 'den',
        'den-Latn-CA': 'den',
        'den-CA': 'den',
        'den-Latn': 'den',
        'xsl': 'den',
        'xsl-CA': 'den',
        'xsl-Latn': 'den',
        'xsl-Latn-CA': 'den',
        'den-Cans': 'den-Cans',
        'den-Cans-CA': 'den-Cans',
        'xsl-Cans': 'den-Cans',
        'xsl-Cans-CA': 'den-Cans',
        'dep': 'dep',
        'dep-Zyyy-US': 'dep',
        'dep-US': 'dep',
        'dep-Zyyy': 'dep',
        'deq': 'deq',
        'deq-Latn-CF': 'deq',
        'deq-CF': 'deq',
        'deq-Latn': 'deq',
        'der-Beng': 'der-Beng',
        'der-Beng-IN': 'der-Beng',
        'der-Latn': 'der-Latn',
        'der-Latn-IN': 'der-Latn',
        'des': 'des',
        'des-Latn-BR': 'des',
        'des-BR': 'des',
        'des-Latn': 'des',
        'dev': 'dev',
        'dev-Latn-PG': 'dev',
        'dev-Latn': 'dev',
        'dev-PG': 'dev',
        'gav': 'dev',
        'gav-Latn': 'dev',
        'gav-Latn-PG': 'dev',
        'gav-PG': 'dev',
        'dez': 'dez',
        'dez-Latn-CD': 'dez',
        'dez-CD': 'dez',
        'dez-Latn': 'dez',
        'dga': 'dga',
        'dga-Latn-GH': 'dga',
        'dga-GH': 'dga',
        'dga-Latn': 'dga',
        'dgb': 'dgb',
        'dgb-Latn-ML': 'dgb',
        'dgb-Latn': 'dgb',
        'dgb-ML': 'dgb',
        'dgc': 'dgc',
        'dgc-Latn-PH': 'dgc',
        'dgc-Latn': 'dgc',
        'dgc-PH': 'dgc',
        'dgd': 'dgd',
        'dgd-Latn-BF': 'dgd',
        'dgd-BF': 'dgd',
        'dgd-Latn': 'dgd',
        'dge': 'dge',
        'dge-Latn-PG': 'dge',
        'dge-Latn': 'dge',
        'dge-PG': 'dge',
        'dgg': 'dgg',
        'dgg-Latn-PG': 'dgg',
        'dgg-Latn': 'dgg',
        'dgg-PG': 'dgg',
        'dgh': 'dgh',
        'dgh-Latn-NG': 'dgh',
        'dgh-Latn': 'dgh',
        'dgh-NG': 'dgh',
        'dgi': 'dgi',
        'dgi-Latn-BF': 'dgi',
        'dgi-BF': 'dgi',
        'dgi-Latn': 'dgi',
        'dgk': 'dgk',
        'dgk-Latn-CF': 'dgk',
        'dgk-CF': 'dgk',
        'dgk-Latn': 'dgk',
        'dgl-Arab': 'dgl-Arab',
        'dgl-Arab-SD': 'dgl-Arab',
        'dgl-Copt': 'dgl-Copt',
        'dgl-Copt-SD-x-olnubian': 'dgl-Copt',
        'dgl-Copt-SD': 'dgl-Copt',
        'dgl-Copt-x-olnubian': 'dgl-Copt',
        'dgl-SD-x-olnubian': 'dgl-Copt',
        'dgl-Latn': 'dgl-Latn',
        'dgl-Latn-SD': 'dgl-Latn',
        'dgn': 'dgn',
        'dgn-Latn-AU': 'dgn',
        'dgn-AU': 'dgn',
        'dgn-Latn': 'dgn',
        'dgr': 'dgr',
        'dgr-Latn-CA': 'dgr',
        'dgr-CA': 'dgr',
        'dgr-Latn': 'dgr',
        'dgs': 'dgs',
        'dgs-Latn-BF': 'dgs',
        'dgs-BF': 'dgs',
        'dgs-Latn': 'dgs',
        'dgt': 'dgt',
        'dgt-Latn-AU': 'dgt',
        'dgt-AU': 'dgt',
        'dgt-Latn': 'dgt',
        'dgu': 'dgu',
        'dgu-Zyyy-IN': 'dgu',
        'dgu-IN': 'dgu',
        'dgu-Zyyy': 'dgu',
        'dgw': 'dgw',
        'dgw-Latn-AU': 'dgw',
        'dgw-AU': 'dgw',
        'dgw-Latn': 'dgw',
        'dgx': 'dgx',
        'dgx-Latn-PG': 'dgx',
        'dgx-Latn': 'dgx',
        'dgx-PG': 'dgx',
        'dgz': 'dgz',
        'dgz-Latn-PG': 'dgz',
        'dgz-Latn': 'dgz',
        'dgz-PG': 'dgz',
        'dhg': 'dhg',
        'dhg-Latn-AU': 'dhg',
        'dhg-AU': 'dhg',
        'dhg-Latn': 'dhg',
        'dhi': 'dhi',
        'dhi-Deva-NP': 'dhi',
        'dhi-Deva': 'dhi',
        'dhi-NP': 'dhi',
        'dhl': 'dhl',
        'dhl-Latn-AU': 'dhl',
        'dhl-AU': 'dhl',
        'dhl-Latn': 'dhl',
        'dhm': 'dhm',
        'dhm-Latn-AO': 'dhm',
        'dhm-AO': 'dhm',
        'dhm-Latn': 'dhm',
        'dhn': 'dhn',
        'dhn-Gujr-IN': 'dhn',
        'dhn-Gujr': 'dhn',
        'dhn-IN': 'dhn',
        'dho': 'dho',
        'dho-Deva-IN': 'dho',
        'dho-Deva': 'dho',
        'dho-IN': 'dho',
        'dhr': 'dhr',
        'dhr-Latn-AU': 'dhr',
        'dhr-AU': 'dhr',
        'dhr-Latn': 'dhr',
        'dhs': 'dhs',
        'dhs-Latn-TZ': 'dhs',
        'dhs-Latn': 'dhs',
        'dhs-TZ': 'dhs',
        'dhu': 'dhu',
        'dhu-Latn-AU': 'dhu',
        'dhu-AU': 'dhu',
        'dhu-Latn': 'dhu',
        'dhv': 'dhv',
        'dhv-Latn-NC': 'dhv',
        'dhv-Latn': 'dhv',
        'dhv-NC': 'dhv',
        'dhw': 'dhw',
        'dhw-Deva-NP': 'dhw',
        'dhw-Deva': 'dhw',
        'dhw-NP': 'dhw',
        'dhx': 'dhx',
        'dhx-Latn-AU': 'dhx',
        'dhx-AU': 'dhx',
        'dhx-Latn': 'dhx',
        'dia': 'dia',
        'dia-Latn-PG': 'dia',
        'dia-Latn': 'dia',
        'dia-PG': 'dia',
        'dib': 'dib',
        'dib-Latn-SS': 'dib',
        'dib-Latn': 'dib',
        'dib-SS': 'dib',
        'dic': 'dic',
        'dic-Latn-CI': 'dic',
        'dic-CI': 'dic',
        'dic-Latn': 'dic',
        'did': 'did',
        'did-Latn-SS': 'did',
        'did-Latn': 'did',
        'did-SS': 'did',
        'dif': 'dif',
        'dif-Latn-AU': 'dif',
        'dif-AU': 'dif',
        'dif-Latn': 'dif',
        'dit': 'dif',
        'dit-AU': 'dif',
        'dit-Latn': 'dif',
        'dit-Latn-AU': 'dif',
        'dig': 'dig',
        'dig-Latn-KE': 'dig',
        'dig-KE': 'dig',
        'dig-Latn': 'dig',
        'dih': 'dih',
        'dih-Latn-MX': 'dih',
        'dih-Latn': 'dih',
        'dih-MX': 'dih',
        'dii': 'dii',
        'dii-Latn-CM': 'dii',
        'dii-CM': 'dii',
        'dii-Latn': 'dii',
        'dij': 'dij',
        'dij-Latn-ID': 'dij',
        'dij-ID': 'dij',
        'dij-Latn': 'dij',
        'dik-Arab': 'dik-Arab',
        'dik-Arab-SS': 'dik-Arab',
        'dil': 'dil',
        'dil-Latn-SD': 'dil',
        'dil-Latn': 'dil',
        'dil-SD': 'dil',
        'dim': 'dim',
        'dim-Zyyy-ET': 'dim',
        'dim-ET': 'dim',
        'dim-Zyyy': 'dim',
        'din': 'din',
        'din-Latn-SS': 'din',
        'dik': 'din',
        'dik-Latn': 'din',
        'dik-Latn-SS': 'din',
        'dik-SS': 'din',
        'din-Latn': 'din',
        'din-SS': 'din',
        'din-Arab': 'din-Arab',
        'din-Arab-SS': 'din-Arab',
        'dio': 'dio',
        'dio-Latn-NG': 'dio',
        'dio-Latn': 'dio',
        'dio-NG': 'dio',
        'dip': 'dip',
        'dip-Latn-SS': 'dip',
        'dip-Latn': 'dip',
        'dip-SS': 'dip',
        'dir': 'dir',
        'dir-Latn-NG': 'dir',
        'dir-Latn': 'dir',
        'dir-NG': 'dir',
        'dis-Beng': 'dis-Beng',
        'dis-Beng-IN': 'dis-Beng',
        'dis-Latn': 'dis-Latn',
        'dis-Latn-IN': 'dis-Latn',
        'diu': 'diu',
        'diu-Latn-NA': 'diu',
        'diu-Latn': 'diu',
        'diu-NA': 'diu',
        'diw': 'diw',
        'diw-Latn-SS': 'diw',
        'diw-Latn': 'diw',
        'diw-SS': 'diw',
        'dix': 'dix',
        'dix-Latn-VU': 'dix',
        'dix-Latn': 'dix',
        'dix-VU': 'dix',
        'diy': 'diy',
        'diy-Latn-ID': 'diy',
        'diy-ID': 'diy',
        'diy-Latn': 'diy',
        'diz': 'diz',
        'diz-Latn-CD': 'diz',
        'diz-CD': 'diz',
        'diz-Latn': 'diz',
        'dja': 'dja',
        'dja-Latn-AU': 'dja',
        'dja-AU': 'dja',
        'dja-Latn': 'dja',
        'djb': 'djb',
        'djb-Latn-AU': 'djb',
        'djb-AU': 'djb',
        'djb-Latn': 'djb',
        'djc': 'djc',
        'djc-Latn-TD': 'djc',
        'djc-Latn': 'djc',
        'djc-TD': 'djc',
        'djd': 'djd',
        'djd-Latn-AU': 'djd',
        'djd-AU': 'djd',
        'djd-Latn': 'djd',
        'dje': 'dje',
        'dje-Latn-NE': 'dje',
        'dje-Latn': 'dje',
        'dje-NE': 'dje',
        'dje-Arab': 'dje-Arab',
        'dje-Arab-NE': 'dje-Arab',
        'dje-Brai': 'dje-Brai',
        'dje-Brai-NE': 'dje-Brai',
        'djf': 'djf',
        'djf-Latn-AU': 'djf',
        'djf-AU': 'djf',
        'djf-Latn': 'djf',
        'dji': 'dji',
        'dji-Latn-AU': 'dji',
        'dji-AU': 'dji',
        'dji-Latn': 'dji',
        'djj': 'djj',
        'djj-Latn-AU': 'djj',
        'djj-AU': 'djj',
        'djj-Latn': 'djj',
        'djk': 'djk',
        'djk-Latn-SR': 'djk',
        'djk-Latn': 'djk',
        'djk-SR': 'djk',
        'djk-Afak': 'djk-Afak',
        'djk-Afak-SR': 'djk-Afak',
        'djm': 'djm',
        'djm-Latn-ML': 'djm',
        'djm-Latn': 'djm',
        'djm-ML': 'djm',
        'djn': 'djn',
        'djn-Latn-AU': 'djn',
        'djn-AU': 'djn',
        'djn-Latn': 'djn',
        'djo': 'djo',
        'djo-Latn-ID': 'djo',
        'djo-ID': 'djo',
        'djo-Latn': 'djo',
        'djr': 'djr',
        'djr-Latn-AU': 'djr',
        'djr-AU': 'djr',
        'djr-Latn': 'djr',
        'dju': 'dju',
        'dju-Latn-PG': 'dju',
        'dju-Latn': 'dju',
        'dju-PG': 'dju',
        'djw': 'djw',
        'djw-Latn-AU': 'djw',
        'djw-AU': 'djw',
        'djw-Latn': 'djw',
        'dka': 'dka',
        'dka-Zyyy-BT': 'dka',
        'dka-BT': 'dka',
        'dka-Zyyy': 'dka',
        'dkk': 'dkk',
        'dkk-Latn-ID': 'dkk',
        'dkk-ID': 'dkk',
        'dkk-Latn': 'dkk',
        'dkr': 'dkr',
        'dkr-Latn-MY': 'dkr',
        'dkr-Latn': 'dkr',
        'dkr-MY': 'dkr',
        'dks': 'dks',
        'dks-Latn-SS': 'dks',
        'dks-Latn': 'dks',
        'dks-SS': 'dks',
        'dkx': 'dkx',
        'dkx-Latn-CM': 'dkx',
        'dkx-CM': 'dkx',
        'dkx-Latn': 'dkx',
        'dlg': 'dlg',
        'dlg-Cyrl-RU': 'dlg',
        'dlg-Cyrl': 'dlg',
        'dlg-RU': 'dlg',
        'dlk': 'dlk',
        'dlk-Zyyy-ER': 'dlk',
        'dlk-ER': 'dlk',
        'dlk-Zyyy': 'dlk',
        'dlm': 'dlm',
        'dlm-Latn-HR': 'dlm',
        'dlm-HR': 'dlm',
        'dlm-Latn': 'dlm',
        'dln': 'dln',
        'dln-Latn-IN': 'dln',
        'dln-IN': 'dln',
        'dln-Latn': 'dln',
        'dma': 'dma',
        'dma-Latn-GA': 'dma',
        'dma-GA': 'dma',
        'dma-Latn': 'dma',
        'dmb': 'dmb',
        'dmb-Latn-ML': 'dmb',
        'dmb-Latn': 'dmb',
        'dmb-ML': 'dmb',
        'dmc': 'dmc',
        'dmc-Latn-PG': 'dmc',
        'dmc-Latn': 'dmc',
        'dmc-PG': 'dmc',
        'dmd': 'dmd',
        'dmd-Latn-AU': 'dmd',
        'dmd-AU': 'dmd',
        'dmd-Latn': 'dmd',
        'dme': 'dme',
        'dme-Latn-CM': 'dme',
        'dme-CM': 'dme',
        'dme-Latn': 'dme',
        'dmf': 'dmf',
        'dmf-Medf-NG': 'dmf',
        'dmf-Medf': 'dmf',
        'dmf-NG': 'dmf',
        'dmg': 'dmg',
        'dmg-Latn-MY': 'dmg',
        'dmg-Latn': 'dmg',
        'dmg-MY': 'dmg',
        'dmk': 'dmk',
        'dmk-Arab-PK': 'dmk',
        'dmk-Arab': 'dmk',
        'dmk-PK': 'dmk',
        'dml': 'dml',
        'dml-Arab-PK': 'dml',
        'dml-Arab': 'dml',
        'dml-PK': 'dml',
        'dmm': 'dmm',
        'dmm-Latn-CM': 'dmm',
        'dmm-CM': 'dmm',
        'dmm-Latn': 'dmm',
        'dmo': 'dmo',
        'dmo-Latn-CM': 'dmo',
        'dmo-CM': 'dmo',
        'dmo-Latn': 'dmo',
        'dmr': 'dmr',
        'dmr-Latn-ID': 'dmr',
        'dmr-ID': 'dmr',
        'dmr-Latn': 'dmr',
        'dms': 'dms',
        'dms-Latn-ID': 'dms',
        'dms-ID': 'dms',
        'dms-Latn': 'dms',
        'dmu': 'dmu',
        'dmu-Latn-ID': 'dmu',
        'dmu-ID': 'dmu',
        'dmu-Latn': 'dmu',
        'dmv': 'dmv',
        'dmv-Latn-MY': 'dmv',
        'dmv-Latn': 'dmv',
        'dmv-MY': 'dmv',
        'dmw': 'dmw',
        'dmw-Latn-AU': 'dmw',
        'dmw-AU': 'dmw',
        'dmw-Latn': 'dmw',
        'xrq': 'dmw',
        'xrq-AU': 'dmw',
        'xrq-Latn': 'dmw',
        'xrq-Latn-AU': 'dmw',
        'dmx': 'dmx',
        'dmx-Latn-MZ': 'dmx',
        'dmx-Latn': 'dmx',
        'dmx-MZ': 'dmx',
        'dmy': 'dmy',
        'dmy-Latn-ID': 'dmy',
        'dmy-ID': 'dmy',
        'dmy-Latn': 'dmy',
        'dna': 'dna',
        'dna-Latn-ID': 'dna',
        'dna-ID': 'dna',
        'dna-Latn': 'dna',
        'dnd': 'dnd',
        'dnd-Latn-PG': 'dnd',
        'dnd-Latn': 'dnd',
        'dnd-PG': 'dnd',
        'dne': 'dne',
        'dne-Latn-TZ': 'dne',
        'dne-Latn': 'dne',
        'dne-TZ': 'dne',
        'dng': 'dng',
        'dng-Cyrl-KG': 'dng',
        'dng-Cyrl': 'dng',
        'dng-KG': 'dng',
        'dni': 'dni',
        'dni-Latn-ID': 'dni',
        'dni-ID': 'dni',
        'dni-Latn': 'dni',
        'dnj': 'dnj',
        'dnj-Latn-CI': 'dnj',
        'dnj-CI': 'dnj',
        'dnj-Latn': 'dnj',
        'dnj-LR': 'dnj-LR',
        'dnj-Latn-LR': 'dnj-LR',
        'daf': 'dnj-LR',
        'daf-LR': 'dnj-LR',
        'daf-Latn': 'dnj-LR',
        'daf-Latn-LR': 'dnj-LR',
        'dnk': 'dnk',
        'dnk-Latn-ID': 'dnk',
        'dnk-ID': 'dnk',
        'dnk-Latn': 'dnk',
        'dnn': 'dnn',
        'dnn-Latn-BF': 'dnn',
        'dnn-BF': 'dnn',
        'dnn-Latn': 'dnn',
        'dno': 'dno',
        'dno-Latn-CD': 'dno',
        'dno-CD': 'dno',
        'dno-Latn': 'dno',
        'dnr': 'dnr',
        'dnr-Latn-PG': 'dnr',
        'dnr-Latn': 'dnr',
        'dnr-PG': 'dnr',
        'dnt': 'dnt',
        'dnt-Latn-ID': 'dnt',
        'dnt-ID': 'dnt',
        'dnt-Latn': 'dnt',
        'dnu': 'dnu',
        'dnu-Zyyy-MM': 'dnu',
        'dnu-MM': 'dnu',
        'dnu-Zyyy': 'dnu',
        'dnv': 'dnv',
        'dnv-Zyyy-MM': 'dnv',
        'dnv-MM': 'dnv',
        'dnv-Zyyy': 'dnv',
        'dnw': 'dnw',
        'dnw-Latn-ID': 'dnw',
        'dnw-ID': 'dnw',
        'dnw-Latn': 'dnw',
        'dny': 'dny',
        'dny-Latn-BR': 'dny',
        'dny-BR': 'dny',
        'dny-Latn': 'dny',
        'doa': 'doa',
        'doa-Latn-PG': 'doa',
        'doa-Latn': 'doa',
        'doa-PG': 'doa',
        'dob': 'dob',
        'dob-Latn-PG': 'dob',
        'dob-Latn': 'dob',
        'dob-PG': 'dob',
        'doc': 'doc',
        'doc-Latn-CN': 'doc',
        'doc-CN': 'doc',
        'doc-Latn': 'doc',
        'doe': 'doe',
        'doe-Latn-TZ': 'doe',
        'doe-Latn': 'doe',
        'doe-TZ': 'doe',
        'dof': 'dof',
        'dof-Latn-PG': 'dof',
        'dof-Latn': 'dof',
        'dof-PG': 'dof',
        'doh': 'doh',
        'doh-Latn-NG': 'doh',
        'doh-Latn': 'doh',
        'doh-NG': 'doh',
        'doi': 'doi',
        'doi-Arab-IN': 'doi',
        'dgo': 'doi',
        'dgo-Arab': 'doi',
        'dgo-Arab-IN': 'doi',
        'dgo-IN': 'doi',
        'doi-Arab': 'doi',
        'doi-IN': 'doi',
        'doi-Deva': 'doi-Deva',
        'doi-Deva-IN': 'doi-Deva',
        'dgo-Deva': 'doi-Deva',
        'dgo-Deva-IN': 'doi-Deva',
        'doi-Takr': 'doi-Takr',
        'doi-Takr-IN': 'doi-Takr',
        'dgo-Takr': 'doi-Takr',
        'dgo-Takr-IN': 'doi-Takr',
        'dok': 'dok',
        'dok-Latn-ID': 'dok',
        'dok-ID': 'dok',
        'dok-Latn': 'dok',
        'dol': 'dol',
        'dol-Latn-PG': 'dol',
        'dol-Latn': 'dol',
        'dol-PG': 'dol',
        'don': 'don',
        'don-Latn-PG': 'don',
        'don-Latn': 'don',
        'don-PG': 'don',
        'doo': 'doo',
        'doo-Latn-CD': 'doo',
        'doo-CD': 'doo',
        'doo-Latn': 'doo',
        'dop': 'dop',
        'dop-Latn-BJ': 'dop',
        'dop-BJ': 'dop',
        'dop-Latn': 'dop',
        'doq': 'doq',
        'doq-Zxxx-DO': 'doq',
        'doq-DO': 'doq',
        'doq-Zxxx': 'doq',
        'sgn-doq': 'doq',
        'sgn-doq-DO': 'doq',
        'dor': 'dor',
        'dor-Latn-SB': 'dor',
        'dor-Latn': 'dor',
        'dor-SB': 'dor',
        'dos': 'dos',
        'dos-Latn-BF': 'dos',
        'dos-BF': 'dos',
        'dos-Latn': 'dos',
        'dot': 'dot',
        'dot-Latn-NG': 'dot',
        'dot-Latn': 'dot',
        'dot-NG': 'dot',
        'dov': 'dov',
        'dov-Latn-ZW': 'dov',
        'dov-Latn': 'dov',
        'dov-ZW': 'dov',
        'dow': 'dow',
        'dow-Latn-CM': 'dow',
        'dow-CM': 'dow',
        'dow-Latn': 'dow',
        'dox': 'dox',
        'dox-Zyyy-ET': 'dox',
        'dox-ET': 'dox',
        'dox-Zyyy': 'dox',
        'doy': 'doy',
        'doy-Latn-GH': 'doy',
        'doy-GH': 'doy',
        'doy-Latn': 'doy',
        'doz': 'doz',
        'doz-Zyyy-ET': 'doz',
        'doz-ET': 'doz',
        'doz-Zyyy': 'doz',
        'dpp': 'dpp',
        'dpp-Latn-MY': 'dpp',
        'dpp-Latn': 'dpp',
        'dpp-MY': 'dpp',
        'drb': 'drb',
        'drb-Zyyy-SD': 'drb',
        'drb-SD': 'drb',
        'drb-Zyyy': 'drb',
        'drc': 'drc',
        'drc-Latn-PT': 'drc',
        'drc-Latn': 'drc',
        'drc-PT': 'drc',
        'drd': 'drd',
        'drd-Zyyy-IN': 'drd',
        'drd-IN': 'drd',
        'drd-Zyyy': 'drd',
        'dre': 'dre',
        'dre-Tibt-NP': 'dre',
        'dre-NP': 'dre',
        'dre-Tibt': 'dre',
        'drg': 'drg',
        'drg-Latn-MY': 'drg',
        'drg-Latn': 'drg',
        'drg-MY': 'drg',
        'dri': 'dri',
        'dri-Latn-NG': 'dri',
        'dri-Latn': 'dri',
        'dri-NG': 'dri',
        'drl': 'drl',
        'drl-Latn-AU': 'drl',
        'bjd': 'drl',
        'bjd-AU': 'drl',
        'bjd-Latn': 'drl',
        'bjd-Latn-AU': 'drl',
        'drl-AU': 'drl',
        'drl-Latn': 'drl',
        'drn': 'drn',
        'drn-Latn-ID': 'drn',
        'drn-ID': 'drn',
        'drn-Latn': 'drn',
        'dro': 'dro',
        'dro-Latn-MY': 'dro',
        'dro-Latn': 'dro',
        'dro-MY': 'dro',
        'drq': 'drq',
        'drq-Zyyy-NP': 'drq',
        'drq-NP': 'drq',
        'drq-Zyyy': 'drq',
        'drs': 'drs',
        'drs-Ethi-ET': 'drs',
        'drs-ET': 'drs',
        'drs-Ethi': 'drs',
        'drt': 'drt',
        'drt-Latn-NL': 'drt',
        'drt-Latn': 'drt',
        'drt-NL': 'drt',
        'dru': 'dru',
        'dru-Latn-TW': 'dru',
        'dru-Latn': 'dru',
        'dru-TW': 'dru',
        'dry': 'dry',
        'dry-Deva-NP': 'dry',
        'dry-Deva': 'dry',
        'dry-NP': 'dry',
        'dsb': 'dsb',
        'dsb-Latn-DE': 'dsb',
        'dsb-DE': 'dsb',
        'dsb-Latn': 'dsb',
        'dse': 'dse',
        'dse-Zxxx-NL': 'dse',
        'dse-NL': 'dse',
        'dse-Zxxx': 'dse',
        'sgn-dse': 'dse',
        'sgn-dse-NL': 'dse',
        'dsh': 'dsh',
        'dsh-Latn-KE': 'dsh',
        'dsh-KE': 'dsh',
        'dsh-Latn': 'dsh',
        'dsi': 'dsi',
        'dsi-Latn-TD': 'dsi',
        'dsi-Latn': 'dsi',
        'dsi-TD': 'dsi',
        'dsl': 'dsl',
        'dsl-Zxxx-DK': 'dsl',
        'dsl-DK': 'dsl',
        'dsl-Zxxx': 'dsl',
        'sgn-dsl': 'dsl',
        'sgn-dsl-DK': 'dsl',
        'dsn': 'dsn',
        'dsn-Latn-ID': 'dsn',
        'dsn-ID': 'dsn',
        'dsn-Latn': 'dsn',
        'dso': 'dso',
        'dso-Orya-IN': 'dso',
        'dso-IN': 'dso',
        'dso-Orya': 'dso',
        'dsq-Arab': 'dsq-Arab',
        'dsq-Arab-ML': 'dsq-Arab',
        'dsq-Latn': 'dsq-Latn',
        'dsq-Latn-ML': 'dsq-Latn',
        'dta': 'dta',
        'dta-Latn-CN': 'dta',
        'dta-CN': 'dta',
        'dta-Latn': 'dta',
        'dta-Cyrl': 'dta-Cyrl',
        'dta-Cyrl-CN': 'dta-Cyrl',
        'dta-Hans': 'dta-Hans',
        'dta-Hans-CN': 'dta-Hans',
        'dta-Mong-x-manchu': 'dta-Mong-x-manchu',
        'dta-Mong-CN-x-manchu': 'dta-Mong-x-manchu',
        'dta-CN-x-manchu': 'dta-Mong-x-manchu',
        'dtb': 'dtb',
        'dtb-Latn-MY': 'dtb',
        'dtb-Latn': 'dtb',
        'dtb-MY': 'dtb',
        'dtd': 'dtd',
        'dtd-Latn-CA': 'dtd',
        'dtd-CA': 'dtd',
        'dtd-Latn': 'dtd',
        'dth': 'dth',
        'dth-Latn-AU': 'dth',
        'dth-AU': 'dth',
        'dth-Latn': 'dth',
        'dti': 'dti',
        'dti-Latn-ML': 'dti',
        'dti-Latn': 'dti',
        'dti-ML': 'dti',
        'dtk': 'dtk',
        'dtk-Latn-ML': 'dtk',
        'dtk-Latn': 'dtk',
        'dtk-ML': 'dtk',
        'dtm': 'dtm',
        'dtm-Latn-ML': 'dtm',
        'dtm-Latn': 'dtm',
        'dtm-ML': 'dtm',
        'dtn': 'dtn',
        'dtn-Zyyy-ET': 'dtn',
        'dtn-ET': 'dtn',
        'dtn-Zyyy': 'dtn',
        'dto': 'dto',
        'dto-Latn-ML': 'dto',
        'dto-Latn': 'dto',
        'dto-ML': 'dto',
        'dtp': 'dtp',
        'dtp-Latn-MY': 'dtp',
        'dtp-Latn': 'dtp',
        'dtp-MY': 'dtp',
        'ktr': 'dtp',
        'ktr-Latn': 'dtp',
        'ktr-Latn-MY': 'dtp',
        'ktr-MY': 'dtp',
        'kzj': 'dtp',
        'kzj-Latn': 'dtp',
        'kzj-Latn-MY': 'dtp',
        'kzj-MY': 'dtp',
        'kzt': 'dtp',
        'kzt-Latn': 'dtp',
        'kzt-Latn-MY': 'dtp',
        'kzt-MY': 'dtp',
        'tdu': 'dtp',
        'tdu-Latn': 'dtp',
        'tdu-Latn-MY': 'dtp',
        'tdu-MY': 'dtp',
        'dtr': 'dtr',
        'dtr-Latn-MY': 'dtr',
        'dtr-Latn': 'dtr',
        'dtr-MY': 'dtr',
        'dts': 'dts',
        'dts-Latn-ML': 'dts',
        'dts-Latn': 'dts',
        'dts-ML': 'dts',
        'dtt': 'dtt',
        'dtt-Latn-ML': 'dtt',
        'dtt-Latn': 'dtt',
        'dtt-ML': 'dtt',
        'dtu': 'dtu',
        'dtu-Latn-ML': 'dtu',
        'dtu-Latn': 'dtu',
        'dtu-ML': 'dtu',
        'dty': 'dty',
        'dty-Deva-NP': 'dty',
        'dty-Deva': 'dty',
        'dty-NP': 'dty',
        'dua': 'dua',
        'dua-Latn-CM': 'dua',
        'dua-CM': 'dua',
        'dua-Latn': 'dua',
        'dub': 'dub',
        'dub-Gujr-IN': 'dub',
        'dub-Gujr': 'dub',
        'dub-IN': 'dub',
        'duc': 'duc',
        'duc-Latn-PG': 'duc',
        'duc-Latn': 'duc',
        'duc-PG': 'duc',
        'due': 'due',
        'due-Latn-PH': 'due',
        'due-Latn': 'due',
        'due-PH': 'due',
        'duf': 'duf',
        'duf-Latn-NC': 'duf',
        'duf-Latn': 'duf',
        'duf-NC': 'duf',
        'dug': 'dug',
        'dug-Latn-KE': 'dug',
        'dug-KE': 'dug',
        'dug-Latn': 'dug',
        'duh-Deva': 'duh-Deva',
        'duh-Deva-IN': 'duh-Deva',
        'duh-Gujr': 'duh-Gujr',
        'duh-Gujr-IN': 'duh-Gujr',
        'dui': 'dui',
        'dui-Latn-PG': 'dui',
        'dui-Latn': 'dui',
        'dui-PG': 'dui',
        'duk': 'duk',
        'duk-Latn-PG': 'duk',
        'duk-Latn': 'duk',
        'duk-PG': 'duk',
        'dul': 'dul',
        'dul-Latn-PH': 'dul',
        'dul-Latn': 'dul',
        'dul-PH': 'dul',
        'dum': 'dum',
        'dum-Latn-NL': 'dum',
        'dum-Latn': 'dum',
        'dum-NL': 'dum',
        'dun': 'dun',
        'dun-Latn-ID': 'dun',
        'dun-ID': 'dun',
        'dun-Latn': 'dun',
        'duo': 'duo',
        'duo-Latn-PH': 'duo',
        'duo-Latn': 'duo',
        'duo-PH': 'duo',
        'dup': 'dup',
        'dup-Latn-ID': 'dup',
        'dup-ID': 'dup',
        'dup-Latn': 'dup',
        'ms-dup': 'dup',
        'ms-dup-ID': 'dup',
        'duq': 'duq',
        'duq-Latn-ID': 'duq',
        'duq-ID': 'duq',
        'duq-Latn': 'duq',
        'dur': 'dur',
        'dur-Latn-CM': 'dur',
        'dur-CM': 'dur',
        'dur-Latn': 'dur',
        'dus': 'dus',
        'dus-Deva-NP': 'dus',
        'dus-Deva': 'dus',
        'dus-NP': 'dus',
        'duu': 'duu',
        'duu-Latn-CN': 'duu',
        'duu-CN': 'duu',
        'duu-Latn': 'duu',
        'duv': 'duv',
        'duv-Latn-ID': 'duv',
        'duv-ID': 'duv',
        'duv-Latn': 'duv',
        'duw': 'duw',
        'duw-Latn-ID': 'duw',
        'duw-ID': 'duw',
        'duw-Latn': 'duw',
        'dux': 'dux',
        'dux-Latn-ML': 'dux',
        'dux-Latn': 'dux',
        'dux-ML': 'dux',
        'duy': 'duy',
        'duy-Latn-PH': 'duy',
        'duy-Latn': 'duy',
        'duy-PH': 'duy',
        'duz': 'duz',
        'duz-Latn-CM': 'duz',
        'duz-CM': 'duz',
        'duz-Latn': 'duz',
        'guv': 'duz',
        'guv-CM': 'duz',
        'guv-Latn': 'duz',
        'guv-Latn-CM': 'duz',
        'dv': 'dv',
        'dv-Thaa-MV': 'dv',
        'dv-MV': 'dv',
        'dv-Thaa': 'dv',
        'dv-Diak': 'dv-Diak',
        'dv-Diak-MV': 'dv-Diak',
        'dva': 'dva',
        'dva-Latn-PG': 'dva',
        'dva-Latn': 'dva',
        'dva-PG': 'dva',
        'dwa': 'dwa',
        'dwa-Latn-NG': 'dwa',
        'dwa-Latn': 'dwa',
        'dwa-NG': 'dwa',
        'dwk': 'dwk',
        'dwk-Orya-IN': 'dwk',
        'dwk-IN': 'dwk',
        'dwk-Orya': 'dwk',
        'dwr': 'dwr',
        'dwr-Latn-ET': 'dwr',
        'dwr-ET': 'dwr',
        'dwr-Latn': 'dwr',
        'dwr-Ethi': 'dwr-Ethi',
        'dwr-Ethi-ET': 'dwr-Ethi',
        'dws': 'dws',
        'dws-Zyyy-001': 'dws',
        'dws-001': 'dws',
        'dws-Zyyy': 'dws',
        'dwu': 'dwu',
        'dwu-Latn-AU': 'dwu',
        'dwu-AU': 'dwu',
        'dwu-Latn': 'dwu',
        'dww': 'dww',
        'dww-Latn-PG': 'dww',
        'dww-Latn': 'dww',
        'dww-PG': 'dww',
        'dwy': 'dwy',
        'dwy-Latn-AU': 'dwy',
        'duj': 'dwy',
        'duj-AU': 'dwy',
        'duj-Latn': 'dwy',
        'duj-Latn-AU': 'dwy',
        'dwy-AU': 'dwy',
        'dwy-Latn': 'dwy',
        'dwz': 'dwz',
        'dwz-Deva-NP': 'dwz',
        'dwz-Deva': 'dwz',
        'dwz-NP': 'dwz',
        'dya': 'dya',
        'dya-Latn-BF': 'dya',
        'dya-BF': 'dya',
        'dya-Latn': 'dya',
        'dyb': 'dyb',
        'dyb-Latn-AU': 'dyb',
        'dyb-AU': 'dyb',
        'dyb-Latn': 'dyb',
        'dyd': 'dyd',
        'dyd-Latn-AU': 'dyd',
        'dyd-AU': 'dyd',
        'dyd-Latn': 'dyd',
        'dyg': 'dyg',
        'dyg-Latn-PH': 'dyg',
        'dyg-Latn': 'dyg',
        'dyg-PH': 'dyg',
        'dyi': 'dyi',
        'dyi-Latn-CI': 'dyi',
        'dyi-CI': 'dyi',
        'dyi-Latn': 'dyi',
        'dym': 'dym',
        'dym-Latn-ML': 'dym',
        'dym-Latn': 'dym',
        'dym-ML': 'dym',
        'dyn': 'dyn',
        'dyn-Latn-AU': 'dyn',
        'dyn-AU': 'dyn',
        'dyn-Latn': 'dyn',
        'dyo': 'dyo',
        'dyo-Latn-SN': 'dyo',
        'dyo-Latn': 'dyo',
        'dyo-SN': 'dyo',
        'dyo-Arab': 'dyo-Arab',
        'dyo-Arab-SN': 'dyo-Arab',
        'dyu': 'dyu',
        'dyu-Latn-BF': 'dyu',
        'dyu-BF': 'dyu',
        'dyu-Latn': 'dyu',
        'dyu-Arab': 'dyu-Arab',
        'dyu-Arab-CI': 'dyu-Arab',
        'dyu-Nkoo': 'dyu-Nkoo',
        'dyu-Nkoo-CI': 'dyu-Nkoo',
        'dyy': 'dyy',
        'dyy-Latn-AU': 'dyy',
        'dyy-AU': 'dyy',
        'dyy-Latn': 'dyy',
        'dz': 'dz',
        'dz-Tibt-BT': 'dz',
        'adp': 'dz',
        'adp-BT': 'dz',
        'adp-Tibt': 'dz',
        'adp-Tibt-BT': 'dz',
        'dz-BT': 'dz',
        'dz-Tibt': 'dz',
        'dza': 'dza',
        'dza-Latn-NG': 'dza',
        'dza-Latn': 'dza',
        'dza-NG': 'dza',
        'dze': 'dze',
        'dze-Latn-AU': 'dze',
        'djl': 'dze',
        'djl-AU': 'dze',
        'djl-Latn': 'dze',
        'djl-Latn-AU': 'dze',
        'dze-AU': 'dze',
        'dze-Latn': 'dze',
        'dzg': 'dzg',
        'dzg-Latn-TD': 'dzg',
        'dzg-Latn': 'dzg',
        'dzg-TD': 'dzg',
        'dzl': 'dzl',
        'dzl-Zyyy-BT': 'dzl',
        'dzl-BT': 'dzl',
        'dzl-Zyyy': 'dzl',
        'dzn': 'dzn',
        'dzn-Latn-CD': 'dzn',
        'dzn-CD': 'dzn',
        'dzn-Latn': 'dzn',
        'eaa': 'eaa',
        'eaa-Latn-AU': 'eaa',
        'eaa-AU': 'eaa',
        'eaa-Latn': 'eaa',
        'ebc': 'ebc',
        'ebc-Latn-ID': 'ebc',
        'ebc-ID': 'ebc',
        'ebc-Latn': 'ebc',
        'ebg': 'ebg',
        'ebg-Latn-NG': 'ebg',
        'ebg-Latn': 'ebg',
        'ebg-NG': 'ebg',
        'ebk': 'ebk',
        'ebk-Latn-PH': 'ebk',
        'ebk-Latn': 'ebk',
        'ebk-PH': 'ebk',
        'ebo': 'ebo',
        'ebo-Latn-CG': 'ebo',
        'ebo-CG': 'ebo',
        'ebo-Latn': 'ebo',
        'ebr': 'ebr',
        'ebr-Latn-CI': 'ebr',
        'ebr-CI': 'ebr',
        'ebr-Latn': 'ebr',
        'ebu': 'ebu',
        'ebu-Latn-KE': 'ebu',
        'ebu-KE': 'ebu',
        'ebu-Latn': 'ebu',
        'ecr': 'ecr',
        'ecr-Zyyy-GR': 'ecr',
        'ecr-GR': 'ecr',
        'ecr-Zyyy': 'ecr',
        'ecs': 'ecs',
        'ecs-Zxxx-EC': 'ecs',
        'ecs-EC': 'ecs',
        'ecs-Zxxx': 'ecs',
        'sgn-ecs': 'ecs',
        'sgn-ecs-EC': 'ecs',
        'ecy': 'ecy',
        'ecy-Zyyy-CY': 'ecy',
        'ecy-CY': 'ecy',
        'ecy-Zyyy': 'ecy',
        'ee': 'ee',
        'ee-Latn-GH': 'ee',
        'ee-GH': 'ee',
        'ee-Latn': 'ee',
        'ee-Brai': 'ee-Brai',
        'ee-Brai-GH': 'ee-Brai',
        'ee-TG': 'ee-TG',
        'ee-Latn-TG': 'ee-TG',
        'eee': 'eee',
        'eee-Zyyy-CN': 'eee',
        'eee-CN': 'eee',
        'eee-Zyyy': 'eee',
        'efa': 'efa',
        'efa-Latn-NG': 'efa',
        'efa-Latn': 'efa',
        'efa-NG': 'efa',
        'efe': 'efe',
        'efe-Latn-CD': 'efe',
        'efe-CD': 'efe',
        'efe-Latn': 'efe',
        'efi': 'efi',
        'efi-Latn-NG': 'efi',
        'efi-Latn': 'efi',
        'efi-NG': 'efi',
        'ega': 'ega',
        'ega-Latn-CI': 'ega',
        'ega-CI': 'ega',
        'ega-Latn': 'ega',
        'egl': 'egl',
        'egl-Latn-IT': 'egl',
        'egl-IT': 'egl',
        'egl-Latn': 'egl',
        'ego': 'ego',
        'ego-Latn-NG': 'ego',
        'ego-Latn': 'ego',
        'ego-NG': 'ego',
        'egy': 'egy',
        'egy-Egyp-EG': 'egy',
        'egy-EG': 'egy',
        'egy-Egyp': 'egy',
        'ehu': 'ehu',
        'ehu-Latn-NG': 'ehu',
        'ehu-Latn': 'ehu',
        'ehu-NG': 'ehu',
        'eip': 'eip',
        'eip-Latn-ID': 'eip',
        'eip-ID': 'eip',
        'eip-Latn': 'eip',
        'eit': 'eit',
        'eit-Latn-PG': 'eit',
        'eit-Latn': 'eit',
        'eit-PG': 'eit',
        'eiv': 'eiv',
        'eiv-Latn-PG': 'eiv',
        'eiv-Latn': 'eiv',
        'eiv-PG': 'eiv',
        'eja': 'eja',
        'eja-Latn-GW': 'eja',
        'eja-GW': 'eja',
        'eja-Latn': 'eja',
        'eka': 'eka',
        'eka-Latn-NG': 'eka',
        'eka-Latn': 'eka',
        'eka-NG': 'eka',
        'eka-Latn-NG-x-ekajuk': 'eka-Latn-NG-x-ekajuk',
        'ekc': 'ekc',
        'ekc-Latn-AU': 'ekc',
        'ekc-AU': 'ekc',
        'ekc-Latn': 'ekc',
        'eke': 'eke',
        'eke-Latn-NG': 'eke',
        'eke-Latn': 'eke',
        'eke-NG': 'eke',
        'ekg': 'ekg',
        'ekg-Latn-ID': 'ekg',
        'ekg-ID': 'ekg',
        'ekg-Latn': 'ekg',
        'eki': 'eki',
        'eki-Latn-NG': 'eki',
        'eki-Latn': 'eki',
        'eki-NG': 'eki',
        'ekl': 'ekl',
        'ekl-Latn-BD': 'ekl',
        'ekl-BD': 'ekl',
        'ekl-Latn': 'ekl',
        'ekm': 'ekm',
        'ekm-Latn-CM': 'ekm',
        'ekm-CM': 'ekm',
        'ekm-Latn': 'ekm',
        'eko': 'eko',
        'eko-Latn-MZ': 'eko',
        'eko-Latn': 'eko',
        'eko-MZ': 'eko',
        'eko-Arab': 'eko-Arab',
        'eko-Arab-MZ': 'eko-Arab',
        'ekp': 'ekp',
        'ekp-Latn-NG': 'ekp',
        'ekp-Latn': 'ekp',
        'ekp-NG': 'ekp',
        'ekr': 'ekr',
        'ekr-Latn-NG': 'ekr',
        'ekr-Latn': 'ekr',
        'ekr-NG': 'ekr',
        'eky': 'eky',
        'eky-Kali-MM': 'eky',
        'eky-Kali': 'eky',
        'eky-MM': 'eky',
        'el': 'el',
        'el-Grek-GR': 'el',
        'el-GR': 'el',
        'el-Grek': 'el',
        'el-Brai': 'el-Brai',
        'el-Brai-GR': 'el-Brai',
        'el-Cyrl': 'el-Cyrl',
        'el-Cyrl-UA': 'el-Cyrl',
        'el-UA': 'el-Cyrl',
        'ele': 'ele',
        'ele-Latn-PG': 'ele',
        'ele-Latn': 'ele',
        'ele-PG': 'ele',
        'elh': 'elh',
        'elh-Zyyy-SD': 'elh',
        'elh-SD': 'elh',
        'elh-Zyyy': 'elh',
        'eli': 'eli',
        'eli-Zyyy-SD': 'eli',
        'eli-SD': 'eli',
        'eli-Zyyy': 'eli',
        'elk': 'elk',
        'elk-Latn-PG': 'elk',
        'elk-Latn': 'elk',
        'elk-PG': 'elk',
        'elm': 'elm',
        'elm-Latn-NG': 'elm',
        'elm-Latn': 'elm',
        'elm-NG': 'elm',
        'elo': 'elo',
        'elo-Latn-KE': 'elo',
        'elo-KE': 'elo',
        'elo-Latn': 'elo',
        'elu': 'elu',
        'elu-Latn-PG': 'elu',
        'elu-Latn': 'elu',
        'elu-PG': 'elu',
        'elx': 'elx',
        'elx-Zyyy-IR': 'elx',
        'elx-IR': 'elx',
        'elx-Zyyy': 'elx',
        'ema': 'ema',
        'ema-Latn-NG': 'ema',
        'ema-Latn': 'ema',
        'ema-NG': 'ema',
        'uok': 'ema',
        'uok-Latn': 'ema',
        'uok-Latn-NG': 'ema',
        'uok-NG': 'ema',
        'emb': 'emb',
        'emb-Latn-ID': 'emb',
        'emb-ID': 'emb',
        'emb-Latn': 'emb',
        'eme': 'eme',
        'eme-Latn-GF': 'eme',
        'eme-GF': 'eme',
        'eme-Latn': 'eme',
        'emg': 'emg',
        'emg-Deva-NP': 'emg',
        'emg-Deva': 'emg',
        'emg-NP': 'emg',
        'emi': 'emi',
        'emi-Latn-PG': 'emi',
        'emi-Latn': 'emi',
        'emi-PG': 'emi',
        'emm': 'emm',
        'emm-Latn-MX': 'emm',
        'emm-Latn': 'emm',
        'emm-MX': 'emm',
        'emn': 'emn',
        'emn-Latn-CM': 'emn',
        'emn-CM': 'emn',
        'emn-Latn': 'emn',
        'emp': 'emp',
        'emp-Latn-PA': 'emp',
        'emp-Latn': 'emp',
        'emp-PA': 'emp',
        'ems': 'ems',
        'ems-Latn-US': 'ems',
        'ems-Latn': 'ems',
        'ems-US': 'ems',
        'ems-Cyrl': 'ems-Cyrl',
        'ems-Cyrl-US': 'ems-Cyrl',
        'emu': 'emu',
        'emu-Deva-IN': 'emu',
        'emu-Deva': 'emu',
        'emu-IN': 'emu',
        'emw': 'emw',
        'emw-Latn-ID': 'emw',
        'emw-ID': 'emw',
        'emw-Latn': 'emw',
        'emx': 'emx',
        'emx-Latn-FR': 'emx',
        'emx-FR': 'emx',
        'emx-Latn': 'emx',
        'emy': 'emy',
        'emy-Zyyy-MX': 'emy',
        'emy-MX': 'emy',
        'emy-Zyyy': 'emy',
        'en': 'en',
        'en-Latn-US': 'en',
        'en-Latn': 'en',
        'en-US': 'en',
        'en-001': 'en-001',
        'en-Latn-001': 'en-001',
        'en-150': 'en-150',
        'en-Latn-150': 'en-150',
        'en-AE': 'en-AE',
        'en-Latn-AE': 'en-AE',
        'en-AG': 'en-AG',
        'en-Latn-AG': 'en-AG',
        'en-AI': 'en-AI',
        'en-Latn-AI': 'en-AI',
        'en-AT': 'en-AT',
        'en-Latn-AT': 'en-AT',
        'en-AU': 'en-AU',
        'en-Latn-AU': 'en-AU',
        'en-BB': 'en-BB',
        'en-Latn-BB': 'en-BB',
        'en-BE': 'en-BE',
        'en-Latn-BE': 'en-BE',
        'en-BI': 'en-BI',
        'en-Latn-BI': 'en-BI',
        'en-BM': 'en-BM',
        'en-Latn-BM': 'en-BM',
        'en-BS': 'en-BS',
        'en-Latn-BS': 'en-BS',
        'en-BW': 'en-BW',
        'en-Latn-BW': 'en-BW',
        'en-BZ': 'en-BZ',
        'en-Latn-BZ': 'en-BZ',
        'en-Brai': 'en-Brai',
        'en-Brai-GB': 'en-Brai',
        'en-CA': 'en-CA',
        'en-Latn-CA': 'en-CA',
        'en-CC': 'en-CC',
        'en-Latn-CC': 'en-CC',
        'en-CH': 'en-CH',
        'en-Latn-CH': 'en-CH',
        'en-CK': 'en-CK',
        'en-Latn-CK': 'en-CK',
        'en-CM': 'en-CM',
        'en-Latn-CM': 'en-CM',
        'en-CX': 'en-CX',
        'en-Latn-CX': 'en-CX',
        'en-DE': 'en-DE',
        'en-Latn-DE': 'en-DE',
        'en-DG': 'en-DG',
        'en-Latn-DG': 'en-DG',
        'en-DK': 'en-DK',
        'en-Latn-DK': 'en-DK',
        'en-DM': 'en-DM',
        'en-Latn-DM': 'en-DM',
        'en-Dsrt': 'en-Dsrt',
        'en-Dsrt-US': 'en-Dsrt',
        'en-Dupl': 'en-Dupl',
        'en-Dupl-US': 'en-Dupl',
        'en-ER': 'en-ER',
        'en-Latn-ER': 'en-ER',
        'en-FI': 'en-FI',
        'en-Latn-FI': 'en-FI',
        'en-FJ': 'en-FJ',
        'en-Latn-FJ': 'en-FJ',
        'en-FK': 'en-FK',
        'en-Latn-FK': 'en-FK',
        'en-GB': 'en-GB',
        'en-Latn-GB': 'en-GB',
        'en-GD': 'en-GD',
        'en-Latn-GD': 'en-GD',
        'en-GG': 'en-GG',
        'en-Latn-GG': 'en-GG',
        'en-GH': 'en-GH',
        'en-Latn-GH': 'en-GH',
        'en-GI': 'en-GI',
        'en-Latn-GI': 'en-GI',
        'en-GM': 'en-GM',
        'en-Latn-GM': 'en-GM',
        'en-GU': 'en-GU',
        'en-Latn-GU': 'en-GU',
        'en-GY': 'en-GY',
        'en-Latn-GY': 'en-GY',
        'en-HK': 'en-HK',
        'en-Latn-HK': 'en-HK',
        'en-IE': 'en-IE',
        'en-Latn-IE': 'en-IE',
        'en-IL': 'en-IL',
        'en-Latn-IL': 'en-IL',
        'en-IM': 'en-IM',
        'en-Latn-IM': 'en-IM',
        'en-IN': 'en-IN',
        'en-Latn-IN': 'en-IN',
        'en-IO': 'en-IO',
        'en-Latn-IO': 'en-IO',
        'en-JE': 'en-JE',
        'en-Latn-JE': 'en-JE',
        'en-JM': 'en-JM',
        'en-Latn-JM': 'en-JM',
        'en-KE': 'en-KE',
        'en-Latn-KE': 'en-KE',
        'en-KI': 'en-KI',
        'en-Latn-KI': 'en-KI',
        'en-KN': 'en-KN',
        'en-Latn-KN': 'en-KN',
        'en-KY': 'en-KY',
        'en-Latn-KY': 'en-KY',
        'en-LC': 'en-LC',
        'en-Latn-LC': 'en-LC',
        'en-LR': 'en-LR',
        'en-Latn-LR': 'en-LR',
        'en-LS': 'en-LS',
        'en-Latn-LS': 'en-LS',
        'en-MG': 'en-MG',
        'en-Latn-MG': 'en-MG',
        'en-MH': 'en-MH',
        'en-Latn-MH': 'en-MH',
        'en-MO': 'en-MO',
        'en-Latn-MO': 'en-MO',
        'en-MP': 'en-MP',
        'en-Latn-MP': 'en-MP',
        'en-MS': 'en-MS',
        'en-Latn-MS': 'en-MS',
        'en-MT': 'en-MT',
        'en-Latn-MT': 'en-MT',
        'en-MU': 'en-MU',
        'en-Latn-MU': 'en-MU',
        'en-MW': 'en-MW',
        'en-Latn-MW': 'en-MW',
        'en-MY': 'en-MY',
        'en-Latn-MY': 'en-MY',
        'en-NA': 'en-NA',
        'en-Latn-NA': 'en-NA',
        'en-NF': 'en-NF',
        'en-Latn-NF': 'en-NF',
        'en-NG': 'en-NG',
        'en-Latn-NG': 'en-NG',
        'en-NL': 'en-NL',
        'en-Latn-NL': 'en-NL',
        'en-NR': 'en-NR',
        'en-Latn-NR': 'en-NR',
        'en-NU': 'en-NU',
        'en-Latn-NU': 'en-NU',
        'en-NZ': 'en-NZ',
        'en-Latn-NZ': 'en-NZ',
        'en-PG': 'en-PG',
        'en-Latn-PG': 'en-PG',
        'en-PH': 'en-PH',
        'en-Latn-PH': 'en-PH',
        'en-PK': 'en-PK',
        'en-Latn-PK': 'en-PK',
        'en-PN': 'en-PN',
        'en-Latn-PN': 'en-PN',
        'en-PW': 'en-PW',
        'en-Latn-PW': 'en-PW',
        'en-RW': 'en-RW',
        'en-Latn-RW': 'en-RW',
        'en-SB': 'en-SB',
        'en-Latn-SB': 'en-SB',
        'en-SC': 'en-SC',
        'en-Latn-SC': 'en-SC',
        'en-SD': 'en-SD',
        'en-Latn-SD': 'en-SD',
        'en-SE': 'en-SE',
        'en-Latn-SE': 'en-SE',
        'en-SG': 'en-SG',
        'en-Latn-SG': 'en-SG',
        'en-SH': 'en-SH',
        'en-Latn-SH': 'en-SH',
        'en-SI': 'en-SI',
        'en-Latn-SI': 'en-SI',
        'en-SL': 'en-SL',
        'en-Latn-SL': 'en-SL',
        'en-SS': 'en-SS',
        'en-Latn-SS': 'en-SS',
        'en-SX': 'en-SX',
        'en-Latn-SX': 'en-SX',
        'en-SZ': 'en-SZ',
        'en-Latn-SZ': 'en-SZ',
        'en-Shaw': 'en-Shaw',
        'en-Shaw-GB': 'en-Shaw',
        'en-TK': 'en-TK',
        'en-Latn-TK': 'en-TK',
        'en-TO': 'en-TO',
        'en-Latn-TO': 'en-TO',
        'en-TT': 'en-TT',
        'en-Latn-TT': 'en-TT',
        'en-TV': 'en-TV',
        'en-Latn-TV': 'en-TV',
        'en-TZ': 'en-TZ',
        'en-Latn-TZ': 'en-TZ',
        'en-UG': 'en-UG',
        'en-Latn-UG': 'en-UG',
        'en-VC': 'en-VC',
        'en-Latn-VC': 'en-VC',
        'en-VU': 'en-VU',
        'en-Latn-VU': 'en-VU',
        'en-WS': 'en-WS',
        'en-Latn-WS': 'en-WS',
        'en-ZA': 'en-ZA',
        'en-Latn-ZA': 'en-ZA',
        'en-ZM': 'en-ZM',
        'en-Latn-ZM': 'en-ZM',
        'en-ZW': 'en-ZW',
        'en-Latn-ZW': 'en-ZW',
        'ena': 'ena',
        'ena-Latn-PG': 'ena',
        'ena-Latn': 'ena',
        'ena-PG': 'ena',
        'enb': 'enb',
        'enb-Latn-KE': 'enb',
        'enb-KE': 'enb',
        'enb-Latn': 'enb',
        'enc': 'enc',
        'enc-Latn-VN': 'enc',
        'enc-Latn': 'enc',
        'enc-VN': 'enc',
        'end': 'end',
        'end-Latn-ID': 'end',
        'end-ID': 'end',
        'end-Latn': 'end',
        'enf': 'enf',
        'enf-Cyrl-RU': 'enf',
        'enf-Cyrl': 'enf',
        'enf-RU': 'enf',
        'enh': 'enh',
        'enh-Cyrl-RU': 'enh',
        'enh-Cyrl': 'enh',
        'enh-RU': 'enh',
        'enl': 'enl',
        'enl-Latn-PY': 'enl',
        'enl-Latn': 'enl',
        'enl-PY': 'enl',
        'leg': 'enl',
        'leg-Latn': 'enl',
        'leg-Latn-PY': 'enl',
        'leg-PY': 'enl',
        'enm': 'enm',
        'enm-Latn-GB': 'enm',
        'enm-GB': 'enm',
        'enm-Latn': 'enm',
        'enn': 'enn',
        'enn-Latn-NG': 'enn',
        'enn-Latn': 'enn',
        'enn-NG': 'enn',
        'eno': 'eno',
        'eno-Latn-ID': 'eno',
        'eno-ID': 'eno',
        'eno-Latn': 'eno',
        'enq': 'enq',
        'enq-Latn-PG': 'enq',
        'enq-Latn': 'enq',
        'enq-PG': 'enq',
        'enr': 'enr',
        'enr-Latn-ID': 'enr',
        'enr-ID': 'enr',
        'enr-Latn': 'enr',
        'enu': 'enu',
        'enu-Zyyy-CN': 'enu',
        'enu-CN': 'enu',
        'enu-Zyyy': 'enu',
        'env': 'env',
        'env-Latn-NG': 'env',
        'env-Latn': 'env',
        'env-NG': 'env',
        'enw': 'enw',
        'enw-Latn-NG': 'enw',
        'enw-Latn': 'enw',
        'enw-NG': 'enw',
        'enx': 'enx',
        'enx-Latn-PY': 'enx',
        'enx-Latn': 'enx',
        'enx-PY': 'enx',
        'eo': 'eo',
        'eo-Latn-001': 'eo',
        'eo-001': 'eo',
        'eo-Latn': 'eo',
        'eot': 'eot',
        'eot-Latn-CI': 'eot',
        'eot-CI': 'eot',
        'eot-Latn': 'eot',
        'epi': 'epi',
        'epi-Latn-NG': 'epi',
        'epi-Latn': 'epi',
        'epi-NG': 'epi',
        'era': 'era',
        'era-Zyyy-IN': 'era',
        'era-IN': 'era',
        'era-Zyyy': 'era',
        'erg': 'erg',
        'erg-Latn-VU': 'erg',
        'erg-Latn': 'erg',
        'erg-VU': 'erg',
        'erh': 'erh',
        'erh-Latn-NG': 'erh',
        'erh-Latn': 'erh',
        'erh-NG': 'erh',
        'eri': 'eri',
        'eri-Latn-PG': 'eri',
        'eri-Latn': 'eri',
        'eri-PG': 'eri',
        'erk': 'erk',
        'erk-Latn-VU': 'erk',
        'erk-Latn': 'erk',
        'erk-VU': 'erk',
        'ero': 'ero',
        'ero-Zyyy-CN': 'ero',
        'ero-CN': 'ero',
        'ero-Zyyy': 'ero',
        'err': 'err',
        'err-Latn-AU': 'err',
        'err-AU': 'err',
        'err-Latn': 'err',
        'ers': 'ers',
        'ers-Zzzz-CN-x-ersushab': 'ers',
        'ers-CN': 'ers',
        'ers-CN-x-ersushab': 'ers',
        'ers-Zzzz': 'ers',
        'ers-Zzzz-CN': 'ers',
        'ers-Zzzz-x-ersushab': 'ers',
        'ers-x-ersushab': 'ers',
        'ert': 'ert',
        'ert-Latn-ID': 'ert',
        'ert-ID': 'ert',
        'ert-Latn': 'ert',
        'erw': 'erw',
        'erw-Latn-ID': 'erw',
        'erw-ID': 'erw',
        'erw-Latn': 'erw',
        'es': 'es',
        'es-Latn-ES': 'es',
        'es-ES': 'es',
        'es-Latn': 'es',
        'es-419': 'es-419',
        'es-Latn-419': 'es-419',
        'es-AR': 'es-AR',
        'es-Latn-AR': 'es-AR',
        'es-BO': 'es-BO',
        'es-Latn-BO': 'es-BO',
        'es-BR': 'es-BR',
        'es-Latn-BR': 'es-BR',
        'es-BZ': 'es-BZ',
        'es-Latn-BZ': 'es-BZ',
        'es-Brai': 'es-Brai',
        'es-Brai-ES': 'es-Brai',
        'es-CL': 'es-CL',
        'es-Latn-CL': 'es-CL',
        'es-CO': 'es-CO',
        'es-Latn-CO': 'es-CO',
        'es-CR': 'es-CR',
        'es-Latn-CR': 'es-CR',
        'es-CU': 'es-CU',
        'es-Latn-CU': 'es-CU',
        'es-DO': 'es-DO',
        'es-Latn-DO': 'es-DO',
        'es-Dupl': 'es-Dupl',
        'es-Dupl-ES': 'es-Dupl',
        'es-EC': 'es-EC',
        'es-Latn-EC': 'es-EC',
        'es-GQ': 'es-GQ',
        'es-Latn-GQ': 'es-GQ',
        'es-GT': 'es-GT',
        'es-Latn-GT': 'es-GT',
        'es-HN': 'es-HN',
        'es-Latn-HN': 'es-HN',
        'es-MX': 'es-MX',
        'es-Latn-MX': 'es-MX',
        'es-NI': 'es-NI',
        'es-Latn-NI': 'es-NI',
        'es-PA': 'es-PA',
        'es-Latn-PA': 'es-PA',
        'es-PE': 'es-PE',
        'es-Latn-PE': 'es-PE',
        'es-PH': 'es-PH',
        'es-Latn-PH': 'es-PH',
        'es-PR': 'es-PR',
        'es-Latn-PR': 'es-PR',
        'es-PY': 'es-PY',
        'es-Latn-PY': 'es-PY',
        'es-SV': 'es-SV',
        'es-Latn-SV': 'es-SV',
        'es-US': 'es-US',
        'es-Latn-US': 'es-US',
        'es-UY': 'es-UY',
        'es-Latn-UY': 'es-UY',
        'es-VE': 'es-VE',
        'es-Latn-VE': 'es-VE',
        'ese': 'ese',
        'ese-Latn-BO': 'ese',
        'ese-BO': 'ese',
        'ese-Latn': 'ese',
        'esg': 'esg',
        'esg-Deva-IN': 'esg',
        'esg-Deva': 'esg',
        'esg-IN': 'esg',
        'esg-Gonm': 'esg-Gonm',
        'esg-Gonm-IN': 'esg-Gonm',
        'esg-Telu': 'esg-Telu',
        'esg-Telu-IN': 'esg-Telu',
        'esh': 'esh',
        'esh-Zyyy-IR': 'esh',
        'esh-IR': 'esh',
        'esh-Zyyy': 'esh',
        'esi': 'esi',
        'esi-Latn-US': 'esi',
        'esi-Latn': 'esi',
        'esi-US': 'esi',
        'esl': 'esl',
        'esl-Zxxx-EG': 'esl',
        'esl-EG': 'esl',
        'esl-Zxxx': 'esl',
        'sgn-esl': 'esl',
        'sgn-esl-EG': 'esl',
        'esm': 'esm',
        'esm-Latn-CI': 'esm',
        'esm-CI': 'esm',
        'esm-Latn': 'esm',
        'esn': 'esn',
        'esn-Zxxx-SV': 'esn',
        'esn-SV': 'esn',
        'esn-Zxxx': 'esn',
        'sgn-esn': 'esn',
        'sgn-esn-SV': 'esn',
        'eso': 'eso',
        'eso-Zxxx-EE': 'eso',
        'eso-EE': 'eso',
        'eso-Zxxx': 'eso',
        'sgn-eso': 'eso',
        'sgn-eso-EE': 'eso',
        'esq': 'esq',
        'esq-Zyyy-US': 'esq',
        'esq-US': 'esq',
        'esq-Zyyy': 'esq',
        'ess': 'ess',
        'ess-Latn-US': 'ess',
        'ess-Latn': 'ess',
        'ess-US': 'ess',
        'ess-Cyrl': 'ess-Cyrl',
        'ess-Cyrl-US': 'ess-Cyrl',
        'esu': 'esu',
        'esu-Latn-US': 'esu',
        'esu-Latn': 'esu',
        'esu-US': 'esu',
        'esy': 'esy',
        'esy-Latn-PH': 'esy',
        'esy-Latn': 'esy',
        'esy-PH': 'esy',
        'esy-Zzzz-x-eskaya': 'esy-Zzzz-x-eskaya',
        'esy-Zzzz-PH-x-eskaya': 'esy-Zzzz-x-eskaya',
        'esy-PH-x-eskaya': 'esy-Zzzz-x-eskaya',
        'et': 'et',
        'et-Latn-EE': 'et',
        'ekk': 'et',
        'ekk-EE': 'et',
        'ekk-Latn': 'et',
        'ekk-Latn-EE': 'et',
        'et-EE': 'et',
        'et-Latn': 'et',
        'et-Brai': 'et-Brai',
        'et-Brai-EE': 'et-Brai',
        'etb': 'etb',
        'etb-Latn-NG': 'etb',
        'etb-Latn': 'etb',
        'etb-NG': 'etb',
        'etc': 'etc',
        'etc-Zyyy-US': 'etc',
        'etc-US': 'etc',
        'etc-Zyyy': 'etc',
        'eth': 'eth',
        'eth-Zxxx-ET': 'eth',
        'eth-ET': 'eth',
        'eth-Zxxx': 'eth',
        'sgn-eth': 'eth',
        'sgn-eth-ET': 'eth',
        'etn': 'etn',
        'etn-Latn-VU': 'etn',
        'etn-Latn': 'etn',
        'etn-VU': 'etn',
        'eto': 'eto',
        'eto-Latn-CM': 'eto',
        'eto-CM': 'eto',
        'eto-Latn': 'eto',
        'etr': 'etr',
        'etr-Latn-PG': 'etr',
        'etr-Latn': 'etr',
        'etr-PG': 'etr',
        'ets': 'ets',
        'ets-Latn-NG': 'ets',
        'ets-Latn': 'ets',
        'ets-NG': 'ets',
        'ett': 'ett',
        'ett-Ital-IT': 'ett',
        'ett-IT': 'ett',
        'ett-Ital': 'ett',
        'ett-Latn': 'ett-Latn',
        'ett-Latn-IT': 'ett-Latn',
        'etu': 'etu',
        'etu-Latn-NG': 'etu',
        'etu-Latn': 'etu',
        'etu-NG': 'etu',
        'etx': 'etx',
        'etx-Latn-NG': 'etx',
        'etx-Latn': 'etx',
        'etx-NG': 'etx',
        'etz': 'etz',
        'etz-Latn-ID': 'etz',
        'etz-ID': 'etz',
        'etz-Latn': 'etz',
        'eu': 'eu',
        'eu-Latn-ES': 'eu',
        'eu-ES': 'eu',
        'eu-Latn': 'eu',
        'eve': 'eve',
        'eve-Cyrl-RU': 'eve',
        'eve-Cyrl': 'eve',
        'eve-RU': 'eve',
        'evh': 'evh',
        'evh-Latn-NG': 'evh',
        'evh-Latn': 'evh',
        'evh-NG': 'evh',
        'evn': 'evn',
        'evn-Cyrl-RU': 'evn',
        'evn-Cyrl': 'evn',
        'evn-RU': 'evn',
        'evn-Latn': 'evn-Latn',
        'evn-Latn-CN': 'evn-Latn',
        'evn-Mong': 'evn-Mong',
        'evn-Mong-CN': 'evn-Mong',
        'ewo': 'ewo',
        'ewo-Latn-CM': 'ewo',
        'ewo-CM': 'ewo',
        'ewo-Latn': 'ewo',
        'ext': 'ext',
        'ext-Latn-ES': 'ext',
        'ext-ES': 'ext',
        'ext-Latn': 'ext',
        'eya': 'eya',
        'eya-Zyyy-US': 'eya',
        'eya-US': 'eya',
        'eya-Zyyy': 'eya',
        'eyo': 'eyo',
        'eyo-Latn-KE': 'eyo',
        'eyo-KE': 'eyo',
        'eyo-Latn': 'eyo',
        'eza': 'eza',
        'eza-Latn-NG': 'eza',
        'eza-Latn': 'eza',
        'eza-NG': 'eza',
        'eze': 'eze',
        'eze-Latn-NG': 'eze',
        'eze-Latn': 'eze',
        'eze-NG': 'eze',
        'fa': 'fa',
        'fa-Arab-IR': 'fa',
        'fa-Arab': 'fa',
        'fa-IR': 'fa',
        'pes-Arab': 'fa',
        'pes-Arab-IR': 'fa',
        'fa-AF': 'fa-AF',
        'fa-Arab-AF': 'fa-AF',
        'faa': 'faa',
        'faa-Latn-PG': 'faa',
        'faa-Latn': 'faa',
        'faa-PG': 'faa',
        'fab': 'fab',
        'fab-Latn-GQ': 'fab',
        'fab-GQ': 'fab',
        'fab-Latn': 'fab',
        'fad': 'fad',
        'fad-Latn-PG': 'fad',
        'fad-Latn': 'fad',
        'fad-PG': 'fad',
        'faf': 'faf',
        'faf-Latn-SB': 'faf',
        'faf-Latn': 'faf',
        'faf-SB': 'faf',
        'fag': 'fag',
        'fag-Latn-PG': 'fag',
        'fag-Latn': 'fag',
        'fag-PG': 'fag',
        'fah': 'fah',
        'fah-Latn-NG': 'fah',
        'fah-Latn': 'fah',
        'fah-NG': 'fah',
        'fai': 'fai',
        'fai-Latn-PG': 'fai',
        'fai-Latn': 'fai',
        'fai-PG': 'fai',
        'faj': 'faj',
        'faj-Latn-PG': 'faj',
        'faj-Latn': 'faj',
        'faj-PG': 'faj',
        'fak': 'fak',
        'fak-Latn-CM': 'fak',
        'fak-CM': 'fak',
        'fak-Latn': 'fak',
        'fal': 'fal',
        'fal-Latn-CM': 'fal',
        'fal-CM': 'fal',
        'fal-Latn': 'fal',
        'fam': 'fam',
        'fam-Latn-NG': 'fam',
        'fam-Latn': 'fam',
        'fam-NG': 'fam',
        'fan': 'fan',
        'fan-Latn-GQ': 'fan',
        'fan-GQ': 'fan',
        'fan-Latn': 'fan',
        'fap': 'fap',
        'fap-Latn-SN': 'fap',
        'fap-Latn': 'fap',
        'fap-SN': 'fap',
        'far': 'far',
        'far-Latn-SB': 'far',
        'far-Latn': 'far',
        'far-SB': 'far',
        'fau': 'fau',
        'fau-Latn-ID': 'fau',
        'fau-ID': 'fau',
        'fau-Latn': 'fau',
        'fax': 'fax',
        'fax-Latn-ES': 'fax',
        'fax-ES': 'fax',
        'fax-Latn': 'fax',
        'fay': 'fay',
        'fay-Arab-IR': 'fay',
        'fay-Arab': 'fay',
        'fay-IR': 'fay',
        'faz': 'faz',
        'faz-Arab-IR': 'faz',
        'faz-Arab': 'faz',
        'faz-IR': 'faz',
        'fbl': 'fbl',
        'fbl-Latn-PH': 'fbl',
        'fbl-Latn': 'fbl',
        'fbl-PH': 'fbl',
        'fcs': 'fcs',
        'fcs-Zxxx-CA': 'fcs',
        'fcs-CA': 'fcs',
        'fcs-Zxxx': 'fcs',
        'sgn-fcs': 'fcs',
        'sgn-fcs-CA': 'fcs',
        'fer': 'fer',
        'fer-Latn-SS': 'fer',
        'fer-Latn': 'fer',
        'fer-SS': 'fer',
        'ff': 'ff',
        'ff-Latn-SN': 'ff',
        'ff-Latn': 'ff',
        'ff-SN': 'ff',
        'fuc': 'ff',
        'fuc-Latn': 'ff',
        'fuc-Latn-SN': 'ff',
        'fuc-SN': 'ff',
        'ff-Adlm': 'ff-Adlm',
        'ff-Adlm-GN': 'ff-Adlm',
        'ff-Arab': 'ff-Arab',
        'ff-Arab-SN': 'ff-Arab',
        'fuc-Arab': 'ff-Arab',
        'fuc-Arab-SN': 'ff-Arab',
        'ff-GH': 'ff-GH',
        'ff-Latn-GH': 'ff-GH',
        'ff-GM': 'ff-GM',
        'ff-Latn-GM': 'ff-GM',
        'ff-GN': 'ff-GN',
        'ff-Latn-GN': 'ff-GN',
        'ff-LR': 'ff-LR',
        'ff-Latn-LR': 'ff-LR',
        'ff-MR': 'ff-MR',
        'ff-Latn-MR': 'ff-MR',
        'ff-NG': 'ff-NG',
        'ff-Latn-NG': 'ff-NG',
        'ff-SL': 'ff-SL',
        'ff-Latn-SL': 'ff-SL',
        'ffi': 'ffi',
        'ffi-Latn-PG': 'ffi',
        'ffi-Latn': 'ffi',
        'ffi-PG': 'ffi',
        'ffm': 'ffm',
        'ffm-Latn-ML': 'ffm',
        'ffm-Latn': 'ffm',
        'ffm-ML': 'ffm',
        'ffm-Arab': 'ffm-Arab',
        'ffm-Arab-ML': 'ffm-Arab',
        'fgr': 'fgr',
        'fgr-Latn-TD': 'fgr',
        'fgr-Latn': 'fgr',
        'fgr-TD': 'fgr',
        'fi': 'fi',
        'fi-Latn-FI': 'fi',
        'fi-FI': 'fi',
        'fi-Latn': 'fi',
        'fi-Brai': 'fi-Brai',
        'fi-Brai-FI': 'fi-Brai',
        'fia': 'fia',
        'fia-Arab-SD': 'fia',
        'fia-Arab': 'fia',
        'fia-SD': 'fia',
        'fia-Copt': 'fia-Copt',
        'fia-Copt-SD-x-olnubian': 'fia-Copt',
        'fia-Copt-SD': 'fia-Copt',
        'fia-Copt-x-olnubian': 'fia-Copt',
        'fia-SD-x-olnubian': 'fia-Copt',
        'fia-Latn': 'fia-Latn',
        'fia-Latn-SD': 'fia-Latn',
        'fie': 'fie',
        'fie-Latn-NG': 'fie',
        'fie-Latn': 'fie',
        'fie-NG': 'fie',
        'fil': 'fil',
        'fil-Latn-PH': 'fil',
        'fil-Latn': 'fil',
        'fil-PH': 'fil',
        'fil-Tglg': 'fil-Tglg',
        'fil-Tglg-PH': 'fil-Tglg',
        'fip': 'fip',
        'fip-Latn-TZ': 'fip',
        'fip-Latn': 'fip',
        'fip-TZ': 'fip',
        'fir': 'fir',
        'fir-Latn-NG': 'fir',
        'fir-Latn': 'fir',
        'fir-NG': 'fir',
        'fit': 'fit',
        'fit-Latn-SE': 'fit',
        'fit-Latn': 'fit',
        'fit-SE': 'fit',
        'fiw': 'fiw',
        'fiw-Latn-PG': 'fiw',
        'fiw-Latn': 'fiw',
        'fiw-PG': 'fiw',
        'fj': 'fj',
        'fj-Latn-FJ': 'fj',
        'fj-FJ': 'fj',
        'fj-Latn': 'fj',
        'fkk': 'fkk',
        'fkk-Latn-NG': 'fkk',
        'fkk-Latn': 'fkk',
        'fkk-NG': 'fkk',
        'fkv': 'fkv',
        'fkv-Latn-NO': 'fkv',
        'fkv-Latn': 'fkv',
        'fkv-NO': 'fkv',
        'fla': 'fla',
        'fla-Latn-US': 'fla',
        'fla-Latn': 'fla',
        'fla-US': 'fla',
        'flh': 'flh',
        'flh-Latn-ID': 'flh',
        'flh-ID': 'flh',
        'flh-Latn': 'flh',
        'fli': 'fli',
        'fli-Latn-NG': 'fli',
        'fli-Latn': 'fli',
        'fli-NG': 'fli',
        'fll': 'fll',
        'fll-Latn-CM': 'fll',
        'fll-CM': 'fll',
        'fll-Latn': 'fll',
        'fln': 'fln',
        'fln-Latn-AU': 'fln',
        'fln-AU': 'fln',
        'fln-Latn': 'fln',
        'flr': 'flr',
        'flr-Latn-CD': 'flr',
        'flr-CD': 'flr',
        'flr-Latn': 'flr',
        'fly': 'fly',
        'fly-Latn-ZA': 'fly',
        'fly-Latn': 'fly',
        'fly-ZA': 'fly',
        'fmp': 'fmp',
        'fmp-Latn-CM': 'fmp',
        'fmp-CM': 'fmp',
        'fmp-Latn': 'fmp',
        'fmu': 'fmu',
        'fmu-Deva-IN': 'fmu',
        'fmu-Deva': 'fmu',
        'fmu-IN': 'fmu',
        'fnb': 'fnb',
        'fnb-Latn-VU': 'fnb',
        'fnb-Latn': 'fnb',
        'fnb-VU': 'fnb',
        'fng': 'fng',
        'fng-Latn-ZA': 'fng',
        'fng-Latn': 'fng',
        'fng-ZA': 'fng',
        'fni': 'fni',
        'fni-Latn-TD': 'fni',
        'fni-Latn': 'fni',
        'fni-TD': 'fni',
        'fo': 'fo',
        'fo-Latn-FO': 'fo',
        'fo-FO': 'fo',
        'fo-Latn': 'fo',
        'fo-DK': 'fo-DK',
        'fo-Latn-DK': 'fo-DK',
        'fod': 'fod',
        'fod-Latn-BJ': 'fod',
        'fod-BJ': 'fod',
        'fod-Latn': 'fod',
        'foi': 'foi',
        'foi-Latn-PG': 'foi',
        'foi-Latn': 'foi',
        'foi-PG': 'foi',
        'fom': 'fom',
        'fom-Latn-CD': 'fom',
        'fom-CD': 'fom',
        'fom-Latn': 'fom',
        'fon': 'fon',
        'fon-Latn-BJ': 'fon',
        'fon-BJ': 'fon',
        'fon-Latn': 'fon',
        'for': 'for',
        'for-Latn-PG': 'for',
        'for-Latn': 'for',
        'for-PG': 'for',
        'fos': 'fos',
        'fos-Latn-TW': 'fos',
        'fos-Latn': 'fos',
        'fos-TW': 'fos',
        'fpe': 'fpe',
        'fpe-Latn-GQ': 'fpe',
        'fpe-GQ': 'fpe',
        'fpe-Latn': 'fpe',
        'fqs': 'fqs',
        'fqs-Latn-PG': 'fqs',
        'fqs-Latn': 'fqs',
        'fqs-PG': 'fqs',
        'fr': 'fr',
        'fr-Latn-FR': 'fr',
        'fr-FR': 'fr',
        'fr-Latn': 'fr',
        'fr-BE': 'fr-BE',
        'fr-Latn-BE': 'fr-BE',
        'fr-BI': 'fr-BI',
        'fr-Latn-BI': 'fr-BI',
        'fr-Brai': 'fr-Brai',
        'fr-Brai-FR': 'fr-Brai',
        'fr-CA': 'fr-CA',
        'fr-Latn-CA': 'fr-CA',
        'fr-CD': 'fr-CD',
        'fr-Latn-CD': 'fr-CD',
        'fr-CH': 'fr-CH',
        'fr-Latn-CH': 'fr-CH',
        'fr-CI': 'fr-CI',
        'fr-Latn-CI': 'fr-CI',
        'fr-CM': 'fr-CM',
        'fr-Latn-CM': 'fr-CM',
        'fr-DJ': 'fr-DJ',
        'fr-Latn-DJ': 'fr-DJ',
        'fr-DZ': 'fr-DZ',
        'fr-Latn-DZ': 'fr-DZ',
        'fr-Dupl': 'fr-Dupl',
        'fr-Dupl-FR': 'fr-Dupl',
        'fr-GF': 'fr-GF',
        'fr-Latn-GF': 'fr-GF',
        'fr-GN': 'fr-GN',
        'fr-Latn-GN': 'fr-GN',
        'fr-HT': 'fr-HT',
        'fr-Latn-HT': 'fr-HT',
        'fr-KM': 'fr-KM',
        'fr-Latn-KM': 'fr-KM',
        'fr-LU': 'fr-LU',
        'fr-Latn-LU': 'fr-LU',
        'fr-MA': 'fr-MA',
        'fr-Latn-MA': 'fr-MA',
        'fr-MG': 'fr-MG',
        'fr-Latn-MG': 'fr-MG',
        'fr-ML': 'fr-ML',
        'fr-Latn-ML': 'fr-ML',
        'fr-MR': 'fr-MR',
        'fr-Latn-MR': 'fr-MR',
        'fr-MU': 'fr-MU',
        'fr-Latn-MU': 'fr-MU',
        'fr-RE': 'fr-RE',
        'fr-Latn-RE': 'fr-RE',
        'fr-RW': 'fr-RW',
        'fr-Latn-RW': 'fr-RW',
        'fr-SC': 'fr-SC',
        'fr-Latn-SC': 'fr-SC',
        'fr-SN': 'fr-SN',
        'fr-Latn-SN': 'fr-SN',
        'fr-SY': 'fr-SY',
        'fr-Latn-SY': 'fr-SY',
        'fr-TD': 'fr-TD',
        'fr-Latn-TD': 'fr-TD',
        'fr-TN': 'fr-TN',
        'fr-Latn-TN': 'fr-TN',
        'fr-VU': 'fr-VU',
        'fr-Latn-VU': 'fr-VU',
        'frc': 'frc',
        'frc-Latn-US': 'frc',
        'frc-Latn': 'frc',
        'frc-US': 'frc',
        'frd': 'frd',
        'frd-Latn-ID': 'frd',
        'frd-ID': 'frd',
        'frd-Latn': 'frd',
        'frk': 'frk',
        'frk-Latn-DE': 'frk',
        'frk-DE': 'frk',
        'frk-Latn': 'frk',
        'frm': 'frm',
        'frm-Latn-FR': 'frm',
        'frm-FR': 'frm',
        'frm-Latn': 'frm',
        'fro': 'fro',
        'fro-Latn-FR': 'fro',
        'fro-FR': 'fro',
        'fro-Latn': 'fro',
        'frp': 'frp',
        'frp-Latn-FR': 'frp',
        'frp-FR': 'frp',
        'frp-Latn': 'frp',
        'frq': 'frq',
        'frq-Latn-PG': 'frq',
        'frq-Latn': 'frq',
        'frq-PG': 'frq',
        'frr': 'frr',
        'frr-Latn-DE': 'frr',
        'frr-DE': 'frr',
        'frr-Latn': 'frr',
        'frs': 'frs',
        'frs-Latn-DE': 'frs',
        'frs-DE': 'frs',
        'frs-Latn': 'frs',
        'frt': 'frt',
        'frt-Latn-VU': 'frt',
        'frt-Latn': 'frt',
        'frt-VU': 'frt',
        'fse': 'fse',
        'fse-Zxxx-FI': 'fse',
        'fse-FI': 'fse',
        'fse-Zxxx': 'fse',
        'sgn-fse': 'fse',
        'sgn-fse-FI': 'fse',
        'fsl': 'fsl',
        'fsl-Zxxx-FR': 'fsl',
        'fsl-FR': 'fsl',
        'fsl-Zxxx': 'fsl',
        'sgn-fsl': 'fsl',
        'sgn-fsl-FR': 'fsl',
        'fss': 'fss',
        'fss-Zxxx-FI': 'fss',
        'fss-FI': 'fss',
        'fss-Zxxx': 'fss',
        'sgn-fss': 'fss',
        'sgn-fss-FI': 'fss',
        'fub': 'fub',
        'fub-Arab-CM': 'fub',
        'fub-Arab': 'fub',
        'fub-CM': 'fub',
        'fub-Latn': 'fub-Latn',
        'fub-Latn-CM': 'fub-Latn',
        'fud': 'fud',
        'fud-Latn-WF': 'fud',
        'fud-Latn': 'fud',
        'fud-WF': 'fud',
        'fue': 'fue',
        'fue-Latn-BJ': 'fue',
        'fue-BJ': 'fue',
        'fue-Latn': 'fue',
        'fuf': 'fuf',
        'fuf-Latn-GN': 'fuf',
        'fuf-GN': 'fuf',
        'fuf-Latn': 'fuf',
        'fuf-Adlm': 'fuf-Adlm',
        'fuf-Adlm-GN': 'fuf-Adlm',
        'fuf-Arab': 'fuf-Arab',
        'fuf-Arab-GN': 'fuf-Arab',
        'fuh-Arab': 'fuh-Arab',
        'fuh-Arab-NE': 'fuh-Arab',
        'fuh-BF': 'fuh-BF',
        'fuh-Latn-BF': 'fuh-BF',
        'fuh-Latn': 'fuh-Latn',
        'fuh-Latn-NE': 'fuh-Latn',
        'fui': 'fui',
        'fui-Latn-TD': 'fui',
        'fui-Latn': 'fui',
        'fui-TD': 'fui',
        'fuj': 'fuj',
        'fuj-Zyyy-SD': 'fuj',
        'fuj-SD': 'fuj',
        'fuj-Zyyy': 'fuj',
        'fum': 'fum',
        'fum-Latn-NG': 'fum',
        'fum-Latn': 'fum',
        'fum-NG': 'fum',
        'fun': 'fun',
        'fun-Latn-BR': 'fun',
        'fun-BR': 'fun',
        'fun-Latn': 'fun',
        'fuq': 'fuq',
        'fuq-Latn-NE': 'fuq',
        'fuq-Latn': 'fuq',
        'fuq-NE': 'fuq',
        'fur': 'fur',
        'fur-Latn-IT': 'fur',
        'fur-IT': 'fur',
        'fur-Latn': 'fur',
        'fut': 'fut',
        'fut-Latn-VU': 'fut',
        'fut-Latn': 'fut',
        'fut-VU': 'fut',
        'fuu': 'fuu',
        'fuu-Latn-CD': 'fuu',
        'fuu-CD': 'fuu',
        'fuu-Latn': 'fuu',
        'fuv': 'fuv',
        'fuv-Latn-NG': 'fuv',
        'fuv-Latn': 'fuv',
        'fuv-NG': 'fuv',
        'fuv-Arab': 'fuv-Arab',
        'fuv-Arab-NG': 'fuv-Arab',
        'fuy': 'fuy',
        'fuy-Latn-PG': 'fuy',
        'fuy-Latn': 'fuy',
        'fuy-PG': 'fuy',
        'fvr': 'fvr',
        'fvr-Latn-SD': 'fvr',
        'fvr-Latn': 'fvr',
        'fvr-SD': 'fvr',
        'fwa': 'fwa',
        'fwa-Latn-NC': 'fwa',
        'fwa-Latn': 'fwa',
        'fwa-NC': 'fwa',
        'fwe': 'fwe',
        'fwe-Latn-NA': 'fwe',
        'fwe-Latn': 'fwe',
        'fwe-NA': 'fwe',
        'fy': 'fy',
        'fy-Latn-NL': 'fy',
        'fy-Latn': 'fy',
        'fy-NL': 'fy',
        'ga': 'ga',
        'ga-Latn-IE': 'ga',
        'ga-IE': 'ga',
        'ga-Latn': 'ga',
        'ga-Latg': 'ga-Latg',
        'ga-Latg-IE': 'ga-Latg',
        'ga-Ogam': 'ga-Ogam',
        'ga-Ogam-IE': 'ga-Ogam',
        'gaa': 'gaa',
        'gaa-Latn-GH': 'gaa',
        'gaa-GH': 'gaa',
        'gaa-Latn': 'gaa',
        'gaa-Arab': 'gaa-Arab',
        'gaa-Arab-GH': 'gaa-Arab',
        'gab': 'gab',
        'gab-Latn-TD': 'gab',
        'gab-Latn': 'gab',
        'gab-TD': 'gab',
        'gac': 'gac',
        'gac-Zyyy-IN': 'gac',
        'gac-IN': 'gac',
        'gac-Zyyy': 'gac',
        'gad': 'gad',
        'gad-Latn-PH': 'gad',
        'gad-Latn': 'gad',
        'gad-PH': 'gad',
        'gae': 'gae',
        'gae-Latn-VE': 'gae',
        'gae-Latn': 'gae',
        'gae-VE': 'gae',
        'gaf': 'gaf',
        'gaf-Latn-PG': 'gaf',
        'gaf-Latn': 'gaf',
        'gaf-PG': 'gaf',
        'gag': 'gag',
        'gag-Latn-MD': 'gag',
        'gag-Latn': 'gag',
        'gag-MD': 'gag',
        'gag-Cyrl': 'gag-Cyrl',
        'gag-Cyrl-MD': 'gag-Cyrl',
        'gag-Grek': 'gag-Grek',
        'gag-Grek-MD': 'gag-Grek',
        'gah': 'gah',
        'gah-Latn-PG': 'gah',
        'gah-Latn': 'gah',
        'gah-PG': 'gah',
        'gai': 'gai',
        'gai-Latn-PG': 'gai',
        'gai-Latn': 'gai',
        'gai-PG': 'gai',
        'gaj': 'gaj',
        'gaj-Latn-PG': 'gaj',
        'gaj-Latn': 'gaj',
        'gaj-PG': 'gaj',
        'gak': 'gak',
        'gak-Latn-ID': 'gak',
        'gak-ID': 'gak',
        'gak-Latn': 'gak',
        'gal': 'gal',
        'gal-Latn-TL': 'gal',
        'gal-Latn': 'gal',
        'gal-TL': 'gal',
        'ilw': 'gal',
        'ilw-TL': 'gal',
        'ime': 'gal',
        'ime-Latn': 'gal',
        'ime-Latn-TL': 'gal',
        'ime-TL': 'gal',
        'gam': 'gam',
        'gam-Latn-PG': 'gam',
        'gam-Latn': 'gam',
        'gam-PG': 'gam',
        'gan': 'gan',
        'gan-Hans-CN': 'gan',
        'gan-CN': 'gan',
        'gan-Hans': 'gan',
        'zh-gan': 'gan',
        'zh-gan-CN': 'gan',
        'gan-Hant': 'gan-Hant',
        'gan-Hant-CN': 'gan-Hant',
        'gan-Latn': 'gan-Latn',
        'gan-Latn-CN': 'gan-Latn',
        'gao': 'gao',
        'gao-Latn-PG': 'gao',
        'gao-Latn': 'gao',
        'gao-PG': 'gao',
        'gap': 'gap',
        'gap-Latn-PG': 'gap',
        'gap-Latn': 'gap',
        'gap-PG': 'gap',
        'gaq': 'gaq',
        'gaq-Orya-IN': 'gaq',
        'gaq-IN': 'gaq',
        'gaq-Orya': 'gaq',
        'gar': 'gar',
        'gar-Latn-PG': 'gar',
        'gar-Latn': 'gar',
        'gar-PG': 'gar',
        'gas': 'gas',
        'gas-Gujr-IN': 'gas',
        'gas-Gujr': 'gas',
        'gas-IN': 'gas',
        'gat': 'gat',
        'gat-Latn-PG': 'gat',
        'gat-Latn': 'gat',
        'gat-PG': 'gat',
        'gau': 'gau',
        'gau-Telu-IN': 'gau',
        'gau-IN': 'gau',
        'gau-Telu': 'gau',
        'gaw': 'gaw',
        'gaw-Latn-PG': 'gaw',
        'gaw-Latn': 'gaw',
        'gaw-PG': 'gaw',
        'gax': 'gax',
        'gax-Latn-ET': 'gax',
        'gax-ET': 'gax',
        'gax-Latn': 'gax',
        'gax-Ethi': 'gax-Ethi',
        'gax-Ethi-ET': 'gax-Ethi',
        'gax-Ethi-x-borana': 'gax-Ethi-x-borana',
        'gax-Ethi-ET-x-borana': 'gax-Ethi-x-borana',
        'gax-ET-x-borana': 'gax-Ethi-x-borana',
        'gax-Ethi-x-guji': 'gax-Ethi-x-guji',
        'gax-Ethi-ET-x-guji': 'gax-Ethi-x-guji',
        'gax-ET-x-guji': 'gax-Ethi-x-guji',
        'gay': 'gay',
        'gay-Latn-ID': 'gay',
        'gay-ID': 'gay',
        'gay-Latn': 'gay',
        'gba': 'gba',
        'gba-Latn-CF': 'gba',
        'gba-CF': 'gba',
        'gba-Latn': 'gba',
        'gya': 'gba',
        'gya-CF': 'gba',
        'gya-Latn': 'gba',
        'gya-Latn-CF': 'gba',
        'gba-Arab': 'gba-Arab',
        'gba-Arab-CF': 'gba-Arab',
        'gbb': 'gbb',
        'gbb-Latn-AU': 'gbb',
        'gbb-AU': 'gbb',
        'gbb-Latn': 'gbb',
        'gbd': 'gbd',
        'gbd-Latn-AU': 'gbd',
        'gbd-AU': 'gbd',
        'gbd-Latn': 'gbd',
        'gbe': 'gbe',
        'gbe-Latn-PG': 'gbe',
        'gbe-Latn': 'gbe',
        'gbe-PG': 'gbe',
        'gbf': 'gbf',
        'gbf-Latn-PG': 'gbf',
        'gbf-Latn': 'gbf',
        'gbf-PG': 'gbf',
        'gbg': 'gbg',
        'gbg-Latn-CF': 'gbg',
        'gbg-CF': 'gbg',
        'gbg-Latn': 'gbg',
        'gbh': 'gbh',
        'gbh-Latn-BJ': 'gbh',
        'gbh-BJ': 'gbh',
        'gbh-Latn': 'gbh',
        'gbi': 'gbi',
        'gbi-Latn-ID': 'gbi',
        'gbi-ID': 'gbi',
        'gbi-Latn': 'gbi',
        'gbj': 'gbj',
        'gbj-Orya-IN': 'gbj',
        'gbj-IN': 'gbj',
        'gbj-Orya': 'gbj',
        'gbk': 'gbk',
        'gbk-Deva-IN': 'gbk',
        'gbk-Deva': 'gbk',
        'gbk-IN': 'gbk',
        'gbk-Takr': 'gbk-Takr',
        'gbk-Takr-IN': 'gbk-Takr',
        'gbl': 'gbl',
        'gbl-Gujr-IN': 'gbl',
        'gbl-Gujr': 'gbl',
        'gbl-IN': 'gbl',
        'gbl-Deva': 'gbl-Deva',
        'gbl-Deva-IN': 'gbl-Deva',
        'gbm': 'gbm',
        'gbm-Deva-IN': 'gbm',
        'gbm-Deva': 'gbm',
        'gbm-IN': 'gbm',
        'gbn': 'gbn',
        'gbn-Latn-SS': 'gbn',
        'gbn-Latn': 'gbn',
        'gbn-SS': 'gbn',
        'gbp': 'gbp',
        'gbp-Latn-CF': 'gbp',
        'gbp-CF': 'gbp',
        'gbp-Latn': 'gbp',
        'gbq': 'gbq',
        'gbq-Latn-CF': 'gbq',
        'gbq-CF': 'gbq',
        'gbq-Latn': 'gbq',
        'gbr': 'gbr',
        'gbr-Latn-NG': 'gbr',
        'gbr-Latn': 'gbr',
        'gbr-NG': 'gbr',
        'gbs': 'gbs',
        'gbs-Latn-BJ': 'gbs',
        'gbs-BJ': 'gbs',
        'gbs-Latn': 'gbs',
        'gbu': 'gbu',
        'gbu-Latn-AU': 'gbu',
        'gbu-AU': 'gbu',
        'gbu-Latn': 'gbu',
        'gbv': 'gbv',
        'gbv-Latn-CF': 'gbv',
        'gbv-CF': 'gbv',
        'gbv-Latn': 'gbv',
        'gbw': 'gbw',
        'gbw-Latn-AU': 'gbw',
        'gbw-AU': 'gbw',
        'gbw-Latn': 'gbw',
        'gbx': 'gbx',
        'gbx-Latn-BJ': 'gbx',
        'gbx-BJ': 'gbx',
        'gbx-Latn': 'gbx',
        'gby': 'gby',
        'gby-Latn-NG': 'gby',
        'gby-Latn': 'gby',
        'gby-NG': 'gby',
        'gbz': 'gbz',
        'gbz-Arab-IR': 'gbz',
        'gbz-Arab': 'gbz',
        'gbz-IR': 'gbz',
        'gcc': 'gcc',
        'gcc-Latn-PG': 'gcc',
        'gcc-Latn': 'gcc',
        'gcc-PG': 'gcc',
        'gcd': 'gcd',
        'gcd-Latn-AU': 'gcd',
        'gcd-AU': 'gcd',
        'gcd-Latn': 'gcd',
        'gce': 'gce',
        'gce-Zyyy-US': 'gce',
        'gce-US': 'gce',
        'gce-Zyyy': 'gce',
        'gcf': 'gcf',
        'gcf-Latn-GP': 'gcf',
        'gcf-GP': 'gcf',
        'gcf-Latn': 'gcf',
        'gcl': 'gcl',
        'gcl-Latn-GD': 'gcl',
        'gcl-GD': 'gcl',
        'gcl-Latn': 'gcl',
        'gcn': 'gcn',
        'gcn-Latn-PG': 'gcn',
        'gcn-Latn': 'gcn',
        'gcn-PG': 'gcn',
        'gcr': 'gcr',
        'gcr-Latn-GF': 'gcr',
        'gcr-GF': 'gcr',
        'gcr-Latn': 'gcr',
        'gct': 'gct',
        'gct-Latn-VE': 'gct',
        'gct-Latn': 'gct',
        'gct-VE': 'gct',
        'gd': 'gd',
        'gd-Latn-GB': 'gd',
        'gd-GB': 'gd',
        'gd-Latn': 'gd',
        'gda': 'gda',
        'gda-Zyyy-IN': 'gda',
        'gda-IN': 'gda',
        'gda-Zyyy': 'gda',
        'gdb': 'gdb',
        'gdb-Orya-IN': 'gdb',
        'gdb-IN': 'gdb',
        'gdb-Orya': 'gdb',
        'gdb-Telu': 'gdb-Telu',
        'gdb-Telu-IN': 'gdb-Telu',
        'gdc': 'gdc',
        'gdc-Latn-AU': 'gdc',
        'gdc-AU': 'gdc',
        'gdc-Latn': 'gdc',
        'gdd': 'gdd',
        'gdd-Latn-PG': 'gdd',
        'gdd-Latn': 'gdd',
        'gdd-PG': 'gdd',
        'gde': 'gde',
        'gde-Latn-NG': 'gde',
        'gde-Latn': 'gde',
        'gde-NG': 'gde',
        'gdf': 'gdf',
        'gdf-Latn-NG': 'gdf',
        'gdf-Latn': 'gdf',
        'gdf-NG': 'gdf',
        'gdg': 'gdg',
        'gdg-Latn-PH': 'gdg',
        'gdg-Latn': 'gdg',
        'gdg-PH': 'gdg',
        'gdh': 'gdh',
        'gdh-Latn-AU': 'gdh',
        'gdh-AU': 'gdh',
        'gdh-Latn': 'gdh',
        'gdi': 'gdi',
        'gdi-Latn-CF': 'gdi',
        'gdi-CF': 'gdi',
        'gdi-Latn': 'gdi',
        'gdj': 'gdj',
        'gdj-Latn-AU': 'gdj',
        'gdj-AU': 'gdj',
        'gdj-Latn': 'gdj',
        'kvs': 'gdj',
        'kvs-AU': 'gdj',
        'kvs-Latn': 'gdj',
        'kvs-Latn-AU': 'gdj',
        'gdk': 'gdk',
        'gdk-Latn-TD': 'gdk',
        'gdk-Latn': 'gdk',
        'gdk-TD': 'gdk',
        'gdl': 'gdl',
        'gdl-Latn-ET': 'gdl',
        'gdl-ET': 'gdl',
        'gdl-Latn': 'gdl',
        'gdl-Ethi': 'gdl-Ethi',
        'gdl-Ethi-ET': 'gdl-Ethi',
        'gdm': 'gdm',
        'gdm-Latn-TD': 'gdm',
        'gdm-Latn': 'gdm',
        'gdm-TD': 'gdm',
        'gdn': 'gdn',
        'gdn-Latn-PG': 'gdn',
        'gdn-Latn': 'gdn',
        'gdn-PG': 'gdn',
        'gdo': 'gdo',
        'gdo-Cyrl-RU': 'gdo',
        'gdo-Cyrl': 'gdo',
        'gdo-RU': 'gdo',
        'gdq': 'gdq',
        'gdq-Latn-YE': 'gdq',
        'gdq-Latn': 'gdq',
        'gdq-YE': 'gdq',
        'gdr': 'gdr',
        'gdr-Latn-PG': 'gdr',
        'gdr-Latn': 'gdr',
        'gdr-PG': 'gdr',
        'gds': 'gds',
        'gds-Zxxx-NP': 'gds',
        'gds-NP': 'gds',
        'gds-Zxxx': 'gds',
        'sgn-gds': 'gds',
        'sgn-gds-NP': 'gds',
        'gdt': 'gdt',
        'gdt-Latn-AU': 'gdt',
        'gdt-AU': 'gdt',
        'gdt-Latn': 'gdt',
        'gdu': 'gdu',
        'gdu-Latn-NG': 'gdu',
        'gdu-Latn': 'gdu',
        'gdu-NG': 'gdu',
        'gdx': 'gdx',
        'gdx-Zyyy-IN': 'gdx',
        'gdx-IN': 'gdx',
        'gdx-Zyyy': 'gdx',
        'gea': 'gea',
        'gea-Latn-NG': 'gea',
        'gea-Latn': 'gea',
        'gea-NG': 'gea',
        'geb': 'geb',
        'geb-Latn-PG': 'geb',
        'geb-Latn': 'geb',
        'geb-PG': 'geb',
        'gec': 'gec',
        'gec-Latn-LR': 'gec',
        'gec-LR': 'gec',
        'gec-Latn': 'gec',
        'ged': 'ged',
        'ged-Latn-NG': 'ged',
        'ged-Latn': 'ged',
        'ged-NG': 'ged',
        'gef': 'gef',
        'gef-Latn-ID': 'gef',
        'gef-ID': 'gef',
        'gef-Latn': 'gef',
        'geg': 'geg',
        'geg-Latn-NG': 'geg',
        'geg-Latn': 'geg',
        'geg-NG': 'geg',
        'geh': 'geh',
        'geh-Latn-CA': 'geh',
        'geh-CA': 'geh',
        'geh-Latn': 'geh',
        'gei': 'gei',
        'gei-Latn-ID': 'gei',
        'gei-ID': 'gei',
        'gei-Latn': 'gei',
        'gej': 'gej',
        'gej-Latn-TG': 'gej',
        'gej-Latn': 'gej',
        'gej-TG': 'gej',
        'gek': 'gek',
        'gek-Latn-NG': 'gek',
        'gek-Latn': 'gek',
        'gek-NG': 'gek',
        'gel': 'gel',
        'gel-Latn-NG': 'gel',
        'gel-Latn': 'gel',
        'gel-NG': 'gel',
        'geq': 'geq',
        'geq-Latn-CF': 'geq',
        'geq-CF': 'geq',
        'geq-Latn': 'geq',
        'ges': 'ges',
        'ges-Latn-ID': 'ges',
        'ges-ID': 'ges',
        'ges-Latn': 'ges',
        'gev': 'gev',
        'gev-Latn-GA': 'gev',
        'gev-GA': 'gev',
        'gev-Latn': 'gev',
        'gew': 'gew',
        'gew-Latn-NG': 'gew',
        'gew-Latn': 'gew',
        'gew-NG': 'gew',
        'gex': 'gex',
        'gex-Zyyy-SO': 'gex',
        'gex-SO': 'gex',
        'gex-Zyyy': 'gex',
        'gey': 'gey',
        'gey-Latn-CD': 'gey',
        'gey-CD': 'gey',
        'gey-Latn': 'gey',
        'gez': 'gez',
        'gez-Ethi-ET': 'gez',
        'gez-ET': 'gez',
        'gez-Ethi': 'gez',
        'gfk': 'gfk',
        'gfk-Latn-PG': 'gfk',
        'gfk-Latn': 'gfk',
        'gfk-PG': 'gfk',
        'gft': 'gft',
        'gft-Zyyy-ET': 'gft',
        'gft-ET': 'gft',
        'gft-Zyyy': 'gft',
        'gga': 'gga',
        'gga-Latn-SB': 'gga',
        'gga-Latn': 'gga',
        'gga-SB': 'gga',
        'ggb': 'ggb',
        'ggb-Latn-LR': 'ggb',
        'ggb-LR': 'ggb',
        'ggb-Latn': 'ggb',
        'ggd': 'ggd',
        'ggd-Latn-AU': 'ggd',
        'ggd-AU': 'ggd',
        'ggd-Latn': 'ggd',
        'gge': 'gge',
        'gge-Latn-AU': 'gge',
        'gge-AU': 'gge',
        'gge-Latn': 'gge',
        'ggg': 'ggg',
        'ggg-Arab-PK': 'ggg',
        'ggg-Arab': 'ggg',
        'ggg-PK': 'ggg',
        'ggk': 'ggk',
        'ggk-Latn-AU': 'ggk',
        'ggk-AU': 'ggk',
        'ggk-Latn': 'ggk',
        'ggl': 'ggl',
        'ggl-Latn-PG': 'ggl',
        'ggl-Latn': 'ggl',
        'ggl-PG': 'ggl',
        'ggt': 'ggt',
        'ggt-Latn-PG': 'ggt',
        'ggt-Latn': 'ggt',
        'ggt-PG': 'ggt',
        'ggu': 'ggu',
        'ggu-Latn-CI': 'ggu',
        'ggu-CI': 'ggu',
        'ggu-Latn': 'ggu',
        'ggw': 'ggw',
        'ggw-Latn-PG': 'ggw',
        'ggw-Latn': 'ggw',
        'ggw-PG': 'ggw',
        'gha': 'gha',
        'gha-Zyyy-LY': 'gha',
        'gha-LY': 'gha',
        'gha-Zyyy': 'gha',
        'ghc': 'ghc',
        'ghc-Latn-GB': 'ghc',
        'ghc-GB': 'ghc',
        'ghc-Latn': 'ghc',
        'ghe': 'ghe',
        'ghe-Deva-NP': 'ghe',
        'ghe-Deva': 'ghe',
        'ghe-NP': 'ghe',
        'ghh': 'ghh',
        'ghh-Zyyy-NP': 'ghh',
        'ghh-NP': 'ghh',
        'ghh-Zyyy': 'ghh',
        'ghk': 'ghk',
        'ghk-Latn-MM': 'ghk',
        'ghk-Latn': 'ghk',
        'ghk-MM': 'ghk',
        'ghl': 'ghl',
        'ghl-Zyyy-SD': 'ghl',
        'ghl-SD': 'ghl',
        'ghl-Zyyy': 'ghl',
        'ghn': 'ghn',
        'ghn-Latn-SB': 'ghn',
        'ghn-Latn': 'ghn',
        'ghn-SB': 'ghn',
        'gho': 'gho',
        'gho-Zyyy-MA': 'gho',
        'gho-MA': 'gho',
        'gho-Zyyy': 'gho',
        'ghr': 'ghr',
        'ghr-Arab-PK': 'ghr',
        'ghr-Arab': 'ghr',
        'ghr-PK': 'ghr',
        'ghs': 'ghs',
        'ghs-Latn-PG': 'ghs',
        'ghs-Latn': 'ghs',
        'ghs-PG': 'ghs',
        'ght': 'ght',
        'ght-Tibt-NP': 'ght',
        'ght-NP': 'ght',
        'ght-Tibt': 'ght',
        'gia': 'gia',
        'gia-Latn-AU': 'gia',
        'gia-AU': 'gia',
        'gia-Latn': 'gia',
        'gib': 'gib',
        'gib-Latn-NG': 'gib',
        'gib-Latn': 'gib',
        'gib-NG': 'gib',
        'gic': 'gic',
        'gic-Latn-ZA': 'gic',
        'gic-Latn': 'gic',
        'gic-ZA': 'gic',
        'gid': 'gid',
        'gid-Latn-CM': 'gid',
        'gid-CM': 'gid',
        'gid-Latn': 'gid',
        'gie': 'gie',
        'gie-Latn-CI': 'gie',
        'gie-CI': 'gie',
        'gie-Latn': 'gie',
        'gig': 'gig',
        'gig-Arab-PK': 'gig',
        'gig-Arab': 'gig',
        'gig-PK': 'gig',
        'gih': 'gih',
        'gih-Latn-AU': 'gih',
        'gih-AU': 'gih',
        'gih-Latn': 'gih',
        'gil': 'gil',
        'gil-Latn-KI': 'gil',
        'gil-KI': 'gil',
        'gil-Latn': 'gil',
        'gim': 'gim',
        'gim-Latn-PG': 'gim',
        'gim-Latn': 'gim',
        'gim-PG': 'gim',
        'gin': 'gin',
        'gin-Cyrl-RU': 'gin',
        'gin-Cyrl': 'gin',
        'gin-RU': 'gin',
        'gip': 'gip',
        'gip-Latn-PG': 'gip',
        'gip-Latn': 'gip',
        'gip-PG': 'gip',
        'giq': 'giq',
        'giq-Latn-VN': 'giq',
        'giq-Latn': 'giq',
        'giq-VN': 'giq',
        'gir': 'gir',
        'gir-Latn-VN': 'gir',
        'gir-Latn': 'gir',
        'gir-VN': 'gir',
        'gis': 'gis',
        'gis-Latn-CM': 'gis',
        'gis-CM': 'gis',
        'gis-Latn': 'gis',
        'git': 'git',
        'git-Latn-CA': 'git',
        'git-CA': 'git',
        'git-Latn': 'git',
        'giu': 'giu',
        'giu-Zyyy-CN': 'giu',
        'giu-CN': 'giu',
        'giu-Zyyy': 'giu',
        'giw': 'giw',
        'giw-Zyyy-CN': 'giw',
        'giw-CN': 'giw',
        'giw-Zyyy': 'giw',
        'gix': 'gix',
        'gix-Latn-CD': 'gix',
        'gix-CD': 'gix',
        'gix-Latn': 'gix',
        'giy': 'giy',
        'giy-Latn-AU': 'giy',
        'giy-AU': 'giy',
        'giy-Latn': 'giy',
        'giz': 'giz',
        'giz-Latn-CM': 'giz',
        'giz-CM': 'giz',
        'giz-Latn': 'giz',
        'gji': 'gji',
        'gji-Latn-NG': 'gji',
        'gji-Latn': 'gji',
        'gji-NG': 'gji',
        'gjk': 'gjk',
        'gjk-Arab-PK': 'gjk',
        'gjk-Arab': 'gjk',
        'gjk-PK': 'gjk',
        'gjk-Gujr': 'gjk-Gujr',
        'gjk-Gujr-PK': 'gjk-Gujr',
        'gjm': 'gjm',
        'gjm-Latn-AU': 'gjm',
        'gjm-AU': 'gjm',
        'gjm-Latn': 'gjm',
        'gjn': 'gjn',
        'gjn-Latn-GH': 'gjn',
        'gjn-GH': 'gjn',
        'gjn-Latn': 'gjn',
        'gjn-Arab': 'gjn-Arab',
        'gjn-Arab-GH': 'gjn-Arab',
        'gjr': 'gjr',
        'gjr-Latn-AU': 'gjr',
        'gjr-AU': 'gjr',
        'gjr-Latn': 'gjr',
        'gju': 'gju',
        'gju-Arab-PK': 'gju',
        'gju-Arab': 'gju',
        'gju-PK': 'gju',
        'gju-Deva': 'gju-Deva',
        'gju-Deva-IN': 'gju-Deva',
        'gju-IN': 'gju-Deva',
        'gka': 'gka',
        'gka-Latn-PG': 'gka',
        'gka-Latn': 'gka',
        'gka-PG': 'gka',
        'gkd': 'gkd',
        'gkd-Latn-PG': 'gkd',
        'gkd-Latn': 'gkd',
        'gkd-PG': 'gkd',
        'gke': 'gke',
        'gke-Latn-CM': 'gke',
        'gke-CM': 'gke',
        'gke-Latn': 'gke',
        'gkn': 'gkn',
        'gkn-Latn-NG': 'gkn',
        'gkn-Latn': 'gkn',
        'gkn-NG': 'gkn',
        'gko': 'gko',
        'gko-Latn-AU': 'gko',
        'gko-AU': 'gko',
        'gko-Latn': 'gko',
        'gkp': 'gkp',
        'gkp-Latn-GN': 'gkp',
        'gkp-GN': 'gkp',
        'gkp-Latn': 'gkp',
        'gku': 'gku',
        'gku-Latn-ZA': 'gku',
        'gku-Latn': 'gku',
        'gku-ZA': 'gku',
        'gl': 'gl',
        'gl-Latn-ES': 'gl',
        'gl-ES': 'gl',
        'gl-Latn': 'gl',
        'glc': 'glc',
        'glc-Latn-TD': 'glc',
        'glc-Latn': 'glc',
        'glc-TD': 'glc',
        'gld': 'gld',
        'gld-Cyrl-RU': 'gld',
        'gld-Cyrl': 'gld',
        'gld-RU': 'gld',
        'glh': 'glh',
        'glh-Arab-AF': 'glh',
        'glh-AF': 'glh',
        'glh-Arab': 'glh',
        'glj': 'glj',
        'glj-Latn-TD': 'glj',
        'glj-Latn': 'glj',
        'glj-TD': 'glj',
        'glk': 'glk',
        'glk-Arab-IR': 'glk',
        'glk-Arab': 'glk',
        'glk-IR': 'glk',
        'glk-Latn': 'glk-Latn',
        'glk-Latn-IR': 'glk-Latn',
        'gll': 'gll',
        'gll-Latn-AU': 'gll',
        'gll-AU': 'gll',
        'gll-Latn': 'gll',
        'glo': 'glo',
        'glo-Latn-NG': 'glo',
        'glo-Latn': 'glo',
        'glo-NG': 'glo',
        'glr': 'glr',
        'glr-Latn-LR': 'glr',
        'glr-LR': 'glr',
        'glr-Latn': 'glr',
        'glu': 'glu',
        'glu-Latn-TD': 'glu',
        'glu-Latn': 'glu',
        'glu-TD': 'glu',
        'glw': 'glw',
        'glw-Latn-NG': 'glw',
        'glw-Latn': 'glw',
        'glw-NG': 'glw',
        'gly': 'gly',
        'gly-Zyyy-SD': 'gly',
        'gly-SD': 'gly',
        'gly-Zyyy': 'gly',
        'gma': 'gma',
        'gma-Latn-AU': 'gma',
        'gma-AU': 'gma',
        'gma-Latn': 'gma',
        'gmb': 'gmb',
        'gmb-Latn-SB': 'gmb',
        'gmb-Latn': 'gmb',
        'gmb-SB': 'gmb',
        'gmd': 'gmd',
        'gmd-Latn-NG': 'gmd',
        'gmd-Latn': 'gmd',
        'gmd-NG': 'gmd',
        'gmg': 'gmg',
        'gmg-Latn-PG': 'gmg',
        'gmg-Latn': 'gmg',
        'gmg-PG': 'gmg',
        'gmh': 'gmh',
        'gmh-Latn-DE': 'gmh',
        'gmh-DE': 'gmh',
        'gmh-Latn': 'gmh',
        'gml': 'gml',
        'gml-Latf-DE': 'gml',
        'gml-DE': 'gml',
        'gml-Latf': 'gml',
        'gmm': 'gmm',
        'gmm-Latn-CM': 'gmm',
        'gmm-CM': 'gmm',
        'gmm-Latn': 'gmm',
        'gmn': 'gmn',
        'gmn-Latn-CM': 'gmn',
        'gmn-CM': 'gmn',
        'gmn-Latn': 'gmn',
        'gmr': 'gmr',
        'gmr-Latn-AU': 'gmr',
        'gmr-AU': 'gmr',
        'gmr-Latn': 'gmr',
        'gmu': 'gmu',
        'gmu-Latn-PG': 'gmu',
        'gmu-Latn': 'gmu',
        'gmu-PG': 'gmu',
        'gmv': 'gmv',
        'gmv-Ethi-ET': 'gmv',
        'gmv-ET': 'gmv',
        'gmv-Ethi': 'gmv',
        'gmv-Latn': 'gmv-Latn',
        'gmv-Latn-ET': 'gmv-Latn',
        'gmx': 'gmx',
        'gmx-Latn-TZ': 'gmx',
        'gmx-Latn': 'gmx',
        'gmx-TZ': 'gmx',
        'gmy': 'gmy',
        'gmy-Zyyy-GR': 'gmy',
        'gmy-GR': 'gmy',
        'gmy-Zyyy': 'gmy',
        'gmz': 'gmz',
        'gmz-Latn-NG': 'gmz',
        'gmz-Latn': 'gmz',
        'gmz-NG': 'gmz',
        'gn': 'gn',
        'gn-Latn-PY': 'gn',
        'gn-Latn': 'gn',
        'gn-PY': 'gn',
        'gug': 'gn',
        'gug-Latn': 'gn',
        'gug-Latn-PY': 'gn',
        'gug-PY': 'gn',
        'gna': 'gna',
        'gna-Latn-BF': 'gna',
        'gna-BF': 'gna',
        'gna-Latn': 'gna',
        'gnb': 'gnb',
        'gnb-Latn-IN': 'gnb',
        'gnb-IN': 'gnb',
        'gnb-Latn': 'gnb',
        'gnc': 'gnc',
        'gnc-Latn-ES': 'gnc',
        'gnc-ES': 'gnc',
        'gnc-Latn': 'gnc',
        'gnd': 'gnd',
        'gnd-Latn-CM': 'gnd',
        'gnd-CM': 'gnd',
        'gnd-Latn': 'gnd',
        'gne': 'gne',
        'gne-Latn-NG': 'gne',
        'gne-Latn': 'gne',
        'gne-NG': 'gne',
        'gng': 'gng',
        'gng-Latn-TG': 'gng',
        'gng-Latn': 'gng',
        'gng-TG': 'gng',
        'gnh': 'gnh',
        'gnh-Latn-NG': 'gnh',
        'gnh-Latn': 'gnh',
        'gnh-NG': 'gnh',
        'gni': 'gni',
        'gni-Latn-AU': 'gni',
        'gni-AU': 'gni',
        'gni-Latn': 'gni',
        'gnj': 'gnj',
        'gnj-Latn-CI': 'gnj',
        'gnj-CI': 'gnj',
        'gnj-Latn': 'gnj',
        'gnk': 'gnk',
        'gnk-Latn-BW': 'gnk',
        'gnk-BW': 'gnk',
        'gnk-Latn': 'gnk',
        'gnl': 'gnl',
        'gnl-Latn-AU': 'gnl',
        'gnl-AU': 'gnl',
        'gnl-Latn': 'gnl',
        'gnm': 'gnm',
        'gnm-Latn-PG': 'gnm',
        'gnm-Latn': 'gnm',
        'gnm-PG': 'gnm',
        'gnn': 'gnn',
        'gnn-Latn-AU': 'gnn',
        'gnn-AU': 'gnn',
        'gnn-Latn': 'gnn',
        'gnq': 'gnq',
        'gnq-Latn-MY': 'gnq',
        'gnq-Latn': 'gnq',
        'gnq-MY': 'gnq',
        'gnr': 'gnr',
        'gnr-Latn-AU': 'gnr',
        'gnr-AU': 'gnr',
        'gnr-Latn': 'gnr',
        'gnt': 'gnt',
        'gnt-Latn-PG': 'gnt',
        'gnt-Latn': 'gnt',
        'gnt-PG': 'gnt',
        'gnu': 'gnu',
        'gnu-Latn-PG': 'gnu',
        'gnu-Latn': 'gnu',
        'gnu-PG': 'gnu',
        'gnw': 'gnw',
        'gnw-Latn-BO': 'gnw',
        'gnw-BO': 'gnw',
        'gnw-Latn': 'gnw',
        'gnz': 'gnz',
        'gnz-Latn-CF': 'gnz',
        'gnz-CF': 'gnz',
        'gnz-Latn': 'gnz',
        'goa': 'goa',
        'goa-Latn-CI': 'goa',
        'goa-CI': 'goa',
        'goa-Latn': 'goa',
        'gob': 'gob',
        'gob-Latn-CO': 'gob',
        'gob-CO': 'gob',
        'gob-Latn': 'gob',
        'goc': 'goc',
        'goc-Latn-PG': 'goc',
        'goc-Latn': 'goc',
        'goc-PG': 'goc',
        'god': 'god',
        'god-Latn-CI': 'god',
        'god-CI': 'god',
        'god-Latn': 'god',
        'goe': 'goe',
        'goe-Zyyy-BT': 'goe',
        'goe-BT': 'goe',
        'goe-Zyyy': 'goe',
        'gof': 'gof',
        'gof-Ethi-ET': 'gof',
        'gof-ET': 'gof',
        'gof-Ethi': 'gof',
        'gof-Latn': 'gof-Latn',
        'gof-Latn-ET': 'gof-Latn',
        'gog': 'gog',
        'gog-Latn-TZ': 'gog',
        'gog-Latn': 'gog',
        'gog-TZ': 'gog',
        'goh': 'goh',
        'goh-Latn-DE': 'goh',
        'goh-DE': 'goh',
        'goh-Latn': 'goh',
        'goi': 'goi',
        'goi-Latn-PG': 'goi',
        'goi-Latn': 'goi',
        'goi-PG': 'goi',
        'goj': 'goj',
        'goj-Zyyy-IN': 'goj',
        'goj-IN': 'goj',
        'goj-Zyyy': 'goj',
        'gok': 'gok',
        'gok-Deva-IN': 'gok',
        'gok-Deva': 'gok',
        'gok-IN': 'gok',
        'gol': 'gol',
        'gol-Latn-LR': 'gol',
        'gol-LR': 'gol',
        'gol-Latn': 'gol',
        'gom': 'gom',
        'gom-Deva-IN': 'gom',
        'gom-Deva': 'gom',
        'gom-IN': 'gom',
        'kok-gom': 'gom',
        'kok-gom-IN': 'gom',
        'gom-Knda': 'gom-Knda',
        'gom-Knda-IN': 'gom-Knda',
        'gom-Latn': 'gom-Latn',
        'gom-Latn-IN': 'gom-Latn',
        'gon': 'gon',
        'gon-Telu-IN': 'gon',
        'gon-IN': 'gon',
        'gon-Telu': 'gon',
        'gon-Deva': 'gon-Deva',
        'gon-Deva-IN': 'gon-Deva',
        'gno': 'gon-Deva',
        'gno-Deva': 'gon-Deva',
        'gno-Deva-IN': 'gon-Deva',
        'gno-IN': 'gon-Deva',
        'gon-Gonm': 'gon-Gonm',
        'gon-Gonm-IN': 'gon-Gonm',
        'gno-Gonm': 'gon-Gonm',
        'gno-Gonm-IN': 'gon-Gonm',
        'goo': 'goo',
        'goo-Latn-FJ': 'goo',
        'goo-FJ': 'goo',
        'goo-Latn': 'goo',
        'gop': 'gop',
        'gop-Latn-ID': 'gop',
        'gop-ID': 'gop',
        'gop-Latn': 'gop',
        'goq': 'goq',
        'goq-Latn-ID': 'goq',
        'goq-ID': 'goq',
        'goq-Latn': 'goq',
        'gor': 'gor',
        'gor-Latn-ID': 'gor',
        'gor-ID': 'gor',
        'gor-Latn': 'gor',
        'gos': 'gos',
        'gos-Latn-NL': 'gos',
        'gos-Latn': 'gos',
        'gos-NL': 'gos',
        'got': 'got',
        'got-Goth-UA': 'got',
        'got-Goth': 'got',
        'got-UA': 'got',
        'gou': 'gou',
        'gou-Latn-CM': 'gou',
        'gou-CM': 'gou',
        'gou-Latn': 'gou',
        'gow': 'gow',
        'gow-Latn-TZ': 'gow',
        'gow-Latn': 'gow',
        'gow-TZ': 'gow',
        'gox': 'gox',
        'gox-Latn-CD': 'gox',
        'gox-CD': 'gox',
        'gox-Latn': 'gox',
        'goy': 'goy',
        'goy-Latn-TD': 'goy',
        'goy-Latn': 'goy',
        'goy-TD': 'goy',
        'goz': 'goz',
        'goz-Zyyy-IR': 'goz',
        'goz-IR': 'goz',
        'goz-Zyyy': 'goz',
        'gpa': 'gpa',
        'gpa-Latn-NG': 'gpa',
        'gpa-Latn': 'gpa',
        'gpa-NG': 'gpa',
        'gpe': 'gpe',
        'gpe-Latn-GH': 'gpe',
        'gpe-GH': 'gpe',
        'gpe-Latn': 'gpe',
        'gpn': 'gpn',
        'gpn-Latn-PG': 'gpn',
        'gpn-Latn': 'gpn',
        'gpn-PG': 'gpn',
        'gqa': 'gqa',
        'gqa-Latn-NG': 'gqa',
        'gqa-Latn': 'gqa',
        'gqa-NG': 'gqa',
        'gqi': 'gqi',
        'gqi-Zyyy-CN': 'gqi',
        'gqi-CN': 'gqi',
        'gqi-Zyyy': 'gqi',
        'gqn': 'gqn',
        'gqn-Latn-BR': 'gqn',
        'gqn-BR': 'gqn',
        'gqn-Latn': 'gqn',
        'gqr': 'gqr',
        'gqr-Latn-TD': 'gqr',
        'gqr-Latn': 'gqr',
        'gqr-TD': 'gqr',
        'gqu': 'gqu',
        'gqu-Zyyy-CN': 'gqu',
        'gio': 'gqu',
        'gio-CN': 'gqu',
        'gio-Zyyy': 'gqu',
        'gio-Zyyy-CN': 'gqu',
        'gqu-CN': 'gqu',
        'gqu-Zyyy': 'gqu',
        'gra-Deva': 'gra-Deva',
        'gra-Deva-IN': 'gra-Deva',
        'gra-Gujr': 'gra-Gujr',
        'gra-Gujr-IN': 'gra-Gujr',
        'grb': 'grb',
        'grb-Latn-LR': 'grb',
        'gbo': 'grb',
        'gbo-LR': 'grb',
        'gbo-Latn': 'grb',
        'gbo-Latn-LR': 'grb',
        'grb-LR': 'grb',
        'grb-Latn': 'grb',
        'grc': 'grc',
        'grc-Cprt-CY': 'grc',
        'grc-CY': 'grc',
        'grc-Cprt': 'grc',
        'grc-Grek': 'grc-Grek',
        'grc-Grek-GR': 'grc-Grek',
        'grc-Linb': 'grc-Linb',
        'grc-Linb-GR': 'grc-Linb',
        'grd': 'grd',
        'grd-Latn-NG': 'grd',
        'grd-Latn': 'grd',
        'grd-NG': 'grd',
        'grg': 'grg',
        'grg-Latn-PG': 'grg',
        'grg-Latn': 'grg',
        'grg-PG': 'grg',
        'grh': 'grh',
        'grh-Latn-NG': 'grh',
        'grh-Latn': 'grh',
        'grh-NG': 'grh',
        'gri': 'gri',
        'gri-Latn-SB': 'gri',
        'gri-Latn': 'gri',
        'gri-SB': 'gri',
        'grj': 'grj',
        'grj-Latn-LR': 'grj',
        'grj-LR': 'grj',
        'grj-Latn': 'grj',
        'grm': 'grm',
        'grm-Latn-MY': 'grm',
        'grm-Latn': 'grm',
        'grm-MY': 'grm',
        'gro': 'gro',
        'gro-Zyyy-CN': 'gro',
        'gro-CN': 'gro',
        'gro-Zyyy': 'gro',
        'grq': 'grq',
        'grq-Latn-PG': 'grq',
        'grq-Latn': 'grq',
        'grq-PG': 'grq',
        'grr': 'grr',
        'grr-Zyyy-DZ': 'grr',
        'grr-DZ': 'grr',
        'grr-Zyyy': 'grr',
        'grs': 'grs',
        'grs-Latn-ID': 'grs',
        'grs-ID': 'grs',
        'grs-Latn': 'grs',
        'grt': 'grt',
        'grt-Beng-IN': 'grt',
        'grt-Beng': 'grt',
        'grt-IN': 'grt',
        'grt-Brai': 'grt-Brai',
        'grt-Brai-IN': 'grt-Brai',
        'grt-Latn': 'grt-Latn',
        'grt-Latn-IN': 'grt-Latn',
        'gru': 'gru',
        'gru-Ethi-ET': 'gru',
        'gru-ET': 'gru',
        'gru-Ethi': 'gru',
        'gru-Latn': 'gru-Latn',
        'gru-Latn-ET': 'gru-Latn',
        'grv': 'grv',
        'grv-Latn-LR': 'grv',
        'grv-LR': 'grv',
        'grv-Latn': 'grv',
        'grw': 'grw',
        'grw-Latn-PG': 'grw',
        'grw-Latn': 'grw',
        'grw-PG': 'grw',
        'grx': 'grx',
        'grx-Latn-PG': 'grx',
        'grx-Latn': 'grx',
        'grx-PG': 'grx',
        'gry': 'gry',
        'gry-Latn-LR': 'gry',
        'gry-LR': 'gry',
        'gry-Latn': 'gry',
        'grz': 'grz',
        'grz-Latn-PG': 'grz',
        'grz-Latn': 'grz',
        'grz-PG': 'grz',
        'gse': 'gse',
        'gse-Zxxx-GH': 'gse',
        'gse-GH': 'gse',
        'gse-Zxxx': 'gse',
        'sgn-gse': 'gse',
        'sgn-gse-GH': 'gse',
        'gsg': 'gsg',
        'gsg-Zxxx-DE': 'gsg',
        'gsg-DE': 'gsg',
        'gsg-Zxxx': 'gsg',
        'sgn-gsg': 'gsg',
        'sgn-gsg-DE': 'gsg',
        'gsl': 'gsl',
        'gsl-Latn-SN': 'gsl',
        'gsl-Latn': 'gsl',
        'gsl-SN': 'gsl',
        'gsm': 'gsm',
        'gsm-Zxxx-GT': 'gsm',
        'gsm-GT': 'gsm',
        'gsm-Zxxx': 'gsm',
        'sgn-gsm': 'gsm',
        'sgn-gsm-GT': 'gsm',
        'gsn': 'gsn',
        'gsn-Latn-PG': 'gsn',
        'gsn-Latn': 'gsn',
        'gsn-PG': 'gsn',
        'gso': 'gso',
        'gso-Latn-CF': 'gso',
        'gso-CF': 'gso',
        'gso-Latn': 'gso',
        'gsp': 'gsp',
        'gsp-Latn-PG': 'gsp',
        'gsp-Latn': 'gsp',
        'gsp-PG': 'gsp',
        'gss': 'gss',
        'gss-Zxxx-GR': 'gss',
        'gss-GR': 'gss',
        'gss-Zxxx': 'gss',
        'sgn-gss': 'gss',
        'sgn-gss-GR': 'gss',
        'gsw': 'gsw',
        'gsw-Latn-CH': 'gsw',
        'gsw-CH': 'gsw',
        'gsw-Latn': 'gsw',
        'gta': 'gta',
        'gta-Latn-BR': 'gta',
        'gta-BR': 'gta',
        'gta-Latn': 'gta',
        'gtu': 'gtu',
        'gtu-Latn-AU': 'gtu',
        'ggr': 'gtu',
        'ggr-AU': 'gtu',
        'ggr-Latn': 'gtu',
        'ggr-Latn-AU': 'gtu',
        'gtu-AU': 'gtu',
        'gtu-Latn': 'gtu',
        'gu': 'gu',
        'gu-Gujr-IN': 'gu',
        'gu-Gujr': 'gu',
        'gu-IN': 'gu',
        'gu-Brai': 'gu-Brai',
        'gu-Brai-IN': 'gu-Brai',
        'gu-Khoj': 'gu-Khoj',
        'gu-Khoj-IN': 'gu-Khoj',
        'gua': 'gua',
        'gua-Latn-NG': 'gua',
        'gua-Latn': 'gua',
        'gua-NG': 'gua',
        'gub': 'gub',
        'gub-Latn-BR': 'gub',
        'gub-BR': 'gub',
        'gub-Latn': 'gub',
        'guc': 'guc',
        'guc-Latn-CO': 'guc',
        'guc-CO': 'guc',
        'guc-Latn': 'guc',
        'gud': 'gud',
        'gud-Latn-CI': 'gud',
        'gud-CI': 'gud',
        'gud-Latn': 'gud',
        'gue': 'gue',
        'gue-Latn-AU': 'gue',
        'gue-AU': 'gue',
        'gue-Latn': 'gue',
        'guf': 'guf',
        'guf-Latn-AU': 'guf',
        'guf-AU': 'guf',
        'guf-Latn': 'guf',
        'guh': 'guh',
        'guh-Latn-CO': 'guh',
        'guh-CO': 'guh',
        'guh-Latn': 'guh',
        'gui': 'gui',
        'gui-Latn-BO': 'gui',
        'gui-BO': 'gui',
        'gui-Latn': 'gui',
        'guk': 'guk',
        'guk-Latn-ET': 'guk',
        'guk-ET': 'guk',
        'guk-Latn': 'guk',
        'guk-Ethi': 'guk-Ethi',
        'guk-Ethi-ET': 'guk-Ethi',
        'gul': 'gul',
        'gul-Latn-US': 'gul',
        'gul-Latn': 'gul',
        'gul-US': 'gul',
        'gum': 'gum',
        'gum-Latn-CO': 'gum',
        'gum-CO': 'gum',
        'gum-Latn': 'gum',
        'gun': 'gun',
        'gun-Latn-BR': 'gun',
        'gun-BR': 'gun',
        'gun-Latn': 'gun',
        'guo': 'guo',
        'guo-Latn-CO': 'guo',
        'guo-CO': 'guo',
        'guo-Latn': 'guo',
        'gup': 'gup',
        'gup-Latn-AU': 'gup',
        'gup-AU': 'gup',
        'gup-Latn': 'gup',
        'guq': 'guq',
        'guq-Latn-PY': 'guq',
        'guq-Latn': 'guq',
        'guq-PY': 'guq',
        'gur': 'gur',
        'gur-Latn-GH': 'gur',
        'gur-GH': 'gur',
        'gur-Latn': 'gur',
        'gus': 'gus',
        'gus-Zxxx-GN': 'gus',
        'gus-GN': 'gus',
        'gus-Zxxx': 'gus',
        'sgn-gus': 'gus',
        'sgn-gus-GN': 'gus',
        'gut': 'gut',
        'gut-Latn-CR': 'gut',
        'gut-CR': 'gut',
        'gut-Latn': 'gut',
        'guu': 'guu',
        'guu-Latn-VE': 'guu',
        'guu-Latn': 'guu',
        'guu-VE': 'guu',
        'guw': 'guw',
        'guw-Latn-BJ': 'guw',
        'guw-BJ': 'guw',
        'guw-Latn': 'guw',
        'gux': 'gux',
        'gux-Latn-BF': 'gux',
        'gux-BF': 'gux',
        'gux-Latn': 'gux',
        'guz': 'guz',
        'guz-Latn-KE': 'guz',
        'guz-KE': 'guz',
        'guz-Latn': 'guz',
        'gv': 'gv',
        'gv-Latn-IM': 'gv',
        'gv-IM': 'gv',
        'gv-Latn': 'gv',
        'gva': 'gva',
        'gva-Latn-PY': 'gva',
        'gva-Latn': 'gva',
        'gva-PY': 'gva',
        'gvc': 'gvc',
        'gvc-Latn-BR': 'gvc',
        'gvc-BR': 'gvc',
        'gvc-Latn': 'gvc',
        'gve': 'gve',
        'gve-Latn-PG': 'gve',
        'gve-Latn': 'gve',
        'gve-PG': 'gve',
        'gvf': 'gvf',
        'gvf-Latn-PG': 'gvf',
        'gvf-Latn': 'gvf',
        'gvf-PG': 'gvf',
        'gvj': 'gvj',
        'gvj-Latn-BR': 'gvj',
        'gvj-BR': 'gvj',
        'gvj-Latn': 'gvj',
        'gvl': 'gvl',
        'gvl-Latn-TD': 'gvl',
        'gvl-Latn': 'gvl',
        'gvl-TD': 'gvl',
        'gvm': 'gvm',
        'gvm-Latn-NG': 'gvm',
        'gvm-Latn': 'gvm',
        'gvm-NG': 'gvm',
        'gvn': 'gvn',
        'gvn-Latn-AU': 'gvn',
        'gvn-AU': 'gvn',
        'gvn-Latn': 'gvn',
        'gvo': 'gvo',
        'gvo-Latn-BR': 'gvo',
        'gvo-BR': 'gvo',
        'gvo-Latn': 'gvo',
        'gvp': 'gvp',
        'gvp-Latn-BR': 'gvp',
        'gvp-BR': 'gvp',
        'gvp-Latn': 'gvp',
        'gvr': 'gvr',
        'gvr-Deva-NP': 'gvr',
        'ggn': 'gvr',
        'ggn-Deva': 'gvr',
        'ggn-Deva-NP': 'gvr',
        'ggn-NP': 'gvr',
        'gvr-Deva': 'gvr',
        'gvr-NP': 'gvr',
        'gvr-Latn': 'gvr-Latn',
        'gvr-Latn-IN': 'gvr-Latn',
        'ggn-IN': 'gvr-Latn',
        'ggn-Latn': 'gvr-Latn',
        'ggn-Latn-IN': 'gvr-Latn',
        'gvr-IN': 'gvr-Latn',
        'gvs': 'gvs',
        'gvs-Latn-PG': 'gvs',
        'gvs-Latn': 'gvs',
        'gvs-PG': 'gvs',
        'gvy': 'gvy',
        'gvy-Latn-AU': 'gvy',
        'gvy-AU': 'gvy',
        'gvy-Latn': 'gvy',
        'gwa': 'gwa',
        'gwa-Latn-CI': 'gwa',
        'gwa-CI': 'gwa',
        'gwa-Latn': 'gwa',
        'gwb': 'gwb',
        'gwb-Latn-NG': 'gwb',
        'gwb-Latn': 'gwb',
        'gwb-NG': 'gwb',
        'gwc': 'gwc',
        'gwc-Arab-PK': 'gwc',
        'gwc-Arab': 'gwc',
        'gwc-PK': 'gwc',
        'gwd': 'gwd',
        'gwd-Latn-ET': 'gwd',
        'gwd-ET': 'gwd',
        'gwd-Latn': 'gwd',
        'gwe': 'gwe',
        'gwe-Latn-TZ': 'gwe',
        'gwe-Latn': 'gwe',
        'gwe-TZ': 'gwe',
        'gwf': 'gwf',
        'gwf-Arab-PK': 'gwf',
        'gwf-Arab': 'gwf',
        'gwf-PK': 'gwf',
        'gwg': 'gwg',
        'gwg-Latn-NG': 'gwg',
        'gwg-Latn': 'gwg',
        'gwg-NG': 'gwg',
        'gwi': 'gwi',
        'gwi-Latn-CA': 'gwi',
        'gwi-CA': 'gwi',
        'gwi-Latn': 'gwi',
        'gwj': 'gwj',
        'gwj-Latn-BW': 'gwj',
        'gwj-BW': 'gwj',
        'gwj-Latn': 'gwj',
        'gwm': 'gwm',
        'gwm-Latn-AU': 'gwm',
        'gwm-AU': 'gwm',
        'gwm-Latn': 'gwm',
        'gwn': 'gwn',
        'gwn-Latn-NG': 'gwn',
        'gwn-Latn': 'gwn',
        'gwn-NG': 'gwn',
        'gwr': 'gwr',
        'gwr-Latn-UG': 'gwr',
        'gwr-Latn': 'gwr',
        'gwr-UG': 'gwr',
        'gwt': 'gwt',
        'gwt-Arab-AF': 'gwt',
        'gwt-AF': 'gwt',
        'gwt-Arab': 'gwt',
        'gwu': 'gwu',
        'gwu-Latn-AU': 'gwu',
        'gwu-AU': 'gwu',
        'gwu-Latn': 'gwu',
        'gww': 'gww',
        'gww-Latn-AU': 'gww',
        'gww-AU': 'gww',
        'gww-Latn': 'gww',
        'gwx': 'gwx',
        'gwx-Latn-GH': 'gwx',
        'gwx-GH': 'gwx',
        'gwx-Latn': 'gwx',
        'gxx': 'gxx',
        'gxx-Latn-CI': 'gxx',
        'gxx-CI': 'gxx',
        'gxx-Latn': 'gxx',
        'gyb': 'gyb',
        'gyb-Latn-PG': 'gyb',
        'gyb-Latn': 'gyb',
        'gyb-PG': 'gyb',
        'gyd': 'gyd',
        'gyd-Latn-AU': 'gyd',
        'gyd-AU': 'gyd',
        'gyd-Latn': 'gyd',
        'gye': 'gye',
        'gye-Latn-NG': 'gye',
        'gye-Latn': 'gye',
        'gye-NG': 'gye',
        'gyf': 'gyf',
        'gyf-Latn-AU': 'gyf',
        'gyf-AU': 'gyf',
        'gyf-Latn': 'gyf',
        'gyg': 'gyg',
        'gyg-Latn-CF': 'gyg',
        'gyg-CF': 'gyg',
        'gyg-Latn': 'gyg',
        'gyi': 'gyi',
        'gyi-Latn-CM': 'gyi',
        'gyi-CM': 'gyi',
        'gyi-Latn': 'gyi',
        'gyl': 'gyl',
        'gyl-Zyyy-ET': 'gyl',
        'gyl-ET': 'gyl',
        'gyl-Zyyy': 'gyl',
        'gym': 'gym',
        'gym-Latn-PA': 'gym',
        'gym-Latn': 'gym',
        'gym-PA': 'gym',
        'gyn': 'gyn',
        'gyn-Latn-GY': 'gyn',
        'gyn-GY': 'gyn',
        'gyn-Latn': 'gyn',
        'gyo': 'gyo',
        'gyo-Zyyy-NP': 'gyo',
        'gyo-NP': 'gyo',
        'gyo-Zyyy': 'gyo',
        'gyr': 'gyr',
        'gyr-Latn-BO': 'gyr',
        'gyr-BO': 'gyr',
        'gyr-Latn': 'gyr',
        'gyy': 'gyy',
        'gyy-Latn-AU': 'gyy',
        'gyy-AU': 'gyy',
        'gyy-Latn': 'gyy',
        'gza': 'gza',
        'gza-Latn-SD': 'gza',
        'gza-Latn': 'gza',
        'gza-SD': 'gza',
        'gzi': 'gzi',
        'gzi-Arab-IR': 'gzi',
        'gzi-Arab': 'gzi',
        'gzi-IR': 'gzi',
        'gzn': 'gzn',
        'gzn-Latn-ID': 'gzn',
        'gzn-ID': 'gzn',
        'gzn-Latn': 'gzn',
        'ha': 'ha',
        'ha-Latn-NG': 'ha',
        'ha-Latn': 'ha',
        'ha-NG': 'ha',
        'ha-Arab': 'ha-Arab',
        'ha-Arab-NG': 'ha-Arab',
        'ha-Brai': 'ha-Brai',
        'ha-Brai-NG': 'ha-Brai',
        'ha-CM': 'ha-CM',
        'ha-Arab-CM': 'ha-CM',
        'ha-GH': 'ha-GH',
        'ha-Latn-GH': 'ha-GH',
        'ha-NE': 'ha-NE',
        'ha-Arab-NE': 'ha-NE',
        'ha-SD': 'ha-SD',
        'ha-Arab-SD': 'ha-SD',
        'haa': 'haa',
        'haa-Latn-US': 'haa',
        'haa-Latn': 'haa',
        'haa-US': 'haa',
        'hab': 'hab',
        'hab-Zxxx-VN': 'hab',
        'hab-VN': 'hab',
        'hab-Zxxx': 'hab',
        'sgn-hab': 'hab',
        'sgn-hab-VN': 'hab',
        'hac': 'hac',
        'hac-Arab-IR': 'hac',
        'hac-Arab': 'hac',
        'hac-IR': 'hac',
        'had': 'had',
        'had-Latn-ID': 'had',
        'had-ID': 'had',
        'had-Latn': 'had',
        'hae': 'hae',
        'hae-Latn-ET': 'hae',
        'hae-ET': 'hae',
        'hae-Latn': 'hae',
        'haf': 'haf',
        'haf-Zxxx-VN': 'haf',
        'haf-VN': 'haf',
        'haf-Zxxx': 'haf',
        'sgn-haf': 'haf',
        'sgn-haf-VN': 'haf',
        'hag': 'hag',
        'hag-Latn-GH': 'hag',
        'hag-GH': 'hag',
        'hag-Latn': 'hag',
        'hah': 'hah',
        'hah-Latn-PG': 'hah',
        'hah-Latn': 'hah',
        'hah-PG': 'hah',
        'hai': 'hai',
        'hai-Latn-CA': 'hai',
        'hai-CA': 'hai',
        'hai-Latn': 'hai',
        'hdn': 'hai',
        'hdn-CA': 'hai',
        'hdn-Latn': 'hai',
        'hdn-Latn-CA': 'hai',
        'haj': 'haj',
        'haj-Latn-IN': 'haj',
        'haj-IN': 'haj',
        'haj-Latn': 'haj',
        'haj-Beng': 'haj-Beng',
        'haj-Beng-IN': 'haj-Beng',
        'hak': 'hak',
        'hak-Hans-CN': 'hak',
        'hak-CN': 'hak',
        'hak-Hans': 'hak',
        'zh-hak': 'hak',
        'zh-hak-CN': 'hak',
        'hak-Hant': 'hak-Hant',
        'hak-Hant-CN': 'hak-Hant',
        'hak-Latn': 'hak-Latn',
        'hak-Latn-CN': 'hak-Latn',
        'hal': 'hal',
        'hal-Latn-VN': 'hal',
        'hal-Latn': 'hal',
        'hal-VN': 'hal',
        'ham': 'ham',
        'ham-Latn-PG': 'ham',
        'ham-Latn': 'ham',
        'ham-PG': 'ham',
        'han': 'han',
        'han-Latn-TZ': 'han',
        'han-Latn': 'han',
        'han-TZ': 'han',
        'hao': 'hao',
        'hao-Latn-PG': 'hao',
        'hao-Latn': 'hao',
        'hao-PG': 'hao',
        'hap': 'hap',
        'hap-Latn-ID': 'hap',
        'hap-ID': 'hap',
        'hap-Latn': 'hap',
        'haq': 'haq',
        'haq-Latn-TZ': 'haq',
        'haq-Latn': 'haq',
        'haq-TZ': 'haq',
        'har': 'har',
        'har-Ethi-ET': 'har',
        'har-ET': 'har',
        'har-Ethi': 'har',
        'har-Arab': 'har-Arab',
        'har-Arab-ET': 'har-Arab',
        'har-Latn': 'har-Latn',
        'har-Latn-ET': 'har-Latn',
        'has': 'has',
        'has-Latn-CA': 'has',
        'has-CA': 'has',
        'has-Latn': 'has',
        'hav': 'hav',
        'hav-Latn-CD': 'hav',
        'hav-CD': 'hav',
        'hav-Latn': 'hav',
        'haw': 'haw',
        'haw-Latn-US': 'haw',
        'haw-Latn': 'haw',
        'haw-US': 'haw',
        'hax': 'hax',
        'hax-Latn-CA': 'hax',
        'hax-CA': 'hax',
        'hax-Latn': 'hax',
        'hay': 'hay',
        'hay-Latn-TZ': 'hay',
        'hay-Latn': 'hay',
        'hay-TZ': 'hay',
        'haz': 'haz',
        'haz-Arab-AF': 'haz',
        'haz-AF': 'haz',
        'haz-Arab': 'haz',
        'hba': 'hba',
        'hba-Latn-CD': 'hba',
        'hba-CD': 'hba',
        'hba-Latn': 'hba',
        'hbb': 'hbb',
        'hbb-Latn-NG': 'hbb',
        'hbb-Latn': 'hbb',
        'hbb-NG': 'hbb',
        'hbn': 'hbn',
        'hbn-Latn-SD': 'hbn',
        'hbn-Latn': 'hbn',
        'hbn-SD': 'hbn',
        'hbo': 'hbo',
        'hbo-Hebr-IL': 'hbo',
        'hbo-Hebr': 'hbo',
        'hbo-IL': 'hbo',
        'hbu': 'hbu',
        'hbu-Latn-TL': 'hbu',
        'hbu-Latn': 'hbu',
        'hbu-TL': 'hbu',
        'hca': 'hca',
        'hca-Zyyy-IN': 'hca',
        'hca-IN': 'hca',
        'hca-Zyyy': 'hca',
        'hch': 'hch',
        'hch-Latn-MX': 'hch',
        'hch-Latn': 'hch',
        'hch-MX': 'hch',
        'hds': 'hds',
        'hds-Zxxx-HN': 'hds',
        'hds-HN': 'hds',
        'hds-Zxxx': 'hds',
        'sgn-hds': 'hds',
        'sgn-hds-HN': 'hds',
        'hdy': 'hdy',
        'hdy-Ethi-ET': 'hdy',
        'hdy-ET': 'hdy',
        'hdy-Ethi': 'hdy',
        'hdy-Latn': 'hdy-Latn',
        'hdy-Latn-ET': 'hdy-Latn',
        'he': 'he',
        'he-Hebr-IL': 'he',
        'he-Hebr': 'he',
        'he-IL': 'he',
        'iw': 'he',
        'iw-Hebr': 'he',
        'iw-Hebr-IL': 'he',
        'iw-IL': 'he',
        'he-Brai': 'he-Brai',
        'he-Brai-IL': 'he-Brai',
        'hed': 'hed',
        'hed-Latn-TD': 'hed',
        'hed-Latn': 'hed',
        'hed-TD': 'hed',
        'heg': 'heg',
        'heg-Latn-ID': 'heg',
        'heg-ID': 'heg',
        'heg-Latn': 'heg',
        'heh': 'heh',
        'heh-Latn-TZ': 'heh',
        'heh-Latn': 'heh',
        'heh-TZ': 'heh',
        'hei': 'hei',
        'hei-Latn-CA': 'hei',
        'hei-CA': 'hei',
        'hei-Latn': 'hei',
        'hem': 'hem',
        'hem-Latn-CD': 'hem',
        'hem-CD': 'hem',
        'hem-Latn': 'hem',
        'hgm': 'hgm',
        'hgm-Latn-NA': 'hgm',
        'hgm-Latn': 'hgm',
        'hgm-NA': 'hgm',
        'hgw': 'hgw',
        'hgw-Latn-PG': 'hgw',
        'hgw-Latn': 'hgw',
        'hgw-PG': 'hgw',
        'hhi': 'hhi',
        'hhi-Latn-PG': 'hhi',
        'hhi-Latn': 'hhi',
        'hhi-PG': 'hhi',
        'hhr': 'hhr',
        'hhr-Latn-SN': 'hhr',
        'hhr-Latn': 'hhr',
        'hhr-SN': 'hhr',
        'hhy': 'hhy',
        'hhy-Latn-PG': 'hhy',
        'hhy-Latn': 'hhy',
        'hhy-PG': 'hhy',
        'hi': 'hi',
        'hi-Deva-IN': 'hi',
        'hi-Deva': 'hi',
        'hi-IN': 'hi',
        'hi-Brai': 'hi-Brai',
        'hi-Brai-IN': 'hi-Brai',
        'hi-Mahj': 'hi-Mahj',
        'hi-Mahj-IN': 'hi-Mahj',
        'hi-Newa': 'hi-Newa',
        'hi-Newa-IN': 'hi-Newa',
        'hia': 'hia',
        'hia-Latn-NG': 'hia',
        'hia-Latn': 'hia',
        'hia-NG': 'hia',
        'hib': 'hib',
        'hib-Latn-PE': 'hib',
        'hib-Latn': 'hib',
        'hib-PE': 'hib',
        'hid': 'hid',
        'hid-Latn-US': 'hid',
        'hid-Latn': 'hid',
        'hid-US': 'hid',
        'hif': 'hif',
        'hif-Latn-FJ': 'hif',
        'hif-FJ': 'hif',
        'hif-Latn': 'hif',
        'hif-Deva': 'hif-Deva',
        'hif-Deva-FJ': 'hif-Deva',
        'hig': 'hig',
        'hig-Latn-NG': 'hig',
        'hig-Latn': 'hig',
        'hig-NG': 'hig',
        'hih': 'hih',
        'hih-Latn-PG': 'hih',
        'hih-Latn': 'hih',
        'hih-PG': 'hih',
        'hii': 'hii',
        'hii-Zyyy-IN': 'hii',
        'hii-IN': 'hii',
        'hii-Zyyy': 'hii',
        'hij': 'hij',
        'hij-Latn-CM': 'hij',
        'hij-CM': 'hij',
        'hij-Latn': 'hij',
        'hik': 'hik',
        'hik-Latn-ID': 'hik',
        'hik-ID': 'hik',
        'hik-Latn': 'hik',
        'hil': 'hil',
        'hil-Latn-PH': 'hil',
        'hil-Latn': 'hil',
        'hil-PH': 'hil',
        'hil-Brai': 'hil-Brai',
        'hil-Brai-PH': 'hil-Brai',
        'hio': 'hio',
        'hio-Latn-BW': 'hio',
        'hio-BW': 'hio',
        'hio-Latn': 'hio',
        'hir': 'hir',
        'hir-Latn-BR': 'hir',
        'hir-BR': 'hir',
        'hir-Latn': 'hir',
        'hit': 'hit',
        'hit-Xsux-TR': 'hit',
        'hit-TR': 'hit',
        'hit-Xsux': 'hit',
        'hiw': 'hiw',
        'hiw-Latn-VU': 'hiw',
        'hiw-Latn': 'hiw',
        'hiw-VU': 'hiw',
        'hix': 'hix',
        'hix-Latn-BR': 'hix',
        'hix-BR': 'hix',
        'hix-Latn': 'hix',
        'hji': 'hji',
        'hji-Latn-ID': 'hji',
        'hji-ID': 'hji',
        'hji-Latn': 'hji',
        'ms-hji': 'hji',
        'ms-hji-ID': 'hji',
        'hka': 'hka',
        'hka-Latn-TZ': 'hka',
        'hka-Latn': 'hka',
        'hka-TZ': 'hka',
        'hke': 'hke',
        'hke-Latn-CD': 'hke',
        'hke-CD': 'hke',
        'hke-Latn': 'hke',
        'hkk': 'hkk',
        'hkk-Latn-PG': 'hkk',
        'hkk-Latn': 'hkk',
        'hkk-PG': 'hkk',
        'hkn': 'hkn',
        'hkn-Zyyy-KH': 'hkn',
        'hkn-KH': 'hkn',
        'hkn-Zyyy': 'hkn',
        'hks': 'hks',
        'hks-Zxxx-HK': 'hks',
        'hks-HK': 'hks',
        'hks-Zxxx': 'hks',
        'sgn-hks': 'hks',
        'sgn-hks-HK': 'hks',
        'hla': 'hla',
        'hla-Latn-PG': 'hla',
        'hla-Latn': 'hla',
        'hla-PG': 'hla',
        'hlb': 'hlb',
        'hlb-Deva-IN': 'hlb',
        'hlb-Deva': 'hlb',
        'hlb-IN': 'hlb',
        'hld': 'hld',
        'hld-Latn-VN': 'hld',
        'hld-Latn': 'hld',
        'hld-VN': 'hld',
        'hle': 'hle',
        'hle-Zyyy-CN': 'hle',
        'hle-CN': 'hle',
        'hle-Zyyy': 'hle',
        'sca': 'hle',
        'sca-CN': 'hle',
        'sca-Zyyy': 'hle',
        'sca-Zyyy-CN': 'hle',
        'hlt': 'hlt',
        'hlt-Latn-MM': 'hlt',
        'hlt-Latn': 'hlt',
        'hlt-MM': 'hlt',
        'hlu': 'hlu',
        'hlu-Hluw-TR': 'hlu',
        'hlu-Hluw': 'hlu',
        'hlu-TR': 'hlu',
        'hma': 'hma',
        'hma-Zyyy-CN': 'hma',
        'hma-CN': 'hma',
        'hma-Zyyy': 'hma',
        'hmb': 'hmb',
        'hmb-Latn-ML': 'hmb',
        'hmb-Latn': 'hmb',
        'hmb-ML': 'hmb',
        'hmc': 'hmc',
        'hmc-Zyyy-CN': 'hmc',
        'hmc-CN': 'hmc',
        'hmc-Zyyy': 'hmc',
        'hmd': 'hmd',
        'hmd-Plrd-CN': 'hmd',
        'hmd-CN': 'hmd',
        'hmd-Plrd': 'hmd',
        'hmd-Hmng': 'hmd-Hmng',
        'hmd-Hmng-CN': 'hmd-Hmng',
        'hmd-Latn': 'hmd-Latn',
        'hmd-Latn-CN': 'hmd-Latn',
        'hme': 'hme',
        'hme-Zyyy-CN': 'hme',
        'hme-CN': 'hme',
        'hme-Zyyy': 'hme',
        'hmf': 'hmf',
        'hmf-Latn-VN': 'hmf',
        'hmf-Latn': 'hmf',
        'hmf-VN': 'hmf',
        'hmg': 'hmg',
        'hmg-Zyyy-CN': 'hmg',
        'hmg-CN': 'hmg',
        'hmg-Zyyy': 'hmg',
        'hmh': 'hmh',
        'hmh-Zyyy-CN': 'hmh',
        'hmh-CN': 'hmh',
        'hmh-Zyyy': 'hmh',
        'hmi': 'hmi',
        'hmi-Zyyy-CN': 'hmi',
        'hmi-CN': 'hmi',
        'hmi-Zyyy': 'hmi',
        'hmj': 'hmj',
        'hmj-Bopo-CN': 'hmj',
        'hmj-Bopo': 'hmj',
        'hmj-CN': 'hmj',
        'hmk': 'hmk',
        'hmk-Zyyy-KR': 'hmk',
        'hmk-KR': 'hmk',
        'hmk-Zyyy': 'hmk',
        'hml': 'hml',
        'hml-Zyyy-CN': 'hml',
        'hml-CN': 'hml',
        'hml-Zyyy': 'hml',
        'hmm': 'hmm',
        'hmm-Zyyy-CN': 'hmm',
        'hmm-CN': 'hmm',
        'hmm-Zyyy': 'hmm',
        'hmn': 'hmn',
        'hmn-Latn-CN': 'hmn',
        'hmn-CN': 'hmn',
        'hmn-Latn': 'hmn',
        'hmn-Bopo': 'hmn-Bopo',
        'hmn-Bopo-CN': 'hmn-Bopo',
        'hea-Bopo': 'hmn-Bopo',
        'hea-Bopo-CN': 'hmn-Bopo',
        'hmn-Hmng': 'hmn-Hmng',
        'hmn-Hmng-CN': 'hmn-Hmng',
        'hmp': 'hmp',
        'hmp-Zyyy-CN': 'hmp',
        'hmp-CN': 'hmp',
        'hmp-Zyyy': 'hmp',
        'hmq': 'hmq',
        'hmq-Bopo-CN': 'hmq',
        'hmq-Bopo': 'hmq',
        'hmq-CN': 'hmq',
        'hmr': 'hmr',
        'hmr-Latn-IN': 'hmr',
        'hmr-IN': 'hmr',
        'hmr-Latn': 'hmr',
        'hms': 'hms',
        'hms-Latn-CN': 'hms',
        'hms-CN': 'hms',
        'hms-Latn': 'hms',
        'hmt': 'hmt',
        'hmt-Latn-PG': 'hmt',
        'hmt-Latn': 'hmt',
        'hmt-PG': 'hmt',
        'hmu': 'hmu',
        'hmu-Latn-ID': 'hmu',
        'hmu-ID': 'hmu',
        'hmu-Latn': 'hmu',
        'hmv': 'hmv',
        'hmv-Latn-VN': 'hmv',
        'hmv-Latn': 'hmv',
        'hmv-VN': 'hmv',
        'hmw': 'hmw',
        'hmw-Zyyy-CN': 'hmw',
        'hmw-CN': 'hmw',
        'hmw-Zyyy': 'hmw',
        'hmy': 'hmy',
        'hmy-Zyyy-CN': 'hmy',
        'hmy-CN': 'hmy',
        'hmy-Zyyy': 'hmy',
        'hmz-Latn': 'hmz-Latn',
        'hmz-Latn-CN': 'hmz-Latn',
        'hmz-Plrd': 'hmz-Plrd',
        'hmz-Plrd-CN': 'hmz-Plrd',
        'hna': 'hna',
        'hna-Latn-CM': 'hna',
        'hna-CM': 'hna',
        'hna-Latn': 'hna',
        'hnd': 'hnd',
        'hnd-Arab-PK': 'hnd',
        'hnd-Arab': 'hnd',
        'hnd-PK': 'hnd',
        'hne': 'hne',
        'hne-Deva-IN': 'hne',
        'hne-Deva': 'hne',
        'hne-IN': 'hne',
        'hng': 'hng',
        'hng-Latn-AO': 'hng',
        'hng-AO': 'hng',
        'hng-Latn': 'hng',
        'hnh': 'hnh',
        'hnh-Latn-BW': 'hnh',
        'hnh-BW': 'hnh',
        'hnh-Latn': 'hnh',
        'hni': 'hni',
        'hni-Latn-CN': 'hni',
        'hni-CN': 'hni',
        'hni-Latn': 'hni',
        'hnj': 'hnj',
        'hnj-Hmng-LA': 'hnj',
        'hnj-Hmng': 'hnj',
        'hnj-LA': 'hnj',
        'hnj-Laoo': 'hnj-Laoo',
        'hnj-Laoo-LA': 'hnj-Laoo',
        'hnj-Latn': 'hnj-Latn',
        'hnj-Latn-LA': 'hnj-Latn',
        'hnj-Plrd': 'hnj-Plrd',
        'hnj-Plrd-CN': 'hnj-Plrd',
        'hnj-CN': 'hnj-Plrd',
        'hnj-Thai': 'hnj-Thai',
        'hnj-Thai-TH': 'hnj-Thai',
        'hnj-TH': 'hnj-Thai',
        'hnn': 'hnn',
        'hnn-Latn-PH': 'hnn',
        'hnn-Latn': 'hnn',
        'hnn-PH': 'hnn',
        'hnn-Hano': 'hnn-Hano',
        'hnn-Hano-PH': 'hnn-Hano',
        'hno': 'hno',
        'hno-Arab-PK': 'hno',
        'hno-Arab': 'hno',
        'hno-PK': 'hno',
        'hns': 'hns',
        'hns-Latn-SR': 'hns',
        'hns-Latn': 'hns',
        'hns-SR': 'hns',
        'hnu': 'hnu',
        'hnu-Zyyy-LA': 'hnu',
        'hnu-LA': 'hnu',
        'hnu-Zyyy': 'hnu',
        'ho': 'ho',
        'ho-Latn-PG': 'ho',
        'ho-Latn': 'ho',
        'ho-PG': 'ho',
        'ho-Brai': 'ho-Brai',
        'ho-Brai-PG': 'ho-Brai',
        'hoa': 'hoa',
        'hoa-Latn-SB': 'hoa',
        'hoa-Latn': 'hoa',
        'hoa-SB': 'hoa',
        'hob': 'hob',
        'hob-Latn-PG': 'hob',
        'hob-Latn': 'hob',
        'hob-PG': 'hob',
        'hoc': 'hoc',
        'hoc-Deva-IN': 'hoc',
        'hoc-Deva': 'hoc',
        'hoc-IN': 'hoc',
        'hoc-Latn': 'hoc-Latn',
        'hoc-Latn-IN': 'hoc-Latn',
        'hoc-Orya': 'hoc-Orya',
        'hoc-Orya-IN': 'hoc-Orya',
        'hoc-Telu': 'hoc-Telu',
        'hoc-Telu-IN': 'hoc-Telu',
        'hoc-Wara': 'hoc-Wara',
        'hoc-Wara-IN': 'hoc-Wara',
        'hod': 'hod',
        'hod-Latn-NG': 'hod',
        'hod-Latn': 'hod',
        'hod-NG': 'hod',
        'hoe': 'hoe',
        'hoe-Latn-NG': 'hoe',
        'hoe-Latn': 'hoe',
        'hoe-NG': 'hoe',
        'hoh': 'hoh',
        'hoh-Zyyy-OM': 'hoh',
        'hoh-OM': 'hoh',
        'hoh-Zyyy': 'hoh',
        'hoi': 'hoi',
        'hoi-Latn-US': 'hoi',
        'hoi-Latn': 'hoi',
        'hoi-US': 'hoi',
        'hoj': 'hoj',
        'hoj-Deva-IN': 'hoj',
        'hoj-Deva': 'hoj',
        'hoj-IN': 'hoj',
        'hol': 'hol',
        'hol-Latn-AO': 'hol',
        'hol-AO': 'hol',
        'hol-Latn': 'hol',
        'hom': 'hom',
        'hom-Latn-SS': 'hom',
        'hom-Latn': 'hom',
        'hom-SS': 'hom',
        'hoo': 'hoo',
        'hoo-Latn-CD': 'hoo',
        'hoo-CD': 'hoo',
        'hoo-Latn': 'hoo',
        'hop': 'hop',
        'hop-Latn-US': 'hop',
        'hop-Latn': 'hop',
        'hop-US': 'hop',
        'hor': 'hor',
        'hor-Latn-TD': 'hor',
        'hor-Latn': 'hor',
        'hor-TD': 'hor',
        'hos': 'hos',
        'hos-Zxxx-VN': 'hos',
        'hos-VN': 'hos',
        'hos-Zxxx': 'hos',
        'sgn-hos': 'hos',
        'sgn-hos-VN': 'hos',
        'hot': 'hot',
        'hot-Latn-PG': 'hot',
        'hot-Latn': 'hot',
        'hot-PG': 'hot',
        'hov': 'hov',
        'hov-Latn-ID': 'hov',
        'hov-ID': 'hov',
        'hov-Latn': 'hov',
        'how': 'how',
        'how-Hani-CN': 'how',
        'how-CN': 'how',
        'how-Hani': 'how',
        'hoy': 'hoy',
        'hoy-Deva-IN': 'hoy',
        'hoy-Deva': 'hoy',
        'hoy-IN': 'hoy',
        'hoz': 'hoz',
        'hoz-Zyyy-ET': 'hoz',
        'hoz-ET': 'hoz',
        'hoz-Zyyy': 'hoz',
        'hpo': 'hpo',
        'hpo-Zyyy-MM': 'hpo',
        'hpo-MM': 'hpo',
        'hpo-Zyyy': 'hpo',
        'hps': 'hps',
        'hps-Zxxx-US': 'hps',
        'hps-US': 'hps',
        'hps-Zxxx': 'hps',
        'sgn-hps': 'hps',
        'sgn-hps-US': 'hps',
        'hr': 'hr',
        'hr-Latn-HR': 'hr',
        'hr-HR': 'hr',
        'hr-Latn': 'hr',
        'hr-BA': 'hr-BA',
        'hr-Latn-BA': 'hr-BA',
        'hr-Brai': 'hr-Brai',
        'hr-Brai-HR': 'hr-Brai',
        'hra': 'hra',
        'hra-Latn-IN': 'hra',
        'hra-IN': 'hra',
        'hra-Latn': 'hra',
        'hrc': 'hrc',
        'hrc-Latn-PG': 'hrc',
        'hrc-Latn': 'hrc',
        'hrc-PG': 'hrc',
        'hre': 'hre',
        'hre-Latn-VN': 'hre',
        'hre-Latn': 'hre',
        'hre-Latn-VN-x-1968': 'hre',
        'hre-Latn-x-1968': 'hre',
        'hre-VN': 'hre',
        'hre-VN-x-1968': 'hre',
        'hre-x-1968': 'hre',
        'hre-x-1960': 'hre-x-1960',
        'hre-Latn-VN-x-1960': 'hre-x-1960',
        'hre-Latn-x-1960': 'hre-x-1960',
        'hre-VN-x-1960': 'hre-x-1960',
        'hrk': 'hrk',
        'hrk-Latn-ID': 'hrk',
        'hrk-ID': 'hrk',
        'hrk-Latn': 'hrk',
        'hrm': 'hrm',
        'hrm-Zyyy-CN': 'hrm',
        'hrm-CN': 'hrm',
        'hrm-Zyyy': 'hrm',
        'hro': 'hro',
        'hro-Latn-VN': 'hro',
        'hro-Latn': 'hro',
        'hro-VN': 'hro',
        'hrp': 'hrp',
        'hrp-Latn-AU': 'hrp',
        'hrp-AU': 'hrp',
        'hrp-Latn': 'hrp',
        'hrt': 'hrt',
        'hrt-Syrc-TR': 'hrt',
        'hrt-Syrc': 'hrt',
        'hrt-TR': 'hrt',
        'hru': 'hru',
        'hru-Latn-IN': 'hru',
        'hru-IN': 'hru',
        'hru-Latn': 'hru',
        'hrw': 'hrw',
        'hrw-Latn-PG': 'hrw',
        'hrw-Latn': 'hrw',
        'hrw-PG': 'hrw',
        'hrx': 'hrx',
        'hrx-Latn-BR': 'hrx',
        'hrx-BR': 'hrx',
        'hrx-Latn': 'hrx',
        'hrz': 'hrz',
        'hrz-Arab-IR': 'hrz',
        'hrz-Arab': 'hrz',
        'hrz-IR': 'hrz',
        'hsb': 'hsb',
        'hsb-Latn-DE': 'hsb',
        'hsb-DE': 'hsb',
        'hsb-Latn': 'hsb',
        'hsh': 'hsh',
        'hsh-Zxxx-HU': 'hsh',
        'hsh-HU': 'hsh',
        'hsh-Zxxx': 'hsh',
        'sgn-hsh': 'hsh',
        'sgn-hsh-HU': 'hsh',
        'hsl': 'hsl',
        'hsl-Zxxx-NG': 'hsl',
        'hsl-NG': 'hsl',
        'hsl-Zxxx': 'hsl',
        'sgn-hsl': 'hsl',
        'sgn-hsl-NG': 'hsl',
        'hsn': 'hsn',
        'hsn-Hans-CN': 'hsn',
        'hsn-CN': 'hsn',
        'hsn-Hans': 'hsn',
        'zh-hsn': 'hsn',
        'zh-hsn-CN': 'hsn',
        'hsn-Hant': 'hsn-Hant',
        'hsn-Hant-CN': 'hsn-Hant',
        'hsn-Nshu': 'hsn-Nshu',
        'hsn-Nshu-CN': 'hsn-Nshu',
        'hss': 'hss',
        'hss-Zyyy-OM': 'hss',
        'hss-OM': 'hss',
        'hss-Zyyy': 'hss',
        'ht': 'ht',
        'ht-Latn-HT': 'ht',
        'ht-HT': 'ht',
        'ht-Latn': 'ht',
        'hti': 'hti',
        'hti-Latn-ID': 'hti',
        'hti-ID': 'hti',
        'hti-Latn': 'hti',
        'hto': 'hto',
        'hto-Latn-CO': 'hto',
        'hto-CO': 'hto',
        'hto-Latn': 'hto',
        'hts': 'hts',
        'hts-Latn-TZ': 'hts',
        'hts-Latn': 'hts',
        'hts-TZ': 'hts',
        'htu': 'htu',
        'htu-Latn-ID': 'htu',
        'htu-ID': 'htu',
        'htu-Latn': 'htu',
        'htx': 'htx',
        'htx-Zyyy-TR': 'htx',
        'htx-TR': 'htx',
        'htx-Zyyy': 'htx',
        'hu': 'hu',
        'hu-Latn-HU': 'hu',
        'hu-HU': 'hu',
        'hu-Latn': 'hu',
        'hu-Brai': 'hu-Brai',
        'hu-Brai-HU': 'hu-Brai',
        'hub': 'hub',
        'hub-Latn-PE': 'hub',
        'hub-Latn': 'hub',
        'hub-PE': 'hub',
        'huc': 'huc',
        'huc-Latn-BW': 'huc',
        'huc-BW': 'huc',
        'huc-Latn': 'huc',
        'hud': 'hud',
        'hud-Latn-ID': 'hud',
        'hud-ID': 'hud',
        'hud-Latn': 'hud',
        'hue': 'hue',
        'hue-Latn-MX': 'hue',
        'hue-Latn': 'hue',
        'hue-MX': 'hue',
        'huf': 'huf',
        'huf-Latn-PG': 'huf',
        'huf-Latn': 'huf',
        'huf-PG': 'huf',
        'hug': 'hug',
        'hug-Latn-PE': 'hug',
        'hug-Latn': 'hug',
        'hug-PE': 'hug',
        'huh': 'huh',
        'huh-Latn-CL': 'huh',
        'huh-CL': 'huh',
        'huh-Latn': 'huh',
        'hui': 'hui',
        'hui-Latn-PG': 'hui',
        'hui-Latn': 'hui',
        'hui-PG': 'hui',
        'huj': 'huj',
        'huj-Zyyy-CN': 'huj',
        'huj-CN': 'huj',
        'huj-Zyyy': 'huj',
        'huk': 'huk',
        'huk-Latn-ID': 'huk',
        'huk-ID': 'huk',
        'huk-Latn': 'huk',
        'hul': 'hul',
        'hul-Latn-PG': 'hul',
        'hul-Latn': 'hul',
        'hul-PG': 'hul',
        'hum': 'hum',
        'hum-Latn-CD': 'hum',
        'hum-CD': 'hum',
        'hum-Latn': 'hum',
        'huo': 'huo',
        'huo-Zyyy-CN': 'huo',
        'huo-CN': 'huo',
        'huo-Zyyy': 'huo',
        'hup': 'hup',
        'hup-Latn-US': 'hup',
        'hup-Latn': 'hup',
        'hup-US': 'hup',
        'huq': 'huq',
        'huq-Zyyy-CN': 'huq',
        'huq-CN': 'huq',
        'huq-Zyyy': 'huq',
        'hur': 'hur',
        'hur-Latn-CA': 'hur',
        'hur-CA': 'hur',
        'hur-Latn': 'hur',
        'hus': 'hus',
        'hus-Latn-MX': 'hus',
        'hus-Latn': 'hus',
        'hus-MX': 'hus',
        'hut': 'hut',
        'hut-Zyyy-NP': 'hut',
        'hut-NP': 'hut',
        'hut-Zyyy': 'hut',
        'huu': 'huu',
        'huu-Latn-PE': 'huu',
        'huu-Latn': 'huu',
        'huu-PE': 'huu',
        'huv': 'huv',
        'huv-Latn-MX': 'huv',
        'huv-Latn': 'huv',
        'huv-MX': 'huv',
        'huw': 'huw',
        'huw-Latn-ID': 'huw',
        'huw-ID': 'huw',
        'huw-Latn': 'huw',
        'pmc': 'huw',
        'pmc-ID': 'huw',
        'pmc-Latn': 'huw',
        'pmc-Latn-ID': 'huw',
        'hux': 'hux',
        'hux-Latn-PE': 'hux',
        'hux-Latn': 'hux',
        'hux-PE': 'hux',
        'huy': 'huy',
        'huy-Hebr-IL': 'huy',
        'huy-Hebr': 'huy',
        'huy-IL': 'huy',
        'huz': 'huz',
        'huz-Cyrl-RU': 'huz',
        'huz-Cyrl': 'huz',
        'huz-RU': 'huz',
        'hvc': 'hvc',
        'hvc-Latn-HT': 'hvc',
        'hvc-HT': 'hvc',
        'hvc-Latn': 'hvc',
        'hve': 'hve',
        'hve-Latn-MX': 'hve',
        'hve-Latn': 'hve',
        'hve-MX': 'hve',
        'hvk': 'hvk',
        'hvk-Latn-NC': 'hvk',
        'hvk-Latn': 'hvk',
        'hvk-NC': 'hvk',
        'hvn': 'hvn',
        'hvn-Latn-ID': 'hvn',
        'hvn-ID': 'hvn',
        'hvn-Latn': 'hvn',
        'hvv': 'hvv',
        'hvv-Latn-MX': 'hvv',
        'hvv-Latn': 'hvv',
        'hvv-MX': 'hvv',
        'hwa': 'hwa',
        'hwa-Latn-CI': 'hwa',
        'hwa-CI': 'hwa',
        'hwa-Latn': 'hwa',
        'hwc': 'hwc',
        'hwc-Latn-US': 'hwc',
        'hwc-Latn': 'hwc',
        'hwc-US': 'hwc',
        'hwo': 'hwo',
        'hwo-Latn-NG': 'hwo',
        'hwo-Latn': 'hwo',
        'hwo-NG': 'hwo',
        'hy': 'hy',
        'hy-Armn-AM': 'hy',
        'hy-AM': 'hy',
        'hy-Armn': 'hy',
        'hy-Brai': 'hy-Brai',
        'hy-Brai-AM': 'hy-Brai',
        'hya': 'hya',
        'hya-Latn-CM': 'hya',
        'hya-CM': 'hya',
        'hya-Latn': 'hya',
        'hyw': 'hyw',
        'hyw-Armn-AM': 'hyw',
        'hyw-AM': 'hyw',
        'hyw-Armn': 'hyw',
        'hz': 'hz',
        'hz-Latn-NA': 'hz',
        'hz-Latn': 'hz',
        'hz-NA': 'hz',
        'ia': 'ia',
        'ia-Latn-FR': 'ia',
        'ia-FR': 'ia',
        'ia-Latn': 'ia',
        'iai': 'iai',
        'iai-Latn-NC': 'iai',
        'iai-Latn': 'iai',
        'iai-NC': 'iai',
        'ian': 'ian',
        'ian-Latn-PG': 'ian',
        'ian-Latn': 'ian',
        'ian-PG': 'ian',
        'iap': 'iap',
        'iap-Latn-BR': 'iap',
        'iap-BR': 'iap',
        'iap-Latn': 'iap',
        'iar': 'iar',
        'iar-Latn-PG': 'iar',
        'iar-Latn': 'iar',
        'iar-PG': 'iar',
        'iba': 'iba',
        'iba-Latn-MY': 'iba',
        'iba-Latn': 'iba',
        'iba-MY': 'iba',
        'ibb': 'ibb',
        'ibb-Latn-NG': 'ibb',
        'ibb-Latn': 'ibb',
        'ibb-NG': 'ibb',
        'ibd': 'ibd',
        'ibd-Latn-AU': 'ibd',
        'ibd-AU': 'ibd',
        'ibd-Latn': 'ibd',
        'ibe': 'ibe',
        'ibe-Latn-NG': 'ibe',
        'ibe-Latn': 'ibe',
        'ibe-NG': 'ibe',
        'ibg': 'ibg',
        'ibg-Latn-PH': 'ibg',
        'ibg-Latn': 'ibg',
        'ibg-PH': 'ibg',
        'ibh': 'ibh',
        'ibh-Latn-VN': 'ibh',
        'ibh-Latn': 'ibh',
        'ibh-VN': 'ibh',
        'ibl': 'ibl',
        'ibl-Latn-PH': 'ibl',
        'ibl-Latn': 'ibl',
        'ibl-PH': 'ibl',
        'ibm': 'ibm',
        'ibm-Latn-NG': 'ibm',
        'ibm-Latn': 'ibm',
        'ibm-NG': 'ibm',
        'ibn': 'ibn',
        'ibn-Latn-NG': 'ibn',
        'ibn-Latn': 'ibn',
        'ibn-NG': 'ibn',
        'ibr': 'ibr',
        'ibr-Latn-NG': 'ibr',
        'ibr-Latn': 'ibr',
        'ibr-NG': 'ibr',
        'ibu': 'ibu',
        'ibu-Latn-ID': 'ibu',
        'ibu-ID': 'ibu',
        'ibu-Latn': 'ibu',
        'iby': 'iby',
        'iby-Latn-NG': 'iby',
        'iby-Latn': 'iby',
        'iby-NG': 'iby',
        'ica': 'ica',
        'ica-Latn-BJ': 'ica',
        'ica-BJ': 'ica',
        'ica-Latn': 'ica',
        'ich': 'ich',
        'ich-Latn-NG': 'ich',
        'ich-Latn': 'ich',
        'ich-NG': 'ich',
        'icl': 'icl',
        'icl-Zxxx-IS': 'icl',
        'icl-IS': 'icl',
        'icl-Zxxx': 'icl',
        'sgn-icl': 'icl',
        'sgn-icl-IS': 'icl',
        'icr': 'icr',
        'icr-Latn-CO': 'icr',
        'icr-CO': 'icr',
        'icr-Latn': 'icr',
        'id': 'id',
        'id-Latn-ID': 'id',
        'id-ID': 'id',
        'id-Latn': 'id',
        'in': 'id',
        'in-ID': 'id',
        'in-Latn': 'id',
        'in-Latn-ID': 'id',
        'id-Arab': 'id-Arab',
        'id-Arab-ID': 'id-Arab',
        'id-Brai': 'id-Brai',
        'id-Brai-ID': 'id-Brai',
        'ida': 'ida',
        'ida-Latn-KE': 'ida',
        'ida-KE': 'ida',
        'ida-Latn': 'ida',
        'idb': 'idb',
        'idb-Latn-IN': 'idb',
        'idb-IN': 'idb',
        'idb-Latn': 'idb',
        'idc': 'idc',
        'idc-Latn-NG': 'idc',
        'idc-Latn': 'idc',
        'idc-NG': 'idc',
        'idd': 'idd',
        'idd-Latn-BJ': 'idd',
        'idd-BJ': 'idd',
        'idd-Latn': 'idd',
        'ide': 'ide',
        'ide-Latn-NG': 'ide',
        'ide-Latn': 'ide',
        'ide-NG': 'ide',
        'idi': 'idi',
        'idi-Latn-PG': 'idi',
        'idi-Latn': 'idi',
        'idi-PG': 'idi',
        'idr': 'idr',
        'idr-Latn-SS': 'idr',
        'idr-Latn': 'idr',
        'idr-SS': 'idr',
        'ids': 'ids',
        'ids-Latn-NG': 'ids',
        'ids-Latn': 'ids',
        'ids-NG': 'ids',
        'idt': 'idt',
        'idt-Latn-TL': 'idt',
        'idt-Latn': 'idt',
        'idt-TL': 'idt',
        'idu': 'idu',
        'idu-Latn-NG': 'idu',
        'idu-Latn': 'idu',
        'idu-NG': 'idu',
        'ie': 'ie',
        'ie-Latn-001': 'ie',
        'ie-001': 'ie',
        'ie-Latn': 'ie',
        'ifa': 'ifa',
        'ifa-Latn-PH': 'ifa',
        'ifa-Latn': 'ifa',
        'ifa-PH': 'ifa',
        'ifb': 'ifb',
        'ifb-Latn-PH': 'ifb',
        'ifb-Latn': 'ifb',
        'ifb-PH': 'ifb',
        'ife': 'ife',
        'ife-Latn-TG': 'ife',
        'ife-Latn': 'ife',
        'ife-TG': 'ife',
        'ife-BJ': 'ife-BJ',
        'ife-Latn-BJ': 'ife-BJ',
        'iff': 'iff',
        'iff-Latn-VU': 'iff',
        'iff-Latn': 'iff',
        'iff-VU': 'iff',
        'ifk': 'ifk',
        'ifk-Latn-PH': 'ifk',
        'ifk-Latn': 'ifk',
        'ifk-PH': 'ifk',
        'ifm': 'ifm',
        'ifm-Latn-CG': 'ifm',
        'ifm-CG': 'ifm',
        'ifm-Latn': 'ifm',
        'ifu': 'ifu',
        'ifu-Latn-PH': 'ifu',
        'ifu-Latn': 'ifu',
        'ifu-PH': 'ifu',
        'ify': 'ify',
        'ify-Latn-PH': 'ify',
        'ify-Latn': 'ify',
        'ify-PH': 'ify',
        'ig': 'ig',
        'ig-Latn-NG': 'ig',
        'ig-Latn': 'ig',
        'ig-NG': 'ig',
        'igb': 'igb',
        'igb-Latn-NG': 'igb',
        'igb-Latn': 'igb',
        'igb-NG': 'igb',
        'ige': 'ige',
        'ige-Latn-NG': 'ige',
        'ige-Latn': 'ige',
        'ige-NG': 'ige',
        'igg': 'igg',
        'igg-Latn-PG': 'igg',
        'igg-Latn': 'igg',
        'igg-PG': 'igg',
        'igl': 'igl',
        'igl-Latn-NG': 'igl',
        'igl-Latn': 'igl',
        'igl-NG': 'igl',
        'igm': 'igm',
        'igm-Latn-PG': 'igm',
        'igm-Latn': 'igm',
        'igm-PG': 'igm',
        'ign': 'ign',
        'ign-Latn-BO': 'ign',
        'ign-BO': 'ign',
        'ign-Latn': 'ign',
        'igo': 'igo',
        'igo-Latn-PG': 'igo',
        'igo-Latn': 'igo',
        'igo-PG': 'igo',
        'igs': 'igs',
        'igs-Zyyy-001': 'igs',
        'igs-001': 'igs',
        'igs-Zyyy': 'igs',
        'igw': 'igw',
        'igw-Latn-NG': 'igw',
        'igw-Latn': 'igw',
        'igw-NG': 'igw',
        'ihb': 'ihb',
        'ihb-Latn-ID': 'ihb',
        'ihb-ID': 'ihb',
        'ihb-Latn': 'ihb',
        'ihi': 'ihi',
        'ihi-Latn-NG': 'ihi',
        'ihi-Latn': 'ihi',
        'ihi-NG': 'ihi',
        'ihp': 'ihp',
        'ihp-Latn-ID': 'ihp',
        'ihp-ID': 'ihp',
        'ihp-Latn': 'ihp',
        'ihw': 'ihw',
        'ihw-Latn-AU': 'ihw',
        'ihw-AU': 'ihw',
        'ihw-Latn': 'ihw',
        'ii': 'ii',
        'ii-Yiii-CN': 'ii',
        'ii-CN': 'ii',
        'ii-Yiii': 'ii',
        'ii-Latn': 'ii-Latn',
        'ii-Latn-CN': 'ii-Latn',
        'iin': 'iin',
        'iin-Latn-AU': 'iin',
        'iin-AU': 'iin',
        'iin-Latn': 'iin',
        'ijc': 'ijc',
        'ijc-Latn-NG': 'ijc',
        'ijc-Latn': 'ijc',
        'ijc-NG': 'ijc',
        'ije': 'ije',
        'ije-Latn-NG': 'ije',
        'ije-Latn': 'ije',
        'ije-NG': 'ije',
        'ijj': 'ijj',
        'ijj-Latn-BJ': 'ijj',
        'ijj-BJ': 'ijj',
        'ijj-Latn': 'ijj',
        'ijn': 'ijn',
        'ijn-Latn-NG': 'ijn',
        'ijn-Latn': 'ijn',
        'ijn-NG': 'ijn',
        'ijs': 'ijs',
        'ijs-Latn-NG': 'ijs',
        'ijs-Latn': 'ijs',
        'ijs-NG': 'ijs',
        'ik': 'ik',
        'ik-Latn-US': 'ik',
        'esk': 'ik',
        'esk-Latn': 'ik',
        'esk-Latn-US': 'ik',
        'esk-US': 'ik',
        'ik-Latn': 'ik',
        'ik-US': 'ik',
        'ike-Latn': 'ike-Latn',
        'ike-Latn-US': 'ike-Latn',
        'ike-US': 'ike-Latn',
        'iki': 'iki',
        'iki-Latn-NG': 'iki',
        'iki-Latn': 'iki',
        'iki-NG': 'iki',
        'ikk': 'ikk',
        'ikk-Latn-NG': 'ikk',
        'ikk-Latn': 'ikk',
        'ikk-NG': 'ikk',
        'ikl': 'ikl',
        'ikl-Latn-NG': 'ikl',
        'ikl-Latn': 'ikl',
        'ikl-NG': 'ikl',
        'iko': 'iko',
        'iko-Latn-NG': 'iko',
        'iko-Latn': 'iko',
        'iko-NG': 'iko',
        'ikp': 'ikp',
        'ikp-Latn-NG': 'ikp',
        'ikp-Latn': 'ikp',
        'ikp-NG': 'ikp',
        'ikr': 'ikr',
        'ikr-Latn-AU': 'ikr',
        'ikr-AU': 'ikr',
        'ikr-Latn': 'ikr',
        'iks': 'iks',
        'iks-Zxxx-CA': 'iks',
        'iks-CA': 'iks',
        'iks-Zxxx': 'iks',
        'sgn-iks': 'iks',
        'sgn-iks-CA': 'iks',
        'ikt': 'ikt',
        'ikt-Latn-CA': 'ikt',
        'ikt-CA': 'ikt',
        'ikt-Latn': 'ikt',
        'ikt-Cans': 'ikt-Cans',
        'ikt-Cans-CA': 'ikt-Cans',
        'ikv': 'ikv',
        'ikv-Latn-NG': 'ikv',
        'ikv-Latn': 'ikv',
        'ikv-NG': 'ikv',
        'ikw': 'ikw',
        'ikw-Latn-NG': 'ikw',
        'ikw-Latn': 'ikw',
        'ikw-NG': 'ikw',
        'ikx': 'ikx',
        'ikx-Latn-UG': 'ikx',
        'ikx-Latn': 'ikx',
        'ikx-UG': 'ikx',
        'ikz': 'ikz',
        'ikz-Latn-TZ': 'ikz',
        'ikz-Latn': 'ikz',
        'ikz-TZ': 'ikz',
        'ila': 'ila',
        'ila-Latn-ID': 'ila',
        'ila-ID': 'ila',
        'ila-Latn': 'ila',
        'ilb': 'ilb',
        'ilb-Latn-ZM': 'ilb',
        'ilb-Latn': 'ilb',
        'ilb-ZM': 'ilb',
        'ilg': 'ilg',
        'ilg-Latn-AU': 'ilg',
        'ilg-AU': 'ilg',
        'ilg-Latn': 'ilg',
        'ili': 'ili',
        'ili-Zyyy-CN': 'ili',
        'ili-CN': 'ili',
        'ili-Zyyy': 'ili',
        'ilk': 'ilk',
        'ilk-Latn-PH': 'ilk',
        'ilk-Latn': 'ilk',
        'ilk-PH': 'ilk',
        'ilm': 'ilm',
        'ilm-Latn-MY': 'ilm',
        'ill': 'ilm',
        'ill-Latn': 'ilm',
        'ill-Latn-MY': 'ilm',
        'ill-MY': 'ilm',
        'ilm-Latn': 'ilm',
        'ilm-MY': 'ilm',
        'ilo': 'ilo',
        'ilo-Latn-PH': 'ilo',
        'ilo-Latn': 'ilo',
        'ilo-PH': 'ilo',
        'ilo-Brai': 'ilo-Brai',
        'ilo-Brai-PH': 'ilo-Brai',
        'ilo-Tglg': 'ilo-Tglg',
        'ilo-Tglg-PH': 'ilo-Tglg',
        'ilp': 'ilp',
        'ilp-Latn-PH': 'ilp',
        'ilp-Latn': 'ilp',
        'ilp-PH': 'ilp',
        'ils': 'ils',
        'ils-Zxxx-IT': 'ils',
        'ils-IT': 'ils',
        'ils-Zxxx': 'ils',
        'sgn-ils': 'ils',
        'sgn-ils-IT': 'ils',
        'ilu': 'ilu',
        'ilu-Latn-ID': 'ilu',
        'ilu-ID': 'ilu',
        'ilu-Latn': 'ilu',
        'ilv': 'ilv',
        'ilv-Latn-NG': 'ilv',
        'ilv-Latn': 'ilv',
        'ilv-NG': 'ilv',
        'ima': 'ima',
        'ima-Zyyy-IN': 'ima',
        'ima-IN': 'ima',
        'ima-Zyyy': 'ima',
        'imi': 'imi',
        'imi-Latn-PG': 'imi',
        'imi-Latn': 'imi',
        'imi-PG': 'imi',
        'iml': 'iml',
        'iml-Zyyy-US': 'iml',
        'iml-US': 'iml',
        'iml-Zyyy': 'iml',
        'imn': 'imn',
        'imn-Latn-PG': 'imn',
        'imn-Latn': 'imn',
        'imn-PG': 'imn',
        'imo': 'imo',
        'imo-Latn-PG': 'imo',
        'imo-Latn': 'imo',
        'imo-PG': 'imo',
        'imr': 'imr',
        'imr-Latn-ID': 'imr',
        'imr-ID': 'imr',
        'imr-Latn': 'imr',
        'ims': 'ims',
        'ims-Latn-IT': 'ims',
        'ims-IT': 'ims',
        'ims-Latn': 'ims',
        'imy': 'imy',
        'imy-Zyyy-TR': 'imy',
        'imy-TR': 'imy',
        'imy-Zyyy': 'imy',
        'inb': 'inb',
        'inb-Latn-CO': 'inb',
        'inb-CO': 'inb',
        'inb-Latn': 'inb',
        'ing': 'ing',
        'ing-Latn-US': 'ing',
        'ing-Latn': 'ing',
        'ing-US': 'ing',
        'inh': 'inh',
        'inh-Cyrl-RU': 'inh',
        'inh-Cyrl': 'inh',
        'inh-RU': 'inh',
        'inh-Arab': 'inh-Arab',
        'inh-Arab-RU': 'inh-Arab',
        'inh-Latn': 'inh-Latn',
        'inh-Latn-RU': 'inh-Latn',
        'inj': 'inj',
        'inj-Latn-CO': 'inj',
        'inj-CO': 'inj',
        'inj-Latn': 'inj',
        'inl': 'inl',
        'inl-Zxxx-ID': 'inl',
        'inl-ID': 'inl',
        'inl-Zxxx': 'inl',
        'sgn-inl': 'inl',
        'sgn-inl-ID': 'inl',
        'inm': 'inm',
        'inm-Zyyy-YE': 'inm',
        'inm-YE': 'inm',
        'inm-Zyyy': 'inm',
        'inn': 'inn',
        'inn-Latn-PH': 'inn',
        'inn-Latn': 'inn',
        'inn-PH': 'inn',
        'ino': 'ino',
        'ino-Latn-PG': 'ino',
        'ino-Latn': 'ino',
        'ino-PG': 'ino',
        'inp': 'inp',
        'inp-Latn-PE': 'inp',
        'inp-Latn': 'inp',
        'inp-PE': 'inp',
        'ins': 'ins',
        'ins-Zxxx-IN': 'ins',
        'ins-IN': 'ins',
        'ins-Zxxx': 'ins',
        'sgn-ins': 'ins',
        'sgn-ins-IN': 'ins',
        'int': 'int',
        'int-Mymr-MM': 'int',
        'int-MM': 'int',
        'int-Mymr': 'int',
        'inz': 'inz',
        'inz-Zyyy-US': 'inz',
        'inz-US': 'inz',
        'inz-Zyyy': 'inz',
        'io': 'io',
        'io-Latn-001': 'io',
        'io-001': 'io',
        'io-Latn': 'io',
        'ior': 'ior',
        'ior-Zyyy-ET': 'ior',
        'ior-ET': 'ior',
        'ior-Zyyy': 'ior',
        'iou': 'iou',
        'iou-Latn-PG': 'iou',
        'iou-Latn': 'iou',
        'iou-PG': 'iou',
        'iow': 'iow',
        'iow-Zyyy-US': 'iow',
        'iow-US': 'iow',
        'iow-Zyyy': 'iow',
        'ipi': 'ipi',
        'ipi-Latn-PG': 'ipi',
        'ipi-Latn': 'ipi',
        'ipi-PG': 'ipi',
        'ipo': 'ipo',
        'ipo-Latn-PG': 'ipo',
        'ipo-Latn': 'ipo',
        'ipo-PG': 'ipo',
        'iqu': 'iqu',
        'iqu-Latn-PE': 'iqu',
        'iqu-Latn': 'iqu',
        'iqu-PE': 'iqu',
        'iqw': 'iqw',
        'iqw-Latn-NG': 'iqw',
        'iqw-Latn': 'iqw',
        'iqw-NG': 'iqw',
        'ire': 'ire',
        'ire-Latn-ID': 'ire',
        'ire-ID': 'ire',
        'ire-Latn': 'ire',
        'irh': 'irh',
        'irh-Latn-ID': 'irh',
        'irh-ID': 'irh',
        'irh-Latn': 'irh',
        'iri': 'iri',
        'iri-Latn-NG': 'iri',
        'iri-Latn': 'iri',
        'iri-NG': 'iri',
        'irk': 'irk',
        'irk-Latn-TZ': 'irk',
        'irk-Latn': 'irk',
        'irk-TZ': 'irk',
        'irn': 'irn',
        'irn-Latn-BR': 'irn',
        'irn-BR': 'irn',
        'irn-Latn': 'irn',
        'irr': 'irr',
        'irr-Zyyy-LA': 'irr',
        'irr-LA': 'irr',
        'irr-Zyyy': 'irr',
        'iru': 'iru',
        'iru-Taml-IN': 'iru',
        'iru-IN': 'iru',
        'iru-Taml': 'iru',
        'iru-Mlym': 'iru-Mlym',
        'iru-Mlym-IN': 'iru-Mlym',
        'irx': 'irx',
        'irx-Latn-ID': 'irx',
        'irx-ID': 'irx',
        'irx-Latn': 'irx',
        'iry': 'iry',
        'iry-Latn-PH': 'iry',
        'iry-Latn': 'iry',
        'iry-PH': 'iry',
        'is': 'is',
        'is-Latn-IS': 'is',
        'is-IS': 'is',
        'is-Latn': 'is',
        'isa': 'isa',
        'isa-Latn-PG': 'isa',
        'isa-Latn': 'isa',
        'isa-PG': 'isa',
        'isc': 'isc',
        'isc-Latn-PE': 'isc',
        'isc-Latn': 'isc',
        'isc-PE': 'isc',
        'isd': 'isd',
        'isd-Latn-PH': 'isd',
        'isd-Latn': 'isd',
        'isd-PH': 'isd',
        'ise': 'ise',
        'ise-Zxxx-IT': 'ise',
        'ise-IT': 'ise',
        'ise-Zxxx': 'ise',
        'sgn-ise': 'ise',
        'sgn-ise-IT': 'ise',
        'isg': 'isg',
        'isg-Zxxx-IE': 'isg',
        'isg-IE': 'isg',
        'isg-Zxxx': 'isg',
        'sgn-isg': 'isg',
        'sgn-isg-IE': 'isg',
        'ish': 'ish',
        'ish-Latn-NG': 'ish',
        'ish-Latn': 'ish',
        'ish-NG': 'ish',
        'isi': 'isi',
        'isi-Latn-NG': 'isi',
        'isi-Latn': 'isi',
        'isi-NG': 'isi',
        'isk': 'isk',
        'isk-Arab-AF': 'isk',
        'isk-AF': 'isk',
        'isk-Arab': 'isk',
        'ism': 'ism',
        'ism-Latn-ID': 'ism',
        'ism-ID': 'ism',
        'ism-Latn': 'ism',
        'isn': 'isn',
        'isn-Latn-TZ': 'isn',
        'isn-Latn': 'isn',
        'isn-TZ': 'isn',
        'iso': 'iso',
        'iso-Latn-NG': 'iso',
        'iso-Latn': 'iso',
        'iso-NG': 'iso',
        'isr': 'isr',
        'isr-Zxxx-IL': 'isr',
        'isr-IL': 'isr',
        'isr-Zxxx': 'isr',
        'sgn-isr': 'isr',
        'sgn-isr-IL': 'isr',
        'ist': 'ist',
        'ist-Latn-HR': 'ist',
        'ist-HR': 'ist',
        'ist-Latn': 'ist',
        'isu': 'isu',
        'isu-Latn-CM': 'isu',
        'isu-CM': 'isu',
        'isu-Latn': 'isu',
        'it': 'it',
        'it-Latn-IT': 'it',
        'it-IT': 'it',
        'it-Latn': 'it',
        'it-Brai': 'it-Brai',
        'it-Brai-IT': 'it-Brai',
        'it-CH': 'it-CH',
        'it-Latn-CH': 'it-CH',
        'itb': 'itb',
        'itb-Latn-PH': 'itb',
        'itb-Latn': 'itb',
        'itb-PH': 'itb',
        'itd': 'itd',
        'itd-Latn-ID': 'itd',
        'itd-ID': 'itd',
        'itd-Latn': 'itd',
        'ite': 'ite',
        'ite-Latn-BO': 'ite',
        'ite-BO': 'ite',
        'ite-Latn': 'ite',
        'iti': 'iti',
        'iti-Latn-PH': 'iti',
        'iti-Latn': 'iti',
        'iti-PH': 'iti',
        'itk': 'itk',
        'itk-Hebr-IT': 'itk',
        'itk-Hebr': 'itk',
        'itk-IT': 'itk',
        'itl': 'itl',
        'itl-Cyrl-RU': 'itl',
        'itl-Cyrl': 'itl',
        'itl-RU': 'itl',
        'itm': 'itm',
        'itm-Latn-NG': 'itm',
        'itm-Latn': 'itm',
        'itm-NG': 'itm',
        'ito': 'ito',
        'ito-Latn-BO': 'ito',
        'ito-BO': 'ito',
        'ito-Latn': 'ito',
        'itr': 'itr',
        'itr-Latn-PG': 'itr',
        'itr-Latn': 'itr',
        'itr-PG': 'itr',
        'its': 'its',
        'its-Latn-NG': 'its',
        'its-Latn': 'its',
        'its-NG': 'its',
        'itt': 'itt',
        'itt-Latn-PH': 'itt',
        'itt-Latn': 'itt',
        'itt-PH': 'itt',
        'itv': 'itv',
        'itv-Latn-PH': 'itv',
        'itv-Latn': 'itv',
        'itv-PH': 'itv',
        'itw': 'itw',
        'itw-Latn-NG': 'itw',
        'itw-Latn': 'itw',
        'itw-NG': 'itw',
        'itx': 'itx',
        'itx-Latn-ID': 'itx',
        'itx-ID': 'itx',
        'itx-Latn': 'itx',
        'ity': 'ity',
        'ity-Latn-PH': 'ity',
        'ity-Latn': 'ity',
        'ity-PH': 'ity',
        'itz': 'itz',
        'itz-Latn-GT': 'itz',
        'itz-GT': 'itz',
        'itz-Latn': 'itz',
        'iu': 'iu',
        'iu-Cans-CA': 'iu',
        'ike': 'iu',
        'ike-CA': 'iu',
        'ike-Cans': 'iu',
        'ike-Cans-CA': 'iu',
        'iu-CA': 'iu',
        'iu-Cans': 'iu',
        'iu-Latn': 'iu-Latn',
        'iu-Latn-CA': 'iu-Latn',
        'ium': 'ium',
        'ium-Latn-CN': 'ium',
        'ium-CN': 'ium',
        'ium-Latn': 'ium',
        'ium-Hani': 'ium-Hani',
        'ium-Hani-CN': 'ium-Hani',
        'ium-Laoo': 'ium-Laoo',
        'ium-Laoo-LA': 'ium-Laoo',
        'ium-LA': 'ium-Laoo',
        'ium-Thai': 'ium-Thai',
        'ium-Thai-TH': 'ium-Thai',
        'ium-TH': 'ium-Thai',
        'ium-x-1954': 'ium-x-1954',
        'ium-Latn-CN-x-1954': 'ium-x-1954',
        'ium-CN-x-1954': 'ium-x-1954',
        'ium-Latn-x-1954': 'ium-x-1954',
        'ivb': 'ivb',
        'ivb-Latn-PH': 'ivb',
        'ivb-Latn': 'ivb',
        'ivb-PH': 'ivb',
        'ivv': 'ivv',
        'ivv-Latn-PH': 'ivv',
        'ivv-Latn': 'ivv',
        'ivv-PH': 'ivv',
        'iwk': 'iwk',
        'iwk-Latn-PH': 'iwk',
        'iwk-Latn': 'iwk',
        'iwk-PH': 'iwk',
        'iwm': 'iwm',
        'iwm-Latn-PG': 'iwm',
        'iwm-Latn': 'iwm',
        'iwm-PG': 'iwm',
        'iwo': 'iwo',
        'iwo-Latn-ID': 'iwo',
        'iwo-ID': 'iwo',
        'iwo-Latn': 'iwo',
        'iws': 'iws',
        'iws-Latn-PG': 'iws',
        'iws-Latn': 'iws',
        'iws-PG': 'iws',
        'ixc': 'ixc',
        'ixc-Latn-MX': 'ixc',
        'ixc-Latn': 'ixc',
        'ixc-MX': 'ixc',
        'ixl': 'ixl',
        'ixl-Latn-GT': 'ixl',
        'ixl-GT': 'ixl',
        'ixl-Latn': 'ixl',
        'iya': 'iya',
        'iya-Latn-NG': 'iya',
        'iya-Latn': 'iya',
        'iya-NG': 'iya',
        'iyo': 'iyo',
        'iyo-Latn-CM': 'iyo',
        'iyo-CM': 'iyo',
        'iyo-Latn': 'iyo',
        'iyx': 'iyx',
        'iyx-Latn-CG': 'iyx',
        'iyx-CG': 'iyx',
        'iyx-Latn': 'iyx',
        'izh': 'izh',
        'izh-Latn-RU': 'izh',
        'izh-Latn': 'izh',
        'izh-RU': 'izh',
        'izr': 'izr',
        'izr-Latn-NG': 'izr',
        'izr-Latn': 'izr',
        'izr-NG': 'izr',
        'izz': 'izz',
        'izz-Latn-NG': 'izz',
        'izi': 'izz',
        'izi-Latn': 'izz',
        'izi-Latn-NG': 'izz',
        'izi-NG': 'izz',
        'izz-Latn': 'izz',
        'izz-NG': 'izz',
        'ja': 'ja',
        'ja-Jpan-JP': 'ja',
        'ja-JP': 'ja',
        'ja-Jpan': 'ja',
        'ja-Brai': 'ja-Brai',
        'ja-Brai-JP': 'ja-Brai',
        'ja-Latn': 'ja-Latn',
        'ja-Latn-JP': 'ja-Latn',
        'jaa': 'jaa',
        'jaa-Latn-BR': 'jaa',
        'jaa-BR': 'jaa',
        'jaa-Latn': 'jaa',
        'jab': 'jab',
        'jab-Latn-NG': 'jab',
        'jab-Latn': 'jab',
        'jab-NG': 'jab',
        'jac': 'jac',
        'jac-Latn-GT': 'jac',
        'jac-GT': 'jac',
        'jac-Latn': 'jac',
        'jad': 'jad',
        'jad-Arab-GN': 'jad',
        'jad-Arab': 'jad',
        'jad-GN': 'jad',
        'jae': 'jae',
        'jae-Latn-PG': 'jae',
        'jae-Latn': 'jae',
        'jae-PG': 'jae',
        'jaf': 'jaf',
        'jaf-Latn-NG': 'jaf',
        'jaf-Latn': 'jaf',
        'jaf-NG': 'jaf',
        'jah': 'jah',
        'jah-Latn-MY': 'jah',
        'jah-Latn': 'jah',
        'jah-MY': 'jah',
        'jaj': 'jaj',
        'jaj-Latn-SB': 'jaj',
        'jaj-Latn': 'jaj',
        'jaj-SB': 'jaj',
        'jak': 'jak',
        'jak-Latn-MY': 'jak',
        'jak-Latn': 'jak',
        'jak-MY': 'jak',
        'ms-jak': 'jak',
        'ms-jak-MY': 'jak',
        'jal': 'jal',
        'jal-Latn-ID': 'jal',
        'hrr': 'jal',
        'hrr-ID': 'jal',
        'hrr-Latn': 'jal',
        'hrr-Latn-ID': 'jal',
        'jal-ID': 'jal',
        'jal-Latn': 'jal',
        'jam': 'jam',
        'jam-Latn-JM': 'jam',
        'jam-JM': 'jam',
        'jam-Latn': 'jam',
        'jan': 'jan',
        'jan-Latn-AU': 'jan',
        'jan-AU': 'jan',
        'jan-Latn': 'jan',
        'jao': 'jao',
        'jao-Latn-AU': 'jao',
        'jao-AU': 'jao',
        'jao-Latn': 'jao',
        'jaq': 'jaq',
        'jaq-Latn-ID': 'jaq',
        'jaq-ID': 'jaq',
        'jaq-Latn': 'jaq',
        'jas': 'jas',
        'jas-Latn-NC': 'jas',
        'jas-Latn': 'jas',
        'jas-NC': 'jas',
        'jat': 'jat',
        'jat-Arab-AF': 'jat',
        'jat-AF': 'jat',
        'jat-Arab': 'jat',
        'jau': 'jau',
        'jau-Latn-ID': 'jau',
        'jau-ID': 'jau',
        'jau-Latn': 'jau',
        'jax': 'jax',
        'jax-Latn-ID': 'jax',
        'jax-ID': 'jax',
        'jax-Latn': 'jax',
        'ms-jax': 'jax',
        'ms-jax-ID': 'jax',
        'jay': 'jay',
        'jay-Latn-AU': 'jay',
        'jay-AU': 'jay',
        'jay-Latn': 'jay',
        'jaz': 'jaz',
        'jaz-Latn-NC': 'jaz',
        'jaz-Latn': 'jaz',
        'jaz-NC': 'jaz',
        'jbe': 'jbe',
        'jbe-Hebr-IL': 'jbe',
        'jbe-Hebr': 'jbe',
        'jbe-IL': 'jbe',
        'jbi': 'jbi',
        'jbi-Latn-AU': 'jbi',
        'jbi-AU': 'jbi',
        'jbi-Latn': 'jbi',
        'jbj': 'jbj',
        'jbj-Latn-ID': 'jbj',
        'jbj-ID': 'jbj',
        'jbj-Latn': 'jbj',
        'jbk': 'jbk',
        'jbk-Latn-PG': 'jbk',
        'jbk-Latn': 'jbk',
        'jbk-PG': 'jbk',
        'jbn': 'jbn',
        'jbn-Arab-LY': 'jbn',
        'jbn-Arab': 'jbn',
        'jbn-LY': 'jbn',
        'jbo': 'jbo',
        'jbo-Latn-001': 'jbo',
        'jbo-001': 'jbo',
        'jbo-Latn': 'jbo',
        'jbr': 'jbr',
        'jbr-Latn-ID': 'jbr',
        'jbr-ID': 'jbr',
        'jbr-Latn': 'jbr',
        'jbt': 'jbt',
        'jbt-Latn-BR': 'jbt',
        'jbt-BR': 'jbt',
        'jbt-Latn': 'jbt',
        'jbu': 'jbu',
        'jbu-Latn-CM': 'jbu',
        'jbu-CM': 'jbu',
        'jbu-Latn': 'jbu',
        'jbw': 'jbw',
        'jbw-Latn-AU': 'jbw',
        'jbw-AU': 'jbw',
        'jbw-Latn': 'jbw',
        'jcs': 'jcs',
        'jcs-Zxxx-JM': 'jcs',
        'jcs-JM': 'jcs',
        'jcs-Zxxx': 'jcs',
        'sgn-jcs': 'jcs',
        'sgn-jcs-JM': 'jcs',
        'jct': 'jct',
        'jct-Cyrl-UA': 'jct',
        'jct-Cyrl': 'jct',
        'jct-UA': 'jct',
        'jct-Latn': 'jct-Latn',
        'jct-Latn-UA': 'jct-Latn',
        'jda': 'jda',
        'jda-Zyyy-IN': 'jda',
        'jda-IN': 'jda',
        'jda-Zyyy': 'jda',
        'jdg': 'jdg',
        'jdg-Arab-PK': 'jdg',
        'jdg-Arab': 'jdg',
        'jdg-PK': 'jdg',
        'jdt': 'jdt',
        'jdt-Cyrl-RU': 'jdt',
        'jdt-Cyrl': 'jdt',
        'jdt-RU': 'jdt',
        'jdt-Hebr': 'jdt-Hebr',
        'jdt-Hebr-RU': 'jdt-Hebr',
        'jdt-Latn': 'jdt-Latn',
        'jdt-Latn-AZ': 'jdt-Latn',
        'jdt-AZ': 'jdt-Latn',
        'jeb': 'jeb',
        'jeb-Latn-PE': 'jeb',
        'jeb-Latn': 'jeb',
        'jeb-PE': 'jeb',
        'jee': 'jee',
        'jee-Deva-NP': 'jee',
        'jee-Deva': 'jee',
        'jee-NP': 'jee',
        'jeh': 'jeh',
        'jeh-Latn-VN': 'jeh',
        'jeh-Latn': 'jeh',
        'jeh-VN': 'jeh',
        'jeh-Laoo': 'jeh-Laoo',
        'jeh-Laoo-LA': 'jeh-Laoo',
        'jeh-LA': 'jeh-Laoo',
        'jei': 'jei',
        'jei-Latn-ID': 'jei',
        'jei-ID': 'jei',
        'jei-Latn': 'jei',
        'jek': 'jek',
        'jek-Latn-CI': 'jek',
        'jek-CI': 'jek',
        'jek-Latn': 'jek',
        'jel': 'jel',
        'jel-Latn-ID': 'jel',
        'jel-ID': 'jel',
        'jel-Latn': 'jel',
        'jen': 'jen',
        'jen-Latn-NG': 'jen',
        'jen-Latn': 'jen',
        'jen-NG': 'jen',
        'jer': 'jer',
        'jer-Latn-NG': 'jer',
        'jer-Latn': 'jer',
        'jer-NG': 'jer',
        'jet': 'jet',
        'jet-Latn-PG': 'jet',
        'jet-Latn': 'jet',
        'jet-PG': 'jet',
        'jeu': 'jeu',
        'jeu-Latn-TD': 'jeu',
        'jeu-Latn': 'jeu',
        'jeu-TD': 'jeu',
        'jgb': 'jgb',
        'jgb-Latn-CD': 'jgb',
        'jgb-CD': 'jgb',
        'jgb-Latn': 'jgb',
        'jge': 'jge',
        'jge-Zyyy-IL': 'jge',
        'jge-IL': 'jge',
        'jge-Zyyy': 'jge',
        'jgk': 'jgk',
        'jgk-Latn-NG': 'jgk',
        'jar': 'jgk',
        'jar-Latn': 'jgk',
        'jar-Latn-NG': 'jgk',
        'jar-NG': 'jgk',
        'jgk-Latn': 'jgk',
        'jgk-NG': 'jgk',
        'jgo': 'jgo',
        'jgo-Latn-CM': 'jgo',
        'jgo-CM': 'jgo',
        'jgo-Latn': 'jgo',
        'jhi': 'jhi',
        'jhi-Latn-MY': 'jhi',
        'jhi-Latn': 'jhi',
        'jhi-MY': 'jhi',
        'jhs': 'jhs',
        'jhs-Zxxx-NP': 'jhs',
        'jhs-NP': 'jhs',
        'jhs-Zxxx': 'jhs',
        'sgn-jhs': 'jhs',
        'sgn-jhs-NP': 'jhs',
        'jia': 'jia',
        'jia-Latn-CM': 'jia',
        'jia-CM': 'jia',
        'jia-Latn': 'jia',
        'jib': 'jib',
        'jib-Latn-NG': 'jib',
        'jib-Latn': 'jib',
        'jib-NG': 'jib',
        'jic': 'jic',
        'jic-Latn-HN': 'jic',
        'jic-HN': 'jic',
        'jic-Latn': 'jic',
        'jid': 'jid',
        'jid-Latn-NG': 'jid',
        'jid-Latn': 'jid',
        'jid-NG': 'jid',
        'jie': 'jie',
        'jie-Latn-NG': 'jie',
        'jie-Latn': 'jie',
        'jie-NG': 'jie',
        'jig': 'jig',
        'jig-Latn-AU': 'jig',
        'jig-AU': 'jig',
        'jig-Latn': 'jig',
        'jih': 'jih',
        'jih-Zyyy-CN': 'jih',
        'jih-CN': 'jih',
        'jih-Zyyy': 'jih',
        'jii': 'jii',
        'jii-Zyyy-SO': 'jii',
        'jii-SO': 'jii',
        'jii-Zyyy': 'jii',
        'jil': 'jil',
        'jil-Latn-PG': 'jil',
        'jil-Latn': 'jil',
        'jil-PG': 'jil',
        'jim': 'jim',
        'jim-Latn-CM': 'jim',
        'jim-CM': 'jim',
        'jim-Latn': 'jim',
        'jio': 'jio',
        'jio-Zyyy-CN': 'jio',
        'jio-CN': 'jio',
        'jio-Zyyy': 'jio',
        'jiq': 'jiq',
        'jiq-Zyyy-CN': 'jiq',
        'jiq-CN': 'jiq',
        'jiq-Zyyy': 'jiq',
        'jit': 'jit',
        'jit-Latn-TZ': 'jit',
        'jit-Latn': 'jit',
        'jit-TZ': 'jit',
        'jiu': 'jiu',
        'jiu-Latn-CN': 'jiu',
        'jiu-CN': 'jiu',
        'jiu-Latn': 'jiu',
        'jiv': 'jiv',
        'jiv-Latn-EC': 'jiv',
        'jiv-EC': 'jiv',
        'jiv-Latn': 'jiv',
        'jiy': 'jiy',
        'jiy-Latn-CN': 'jiy',
        'jiy-CN': 'jiy',
        'jiy-Latn': 'jiy',
        'jje': 'jje',
        'jje-Hang-KR': 'jje',
        'jje-Hang': 'jje',
        'jje-KR': 'jje',
        'jjr': 'jjr',
        'jjr-Latn-NG': 'jjr',
        'jjr-Latn': 'jjr',
        'jjr-NG': 'jjr',
        'jka': 'jka',
        'jka-Latn-ID': 'jka',
        'jka-ID': 'jka',
        'jka-Latn': 'jka',
        'jkm': 'jkm',
        'jkm-Zyyy-MM': 'jkm',
        'jkm-MM': 'jkm',
        'jkm-Zyyy': 'jkm',
        'jko': 'jko',
        'jko-Latn-PG': 'jko',
        'jko-Latn': 'jko',
        'jko-PG': 'jko',
        'jkp': 'jkp',
        'jkp-Zyyy-MM': 'jkp',
        'jkp-MM': 'jkp',
        'jkp-Zyyy': 'jkp',
        'kpp': 'jkp',
        'kpp-MM': 'jkp',
        'kpp-Zyyy': 'jkp',
        'kpp-Zyyy-MM': 'jkp',
        'jkr': 'jkr',
        'jkr-Zyyy-IN': 'jkr',
        'jkr-IN': 'jkr',
        'jkr-Zyyy': 'jkr',
        'jku': 'jku',
        'jku-Latn-NG': 'jku',
        'jku-Latn': 'jku',
        'jku-NG': 'jku',
        'jle': 'jle',
        'jle-Latn-SD': 'jle',
        'jle-Latn': 'jle',
        'jle-SD': 'jle',
        'jls': 'jls',
        'jls-Zxxx-JM': 'jls',
        'jls-JM': 'jls',
        'jls-Zxxx': 'jls',
        'sgn-jls': 'jls',
        'sgn-jls-JM': 'jls',
        'jma': 'jma',
        'jma-Latn-PG': 'jma',
        'jma-Latn': 'jma',
        'jma-PG': 'jma',
        'jmb': 'jmb',
        'jmb-Latn-NG': 'jmb',
        'jmb-Latn': 'jmb',
        'jmb-NG': 'jmb',
        'jmc': 'jmc',
        'jmc-Latn-TZ': 'jmc',
        'jmc-Latn': 'jmc',
        'jmc-TZ': 'jmc',
        'jmd': 'jmd',
        'jmd-Latn-ID': 'jmd',
        'jmd-ID': 'jmd',
        'jmd-Latn': 'jmd',
        'jmi': 'jmi',
        'jmi-Latn-NG': 'jmi',
        'jmi-Latn': 'jmi',
        'jmi-NG': 'jmi',
        'jml': 'jml',
        'jml-Deva-NP': 'jml',
        'jml-Deva': 'jml',
        'jml-NP': 'jml',
        'jmn': 'jmn',
        'jmn-Latn-MM': 'jmn',
        'jmn-Latn': 'jmn',
        'jmn-MM': 'jmn',
        'jmr': 'jmr',
        'jmr-Latn-GH': 'jmr',
        'jmr-GH': 'jmr',
        'jmr-Latn': 'jmr',
        'jms': 'jms',
        'jms-Latn-NG': 'jms',
        'jms-Latn': 'jms',
        'jms-NG': 'jms',
        'jmw': 'jmw',
        'jmw-Latn-PG': 'jmw',
        'jmw-Latn': 'jmw',
        'jmw-PG': 'jmw',
        'jmx': 'jmx',
        'jmx-Latn-MX': 'jmx',
        'jmx-Latn': 'jmx',
        'jmx-MX': 'jmx',
        'jna': 'jna',
        'jna-Zyyy-IN': 'jna',
        'jna-IN': 'jna',
        'jna-Zyyy': 'jna',
        'jnd': 'jnd',
        'jnd-Arab-PK': 'jnd',
        'jnd-Arab': 'jnd',
        'jnd-PK': 'jnd',
        'jng': 'jng',
        'jng-Latn-AU': 'jng',
        'jng-AU': 'jng',
        'jng-Latn': 'jng',
        'jni': 'jni',
        'jni-Latn-NG': 'jni',
        'jni-Latn': 'jni',
        'jni-NG': 'jni',
        'jnj': 'jnj',
        'jnj-Latn-ET': 'jnj',
        'jnj-ET': 'jnj',
        'jnj-Latn': 'jnj',
        'jnl': 'jnl',
        'jnl-Deva-IN': 'jnl',
        'jnl-Deva': 'jnl',
        'jnl-IN': 'jnl',
        'jns': 'jns',
        'jns-Deva-IN': 'jns',
        'jns-Deva': 'jns',
        'jns-IN': 'jns',
        'jns-Latn': 'jns-Latn',
        'jns-Latn-IN': 'jns-Latn',
        'jns-Takr': 'jns-Takr',
        'jns-Takr-IN': 'jns-Takr',
        'job': 'job',
        'job-Latn-CD': 'job',
        'job-CD': 'job',
        'job-Latn': 'job',
        'jod': 'jod',
        'jod-Latn-CI': 'jod',
        'jod-CI': 'jod',
        'jod-Latn': 'jod',
        'jog': 'jog',
        'jog-Arab-PK': 'jog',
        'jog-Arab': 'jog',
        'jog-PK': 'jog',
        'jor': 'jor',
        'jor-Latn-BO': 'jor',
        'jor-BO': 'jor',
        'jor-Latn': 'jor',
        'jos': 'jos',
        'jos-Zxxx-JO': 'jos',
        'jos-JO': 'jos',
        'jos-Zxxx': 'jos',
        'sgn-jos': 'jos',
        'sgn-jos-JO': 'jos',
        'jow': 'jow',
        'jow-Latn-ML': 'jow',
        'jow-Latn': 'jow',
        'jow-ML': 'jow',
        'jpa': 'jpa',
        'jpa-Zyyy-PS': 'jpa',
        'jpa-PS': 'jpa',
        'jpa-Zyyy': 'jpa',
        'jpr': 'jpr',
        'jpr-Hebr-IL': 'jpr',
        'jpr-Hebr': 'jpr',
        'jpr-IL': 'jpr',
        'jqr': 'jqr',
        'jqr-Latn-PE': 'jqr',
        'jqr-Latn': 'jqr',
        'jqr-PE': 'jqr',
        'jra': 'jra',
        'jra-Latn-VN': 'jra',
        'jra-Latn': 'jra',
        'jra-VN': 'jra',
        'jra-Khmr': 'jra-Khmr',
        'jra-Khmr-KH': 'jra-Khmr',
        'jra-KH': 'jra-Khmr',
        'jrb': 'jrb',
        'jrb-Hebr-IL': 'jrb',
        'aju-Hebr': 'jrb',
        'aju-Hebr-IL': 'jrb',
        'jrb-Hebr': 'jrb',
        'jrb-IL': 'jrb',
        'jrr': 'jrr',
        'jrr-Latn-NG': 'jrr',
        'jrr-Latn': 'jrr',
        'jrr-NG': 'jrr',
        'jrt': 'jrt',
        'jrt-Latn-NG': 'jrt',
        'jrt-Latn': 'jrt',
        'jrt-NG': 'jrt',
        'jru': 'jru',
        'jru-Latn-VE': 'jru',
        'jru-Latn': 'jru',
        'jru-VE': 'jru',
        'jsl': 'jsl',
        'jsl-Zxxx-JP': 'jsl',
        'jsl-JP': 'jsl',
        'jsl-Zxxx': 'jsl',
        'sgn-jsl': 'jsl',
        'sgn-jsl-JP': 'jsl',
        'jua': 'jua',
        'jua-Latn-BR': 'jua',
        'jua-BR': 'jua',
        'jua-Latn': 'jua',
        'jub': 'jub',
        'jub-Latn-NG': 'jub',
        'jub-Latn': 'jub',
        'jub-NG': 'jub',
        'juc': 'juc',
        'juc-Jurc-CN': 'juc',
        'juc-CN': 'juc',
        'juc-Jurc': 'juc',
        'jud': 'jud',
        'jud-Latn-CI': 'jud',
        'jud-CI': 'jud',
        'jud-Latn': 'jud',
        'juh': 'juh',
        'juh-Latn-NG': 'juh',
        'juh-Latn': 'juh',
        'juh-NG': 'juh',
        'jui': 'jui',
        'jui-Latn-AU': 'jui',
        'jui-AU': 'jui',
        'jui-Latn': 'jui',
        'juk': 'juk',
        'juk-Latn-NG': 'juk',
        'juk-Latn': 'juk',
        'juk-NG': 'juk',
        'jul': 'jul',
        'jul-Deva-NP': 'jul',
        'jul-Deva': 'jul',
        'jul-NP': 'jul',
        'jum': 'jum',
        'jum-Latn-SD': 'jum',
        'jum-Latn': 'jum',
        'jum-SD': 'jum',
        'jun': 'jun',
        'jun-Orya-IN': 'jun',
        'jun-IN': 'jun',
        'jun-Orya': 'jun',
        'juo': 'juo',
        'juo-Latn-NG': 'juo',
        'juo-Latn': 'juo',
        'juo-NG': 'juo',
        'jup': 'jup',
        'jup-Latn-BR': 'jup',
        'jup-BR': 'jup',
        'jup-Latn': 'jup',
        'jur': 'jur',
        'jur-Latn-BR': 'jur',
        'jur-BR': 'jur',
        'jur-Latn': 'jur',
        'jus': 'jus',
        'jus-Zxxx-NP': 'jus',
        'jus-NP': 'jus',
        'jus-Zxxx': 'jus',
        'sgn-jus': 'jus',
        'sgn-jus-NP': 'jus',
        'jut': 'jut',
        'jut-Latn-DK': 'jut',
        'jut-DK': 'jut',
        'jut-Latn': 'jut',
        'juu': 'juu',
        'juu-Latn-NG': 'juu',
        'juu-Latn': 'juu',
        'juu-NG': 'juu',
        'juw': 'juw',
        'juw-Latn-NG': 'juw',
        'juw-Latn': 'juw',
        'juw-NG': 'juw',
        'juy': 'juy',
        'juy-Zyyy-IN': 'juy',
        'juy-IN': 'juy',
        'juy-Zyyy': 'juy',
        'jv': 'jv',
        'jv-Latn-ID': 'jv',
        'jv-ID': 'jv',
        'jv-Latn': 'jv',
        'jw': 'jv',
        'jw-ID': 'jv',
        'jw-Latn': 'jv',
        'jw-Latn-ID': 'jv',
        'jv-Java': 'jv-Java',
        'jv-Java-ID': 'jv-Java',
        'jvd': 'jvd',
        'jvd-Latn-ID': 'jvd',
        'jvd-ID': 'jvd',
        'jvd-Latn': 'jvd',
        'jvn': 'jvn',
        'jvn-Latn-SR': 'jvn',
        'jvn-Latn': 'jvn',
        'jvn-SR': 'jvn',
        'jwi': 'jwi',
        'jwi-Latn-GH': 'jwi',
        'jwi-GH': 'jwi',
        'jwi-Latn': 'jwi',
        'jya': 'jya',
        'jya-Tibt-CN': 'jya',
        'jya-CN': 'jya',
        'jya-Tibt': 'jya',
        'jye': 'jye',
        'jye-Hebr-IL': 'jye',
        'jye-Hebr': 'jye',
        'jye-IL': 'jye',
        'jyy': 'jyy',
        'jyy-Latn-TD': 'jyy',
        'jyy-Latn': 'jyy',
        'jyy-TD': 'jyy',
        'ka': 'ka',
        'ka-Geor-GE': 'ka',
        'ka-GE': 'ka',
        'ka-Geor': 'ka',
        'ka-Brai': 'ka-Brai',
        'ka-Brai-GE': 'ka-Brai',
        'ka-Geok': 'ka-Geok',
        'ka-Geok-GE': 'ka-Geok',
        'kaa': 'kaa',
        'kaa-Cyrl-UZ': 'kaa',
        'kaa-Cyrl': 'kaa',
        'kaa-UZ': 'kaa',
        'kaa-Arab': 'kaa-Arab',
        'kaa-Arab-UZ': 'kaa-Arab',
        'kaa-Latn': 'kaa-Latn',
        'kaa-Latn-UZ': 'kaa-Latn',
        'kab': 'kab',
        'kab-Latn-DZ': 'kab',
        'kab-DZ': 'kab',
        'kab-Latn': 'kab',
        'kab-Arab': 'kab-Arab',
        'kab-Arab-DZ': 'kab-Arab',
        'kab-Tfng': 'kab-Tfng',
        'kab-Tfng-DZ': 'kab-Tfng',
        'kac': 'kac',
        'kac-Latn-MM': 'kac',
        'kac-Latn': 'kac',
        'kac-MM': 'kac',
        'kad': 'kad',
        'kad-Latn-NG': 'kad',
        'kad-Latn': 'kad',
        'kad-NG': 'kad',
        'kae': 'kae',
        'kae-Zyyy-TW': 'kae',
        'kae-TW': 'kae',
        'kae-Zyyy': 'kae',
        'kaf': 'kaf',
        'kaf-Zyyy-CN': 'kaf',
        'kaf-CN': 'kaf',
        'kaf-Zyyy': 'kaf',
        'kag': 'kag',
        'kag-Latn-MY': 'kag',
        'kag-Latn': 'kag',
        'kag-MY': 'kag',
        'kah': 'kah',
        'kah-Latn-CF': 'kah',
        'kah-CF': 'kah',
        'kah-Latn': 'kah',
        'kai': 'kai',
        'kai-Latn-NG': 'kai',
        'kai-Latn': 'kai',
        'kai-NG': 'kai',
        'kaj': 'kaj',
        'kaj-Latn-NG': 'kaj',
        'kaj-Latn': 'kaj',
        'kaj-NG': 'kaj',
        'kak': 'kak',
        'kak-Latn-PH': 'kak',
        'kak-Latn': 'kak',
        'kak-PH': 'kak',
        'tne': 'kak',
        'tne-Latn': 'kak',
        'tne-Latn-PH': 'kak',
        'tne-PH': 'kak',
        'kam': 'kam',
        'kam-Latn-KE': 'kam',
        'kam-KE': 'kam',
        'kam-Latn': 'kam',
        'kao': 'kao',
        'kao-Latn-ML': 'kao',
        'kao-Latn': 'kao',
        'kao-ML': 'kao',
        'kap': 'kap',
        'kap-Cyrl-RU': 'kap',
        'kap-Cyrl': 'kap',
        'kap-RU': 'kap',
        'kaq': 'kaq',
        'kaq-Latn-PE': 'kaq',
        'kaq-Latn': 'kaq',
        'kaq-PE': 'kaq',
        'kav': 'kav',
        'kav-Latn-BR': 'kav',
        'kav-BR': 'kav',
        'kav-Latn': 'kav',
        'kaw': 'kaw',
        'kaw-Bali-MY': 'kaw',
        'kaw-Bali': 'kaw',
        'kaw-MY': 'kaw',
        'kax': 'kax',
        'kax-Latn-ID': 'kax',
        'kax-ID': 'kax',
        'kax-Latn': 'kax',
        'kay': 'kay',
        'kay-Latn-BR': 'kay',
        'kay-BR': 'kay',
        'kay-Latn': 'kay',
        'kba': 'kba',
        'kba-Latn-AU': 'kba',
        'kba-AU': 'kba',
        'kba-Latn': 'kba',
        'kbb': 'kbb',
        'kbb-Latn-BR': 'kbb',
        'kbb-BR': 'kbb',
        'kbb-Latn': 'kbb',
        'kbc': 'kbc',
        'kbc-Latn-BR': 'kbc',
        'kbc-BR': 'kbc',
        'kbc-Latn': 'kbc',
        'kbd': 'kbd',
        'kbd-Cyrl-RU': 'kbd',
        'kbd-Cyrl': 'kbd',
        'kbd-RU': 'kbd',
        'kbe': 'kbe',
        'kbe-Latn-AU': 'kbe',
        'kbe-AU': 'kbe',
        'kbe-Latn': 'kbe',
        'kbg-Tibt': 'kbg-Tibt',
        'kbg-Tibt-IN-x-hingna': 'kbg-Tibt',
        'kbg-IN-x-hingna': 'kbg-Tibt',
        'kbg-Tibt-IN': 'kbg-Tibt',
        'kbg-Tibt-x-hingna': 'kbg-Tibt',
        'kbh': 'kbh',
        'kbh-Latn-CO': 'kbh',
        'kbh-CO': 'kbh',
        'kbh-Latn': 'kbh',
        'kbi': 'kbi',
        'kbi-Latn-ID': 'kbi',
        'kbi-ID': 'kbi',
        'kbi-Latn': 'kbi',
        'kbj': 'kbj',
        'kbj-Latn-CD': 'kbj',
        'kbj-CD': 'kbj',
        'kbj-Latn': 'kbj',
        'kbk': 'kbk',
        'kbk-Latn-PG': 'kbk',
        'kbk-Latn': 'kbk',
        'kbk-PG': 'kbk',
        'kbl': 'kbl',
        'kbl-Latn-TD': 'kbl',
        'kbl-Latn': 'kbl',
        'kbl-TD': 'kbl',
        'kbm': 'kbm',
        'kbm-Latn-PG': 'kbm',
        'kbm-Latn': 'kbm',
        'kbm-PG': 'kbm',
        'kbn': 'kbn',
        'kbn-Latn-CF': 'kbn',
        'kbn-CF': 'kbn',
        'kbn-Latn': 'kbn',
        'kbo': 'kbo',
        'kbo-Latn-SS': 'kbo',
        'kbo-Latn': 'kbo',
        'kbo-SS': 'kbo',
        'kbp': 'kbp',
        'kbp-Latn-TG': 'kbp',
        'kbp-Latn': 'kbp',
        'kbp-TG': 'kbp',
        'kbp-Brai': 'kbp-Brai',
        'kbp-Brai-TG': 'kbp-Brai',
        'kbq': 'kbq',
        'kbq-Latn-PG': 'kbq',
        'kbq-Latn': 'kbq',
        'kbq-PG': 'kbq',
        'kbr': 'kbr',
        'kbr-Latn-ET': 'kbr',
        'kbr-ET': 'kbr',
        'kbr-Latn': 'kbr',
        'kbr-Ethi': 'kbr-Ethi',
        'kbr-Ethi-ET': 'kbr-Ethi',
        'kbs': 'kbs',
        'kbs-Latn-GA': 'kbs',
        'kbs-GA': 'kbs',
        'kbs-Latn': 'kbs',
        'kbt': 'kbt',
        'kbt-Latn-PG': 'kbt',
        'kbt-Latn': 'kbt',
        'kbt-PG': 'kbt',
        'kbu': 'kbu',
        'kbu-Arab-PK': 'kbu',
        'kbu-Arab': 'kbu',
        'kbu-PK': 'kbu',
        'kbv': 'kbv',
        'kbv-Latn-ID': 'kbv',
        'kbv-ID': 'kbv',
        'kbv-Latn': 'kbv',
        'kbw': 'kbw',
        'kbw-Latn-PG': 'kbw',
        'kbw-Latn': 'kbw',
        'kbw-PG': 'kbw',
        'kbx': 'kbx',
        'kbx-Latn-PG': 'kbx',
        'kbx-Latn': 'kbx',
        'kbx-PG': 'kbx',
        'kby': 'kby',
        'kby-Arab-NE': 'kby',
        'kby-Arab': 'kby',
        'kby-NE': 'kby',
        'kby-Latn': 'kby-Latn',
        'kby-Latn-NE': 'kby-Latn',
        'kbz': 'kbz',
        'kbz-Latn-NG': 'kbz',
        'kbz-Latn': 'kbz',
        'kbz-NG': 'kbz',
        'kca': 'kca',
        'kca-Cyrl-RU': 'kca',
        'kca-Cyrl': 'kca',
        'kca-RU': 'kca',
        'kcb': 'kcb',
        'kcb-Latn-PG': 'kcb',
        'kcb-Latn': 'kcb',
        'kcb-PG': 'kcb',
        'kcc': 'kcc',
        'kcc-Latn-NG': 'kcc',
        'kcc-Latn': 'kcc',
        'kcc-NG': 'kcc',
        'kcd': 'kcd',
        'kcd-Latn-ID': 'kcd',
        'kcd-ID': 'kcd',
        'kcd-Latn': 'kcd',
        'kce': 'kce',
        'kce-Latn-NG': 'kce',
        'kce-Latn': 'kce',
        'kce-NG': 'kce',
        'kcf': 'kcf',
        'kcf-Latn-NG': 'kcf',
        'kcf-Latn': 'kcf',
        'kcf-NG': 'kcf',
        'kcg': 'kcg',
        'kcg-Latn-NG': 'kcg',
        'kcg-Latn': 'kcg',
        'kcg-NG': 'kcg',
        'kch': 'kch',
        'kch-Latn-NG': 'kch',
        'kch-Latn': 'kch',
        'kch-NG': 'kch',
        'kci': 'kci',
        'kci-Latn-NG': 'kci',
        'kci-Latn': 'kci',
        'kci-NG': 'kci',
        'kcj': 'kcj',
        'kcj-Latn-GW': 'kcj',
        'kcj-GW': 'kcj',
        'kcj-Latn': 'kcj',
        'kck': 'kck',
        'kck-Latn-ZW': 'kck',
        'kck-Latn': 'kck',
        'kck-ZW': 'kck',
        'kcl': 'kcl',
        'kcl-Latn-PG': 'kcl',
        'kcl-Latn': 'kcl',
        'kcl-PG': 'kcl',
        'kcm': 'kcm',
        'kcm-Latn-CF': 'kcm',
        'kcm-CF': 'kcm',
        'kcm-Latn': 'kcm',
        'kcn': 'kcn',
        'kcn-Latn-UG': 'kcn',
        'kcn-Latn': 'kcn',
        'kcn-UG': 'kcn',
        'kco': 'kco',
        'kco-Latn-PG': 'kco',
        'kco-Latn': 'kco',
        'kco-PG': 'kco',
        'kcp': 'kcp',
        'kcp-Latn-SD': 'kcp',
        'kcp-Latn': 'kcp',
        'kcp-SD': 'kcp',
        'kcq': 'kcq',
        'kcq-Latn-NG': 'kcq',
        'kcq-Latn': 'kcq',
        'kcq-NG': 'kcq',
        'kcr': 'kcr',
        'kcr-Zyyy-SD': 'kcr',
        'kcr-SD': 'kcr',
        'kcr-Zyyy': 'kcr',
        'kcs': 'kcs',
        'kcs-Latn-NG': 'kcs',
        'kcs-Latn': 'kcs',
        'kcs-NG': 'kcs',
        'kct': 'kct',
        'kct-Latn-PG': 'kct',
        'kct-Latn': 'kct',
        'kct-PG': 'kct',
        'kcu': 'kcu',
        'kcu-Latn-TZ': 'kcu',
        'kcu-Latn': 'kcu',
        'kcu-TZ': 'kcu',
        'kcv': 'kcv',
        'kcv-Latn-CD': 'kcv',
        'kcv-CD': 'kcv',
        'kcv-Latn': 'kcv',
        'kcw': 'kcw',
        'kcw-Latn-CD': 'kcw',
        'kcw-CD': 'kcw',
        'kcw-Latn': 'kcw',
        'kcx': 'kcx',
        'kcx-Zyyy-ET': 'kcx',
        'kcx-ET': 'kcx',
        'kcx-Zyyy': 'kcx',
        'kcy': 'kcy',
        'kcy-Zyyy-DZ': 'kcy',
        'kcy-DZ': 'kcy',
        'kcy-Zyyy': 'kcy',
        'kcz': 'kcz',
        'kcz-Latn-TZ': 'kcz',
        'kcz-Latn': 'kcz',
        'kcz-TZ': 'kcz',
        'kda': 'kda',
        'kda-Latn-AU': 'kda',
        'kda-AU': 'kda',
        'kda-Latn': 'kda',
        'kdc': 'kdc',
        'kdc-Latn-TZ': 'kdc',
        'kdc-Latn': 'kdc',
        'kdc-TZ': 'kdc',
        'kdd': 'kdd',
        'kdd-Latn-AU': 'kdd',
        'kdd-AU': 'kdd',
        'kdd-Latn': 'kdd',
        'kde': 'kde',
        'kde-Latn-TZ': 'kde',
        'kde-Latn': 'kde',
        'kde-TZ': 'kde',
        'kdf': 'kdf',
        'kdf-Latn-PG': 'kdf',
        'kdf-Latn': 'kdf',
        'kdf-PG': 'kdf',
        'kdg': 'kdg',
        'kdg-Latn-CD': 'kdg',
        'kdg-CD': 'kdg',
        'kdg-Latn': 'kdg',
        'kdh': 'kdh',
        'kdh-Arab-TG': 'kdh',
        'kdh-Arab': 'kdh',
        'kdh-TG': 'kdh',
        'kdh-Latn': 'kdh-Latn',
        'kdh-Latn-TG': 'kdh-Latn',
        'kdi': 'kdi',
        'kdi-Latn-UG': 'kdi',
        'kdi-Latn': 'kdi',
        'kdi-UG': 'kdi',
        'kdj': 'kdj',
        'kdj-Latn-UG': 'kdj',
        'kdj-Latn': 'kdj',
        'kdj-UG': 'kdj',
        'kdk': 'kdk',
        'kdk-Latn-NC': 'kdk',
        'kdk-Latn': 'kdk',
        'kdk-NC': 'kdk',
        'kdl': 'kdl',
        'kdl-Latn-NG': 'kdl',
        'kdl-Latn': 'kdl',
        'kdl-NG': 'kdl',
        'kdm': 'kdm',
        'kdm-Latn-NG': 'kdm',
        'kdm-Latn': 'kdm',
        'kdm-NG': 'kdm',
        'kdn': 'kdn',
        'kdn-Latn-ZW': 'kdn',
        'kdn-Latn': 'kdn',
        'kdn-ZW': 'kdn',
        'kdp': 'kdp',
        'kdp-Latn-NG': 'kdp',
        'kdp-Latn': 'kdp',
        'kdp-NG': 'kdp',
        'kdq': 'kdq',
        'kdq-Beng-IN': 'kdq',
        'kdq-Beng': 'kdq',
        'kdq-IN': 'kdq',
        'kdr': 'kdr',
        'kdr-Latn-LT': 'kdr',
        'kdr-LT': 'kdr',
        'kdr-Latn': 'kdr',
        'kdr-Cyrl': 'kdr-Cyrl',
        'kdr-Cyrl-UA': 'kdr-Cyrl',
        'kdr-UA': 'kdr-Cyrl',
        'kdt': 'kdt',
        'kdt-Thai-TH': 'kdt',
        'kdt-TH': 'kdt',
        'kdt-Thai': 'kdt',
        'kdt-Khmr': 'kdt-Khmr',
        'kdt-Khmr-KH': 'kdt-Khmr',
        'kdt-KH': 'kdt-Khmr',
        'kdt-Laoo': 'kdt-Laoo',
        'kdt-Laoo-LA': 'kdt-Laoo',
        'kdt-LA': 'kdt-Laoo',
        'kdu': 'kdu',
        'kdu-Zyyy-SD': 'kdu',
        'kdu-SD': 'kdu',
        'kdu-Zyyy': 'kdu',
        'kdw': 'kdw',
        'kdw-Latn-ID': 'kdw',
        'kdw-ID': 'kdw',
        'kdw-Latn': 'kdw',
        'kdx': 'kdx',
        'kdx-Latn-NG': 'kdx',
        'kdx-Latn': 'kdx',
        'kdx-NG': 'kdx',
        'kdy': 'kdy',
        'kdy-Latn-ID': 'kdy',
        'kdy-ID': 'kdy',
        'kdy-Latn': 'kdy',
        'kdz': 'kdz',
        'kdz-Latn-CM': 'kdz',
        'kdz-CM': 'kdz',
        'kdz-Latn': 'kdz',
        'ncp': 'kdz',
        'ncp-CM': 'kdz',
        'ncp-Latn': 'kdz',
        'ncp-Latn-CM': 'kdz',
        'kea': 'kea',
        'kea-Latn-CV': 'kea',
        'kea-CV': 'kea',
        'kea-Latn': 'kea',
        'keb': 'keb',
        'keb-Latn-GA': 'keb',
        'keb-GA': 'keb',
        'keb-Latn': 'keb',
        'kec': 'kec',
        'kec-Latn-SD': 'kec',
        'kec-Latn': 'kec',
        'kec-SD': 'kec',
        'ked': 'ked',
        'ked-Latn-TZ': 'ked',
        'ked-Latn': 'ked',
        'ked-TZ': 'ked',
        'kee': 'kee',
        'kee-Latn-US': 'kee',
        'kee-Latn': 'kee',
        'kee-US': 'kee',
        'kef': 'kef',
        'kef-Latn-TG': 'kef',
        'kef-Latn': 'kef',
        'kef-TG': 'kef',
        'keg': 'keg',
        'keg-Latn-SD': 'keg',
        'keg-Latn': 'keg',
        'keg-SD': 'keg',
        'keh': 'keh',
        'keh-Latn-PG': 'keh',
        'keh-Latn': 'keh',
        'keh-PG': 'keh',
        'kei': 'kei',
        'kei-Latn-ID': 'kei',
        'kei-ID': 'kei',
        'kei-Latn': 'kei',
        'kej': 'kej',
        'kej-Zyyy-IN': 'kej',
        'kej-IN': 'kej',
        'kej-Zyyy': 'kej',
        'kek': 'kek',
        'kek-Latn-GT': 'kek',
        'kek-GT': 'kek',
        'kek-Latn': 'kek',
        'kel': 'kel',
        'kel-Latn-CD': 'kel',
        'kel-CD': 'kel',
        'kel-Latn': 'kel',
        'kem': 'kem',
        'kem-Latn-TL': 'kem',
        'kem-Latn': 'kem',
        'kem-TL': 'kem',
        'ken': 'ken',
        'ken-Latn-CM': 'ken',
        'ken-CM': 'ken',
        'ken-Latn': 'ken',
        'keo': 'keo',
        'keo-Latn-UG': 'keo',
        'keo-Latn': 'keo',
        'keo-UG': 'keo',
        'kep': 'kep',
        'kep-Zyyy-IN': 'kep',
        'kep-IN': 'kep',
        'kep-Zyyy': 'kep',
        'keq': 'keq',
        'keq-Zyyy-IN': 'keq',
        'keq-IN': 'keq',
        'keq-Zyyy': 'keq',
        'ker': 'ker',
        'ker-Latn-TD': 'ker',
        'ker-Latn': 'ker',
        'ker-TD': 'ker',
        'kes': 'kes',
        'kes-Latn-NG': 'kes',
        'kes-Latn': 'kes',
        'kes-NG': 'kes',
        'ket': 'ket',
        'ket-Cyrl-RU': 'ket',
        'ket-Cyrl': 'ket',
        'ket-RU': 'ket',
        'keu': 'keu',
        'keu-Latn-TG': 'keu',
        'keu-Latn': 'keu',
        'keu-TG': 'keu',
        'kev': 'kev',
        'kev-Zyyy-IN': 'kev',
        'kev-IN': 'kev',
        'kev-Zyyy': 'kev',
        'kew': 'kew',
        'kew-Latn-PG': 'kew',
        'kew-Latn': 'kew',
        'kew-PG': 'kew',
        'kex': 'kex',
        'kex-Deva-IN': 'kex',
        'kex-Deva': 'kex',
        'kex-IN': 'kex',
        'kex-Gujr': 'kex-Gujr',
        'kex-Gujr-IN': 'kex-Gujr',
        'key': 'key',
        'key-Telu-IN': 'key',
        'key-IN': 'key',
        'key-Telu': 'key',
        'kez': 'kez',
        'kez-Latn-NG': 'kez',
        'kez-Latn': 'kez',
        'kez-NG': 'kez',
        'kfa': 'kfa',
        'kfa-Knda-IN': 'kfa',
        'kfa-IN': 'kfa',
        'kfa-Knda': 'kfa',
        'kfb': 'kfb',
        'kfb-Deva-IN': 'kfb',
        'kfb-Deva': 'kfb',
        'kfb-IN': 'kfb',
        'kfc': 'kfc',
        'kfc-Telu-IN': 'kfc',
        'kfc-IN': 'kfc',
        'kfc-Telu': 'kfc',
        'kfd': 'kfd',
        'kfd-Zyyy-IN': 'kfd',
        'kfd-IN': 'kfd',
        'kfd-Zyyy': 'kfd',
        'kfe': 'kfe',
        'kfe-Taml-IN': 'kfe',
        'kfe-IN': 'kfe',
        'kfe-Taml': 'kfe',
        'kff-Deva': 'kff-Deva',
        'kff-Deva-IN': 'kff-Deva',
        'kff-Latn': 'kff-Latn',
        'kff-Latn-IN': 'kff-Latn',
        'kff-Orya': 'kff-Orya',
        'kff-Orya-IN': 'kff-Orya',
        'kff-Telu': 'kff-Telu',
        'kff-Telu-IN': 'kff-Telu',
        'kfg-Knda': 'kfg-Knda',
        'kfg-Knda-IN': 'kfg-Knda',
        'kfg-Mlym': 'kfg-Mlym',
        'kfg-Mlym-IN': 'kfg-Mlym',
        'kfh': 'kfh',
        'kfh-Mlym-IN': 'kfh',
        'kfh-IN': 'kfh',
        'kfh-Mlym': 'kfh',
        'kfi': 'kfi',
        'kfi-Taml-IN': 'kfi',
        'kfi-IN': 'kfi',
        'kfi-Taml': 'kfi',
        'kfi-Knda': 'kfi-Knda',
        'kfi-Knda-IN': 'kfi-Knda',
        'kfj': 'kfj',
        'kfj-Zyyy-CN': 'kfj',
        'kfj-CN': 'kfj',
        'kfj-Zyyy': 'kfj',
        'kfk': 'kfk',
        'kfk-Deva-IN': 'kfk',
        'kfk-Deva': 'kfk',
        'kfk-IN': 'kfk',
        'kfk-Takr': 'kfk-Takr',
        'kfk-Takr-IN': 'kfk-Takr',
        'kfl': 'kfl',
        'kfl-Latn-CM': 'kfl',
        'kfl-CM': 'kfl',
        'kfl-Latn': 'kfl',
        'kfm': 'kfm',
        'kfm-Arab-IR': 'kfm',
        'kfm-Arab': 'kfm',
        'kfm-IR': 'kfm',
        'kfn': 'kfn',
        'kfn-Latn-CM': 'kfn',
        'kfn-CM': 'kfn',
        'kfn-Latn': 'kfn',
        'kfo': 'kfo',
        'kfo-Latn-CI': 'kfo',
        'kfo-CI': 'kfo',
        'kfo-Latn': 'kfo',
        'kfp': 'kfp',
        'kfp-Deva-IN': 'kfp',
        'kfp-Deva': 'kfp',
        'kfp-IN': 'kfp',
        'kfq': 'kfq',
        'kfq-Deva-IN': 'kfq',
        'kfq-Deva': 'kfq',
        'kfq-IN': 'kfq',
        'kfr': 'kfr',
        'kfr-Deva-IN': 'kfr',
        'kfr-Deva': 'kfr',
        'kfr-IN': 'kfr',
        'kfr-Gujr': 'kfr-Gujr',
        'kfr-Gujr-IN': 'kfr-Gujr',
        'kfs': 'kfs',
        'kfs-Deva-IN': 'kfs',
        'kfs-Deva': 'kfs',
        'kfs-IN': 'kfs',
        'kft': 'kft',
        'kft-Zyyy-IN': 'kft',
        'kft-IN': 'kft',
        'kft-Zyyy': 'kft',
        'kfu': 'kfu',
        'kfu-Zyyy-IN': 'kfu',
        'kfu-IN': 'kfu',
        'kfu-Zyyy': 'kfu',
        'kfv': 'kfv',
        'kfv-Latn-IN': 'kfv',
        'kfv-IN': 'kfv',
        'kfv-Latn': 'kfv',
        'kfw': 'kfw',
        'kfw-Latn-IN': 'kfw',
        'kfw-IN': 'kfw',
        'kfw-Latn': 'kfw',
        'kfx': 'kfx',
        'kfx-Deva-IN': 'kfx',
        'kfx-Deva': 'kfx',
        'kfx-IN': 'kfx',
        'kfx-Takr': 'kfx-Takr',
        'kfx-Takr-IN': 'kfx-Takr',
        'kfy': 'kfy',
        'kfy-Deva-IN': 'kfy',
        'kfy-Deva': 'kfy',
        'kfy-IN': 'kfy',
        'kfz': 'kfz',
        'kfz-Latn-BF': 'kfz',
        'kfz-BF': 'kfz',
        'kfz-Latn': 'kfz',
        'kg': 'kg',
        'kg-Latn-CD': 'kg',
        'kg-CD': 'kg',
        'kg-Latn': 'kg',
        'kng': 'kg',
        'kng-CD': 'kg',
        'kng-Latn': 'kg',
        'kng-Latn-CD': 'kg',
        'kga': 'kga',
        'kga-Latn-CI': 'kga',
        'kga-CI': 'kga',
        'kga-Latn': 'kga',
        'kgb': 'kgb',
        'kgb-Latn-ID': 'kgb',
        'kgb-ID': 'kgb',
        'kgb-Latn': 'kgb',
        'kge': 'kge',
        'kge-Latn-ID': 'kge',
        'kge-ID': 'kge',
        'kge-Latn': 'kge',
        'kgf': 'kgf',
        'kgf-Latn-PG': 'kgf',
        'kgf-Latn': 'kgf',
        'kgf-PG': 'kgf',
        'kgg': 'kgg',
        'kgg-Zyyy-NP': 'kgg',
        'kgg-NP': 'kgg',
        'kgg-Zyyy': 'kgg',
        'kgi': 'kgi',
        'kgi-Zxxx-MY': 'kgi',
        'kgi-MY': 'kgi',
        'kgi-Zxxx': 'kgi',
        'sgn-kgi': 'kgi',
        'sgn-kgi-MY': 'kgi',
        'kgj': 'kgj',
        'kgj-Deva-NP': 'kgj',
        'kgj-Deva': 'kgj',
        'kgj-NP': 'kgj',
        'kgk': 'kgk',
        'kgk-Latn-BR': 'kgk',
        'kgk-BR': 'kgk',
        'kgk-Latn': 'kgk',
        'kgl': 'kgl',
        'kgl-Latn-AU': 'kgl',
        'kgl-AU': 'kgl',
        'kgl-Latn': 'kgl',
        'kgm': 'kgm',
        'kgm-Latn-BR': 'kgm',
        'kgm-BR': 'kgm',
        'kgm-Latn': 'kgm',
        'kgn': 'kgn',
        'kgn-Zyyy-IR': 'kgn',
        'kgn-IR': 'kgn',
        'kgn-Zyyy': 'kgn',
        'kgo': 'kgo',
        'kgo-Latn-SD': 'kgo',
        'kgo-Latn': 'kgo',
        'kgo-SD': 'kgo',
        'kgp': 'kgp',
        'kgp-Latn-BR': 'kgp',
        'kgp-BR': 'kgp',
        'kgp-Latn': 'kgp',
        'kgq': 'kgq',
        'kgq-Latn-ID': 'kgq',
        'kgq-ID': 'kgq',
        'kgq-Latn': 'kgq',
        'kgr': 'kgr',
        'kgr-Latn-ID': 'kgr',
        'kgr-ID': 'kgr',
        'kgr-Latn': 'kgr',
        'kgs': 'kgs',
        'kgs-Latn-AU': 'kgs',
        'kgs-AU': 'kgs',
        'kgs-Latn': 'kgs',
        'kgt': 'kgt',
        'kgt-Latn-NG': 'kgt',
        'kgt-Latn': 'kgt',
        'kgt-NG': 'kgt',
        'kgu': 'kgu',
        'kgu-Latn-PG': 'kgu',
        'kgu-Latn': 'kgu',
        'kgu-PG': 'kgu',
        'kgv': 'kgv',
        'kgv-Latn-ID': 'kgv',
        'kgv-ID': 'kgv',
        'kgv-Latn': 'kgv',
        'kgw': 'kgw',
        'kgw-Latn-ID': 'kgw',
        'kgw-ID': 'kgw',
        'kgw-Latn': 'kgw',
        'kgx': 'kgx',
        'kgx-Latn-ID': 'kgx',
        'kgx-ID': 'kgx',
        'kgx-Latn': 'kgx',
        'kgy': 'kgy',
        'kgy-Zyyy-CN': 'kgy',
        'kgy-CN': 'kgy',
        'kgy-Zyyy': 'kgy',
        'kha': 'kha',
        'kha-Latn-IN': 'kha',
        'kha-IN': 'kha',
        'kha-Latn': 'kha',
        'kha-Beng': 'kha-Beng',
        'kha-Beng-IN': 'kha-Beng',
        'khb': 'khb',
        'khb-Talu-CN': 'khb',
        'khb-CN': 'khb',
        'khb-Talu': 'khb',
        'khb-Lana': 'khb-Lana',
        'khb-Lana-CN': 'khb-Lana',
        'khc': 'khc',
        'khc-Latn-ID': 'khc',
        'khc-ID': 'khc',
        'khc-Latn': 'khc',
        'khd': 'khd',
        'khd-Latn-ID': 'khd',
        'khd-ID': 'khd',
        'khd-Latn': 'khd',
        'khe': 'khe',
        'khe-Latn-ID': 'khe',
        'khe-ID': 'khe',
        'khe-Latn': 'khe',
        'khf': 'khf',
        'khf-Thai-LA': 'khf',
        'khf-LA': 'khf',
        'khf-Thai': 'khf',
        'khg': 'khg',
        'khg-Tibt-CN': 'khg',
        'khg-CN': 'khg',
        'khg-Tibt': 'khg',
        'khh': 'khh',
        'khh-Latn-ID': 'khh',
        'khh-ID': 'khh',
        'khh-Latn': 'khh',
        'khj': 'khj',
        'khj-Latn-NG': 'khj',
        'khj-Latn': 'khj',
        'khj-NG': 'khj',
        'khl': 'khl',
        'khl-Latn-PG': 'khl',
        'khl-Latn': 'khl',
        'khl-PG': 'khl',
        'khn': 'khn',
        'khn-Deva-IN': 'khn',
        'khn-Deva': 'khn',
        'khn-IN': 'khn',
        'kho': 'kho',
        'kho-Zyyy-IR': 'kho',
        'kho-IR': 'kho',
        'kho-Zyyy': 'kho',
        'khp': 'khp',
        'khp-Latn-ID': 'khp',
        'khp-ID': 'khp',
        'khp-Latn': 'khp',
        'khq': 'khq',
        'khq-Latn-ML': 'khq',
        'khq-Latn': 'khq',
        'khq-ML': 'khq',
        'khr': 'khr',
        'khr-Latn-IN': 'khr',
        'khr-IN': 'khr',
        'khr-Latn': 'khr',
        'khr-Deva': 'khr-Deva',
        'khr-Deva-IN': 'khr-Deva',
        'khs': 'khs',
        'khs-Latn-PG': 'khs',
        'khs-Latn': 'khs',
        'khs-PG': 'khs',
        'kht': 'kht',
        'kht-Mymr-IN': 'kht',
        'kht-IN': 'kht',
        'kht-Mymr': 'kht',
        'khu': 'khu',
        'khu-Latn-AO': 'khu',
        'khu-AO': 'khu',
        'khu-Latn': 'khu',
        'khv': 'khv',
        'khv-Cyrl-RU': 'khv',
        'khv-Cyrl': 'khv',
        'khv-RU': 'khv',
        'khw': 'khw',
        'khw-Arab-PK': 'khw',
        'khw-Arab': 'khw',
        'khw-PK': 'khw',
        'khx': 'khx',
        'khx-Latn-CD': 'khx',
        'khx-CD': 'khx',
        'khx-Latn': 'khx',
        'khy': 'khy',
        'khy-Latn-CD': 'khy',
        'khy-CD': 'khy',
        'khy-Latn': 'khy',
        'khz': 'khz',
        'khz-Latn-PG': 'khz',
        'khz-Latn': 'khz',
        'khz-PG': 'khz',
        'ki': 'ki',
        'ki-Latn-KE': 'ki',
        'ki-KE': 'ki',
        'ki-Latn': 'ki',
        'kia': 'kia',
        'kia-Latn-TD': 'kia',
        'kia-Latn': 'kia',
        'kia-TD': 'kia',
        'kib': 'kib',
        'kib-Latn-SD': 'kib',
        'kib-Latn': 'kib',
        'kib-SD': 'kib',
        'kic': 'kic',
        'kic-Latn-US': 'kic',
        'kic-Latn': 'kic',
        'kic-US': 'kic',
        'kid': 'kid',
        'kid-Latn-CM': 'kid',
        'kid-CM': 'kid',
        'kid-Latn': 'kid',
        'kie': 'kie',
        'kie-Latn-TD': 'kie',
        'kie-Latn': 'kie',
        'kie-TD': 'kie',
        'kif': 'kif',
        'kif-Zyyy-NP': 'kif',
        'kif-NP': 'kif',
        'kif-Zyyy': 'kif',
        'kig': 'kig',
        'kig-Latn-ID': 'kig',
        'kig-ID': 'kig',
        'kig-Latn': 'kig',
        'kih': 'kih',
        'kih-Latn-PG': 'kih',
        'kih-Latn': 'kih',
        'kih-PG': 'kih',
        'kii': 'kii',
        'kii-Zyyy-US': 'kii',
        'kii-US': 'kii',
        'kii-Zyyy': 'kii',
        'kij': 'kij',
        'kij-Latn-PG': 'kij',
        'kij-Latn': 'kij',
        'kij-PG': 'kij',
        'kil': 'kil',
        'kil-Latn-NG': 'kil',
        'kil-Latn': 'kil',
        'kil-NG': 'kil',
        'kim': 'kim',
        'kim-Cyrl-RU': 'kim',
        'kim-Cyrl': 'kim',
        'kim-RU': 'kim',
        'kio': 'kio',
        'kio-Latn-US': 'kio',
        'kio-Latn': 'kio',
        'kio-US': 'kio',
        'kip': 'kip',
        'kip-Deva-NP': 'kip',
        'kip-Deva': 'kip',
        'kip-NP': 'kip',
        'kiq': 'kiq',
        'kiq-Latn-ID': 'kiq',
        'kiq-ID': 'kiq',
        'kiq-Latn': 'kiq',
        'kis': 'kis',
        'kis-Latn-PG': 'kis',
        'kis-Latn': 'kis',
        'kis-PG': 'kis',
        'kit': 'kit',
        'kit-Latn-PG': 'kit',
        'kit-Latn': 'kit',
        'kit-PG': 'kit',
        'kiu': 'kiu',
        'kiu-Latn-TR': 'kiu',
        'kiu-Latn': 'kiu',
        'kiu-TR': 'kiu',
        'kiv': 'kiv',
        'kiv-Latn-TZ': 'kiv',
        'kiv-Latn': 'kiv',
        'kiv-TZ': 'kiv',
        'kiw': 'kiw',
        'kiw-Latn-PG': 'kiw',
        'kiw-Latn': 'kiw',
        'kiw-PG': 'kiw',
        'kix': 'kix',
        'kix-Latn-IN': 'kix',
        'kix-IN': 'kix',
        'kix-Latn': 'kix',
        'kiy': 'kiy',
        'kiy-Latn-ID': 'kiy',
        'kiy-ID': 'kiy',
        'kiy-Latn': 'kiy',
        'kiz': 'kiz',
        'kiz-Latn-TZ': 'kiz',
        'kiz-Latn': 'kiz',
        'kiz-TZ': 'kiz',
        'kj': 'kj',
        'kj-Latn-NA': 'kj',
        'kj-Latn': 'kj',
        'kj-NA': 'kj',
        'kj-Brai': 'kj-Brai',
        'kj-Brai-AO': 'kj-Brai',
        'kj-AO': 'kj-Brai',
        'kja': 'kja',
        'kja-Latn-ID': 'kja',
        'kja-ID': 'kja',
        'kja-Latn': 'kja',
        'kjb': 'kjb',
        'kjb-Latn-GT': 'kjb',
        'kjb-GT': 'kjb',
        'kjb-Latn': 'kjb',
        'kjc': 'kjc',
        'kjc-Latn-ID': 'kjc',
        'kjc-ID': 'kjc',
        'kjc-Latn': 'kjc',
        'kjd': 'kjd',
        'kjd-Latn-PG': 'kjd',
        'kjd-Latn': 'kjd',
        'kjd-PG': 'kjd',
        'kje': 'kje',
        'kje-Latn-ID': 'kje',
        'kje-ID': 'kje',
        'kje-Latn': 'kje',
        'kjf': 'kjf',
        'kjf-Zyyy-AZ': 'kjf',
        'kjf-AZ': 'kjf',
        'kjf-Zyyy': 'kjf',
        'kjg': 'kjg',
        'kjg-Laoo-LA': 'kjg',
        'kjg-LA': 'kjg',
        'kjg-Laoo': 'kjg',
        'kjg-Latn': 'kjg-Latn',
        'kjg-Latn-LA': 'kjg-Latn',
        'kjg-Thai': 'kjg-Thai',
        'kjg-Thai-TH': 'kjg-Thai',
        'kjg-TH': 'kjg-Thai',
        'kjh': 'kjh',
        'kjh-Cyrl-RU': 'kjh',
        'kjh-Cyrl': 'kjh',
        'kjh-RU': 'kjh',
        'kji': 'kji',
        'kji-Latn-SB': 'kji',
        'kji-Latn': 'kji',
        'kji-SB': 'kji',
        'kjj': 'kjj',
        'kjj-Latn-AZ': 'kjj',
        'kjj-AZ': 'kjj',
        'kjj-Latn': 'kjj',
        'kjk': 'kjk',
        'kjk-Latn-ID': 'kjk',
        'kjk-ID': 'kjk',
        'kjk-Latn': 'kjk',
        'kjl': 'kjl',
        'kjl-Deva-NP': 'kjl',
        'kjl-Deva': 'kjl',
        'kjl-NP': 'kjl',
        'kjm': 'kjm',
        'kjm-Latn-VN': 'kjm',
        'kjm-Latn': 'kjm',
        'kjm-VN': 'kjm',
        'kjn': 'kjn',
        'kjn-Latn-AU': 'kjn',
        'kjn-AU': 'kjn',
        'kjn-Latn': 'kjn',
        'kjo': 'kjo',
        'kjo-Deva-IN': 'kjo',
        'kjo-Deva': 'kjo',
        'kjo-IN': 'kjo',
        'kjp': 'kjp',
        'kjp-Mymr-MM': 'kjp',
        'kjp-MM': 'kjp',
        'kjp-Mymr': 'kjp',
        'kjp-Leke': 'kjp-Leke',
        'kjp-Leke-MM': 'kjp-Leke',
        'kjp-Mymr-x-chekhi': 'kjp-Mymr-x-chekhi',
        'kjp-Mymr-MM-x-chekhi': 'kjp-Mymr-x-chekhi',
        'kjp-MM-x-chekhi': 'kjp-Mymr-x-chekhi',
        'kjp-Mymr-x-phlouyu': 'kjp-Mymr-x-phlouyu',
        'kjp-Mymr-MM-x-phlouyu': 'kjp-Mymr-x-phlouyu',
        'kjp-MM-x-phlouyu': 'kjp-Mymr-x-phlouyu',
        'kjp-Mymr-x-thiyon': 'kjp-Mymr-x-thiyon',
        'kjp-Mymr-MM-x-thiyon': 'kjp-Mymr-x-thiyon',
        'kjp-MM-x-thiyon': 'kjp-Mymr-x-thiyon',
        'kjp-Thai': 'kjp-Thai',
        'kjp-Thai-TH': 'kjp-Thai',
        'kjp-TH': 'kjp-Thai',
        'kjq': 'kjq',
        'kjq-Latn-US': 'kjq',
        'kjq-Latn': 'kjq',
        'kjq-US': 'kjq',
        'kjr': 'kjr',
        'kjr-Latn-ID': 'kjr',
        'kjr-ID': 'kjr',
        'kjr-Latn': 'kjr',
        'kjs': 'kjs',
        'kjs-Latn-PG': 'kjs',
        'kjs-Latn': 'kjs',
        'kjs-PG': 'kjs',
        'kjt': 'kjt',
        'kjt-Thai-TH': 'kjt',
        'kjt-TH': 'kjt',
        'kjt-Thai': 'kjt',
        'kju': 'kju',
        'kju-Latn-US': 'kju',
        'kju-Latn': 'kju',
        'kju-US': 'kju',
        'kjv': 'kjv',
        'kjv-Latn-001': 'kjv',
        'kjv-001': 'kjv',
        'kjv-Latn': 'kjv',
        'kjx': 'kjx',
        'kjx-Latn-PG': 'kjx',
        'kjx-Latn': 'kjx',
        'kjx-PG': 'kjx',
        'kjy': 'kjy',
        'kjy-Latn-PG': 'kjy',
        'kjy-Latn': 'kjy',
        'kjy-PG': 'kjy',
        'kjz-Tibt': 'kjz-Tibt',
        'kjz-Tibt-BT-x-uchen': 'kjz-Tibt',
        'kjz-BT-x-uchen': 'kjz-Tibt',
        'kjz-Tibt-BT': 'kjz-Tibt',
        'kjz-Tibt-x-uchen': 'kjz-Tibt',
        'kk': 'kk',
        'kk-Cyrl-KZ': 'kk',
        'kk-Cyrl': 'kk',
        'kk-KZ': 'kk',
        'kk-AF': 'kk-AF',
        'kk-Arab-AF': 'kk-AF',
        'kk-Brai': 'kk-Brai',
        'kk-Brai-KZ': 'kk-Brai',
        'kk-CN': 'kk-CN',
        'kk-Arab-CN': 'kk-CN',
        'kk-Arab': 'kk-CN',
        'kk-IR': 'kk-IR',
        'kk-Arab-IR': 'kk-IR',
        'kk-Latn': 'kk-Latn',
        'kk-Latn-TR': 'kk-Latn',
        'kk-TR': 'kk-Latn',
        'kk-MN': 'kk-MN',
        'kk-Arab-MN': 'kk-MN',
        'kka': 'kka',
        'kka-Latn-NG': 'kka',
        'kka-Latn': 'kka',
        'kka-NG': 'kka',
        'kkb': 'kkb',
        'kkb-Latn-ID': 'kkb',
        'kkb-ID': 'kkb',
        'kkb-Latn': 'kkb',
        'kkc': 'kkc',
        'kkc-Latn-PG': 'kkc',
        'kkc-Latn': 'kkc',
        'kkc-PG': 'kkc',
        'kkd': 'kkd',
        'kkd-Latn-NG': 'kkd',
        'kkd-Latn': 'kkd',
        'kkd-NG': 'kkd',
        'kke': 'kke',
        'kke-Latn-GN': 'kke',
        'kke-GN': 'kke',
        'kke-Latn': 'kke',
        'kke-Arab': 'kke-Arab',
        'kke-Arab-GN': 'kke-Arab',
        'kkf': 'kkf',
        'kkf-Zyyy-IN': 'kkf',
        'kkf-IN': 'kkf',
        'kkf-Zyyy': 'kkf',
        'kkg': 'kkg',
        'kkg-Latn-PH': 'kkg',
        'kkg-Latn': 'kkg',
        'kkg-PH': 'kkg',
        'kkh': 'kkh',
        'kkh-Lana-MM': 'kkh',
        'kkh-Lana': 'kkh',
        'kkh-MM': 'kkh',
        'kki': 'kki',
        'kki-Latn-TZ': 'kki',
        'kki-Latn': 'kki',
        'kki-TZ': 'kki',
        'kkj': 'kkj',
        'kkj-Latn-CM': 'kkj',
        'kkj-CM': 'kkj',
        'kkj-Latn': 'kkj',
        'kkj-TD': 'kkj-TD',
        'kkj-Latn-TD': 'kkj-TD',
        'kkk': 'kkk',
        'kkk-Latn-SB': 'kkk',
        'kkk-Latn': 'kkk',
        'kkk-SB': 'kkk',
        'kkl': 'kkl',
        'kkl-Latn-ID': 'kkl',
        'kkl-ID': 'kkl',
        'kkl-Latn': 'kkl',
        'kkm': 'kkm',
        'kkm-Latn-NG': 'kkm',
        'kkm-Latn': 'kkm',
        'kkm-NG': 'kkm',
        'kkn': 'kkn',
        'kkn-Zyyy-CN': 'kkn',
        'kkn-CN': 'kkn',
        'kkn-Zyyy': 'kkn',
        'kko': 'kko',
        'kko-Latn-SD': 'kko',
        'kko-Latn': 'kko',
        'kko-SD': 'kko',
        'kkp': 'kkp',
        'kkp-Latn-AU': 'kkp',
        'kkp-AU': 'kkp',
        'kkp-Latn': 'kkp',
        'kkq': 'kkq',
        'kkq-Latn-CD': 'kkq',
        'kkq-CD': 'kkq',
        'kkq-Latn': 'kkq',
        'kkr': 'kkr',
        'kkr-Latn-NG': 'kkr',
        'kkr-Latn': 'kkr',
        'kkr-NG': 'kkr',
        'kks': 'kks',
        'kks-Latn-NG': 'kks',
        'kks-Latn': 'kks',
        'kks-NG': 'kks',
        'kkt': 'kkt',
        'kkt-Deva-NP': 'kkt',
        'kkt-Deva': 'kkt',
        'kkt-NP': 'kkt',
        'kku': 'kku',
        'kku-Latn-NG': 'kku',
        'kku-Latn': 'kku',
        'kku-NG': 'kku',
        'kkv': 'kkv',
        'kkv-Latn-ID': 'kkv',
        'kkv-ID': 'kkv',
        'kkv-Latn': 'kkv',
        'kkw': 'kkw',
        'kkw-Latn-CG': 'kkw',
        'kkw-CG': 'kkw',
        'kkw-Latn': 'kkw',
        'kkx': 'kkx',
        'kkx-Latn-ID': 'kkx',
        'kkx-ID': 'kkx',
        'kkx-Latn': 'kkx',
        'kky': 'kky',
        'kky-Latn-AU': 'kky',
        'kky-AU': 'kky',
        'kky-Latn': 'kky',
        'kkz': 'kkz',
        'kkz-Latn-CA': 'kkz',
        'kkz-CA': 'kkz',
        'kkz-Latn': 'kkz',
        'kl': 'kl',
        'kl-Latn-GL': 'kl',
        'kl-GL': 'kl',
        'kl-Latn': 'kl',
        'kla': 'kla',
        'kla-Zyyy-US': 'kla',
        'kla-US': 'kla',
        'kla-Zyyy': 'kla',
        'klb': 'klb',
        'klb-Latn-MX': 'klb',
        'klb-Latn': 'klb',
        'klb-MX': 'klb',
        'klc': 'klc',
        'klc-Latn-CM': 'klc',
        'klc-CM': 'klc',
        'klc-Latn': 'klc',
        'kld': 'kld',
        'kld-Latn-AU': 'kld',
        'kld-AU': 'kld',
        'kld-Latn': 'kld',
        'kle': 'kle',
        'kle-Deva-NP': 'kle',
        'kle-Deva': 'kle',
        'kle-NP': 'kle',
        'klf': 'klf',
        'klf-Latn-TD': 'klf',
        'klf-Latn': 'klf',
        'klf-TD': 'klf',
        'klg': 'klg',
        'klg-Latn-PH': 'klg',
        'klg-Latn': 'klg',
        'klg-PH': 'klg',
        'klh': 'klh',
        'klh-Latn-PG': 'klh',
        'klh-Latn': 'klh',
        'klh-PG': 'klh',
        'kli': 'kli',
        'kli-Latn-ID': 'kli',
        'kli-ID': 'kli',
        'kli-Latn': 'kli',
        'klj': 'klj',
        'klj-Zyyy-IR': 'klj',
        'klj-IR': 'klj',
        'klj-Zyyy': 'klj',
        'klk': 'klk',
        'klk-Latn-NG': 'klk',
        'klk-Latn': 'klk',
        'klk-NG': 'klk',
        'kll': 'kll',
        'kll-Latn-PH': 'kll',
        'kll-Latn': 'kll',
        'kll-PH': 'kll',
        'klm': 'klm',
        'klm-Latn-PG': 'klm',
        'klm-Latn': 'klm',
        'klm-PG': 'klm',
        'kln': 'kln',
        'kln-Latn-KE': 'kln',
        'kln-KE': 'kln',
        'kln-Latn': 'kln',
        'spy': 'kln',
        'spy-KE': 'kln',
        'spy-Latn': 'kln',
        'spy-Latn-KE': 'kln',
        'klo': 'klo',
        'klo-Latn-NG': 'klo',
        'klo-Latn': 'klo',
        'klo-NG': 'klo',
        'klp': 'klp',
        'klp-Latn-PG': 'klp',
        'klp-Latn': 'klp',
        'klp-PG': 'klp',
        'klq': 'klq',
        'klq-Latn-PG': 'klq',
        'klq-Latn': 'klq',
        'klq-PG': 'klq',
        'klr': 'klr',
        'klr-Deva-NP': 'klr',
        'klr-Deva': 'klr',
        'klr-NP': 'klr',
        'kls': 'kls',
        'kls-Latn-PK': 'kls',
        'kls-Latn': 'kls',
        'kls-PK': 'kls',
        'kls-Arab': 'kls-Arab',
        'kls-Arab-PK': 'kls-Arab',
        'klt': 'klt',
        'klt-Latn-PG': 'klt',
        'klt-Latn': 'klt',
        'klt-PG': 'klt',
        'klu': 'klu',
        'klu-Latn-LR': 'klu',
        'klu-LR': 'klu',
        'klu-Latn': 'klu',
        'klv': 'klv',
        'klv-Latn-VU': 'klv',
        'klv-Latn': 'klv',
        'klv-VU': 'klv',
        'klw': 'klw',
        'klw-Latn-ID': 'klw',
        'klw-ID': 'klw',
        'klw-Latn': 'klw',
        'klx': 'klx',
        'klx-Latn-PG': 'klx',
        'klx-Latn': 'klx',
        'klx-PG': 'klx',
        'kly': 'kly',
        'kly-Latn-ID': 'kly',
        'kly-ID': 'kly',
        'kly-Latn': 'kly',
        'klz': 'klz',
        'klz-Latn-ID': 'klz',
        'klz-ID': 'klz',
        'klz-Latn': 'klz',
        'km': 'km',
        'km-Khmr-KH': 'km',
        'km-KH': 'km',
        'km-Khmr': 'km',
        'kma': 'kma',
        'kma-Latn-GH': 'kma',
        'kma-GH': 'kma',
        'kma-Latn': 'kma',
        'kmb': 'kmb',
        'kmb-Latn-AO': 'kmb',
        'kmb-AO': 'kmb',
        'kmb-Latn': 'kmb',
        'kmc': 'kmc',
        'kmc-Latn-CN': 'kmc',
        'kmc-CN': 'kmc',
        'kmc-Latn': 'kmc',
        'kmc-Hani': 'kmc-Hani',
        'kmc-Hani-CN': 'kmc-Hani',
        'kmd': 'kmd',
        'kmd-Latn-PH': 'kmd',
        'kmd-Latn': 'kmd',
        'kmd-PH': 'kmd',
        'kme': 'kme',
        'kme-Latn-CM': 'kme',
        'kme-CM': 'kme',
        'kme-Latn': 'kme',
        'kmf': 'kmf',
        'kmf-Latn-PG': 'kmf',
        'kmf-Latn': 'kmf',
        'kmf-PG': 'kmf',
        'kmg': 'kmg',
        'kmg-Latn-PG': 'kmg',
        'kmg-Latn': 'kmg',
        'kmg-PG': 'kmg',
        'kmh': 'kmh',
        'kmh-Latn-PG': 'kmh',
        'kmh-Latn': 'kmh',
        'kmh-PG': 'kmh',
        'kmi': 'kmi',
        'kmi-Latn-NG': 'kmi',
        'kmi-Latn': 'kmi',
        'kmi-NG': 'kmi',
        'kmj': 'kmj',
        'kmj-Zyyy-IN': 'kmj',
        'kmj-IN': 'kmj',
        'kmj-Zyyy': 'kmj',
        'kmk': 'kmk',
        'kmk-Latn-PH': 'kmk',
        'kmk-Latn': 'kmk',
        'kmk-PH': 'kmk',
        'kml': 'kml',
        'kml-Latn-PH': 'kml',
        'kgh': 'kml',
        'kgh-Latn': 'kml',
        'kgh-Latn-PH': 'kml',
        'kgh-PH': 'kml',
        'kml-Latn': 'kml',
        'kml-PH': 'kml',
        'kmm': 'kmm',
        'kmm-Latn-IN': 'kmm',
        'kmm-IN': 'kmm',
        'kmm-Latn': 'kmm',
        'kmn': 'kmn',
        'kmn-Latn-PG': 'kmn',
        'kmn-Latn': 'kmn',
        'kmn-PG': 'kmn',
        'kmo': 'kmo',
        'kmo-Latn-PG': 'kmo',
        'kmo-Latn': 'kmo',
        'kmo-PG': 'kmo',
        'kmp': 'kmp',
        'kmp-Latn-CM': 'kmp',
        'kmp-CM': 'kmp',
        'kmp-Latn': 'kmp',
        'kmq': 'kmq',
        'kmq-Latn-ET': 'kmq',
        'kmq-ET': 'kmq',
        'kmq-Latn': 'kmq',
        'kms': 'kms',
        'kms-Latn-PG': 'kms',
        'kms-Latn': 'kms',
        'kms-PG': 'kms',
        'kmt': 'kmt',
        'kmt-Latn-ID': 'kmt',
        'kmt-ID': 'kmt',
        'kmt-Latn': 'kmt',
        'kmu': 'kmu',
        'kmu-Latn-PG': 'kmu',
        'kmu-Latn': 'kmu',
        'kmu-PG': 'kmu',
        'kmv': 'kmv',
        'kmv-Latn-BR': 'kmv',
        'kmv-BR': 'kmv',
        'kmv-Latn': 'kmv',
        'kmw': 'kmw',
        'kmw-Latn-CD': 'kmw',
        'kmw-CD': 'kmw',
        'kmw-Latn': 'kmw',
        'kmx': 'kmx',
        'kmx-Latn-PG': 'kmx',
        'kmx-Latn': 'kmx',
        'kmx-PG': 'kmx',
        'kmy': 'kmy',
        'kmy-Latn-NG': 'kmy',
        'kmy-Latn': 'kmy',
        'kmy-NG': 'kmy',
        'kmz': 'kmz',
        'kmz-Arab-IR': 'kmz',
        'kmz-Arab': 'kmz',
        'kmz-IR': 'kmz',
        'kn': 'kn',
        'kn-Knda-IN': 'kn',
        'kn-IN': 'kn',
        'kn-Knda': 'kn',
        'kn-Brai': 'kn-Brai',
        'kn-Brai-IN': 'kn-Brai',
        'kn-Nand': 'kn-Nand',
        'kn-Nand-IN': 'kn-Nand',
        'kna': 'kna',
        'kna-Latn-NG': 'kna',
        'kna-Latn': 'kna',
        'kna-NG': 'kna',
        'knb': 'knb',
        'knb-Latn-PH': 'knb',
        'knb-Latn': 'knb',
        'knb-PH': 'knb',
        'knd': 'knd',
        'knd-Latn-ID': 'knd',
        'knd-ID': 'knd',
        'knd-Latn': 'knd',
        'kne': 'kne',
        'kne-Latn-PH': 'kne',
        'kne-Latn': 'kne',
        'kne-PH': 'kne',
        'knf': 'knf',
        'knf-Latn-GW': 'knf',
        'knf-GW': 'knf',
        'knf-Latn': 'knf',
        'kni': 'kni',
        'kni-Latn-NG': 'kni',
        'kni-Latn': 'kni',
        'kni-NG': 'kni',
        'knj': 'knj',
        'knj-Latn-GT': 'knj',
        'knj-GT': 'knj',
        'knj-Latn': 'knj',
        'knk': 'knk',
        'knk-Latn-SL': 'knk',
        'knk-Latn': 'knk',
        'knk-SL': 'knk',
        'knk-Arab': 'knk-Arab',
        'knk-Arab-SL': 'knk-Arab',
        'knl': 'knl',
        'knl-Latn-ID': 'knl',
        'knl-ID': 'knl',
        'knl-Latn': 'knl',
        'knm': 'knm',
        'knm-Latn-BR': 'knm',
        'knm-BR': 'knm',
        'knm-Latn': 'knm',
        'knn-Knda': 'knn-Knda',
        'knn-Knda-IN': 'knn-Knda',
        'knn-Latn': 'knn-Latn',
        'knn-Latn-IN': 'knn-Latn',
        'kno': 'kno',
        'kno-Latn-SL': 'kno',
        'kno-Latn': 'kno',
        'kno-SL': 'kno',
        'knp': 'knp',
        'knp-Latn-CM': 'knp',
        'knp-CM': 'knp',
        'knp-Latn': 'knp',
        'knq': 'knq',
        'knq-Latn-MY': 'knq',
        'knq-Latn': 'knq',
        'knq-MY': 'knq',
        'knr': 'knr',
        'knr-Latn-PG': 'knr',
        'knr-Latn': 'knr',
        'knr-PG': 'knr',
        'kns': 'kns',
        'kns-Latn-MY': 'kns',
        'kns-Latn': 'kns',
        'kns-MY': 'kns',
        'kns-Thai': 'kns-Thai',
        'kns-Thai-TH': 'kns-Thai',
        'kns-TH': 'kns-Thai',
        'knt': 'knt',
        'knt-Latn-BR': 'knt',
        'knt-BR': 'knt',
        'knt-Latn': 'knt',
        'knu': 'knu',
        'knu-Latn-GN': 'knu',
        'knu-GN': 'knu',
        'knu-Latn': 'knu',
        'knv': 'knv',
        'knv-Latn-PG': 'knv',
        'knv-Latn': 'knv',
        'knv-PG': 'knv',
        'knw': 'knw',
        'knw-Latn-NA': 'knw',
        'knw-Latn': 'knw',
        'knw-NA': 'knw',
        'knx': 'knx',
        'knx-Latn-ID': 'knx',
        'knx-ID': 'knx',
        'knx-Latn': 'knx',
        'kny': 'kny',
        'kny-Latn-CD': 'kny',
        'kny-CD': 'kny',
        'kny-Latn': 'kny',
        'knz': 'knz',
        'knz-Latn-BF': 'knz',
        'knz-BF': 'knz',
        'knz-Latn': 'knz',
        'ko': 'ko',
        'ko-Kore-KR': 'ko',
        'ko-KR': 'ko',
        'ko-Kore': 'ko',
        'ko-Brai': 'ko-Brai',
        'ko-Brai-KR': 'ko-Brai',
        'ko-KP': 'ko-KP',
        'ko-Kore-KP': 'ko-KP',
        'ko-Latn': 'ko-Latn',
        'ko-Latn-KR': 'ko-Latn',
        'koa': 'koa',
        'koa-Latn-PG': 'koa',
        'koa-Latn': 'koa',
        'koa-PG': 'koa',
        'koc': 'koc',
        'koc-Latn-NG': 'koc',
        'koc-Latn': 'koc',
        'koc-NG': 'koc',
        'kod': 'kod',
        'kod-Latn-ID': 'kod',
        'kod-ID': 'kod',
        'kod-Latn': 'kod',
        'koe': 'koe',
        'koe-Latn-SS': 'koe',
        'koe-Latn': 'koe',
        'koe-SS': 'koe',
        'kof': 'kof',
        'kof-Latn-NG': 'kof',
        'kof-Latn': 'kof',
        'kof-NG': 'kof',
        'kog': 'kog',
        'kog-Latn-CO': 'kog',
        'kog-CO': 'kog',
        'kog-Latn': 'kog',
        'koh': 'koh',
        'koh-Latn-CG': 'koh',
        'koh-CG': 'koh',
        'koh-Latn': 'koh',
        'koi': 'koi',
        'koi-Cyrl-RU': 'koi',
        'koi-Cyrl': 'koi',
        'koi-RU': 'koi',
        'koi-Latn': 'koi-Latn',
        'koi-Latn-RU': 'koi-Latn',
        'koi-Perm': 'koi-Perm',
        'koi-Perm-RU': 'koi-Perm',
        'kok': 'kok',
        'kok-Deva-IN': 'kok',
        'knn': 'kok',
        'knn-Deva': 'kok',
        'knn-Deva-IN': 'kok',
        'knn-IN': 'kok',
        'kok-Deva': 'kok',
        'kok-IN': 'kok',
        'kok-knn': 'kok',
        'kok-knn-IN': 'kok',
        'kol': 'kol',
        'kol-Latn-PG': 'kol',
        'kol-Latn': 'kol',
        'kol-PG': 'kol',
        'koo': 'koo',
        'koo-Latn-UG': 'koo',
        'koo-Latn': 'koo',
        'koo-UG': 'koo',
        'kop': 'kop',
        'kop-Latn-PG': 'kop',
        'kop-Latn': 'kop',
        'kop-PG': 'kop',
        'koq': 'koq',
        'koq-Latn-GA': 'koq',
        'koq-GA': 'koq',
        'koq-Latn': 'koq',
        'kos': 'kos',
        'kos-Latn-FM': 'kos',
        'kos-FM': 'kos',
        'kos-Latn': 'kos',
        'kot': 'kot',
        'kot-Latn-CM': 'kot',
        'kot-CM': 'kot',
        'kot-Latn': 'kot',
        'kou': 'kou',
        'kou-Latn-TD': 'kou',
        'kou-Latn': 'kou',
        'kou-TD': 'kou',
        'kov': 'kov',
        'kov-Latn-NG': 'kov',
        'kov-Latn': 'kov',
        'kov-NG': 'kov',
        'kow': 'kow',
        'kow-Latn-NG': 'kow',
        'kow-Latn': 'kow',
        'kow-NG': 'kow',
        'koy': 'koy',
        'koy-Latn-US': 'koy',
        'koy-Latn': 'koy',
        'koy-US': 'koy',
        'koz': 'koz',
        'koz-Latn-PG': 'koz',
        'koz-Latn': 'koz',
        'koz-PG': 'koz',
        'kpa': 'kpa',
        'kpa-Latn-NG': 'kpa',
        'kpa-Latn': 'kpa',
        'kpa-NG': 'kpa',
        'kpb': 'kpb',
        'kpb-Zyyy-IN': 'kpb',
        'kpb-IN': 'kpb',
        'kpb-Zyyy': 'kpb',
        'kpc': 'kpc',
        'kpc-Latn-CO': 'kpc',
        'kpc-CO': 'kpc',
        'kpc-Latn': 'kpc',
        'kpd': 'kpd',
        'kpd-Latn-ID': 'kpd',
        'kpd-ID': 'kpd',
        'kpd-Latn': 'kpd',
        'kpe': 'kpe',
        'kpe-Latn-LR': 'kpe',
        'kpe-LR': 'kpe',
        'kpe-Latn': 'kpe',
        'xpe': 'kpe',
        'xpe-LR': 'kpe',
        'xpe-Latn': 'kpe',
        'xpe-Latn-LR': 'kpe',
        'kpe-Kpel': 'kpe-Kpel',
        'kpe-Kpel-LR': 'kpe-Kpel',
        'xpe-Kpel': 'kpe-Kpel',
        'xpe-Kpel-LR': 'kpe-Kpel',
        'kpf': 'kpf',
        'kpf-Latn-PG': 'kpf',
        'kpf-Latn': 'kpf',
        'kpf-PG': 'kpf',
        'kpg': 'kpg',
        'kpg-Latn-FM': 'kpg',
        'kpg-FM': 'kpg',
        'kpg-Latn': 'kpg',
        'kph': 'kph',
        'kph-Latn-GH': 'kph',
        'kph-GH': 'kph',
        'kph-Latn': 'kph',
        'kpi': 'kpi',
        'kpi-Latn-ID': 'kpi',
        'kpi-ID': 'kpi',
        'kpi-Latn': 'kpi',
        'kpj': 'kpj',
        'kpj-Latn-BR': 'kpj',
        'kpj-BR': 'kpj',
        'kpj-Latn': 'kpj',
        'kpk': 'kpk',
        'kpk-Latn-NG': 'kpk',
        'kpk-Latn': 'kpk',
        'kpk-NG': 'kpk',
        'kpl': 'kpl',
        'kpl-Latn-CD': 'kpl',
        'kpl-CD': 'kpl',
        'kpl-Latn': 'kpl',
        'kpm': 'kpm',
        'kpm-Latn-VN': 'kpm',
        'kpm-Latn': 'kpm',
        'kpm-VN': 'kpm',
        'kpn': 'kpn',
        'kpn-Latn-BR': 'kpn',
        'kpn-BR': 'kpn',
        'kpn-Latn': 'kpn',
        'kpo': 'kpo',
        'kpo-Latn-TG': 'kpo',
        'kpo-Latn': 'kpo',
        'kpo-TG': 'kpo',
        'kpq': 'kpq',
        'kpq-Latn-ID': 'kpq',
        'kpq-ID': 'kpq',
        'kpq-Latn': 'kpq',
        'kpr': 'kpr',
        'kpr-Latn-PG': 'kpr',
        'kpr-Latn': 'kpr',
        'kpr-PG': 'kpr',
        'kps': 'kps',
        'kps-Latn-ID': 'kps',
        'kps-ID': 'kps',
        'kps-Latn': 'kps',
        'kpt': 'kpt',
        'kpt-Cyrl-RU': 'kpt',
        'kpt-Cyrl': 'kpt',
        'kpt-RU': 'kpt',
        'kpu': 'kpu',
        'kpu-Latn-ID': 'kpu',
        'kpu-ID': 'kpu',
        'kpu-Latn': 'kpu',
        'kpw': 'kpw',
        'kpw-Latn-PG': 'kpw',
        'kpw-Latn': 'kpw',
        'kpw-PG': 'kpw',
        'kpx': 'kpx',
        'kpx-Latn-PG': 'kpx',
        'kpx-Latn': 'kpx',
        'kpx-PG': 'kpx',
        'kpy': 'kpy',
        'kpy-Cyrl-RU': 'kpy',
        'kpy-Cyrl': 'kpy',
        'kpy-RU': 'kpy',
        'kpz': 'kpz',
        'kpz-Latn-UG': 'kpz',
        'kpz-Latn': 'kpz',
        'kpz-UG': 'kpz',
        'kqa': 'kqa',
        'kqa-Latn-PG': 'kqa',
        'kqa-Latn': 'kqa',
        'kqa-PG': 'kqa',
        'kqb': 'kqb',
        'kqb-Latn-PG': 'kqb',
        'kqb-Latn': 'kqb',
        'kqb-PG': 'kqb',
        'kqc': 'kqc',
        'kqc-Latn-PG': 'kqc',
        'kqc-Latn': 'kqc',
        'kqc-PG': 'kqc',
        'kqd': 'kqd',
        'kqd-Syrc-IQ': 'kqd',
        'kqd-IQ': 'kqd',
        'kqd-Syrc': 'kqd',
        'kqe': 'kqe',
        'kqe-Latn-PH': 'kqe',
        'kqe-Latn': 'kqe',
        'kqe-PH': 'kqe',
        'kqf': 'kqf',
        'kqf-Latn-PG': 'kqf',
        'kqf-Latn': 'kqf',
        'kqf-PG': 'kqf',
        'kqg': 'kqg',
        'kqg-Latn-BF': 'kqg',
        'kqg-BF': 'kqg',
        'kqg-Latn': 'kqg',
        'kqh': 'kqh',
        'kqh-Latn-TZ': 'kqh',
        'kqh-Latn': 'kqh',
        'kqh-TZ': 'kqh',
        'kqi': 'kqi',
        'kqi-Latn-PG': 'kqi',
        'kqi-Latn': 'kqi',
        'kqi-PG': 'kqi',
        'kqj': 'kqj',
        'kqj-Latn-PG': 'kqj',
        'kqj-Latn': 'kqj',
        'kqj-PG': 'kqj',
        'kqk': 'kqk',
        'kqk-Latn-BJ': 'kqk',
        'kqk-BJ': 'kqk',
        'kqk-Latn': 'kqk',
        'kql': 'kql',
        'kql-Latn-PG': 'kql',
        'kql-Latn': 'kql',
        'kql-PG': 'kql',
        'kqm': 'kqm',
        'kqm-Latn-CI': 'kqm',
        'kqm-CI': 'kqm',
        'kqm-Latn': 'kqm',
        'kqn': 'kqn',
        'kqn-Latn-ZM': 'kqn',
        'kqn-Latn': 'kqn',
        'kqn-ZM': 'kqn',
        'kqo': 'kqo',
        'kqo-Latn-LR': 'kqo',
        'kqo-LR': 'kqo',
        'kqo-Latn': 'kqo',
        'kqp': 'kqp',
        'kqp-Latn-TD': 'kqp',
        'kqp-Latn': 'kqp',
        'kqp-TD': 'kqp',
        'kqq': 'kqq',
        'kqq-Latn-BR': 'kqq',
        'kqq-BR': 'kqq',
        'kqq-Latn': 'kqq',
        'kqr': 'kqr',
        'kqr-Latn-MY': 'kqr',
        'kqr-Latn': 'kqr',
        'kqr-MY': 'kqr',
        'kqs': 'kqs',
        'kqs-Latn-GN': 'kqs',
        'kqs-GN': 'kqs',
        'kqs-Latn': 'kqs',
        'kqt': 'kqt',
        'kqt-Latn-MY': 'kqt',
        'kqt-Latn': 'kqt',
        'kqt-MY': 'kqt',
        'kqu': 'kqu',
        'kqu-Latn-ZA': 'kqu',
        'kqu-Latn': 'kqu',
        'kqu-ZA': 'kqu',
        'kqv': 'kqv',
        'kqv-Latn-ID': 'kqv',
        'kqv-ID': 'kqv',
        'kqv-Latn': 'kqv',
        'kqw': 'kqw',
        'kqw-Latn-PG': 'kqw',
        'kqw-Latn': 'kqw',
        'kqw-PG': 'kqw',
        'kqx': 'kqx',
        'kqx-Latn-CM': 'kqx',
        'kqx-CM': 'kqx',
        'kqx-Latn': 'kqx',
        'kqy': 'kqy',
        'kqy-Ethi-ET': 'kqy',
        'kqy-ET': 'kqy',
        'kqy-Ethi': 'kqy',
        'kqy-Latn': 'kqy-Latn',
        'kqy-Latn-ET': 'kqy-Latn',
        'kqz': 'kqz',
        'kqz-Latn-ZA': 'kqz',
        'kqz-Latn': 'kqz',
        'kqz-ZA': 'kqz',
        'kr': 'kr',
        'kr-Latn-NG': 'kr',
        'knc': 'kr',
        'knc-Latn': 'kr',
        'knc-Latn-NG': 'kr',
        'knc-NG': 'kr',
        'kr-Latn': 'kr',
        'kr-NG': 'kr',
        'kr-Arab': 'kr-Arab',
        'kr-Arab-NG': 'kr-Arab',
        'knc-Arab': 'kr-Arab',
        'knc-Arab-NG': 'kr-Arab',
        'kra': 'kra',
        'kra-Deva-NP': 'kra',
        'kra-Deva': 'kra',
        'kra-NP': 'kra',
        'krb': 'krb',
        'krb-Zyyy-US': 'krb',
        'krb-US': 'krb',
        'krb-Zyyy': 'krb',
        'krc': 'krc',
        'krc-Cyrl-RU': 'krc',
        'krc-Cyrl': 'krc',
        'krc-RU': 'krc',
        'krd': 'krd',
        'krd-Latn-TL': 'krd',
        'krd-Latn': 'krd',
        'krd-TL': 'krd',
        'kre': 'kre',
        'kre-Latn-BR': 'kre',
        'kre-BR': 'kre',
        'kre-Latn': 'kre',
        'krf': 'krf',
        'krf-Latn-VU': 'krf',
        'krf-Latn': 'krf',
        'krf-VU': 'krf',
        'krh': 'krh',
        'krh-Latn-NG': 'krh',
        'krh-Latn': 'krh',
        'krh-NG': 'krh',
        'kri': 'kri',
        'kri-Latn-SL': 'kri',
        'kri-Latn': 'kri',
        'kri-SL': 'kri',
        'krj': 'krj',
        'krj-Latn-PH': 'krj',
        'krj-Latn': 'krj',
        'krj-PH': 'krj',
        'krk': 'krk',
        'krk-Cyrl-RU': 'krk',
        'krk-Cyrl': 'krk',
        'krk-RU': 'krk',
        'krl': 'krl',
        'krl-Latn-RU': 'krl',
        'krl-Latn': 'krl',
        'krl-RU': 'krl',
        'krl-Cyrl': 'krl-Cyrl',
        'krl-Cyrl-RU': 'krl-Cyrl',
        'krn': 'krn',
        'krn-Latn-LR': 'krn',
        'krn-LR': 'krn',
        'krn-Latn': 'krn',
        'krp': 'krp',
        'krp-Latn-NG': 'krp',
        'krp-Latn': 'krp',
        'krp-NG': 'krp',
        'krr': 'krr',
        'krr-Khmr-KH': 'krr',
        'krr-KH': 'krr',
        'krr-Khmr': 'krr',
        'krs': 'krs',
        'krs-Latn-SS': 'krs',
        'krs-Latn': 'krs',
        'krs-SS': 'krs',
        'krt': 'krt',
        'krt-Latn-NE': 'krt',
        'krt-Latn': 'krt',
        'krt-NE': 'krt',
        'kru': 'kru',
        'kru-Deva-IN': 'kru',
        'kru-Deva': 'kru',
        'kru-IN': 'kru',
        'kru-Deva-NP': 'kru-Deva-NP',
        'kxl': 'kru-Deva-NP',
        'kxl-Deva': 'kru-Deva-NP',
        'kxl-Deva-NP': 'kru-Deva-NP',
        'kxl-NP': 'kru-Deva-NP',
        'krv': 'krv',
        'krv-Khmr-KH': 'krv',
        'krv-KH': 'krv',
        'krv-Khmr': 'krv',
        'krw': 'krw',
        'krw-Latn-LR': 'krw',
        'krw-LR': 'krw',
        'krw-Latn': 'krw',
        'krx': 'krx',
        'krx-Latn-SN': 'krx',
        'krx-Latn': 'krx',
        'krx-SN': 'krx',
        'kry': 'kry',
        'kry-Latn-AZ': 'kry',
        'kry-AZ': 'kry',
        'kry-Latn': 'kry',
        'krz': 'krz',
        'krz-Latn-ID': 'krz',
        'krz-ID': 'krz',
        'krz-Latn': 'krz',
        'ks': 'ks',
        'ks-Arab-IN': 'ks',
        'ks-Arab': 'ks',
        'ks-IN': 'ks',
        'ks-Deva': 'ks-Deva',
        'ks-Deva-IN': 'ks-Deva',
        'ks-Latn': 'ks-Latn',
        'ks-Latn-IN': 'ks-Latn',
        'ks-Shrd': 'ks-Shrd',
        'ks-Shrd-IN': 'ks-Shrd',
        'ksa': 'ksa',
        'ksa-Latn-NG': 'ksa',
        'ksa-Latn': 'ksa',
        'ksa-NG': 'ksa',
        'ksb': 'ksb',
        'ksb-Latn-TZ': 'ksb',
        'ksb-Latn': 'ksb',
        'ksb-TZ': 'ksb',
        'ksc': 'ksc',
        'ksc-Latn-PH': 'ksc',
        'ksc-Latn': 'ksc',
        'ksc-PH': 'ksc',
        'ksd': 'ksd',
        'ksd-Latn-PG': 'ksd',
        'ksd-Latn': 'ksd',
        'ksd-PG': 'ksd',
        'kse': 'kse',
        'kse-Latn-PG': 'kse',
        'kse-Latn': 'kse',
        'kse-PG': 'kse',
        'ksf': 'ksf',
        'ksf-Latn-CM': 'ksf',
        'ksf-CM': 'ksf',
        'ksf-Latn': 'ksf',
        'ksg': 'ksg',
        'ksg-Latn-SB': 'ksg',
        'ksg-Latn': 'ksg',
        'ksg-SB': 'ksg',
        'ksh': 'ksh',
        'ksh-Latn-DE': 'ksh',
        'ksh-DE': 'ksh',
        'ksh-Latn': 'ksh',
        'ksi': 'ksi',
        'ksi-Latn-PG': 'ksi',
        'ksi-Latn': 'ksi',
        'ksi-PG': 'ksi',
        'ksj': 'ksj',
        'ksj-Latn-PG': 'ksj',
        'ksj-Latn': 'ksj',
        'ksj-PG': 'ksj',
        'ksk': 'ksk',
        'ksk-Latn-US': 'ksk',
        'ksk-Latn': 'ksk',
        'ksk-US': 'ksk',
        'ksl': 'ksl',
        'ksl-Latn-PG': 'ksl',
        'ksl-Latn': 'ksl',
        'ksl-PG': 'ksl',
        'ksm': 'ksm',
        'ksm-Latn-NG': 'ksm',
        'ksm-Latn': 'ksm',
        'ksm-NG': 'ksm',
        'ksn': 'ksn',
        'ksn-Latn-PH': 'ksn',
        'ksn-Latn': 'ksn',
        'ksn-PH': 'ksn',
        'kso': 'kso',
        'kso-Latn-NG': 'kso',
        'kso-Latn': 'kso',
        'kso-NG': 'kso',
        'ksp': 'ksp',
        'ksp-Latn-CF': 'ksp',
        'ksp-CF': 'ksp',
        'ksp-Latn': 'ksp',
        'ksq': 'ksq',
        'ksq-Latn-NG': 'ksq',
        'ksq-Latn': 'ksq',
        'ksq-NG': 'ksq',
        'ksr': 'ksr',
        'ksr-Latn-PG': 'ksr',
        'ksr-Latn': 'ksr',
        'ksr-PG': 'ksr',
        'kss': 'kss',
        'kss-Latn-LR': 'kss',
        'kss-LR': 'kss',
        'kss-Latn': 'kss',
        'kst': 'kst',
        'kst-Latn-BF': 'kst',
        'kst-BF': 'kst',
        'kst-Latn': 'kst',
        'ksu': 'ksu',
        'ksu-Zyyy-IN': 'ksu',
        'ksu-IN': 'ksu',
        'ksu-Zyyy': 'ksu',
        'ksv': 'ksv',
        'ksv-Latn-CD': 'ksv',
        'ksv-CD': 'ksv',
        'ksv-Latn': 'ksv',
        'ksw': 'ksw',
        'ksw-Mymr-MM': 'ksw',
        'ksw-MM': 'ksw',
        'ksw-Mymr': 'ksw',
        'ksw-Latn': 'ksw-Latn',
        'ksw-Latn-MM': 'ksw-Latn',
        'ksx': 'ksx',
        'ksx-Latn-ID': 'ksx',
        'ksx-ID': 'ksx',
        'ksx-Latn': 'ksx',
        'ksy': 'ksy',
        'ksy-Zyyy-IN': 'ksy',
        'ksy-IN': 'ksy',
        'ksy-Zyyy': 'ksy',
        'ksz': 'ksz',
        'ksz-Deva-IN': 'ksz',
        'ksz-Deva': 'ksz',
        'ksz-IN': 'ksz',
        'kta': 'kta',
        'kta-Latn-VN': 'kta',
        'kta-Latn': 'kta',
        'kta-VN': 'kta',
        'ktb': 'ktb',
        'ktb-Ethi-ET': 'ktb',
        'ktb-ET': 'ktb',
        'ktb-Ethi': 'ktb',
        'ktb-Latn': 'ktb-Latn',
        'ktb-Latn-ET': 'ktb-Latn',
        'ktc': 'ktc',
        'ktc-Latn-NG': 'ktc',
        'ktc-Latn': 'ktc',
        'ktc-NG': 'ktc',
        'ktd': 'ktd',
        'ktd-Latn-AU': 'ktd',
        'ktd-AU': 'ktd',
        'ktd-Latn': 'ktd',
        'kte': 'kte',
        'kte-Zyyy-NP': 'kte',
        'kte-NP': 'kte',
        'kte-Zyyy': 'kte',
        'ktf': 'ktf',
        'ktf-Latn-CD': 'ktf',
        'ktf-CD': 'ktf',
        'ktf-Latn': 'ktf',
        'ktg': 'ktg',
        'ktg-Latn-AU': 'ktg',
        'ktg-AU': 'ktg',
        'ktg-Latn': 'ktg',
        'kth': 'kth',
        'kth-Latn-TD': 'kth',
        'kth-Latn': 'kth',
        'kth-TD': 'kth',
        'kti': 'kti',
        'kti-Latn-ID': 'kti',
        'kti-ID': 'kti',
        'kti-Latn': 'kti',
        'ktj': 'ktj',
        'ktj-Latn-CI': 'ktj',
        'ktj-CI': 'ktj',
        'ktj-Latn': 'ktj',
        'ktk': 'ktk',
        'ktk-Latn-PG': 'ktk',
        'ktk-Latn': 'ktk',
        'ktk-PG': 'ktk',
        'ktl': 'ktl',
        'ktl-Zyyy-IR': 'ktl',
        'ktl-IR': 'ktl',
        'ktl-Zyyy': 'ktl',
        'ktm': 'ktm',
        'ktm-Latn-PG': 'ktm',
        'ktm-Latn': 'ktm',
        'ktm-PG': 'ktm',
        'ktn': 'ktn',
        'ktn-Latn-BR': 'ktn',
        'ktn-BR': 'ktn',
        'ktn-Latn': 'ktn',
        'kto': 'kto',
        'kto-Latn-PG': 'kto',
        'kto-Latn': 'kto',
        'kto-PG': 'kto',
        'ktp': 'ktp',
        'ktp-Plrd-CN': 'ktp',
        'ktp-CN': 'ktp',
        'ktp-Plrd': 'ktp',
        'ktq': 'ktq',
        'ktq-Latn-PH': 'ktq',
        'ktq-Latn': 'ktq',
        'ktq-PH': 'ktq',
        'kts': 'kts',
        'kts-Latn-ID': 'kts',
        'kts-ID': 'kts',
        'kts-Latn': 'kts',
        'ktt': 'ktt',
        'ktt-Latn-ID': 'ktt',
        'ktt-ID': 'ktt',
        'ktt-Latn': 'ktt',
        'ktu': 'ktu',
        'ktu-Latn-CD': 'ktu',
        'ktu-CD': 'ktu',
        'ktu-Latn': 'ktu',
        'ktv': 'ktv',
        'ktv-Latn-VN': 'ktv',
        'ktv-Latn': 'ktv',
        'ktv-VN': 'ktv',
        'ktw': 'ktw',
        'ktw-Zyyy-US': 'ktw',
        'ktw-US': 'ktw',
        'ktw-Zyyy': 'ktw',
        'ktx': 'ktx',
        'ktx-Latn-BR': 'ktx',
        'ktx-BR': 'ktx',
        'ktx-Latn': 'ktx',
        'kty': 'kty',
        'kty-Latn-CD': 'kty',
        'kty-CD': 'kty',
        'kty-Latn': 'kty',
        'ktz': 'ktz',
        'ktz-Latn-NA': 'ktz',
        'aue': 'ktz',
        'aue-Latn': 'ktz',
        'aue-Latn-NA': 'ktz',
        'aue-NA': 'ktz',
        'ktz-Latn': 'ktz',
        'ktz-NA': 'ktz',
        'ku': 'ku',
        'ku-Latn-TR': 'ku',
        'kmr-Latn': 'ku',
        'kmr-Latn-TR': 'ku',
        'ku-Latn': 'ku',
        'ku-TR': 'ku',
        'ku-Arab': 'ku-Arab',
        'ku-Arab-IQ': 'ku-Arab',
        'ku-Arab-TR': 'ku-Arab-TR',
        'kmr-Arab': 'ku-Arab-TR',
        'kmr-Arab-TR': 'ku-Arab-TR',
        'ku-Armn': 'ku-Armn',
        'ku-Armn-AZ': 'ku-Armn',
        'kmr-Armn': 'ku-Armn',
        'kmr-Armn-AZ': 'ku-Armn',
        'ku-Cyrl': 'ku-Cyrl',
        'ku-Cyrl-IQ': 'ku-Cyrl',
        'ku-Cyrl-AZ': 'ku-Cyrl-AZ',
        'kmr-Cyrl': 'ku-Cyrl-AZ',
        'kmr-Cyrl-AZ': 'ku-Cyrl-AZ',
        'ku-LB': 'ku-LB',
        'ku-Arab-LB': 'ku-LB',
        'ku-Yezi-GE': 'ku-Yezi-GE',
        'kmr-Yezi': 'ku-Yezi-GE',
        'kmr-Yezi-GE': 'ku-Yezi-GE',
        'kub': 'kub',
        'kub-Latn-NG': 'kub',
        'kub-Latn': 'kub',
        'kub-NG': 'kub',
        'kuc': 'kuc',
        'kuc-Latn-ID': 'kuc',
        'kuc-ID': 'kuc',
        'kuc-Latn': 'kuc',
        'kud': 'kud',
        'kud-Latn-PG': 'kud',
        'kud-Latn': 'kud',
        'kud-PG': 'kud',
        'kue': 'kue',
        'kue-Latn-PG': 'kue',
        'kue-Latn': 'kue',
        'kue-PG': 'kue',
        'kuf': 'kuf',
        'kuf-Laoo-LA': 'kuf',
        'kuf-LA': 'kuf',
        'kuf-Laoo': 'kuf',
        'kug': 'kug',
        'kug-Latn-NG': 'kug',
        'kug-Latn': 'kug',
        'kug-NG': 'kug',
        'kuh': 'kuh',
        'kuh-Latn-NG': 'kuh',
        'kuh-Latn': 'kuh',
        'kuh-NG': 'kuh',
        'kui': 'kui',
        'kui-Latn-BR': 'kui',
        'kui-BR': 'kui',
        'kui-Latn': 'kui',
        'kuj': 'kuj',
        'kuj-Latn-TZ': 'kuj',
        'kuj-Latn': 'kuj',
        'kuj-TZ': 'kuj',
        'kuk': 'kuk',
        'kuk-Latn-ID': 'kuk',
        'kuk-ID': 'kuk',
        'kuk-Latn': 'kuk',
        'kul': 'kul',
        'kul-Latn-NG': 'kul',
        'kul-Latn': 'kul',
        'kul-NG': 'kul',
        'kum': 'kum',
        'kum-Cyrl-RU': 'kum',
        'kum-Cyrl': 'kum',
        'kum-RU': 'kum',
        'kum-Arab': 'kum-Arab',
        'kum-Arab-RU': 'kum-Arab',
        'kum-Latn': 'kum-Latn',
        'kum-Latn-RU': 'kum-Latn',
        'kun': 'kun',
        'kun-Latn-ER': 'kun',
        'kun-ER': 'kun',
        'kun-Latn': 'kun',
        'kuo': 'kuo',
        'kuo-Latn-PG': 'kuo',
        'kuo-Latn': 'kuo',
        'kuo-PG': 'kuo',
        'kup': 'kup',
        'kup-Latn-PG': 'kup',
        'kup-Latn': 'kup',
        'kup-PG': 'kup',
        'kuq': 'kuq',
        'kuq-Latn-BR': 'kuq',
        'kuq-BR': 'kuq',
        'kuq-Latn': 'kuq',
        'kus': 'kus',
        'kus-Latn-GH': 'kus',
        'kus-GH': 'kus',
        'kus-Latn': 'kus',
        'kut': 'kut',
        'kut-Latn-CA': 'kut',
        'kut-CA': 'kut',
        'kut-Latn': 'kut',
        'kuu': 'kuu',
        'kuu-Latn-US': 'kuu',
        'kuu-Latn': 'kuu',
        'kuu-US': 'kuu',
        'kuv': 'kuv',
        'kuv-Latn-ID': 'kuv',
        'kuv-ID': 'kuv',
        'kuv-Latn': 'kuv',
        'kuw': 'kuw',
        'kuw-Latn-CF': 'kuw',
        'kuw-CF': 'kuw',
        'kuw-Latn': 'kuw',
        'kux': 'kux',
        'kux-Latn-AU': 'kux',
        'kux-AU': 'kux',
        'kux-Latn': 'kux',
        'kuy': 'kuy',
        'kuy-Latn-AU': 'kuy',
        'kuy-AU': 'kuy',
        'kuy-Latn': 'kuy',
        'kuz': 'kuz',
        'kuz-Latn-CL': 'kuz',
        'kuz-CL': 'kuz',
        'kuz-Latn': 'kuz',
        'kv': 'kv',
        'kv-Cyrl-RU': 'kv',
        'kpv': 'kv',
        'kpv-Cyrl': 'kv',
        'kpv-Cyrl-RU': 'kv',
        'kpv-RU': 'kv',
        'kv-Cyrl': 'kv',
        'kv-RU': 'kv',
        'kv-Latn': 'kv-Latn',
        'kv-Latn-RU': 'kv-Latn',
        'kv-Perm': 'kv-Perm',
        'kv-Perm-RU': 'kv-Perm',
        'kva': 'kva',
        'kva-Cyrl-RU': 'kva',
        'kva-Cyrl': 'kva',
        'kva-RU': 'kva',
        'kvb': 'kvb',
        'kvb-Latn-ID': 'kvb',
        'kvb-ID': 'kvb',
        'kvb-Latn': 'kvb',
        'ms-kvb': 'kvb',
        'ms-kvb-ID': 'kvb',
        'kvc': 'kvc',
        'kvc-Latn-PG': 'kvc',
        'kvc-Latn': 'kvc',
        'kvc-PG': 'kvc',
        'kvd': 'kvd',
        'kvd-Latn-ID': 'kvd',
        'kvd-ID': 'kvd',
        'kvd-Latn': 'kvd',
        'kve': 'kve',
        'kve-Latn-MY': 'kve',
        'kve-Latn': 'kve',
        'kve-MY': 'kve',
        'kvf': 'kvf',
        'kvf-Latn-TD': 'kvf',
        'kvf-Latn': 'kvf',
        'kvf-TD': 'kvf',
        'kvg': 'kvg',
        'kvg-Latn-PG': 'kvg',
        'kvg-Latn': 'kvg',
        'kvg-PG': 'kvg',
        'kvh': 'kvh',
        'kvh-Latn-ID': 'kvh',
        'kvh-ID': 'kvh',
        'kvh-Latn': 'kvh',
        'kvi': 'kvi',
        'kvi-Latn-TD': 'kvi',
        'kvi-Latn': 'kvi',
        'kvi-TD': 'kvi',
        'kvj': 'kvj',
        'kvj-Latn-CM': 'kvj',
        'kvj-CM': 'kvj',
        'kvj-Latn': 'kvj',
        'kvk': 'kvk',
        'kvk-Zxxx-KR': 'kvk',
        'kvk-KR': 'kvk',
        'kvk-Zxxx': 'kvk',
        'sgn-kvk': 'kvk',
        'sgn-kvk-KR': 'kvk',
        'kvl': 'kvl',
        'kvl-Latn-MM': 'kvl',
        'kvl-Latn': 'kvl',
        'kvl-MM': 'kvl',
        'kvm': 'kvm',
        'kvm-Latn-CM': 'kvm',
        'kvm-CM': 'kvm',
        'kvm-Latn': 'kvm',
        'kvn': 'kvn',
        'kvn-Latn-CO': 'kvn',
        'kvn-CO': 'kvn',
        'kvn-Latn': 'kvn',
        'kvo': 'kvo',
        'kvo-Latn-ID': 'kvo',
        'kvo-ID': 'kvo',
        'kvo-Latn': 'kvo',
        'kvp': 'kvp',
        'kvp-Latn-ID': 'kvp',
        'kvp-ID': 'kvp',
        'kvp-Latn': 'kvp',
        'kvq-Latn': 'kvq-Latn',
        'kvq-Latn-MM': 'kvq-Latn',
        'kvq-Mymr': 'kvq-Mymr',
        'kvq-Mymr-MM': 'kvq-Mymr',
        'kvr': 'kvr',
        'kvr-Latn-ID': 'kvr',
        'kvr-ID': 'kvr',
        'kvr-Latn': 'kvr',
        'ms-kvr': 'kvr',
        'ms-kvr-ID': 'kvr',
        'kvr-Rjng': 'kvr-Rjng',
        'kvr-Rjng-ID': 'kvr-Rjng',
        'kvt': 'kvt',
        'kvt-Zyyy-MM': 'kvt',
        'kvt-MM': 'kvt',
        'kvt-Zyyy': 'kvt',
        'kvu': 'kvu',
        'kvu-Zyyy-MM': 'kvu',
        'kvu-MM': 'kvu',
        'kvu-Zyyy': 'kvu',
        'kvv': 'kvv',
        'kvv-Latn-ID': 'kvv',
        'kvv-ID': 'kvv',
        'kvv-Latn': 'kvv',
        'kvw': 'kvw',
        'kvw-Latn-ID': 'kvw',
        'kvw-ID': 'kvw',
        'kvw-Latn': 'kvw',
        'kvx': 'kvx',
        'kvx-Arab-PK': 'kvx',
        'kvx-Arab': 'kvx',
        'kvx-PK': 'kvx',
        'kvy': 'kvy',
        'kvy-Zyyy-MM': 'kvy',
        'kvy-MM': 'kvy',
        'kvy-Zyyy': 'kvy',
        'kvz': 'kvz',
        'kvz-Latn-ID': 'kvz',
        'kvz-ID': 'kvz',
        'kvz-Latn': 'kvz',
        'kw': 'kw',
        'kw-Latn-GB': 'kw',
        'kw-GB': 'kw',
        'kw-Latn': 'kw',
        'kwa': 'kwa',
        'kwa-Latn-BR': 'kwa',
        'kwa-BR': 'kwa',
        'kwa-Latn': 'kwa',
        'kwb': 'kwb',
        'kwb-Latn-NG': 'kwb',
        'kwb-Latn': 'kwb',
        'kwb-NG': 'kwb',
        'kwc': 'kwc',
        'kwc-Latn-CG': 'kwc',
        'kwc-CG': 'kwc',
        'kwc-Latn': 'kwc',
        'kwd': 'kwd',
        'kwd-Latn-SB': 'kwd',
        'kwd-Latn': 'kwd',
        'kwd-SB': 'kwd',
        'kwe': 'kwe',
        'kwe-Latn-ID': 'kwe',
        'kwe-ID': 'kwe',
        'kwe-Latn': 'kwe',
        'kwf': 'kwf',
        'kwf-Latn-SB': 'kwf',
        'kwf-Latn': 'kwf',
        'kwf-SB': 'kwf',
        'kwg': 'kwg',
        'kwg-Latn-TD': 'kwg',
        'kwg-Latn': 'kwg',
        'kwg-TD': 'kwg',
        'kwh': 'kwh',
        'kwh-Latn-ID': 'kwh',
        'kwh-ID': 'kwh',
        'kwh-Latn': 'kwh',
        'kwi': 'kwi',
        'kwi-Latn-CO': 'kwi',
        'kwi-CO': 'kwi',
        'kwi-Latn': 'kwi',
        'kwj': 'kwj',
        'kwj-Latn-PG': 'kwj',
        'kwj-Latn': 'kwj',
        'kwj-PG': 'kwj',
        'kwk': 'kwk',
        'kwk-Latn-CA': 'kwk',
        'kwk-CA': 'kwk',
        'kwk-Latn': 'kwk',
        'kwl': 'kwl',
        'kwl-Latn-NG': 'kwl',
        'kwl-Latn': 'kwl',
        'kwl-NG': 'kwl',
        'kwm': 'kwm',
        'kwm-Latn-NA': 'kwm',
        'kwm-Latn': 'kwm',
        'kwm-NA': 'kwm',
        'kwn': 'kwn',
        'kwn-Latn-NA': 'kwn',
        'kwn-Latn': 'kwn',
        'kwn-NA': 'kwn',
        'kwo': 'kwo',
        'kwo-Latn-PG': 'kwo',
        'kwo-Latn': 'kwo',
        'kwo-PG': 'kwo',
        'kwp': 'kwp',
        'kwp-Latn-CI': 'kwp',
        'kwp-CI': 'kwp',
        'kwp-Latn': 'kwp',
        'kwr': 'kwr',
        'kwr-Latn-ID': 'kwr',
        'kwr-ID': 'kwr',
        'kwr-Latn': 'kwr',
        'kws': 'kws',
        'kws-Latn-CD': 'kws',
        'kws-CD': 'kws',
        'kws-Latn': 'kws',
        'kwt': 'kwt',
        'kwt-Latn-ID': 'kwt',
        'kwt-ID': 'kwt',
        'kwt-Latn': 'kwt',
        'kwu': 'kwu',
        'kwu-Latn-CM': 'kwu',
        'kwu-CM': 'kwu',
        'kwu-Latn': 'kwu',
        'kwv': 'kwv',
        'kwv-Latn-TD': 'kwv',
        'koj': 'kwv',
        'koj-Latn': 'kwv',
        'koj-Latn-TD': 'kwv',
        'koj-TD': 'kwv',
        'kwv-Latn': 'kwv',
        'kwv-TD': 'kwv',
        'kww': 'kww',
        'kww-Latn-SR': 'kww',
        'kww-Latn': 'kww',
        'kww-SR': 'kww',
        'kwx': 'kwx',
        'kwx-Zyyy-IN': 'kwx',
        'kwx-IN': 'kwx',
        'kwx-Zyyy': 'kwx',
        'kwy': 'kwy',
        'kwy-Latn-CD': 'kwy',
        'kwy-CD': 'kwy',
        'kwy-Latn': 'kwy',
        'kwz': 'kwz',
        'kwz-Latn-AO': 'kwz',
        'kwz-AO': 'kwz',
        'kwz-Latn': 'kwz',
        'kxa': 'kxa',
        'kxa-Latn-PG': 'kxa',
        'kxa-Latn': 'kxa',
        'kxa-PG': 'kxa',
        'kxb': 'kxb',
        'kxb-Latn-CI': 'kxb',
        'kxb-CI': 'kxb',
        'kxb-Latn': 'kxb',
        'kxc': 'kxc',
        'kxc-Ethi-ET': 'kxc',
        'kxc-ET': 'kxc',
        'kxc-Ethi': 'kxc',
        'kxc-Latn': 'kxc-Latn',
        'kxc-Latn-ET': 'kxc-Latn',
        'kxd': 'kxd',
        'kxd-Latn-BN': 'kxd',
        'kxd-BN': 'kxd',
        'kxd-Latn': 'kxd',
        'ms-kxd': 'kxd',
        'ms-kxd-BN': 'kxd',
        'kxd-Arab': 'kxd-Arab',
        'kxd-Arab-BN': 'kxd-Arab',
        'kxf': 'kxf',
        'kxf-Mymr-MM': 'kxf',
        'kxf-MM': 'kxf',
        'kxf-Mymr': 'kxf',
        'kxf-Latn': 'kxf-Latn',
        'kxf-Latn-MM': 'kxf-Latn',
        'kxf-Latn-x-manuma': 'kxf-Latn-x-manuma',
        'kxf-Latn-MM-x-manuma': 'kxf-Latn-x-manuma',
        'kxf-MM-x-manuma': 'kxf-Latn-x-manuma',
        'kxh': 'kxh',
        'kxh-Zyyy-ET': 'kxh',
        'kxh-ET': 'kxh',
        'kxh-Zyyy': 'kxh',
        'kxi': 'kxi',
        'kxi-Latn-MY': 'kxi',
        'kxi-Latn': 'kxi',
        'kxi-MY': 'kxi',
        'kxj': 'kxj',
        'kxj-Latn-TD': 'kxj',
        'kxj-Latn': 'kxj',
        'kxj-TD': 'kxj',
        'kxk': 'kxk',
        'kxk-Zyyy-MM': 'kxk',
        'kxk-MM': 'kxk',
        'kxk-Zyyy': 'kxk',
        'kxm': 'kxm',
        'kxm-Thai-TH': 'kxm',
        'kxm-TH': 'kxm',
        'kxm-Thai': 'kxm',
        'kxm-Khmr': 'kxm-Khmr',
        'kxm-Khmr-TH': 'kxm-Khmr',
        'kxn': 'kxn',
        'kxn-Latn-MY': 'kxn',
        'kxn-Latn': 'kxn',
        'kxn-MY': 'kxn',
        'kxo': 'kxo',
        'kxo-Latn-BR': 'kxo',
        'kxo-BR': 'kxo',
        'kxo-Latn': 'kxo',
        'kxp': 'kxp',
        'kxp-Arab-PK': 'kxp',
        'kxp-Arab': 'kxp',
        'kxp-PK': 'kxp',
        'kxp-Gujr': 'kxp-Gujr',
        'kxp-Gujr-IN': 'kxp-Gujr',
        'kxp-IN': 'kxp-Gujr',
        'kxp-x-thr': 'kxp-x-thr',
        'kxp-Arab-PK-x-thr': 'kxp-x-thr',
        'kxp-Arab-x-thr': 'kxp-x-thr',
        'kxp-PK-x-thr': 'kxp-x-thr',
        'kxq': 'kxq',
        'kxq-Latn-ID': 'kxq',
        'kxq-ID': 'kxq',
        'kxq-Latn': 'kxq',
        'kxr': 'kxr',
        'kxr-Latn-PG': 'kxr',
        'kxr-Latn': 'kxr',
        'kxr-PG': 'kxr',
        'kxs': 'kxs',
        'kxs-Zyyy-CN': 'kxs',
        'kxs-CN': 'kxs',
        'kxs-Zyyy': 'kxs',
        'kxt': 'kxt',
        'kxt-Latn-PG': 'kxt',
        'kxt-Latn': 'kxt',
        'kxt-PG': 'kxt',
        'kxu': 'kxu',
        'kxu-Orya-IN': 'kxu',
        'kxu-IN': 'kxu',
        'kxu-Orya': 'kxu',
        'kxv': 'kxv',
        'kxv-Orya-IN': 'kxv',
        'kxv-IN': 'kxv',
        'kxv-Orya': 'kxv',
        'kxw': 'kxw',
        'kxw-Latn-PG': 'kxw',
        'kxw-Latn': 'kxw',
        'kxw-PG': 'kxw',
        'kxx': 'kxx',
        'kxx-Latn-CG': 'kxx',
        'kxx-CG': 'kxx',
        'kxx-Latn': 'kxx',
        'kxy': 'kxy',
        'kxy-Latn-VN': 'kxy',
        'kxy-Latn': 'kxy',
        'kxy-VN': 'kxy',
        'kxz': 'kxz',
        'kxz-Latn-PG': 'kxz',
        'kxz-Latn': 'kxz',
        'kxz-PG': 'kxz',
        'ky': 'ky',
        'ky-Cyrl-KG': 'ky',
        'ky-Cyrl': 'ky',
        'ky-KG': 'ky',
        'ky-CN': 'ky-CN',
        'ky-Arab-CN': 'ky-CN',
        'ky-Arab': 'ky-CN',
        'ky-TR': 'ky-TR',
        'ky-Latn-TR': 'ky-TR',
        'ky-Latn': 'ky-TR',
        'kya': 'kya',
        'kya-Latn-TZ': 'kya',
        'kya-Latn': 'kya',
        'kya-TZ': 'kya',
        'kyb': 'kyb',
        'kyb-Latn-PH': 'kyb',
        'kyb-Latn': 'kyb',
        'kyb-PH': 'kyb',
        'kyc': 'kyc',
        'kyc-Latn-PG': 'kyc',
        'kyc-Latn': 'kyc',
        'kyc-PG': 'kyc',
        'kyd': 'kyd',
        'kyd-Latn-ID': 'kyd',
        'kyd-ID': 'kyd',
        'kyd-Latn': 'kyd',
        'kye': 'kye',
        'kye-Latn-GH': 'kye',
        'kye-GH': 'kye',
        'kye-Latn': 'kye',
        'kyf': 'kyf',
        'kyf-Latn-CI': 'kyf',
        'kyf-CI': 'kyf',
        'kyf-Latn': 'kyf',
        'kyg': 'kyg',
        'kyg-Latn-PG': 'kyg',
        'kyg-Latn': 'kyg',
        'kyg-PG': 'kyg',
        'kyh': 'kyh',
        'kyh-Latn-US': 'kyh',
        'kyh-Latn': 'kyh',
        'kyh-US': 'kyh',
        'kyi': 'kyi',
        'kyi-Latn-MY': 'kyi',
        'kyi-Latn': 'kyi',
        'kyi-MY': 'kyi',
        'kyj': 'kyj',
        'kyj-Latn-PH': 'kyj',
        'kyj-Latn': 'kyj',
        'kyj-PH': 'kyj',
        'kyk': 'kyk',
        'kyk-Latn-PH': 'kyk',
        'kyk-Latn': 'kyk',
        'kyk-PH': 'kyk',
        'kyl': 'kyl',
        'kyl-Latn-US': 'kyl',
        'kyl-Latn': 'kyl',
        'kyl-US': 'kyl',
        'kym': 'kym',
        'kym-Latn-CF': 'kym',
        'kym-CF': 'kym',
        'kym-Latn': 'kym',
        'kyn': 'kyn',
        'kyn-Latn-PH': 'kyn',
        'kyn-Latn': 'kyn',
        'kyn-PH': 'kyn',
        'kyo': 'kyo',
        'kyo-Latn-ID': 'kyo',
        'kyo-ID': 'kyo',
        'kyo-Latn': 'kyo',
        'kyp': 'kyp',
        'kyp-Zyyy-LA': 'kyp',
        'kyp-LA': 'kyp',
        'kyp-Zyyy': 'kyp',
        'kyq': 'kyq',
        'kyq-Latn-TD': 'kyq',
        'kyq-Latn': 'kyq',
        'kyq-TD': 'kyq',
        'kyr': 'kyr',
        'kyr-Latn-BR': 'kyr',
        'kyr-BR': 'kyr',
        'kyr-Latn': 'kyr',
        'kys': 'kys',
        'kys-Latn-MY': 'kys',
        'kys-Latn': 'kys',
        'kys-MY': 'kys',
        'kyt': 'kyt',
        'kyt-Latn-ID': 'kyt',
        'kyt-ID': 'kyt',
        'kyt-Latn': 'kyt',
        'kyu': 'kyu',
        'kyu-Kali-MM': 'kyu',
        'kyu-Kali': 'kyu',
        'kyu-MM': 'kyu',
        'kyu-Latn': 'kyu-Latn',
        'kyu-Latn-MM': 'kyu-Latn',
        'kyu-Mymr': 'kyu-Mymr',
        'kyu-Mymr-MM': 'kyu-Mymr',
        'kyv': 'kyv',
        'kyv-Zyyy-NP': 'kyv',
        'kyv-NP': 'kyv',
        'kyv-Zyyy': 'kyv',
        'kyw-Beng': 'kyw-Beng',
        'kyw-Beng-IN': 'kyw-Beng',
        'kyw-Deva': 'kyw-Deva',
        'kyw-Deva-IN': 'kyw-Deva',
        'kyw-Orya': 'kyw-Orya',
        'kyw-Orya-IN': 'kyw-Orya',
        'kyx': 'kyx',
        'kyx-Latn-PG': 'kyx',
        'kyx-Latn': 'kyx',
        'kyx-PG': 'kyx',
        'kyy': 'kyy',
        'kyy-Latn-PG': 'kyy',
        'kyy-Latn': 'kyy',
        'kyy-PG': 'kyy',
        'kyz': 'kyz',
        'kyz-Latn-BR': 'kyz',
        'kyz-BR': 'kyz',
        'kyz-Latn': 'kyz',
        'kza': 'kza',
        'kza-Latn-BF': 'kza',
        'kza-BF': 'kza',
        'kza-Latn': 'kza',
        'kzb': 'kzb',
        'kzb-Latn-ID': 'kzb',
        'kzb-ID': 'kzb',
        'kzb-Latn': 'kzb',
        'kzc': 'kzc',
        'kzc-Latn-CI': 'kzc',
        'kzc-CI': 'kzc',
        'kzc-Latn': 'kzc',
        'kzd': 'kzd',
        'kzd-Latn-ID': 'kzd',
        'kzd-ID': 'kzd',
        'kzd-Latn': 'kzd',
        'kze': 'kze',
        'kze-Latn-PG': 'kze',
        'kze-Latn': 'kze',
        'kze-PG': 'kze',
        'kzf': 'kzf',
        'kzf-Latn-ID': 'kzf',
        'kzf-ID': 'kzf',
        'kzf-Latn': 'kzf',
        'kzg': 'kzg',
        'kzg-Zyyy-JP': 'kzg',
        'kzg-JP': 'kzg',
        'kzg-Zyyy': 'kzg',
        'kzi': 'kzi',
        'kzi-Latn-MY': 'kzi',
        'kzi-Latn': 'kzi',
        'kzi-MY': 'kzi',
        'kzk': 'kzk',
        'kzk-Latn-SB': 'kzk',
        'drr': 'kzk',
        'drr-Latn': 'kzk',
        'drr-Latn-SB': 'kzk',
        'drr-SB': 'kzk',
        'gli': 'kzk',
        'gli-Latn': 'kzk',
        'gli-Latn-SB': 'kzk',
        'gli-SB': 'kzk',
        'kzk-Latn': 'kzk',
        'kzk-SB': 'kzk',
        'kzl': 'kzl',
        'kzl-Latn-ID': 'kzl',
        'kzl-ID': 'kzl',
        'kzl-Latn': 'kzl',
        'kzm': 'kzm',
        'kzm-Latn-ID': 'kzm',
        'kzm-ID': 'kzm',
        'kzm-Latn': 'kzm',
        'kzn': 'kzn',
        'kzn-Latn-MW': 'kzn',
        'kzn-Latn': 'kzn',
        'kzn-MW': 'kzn',
        'kzo': 'kzo',
        'kzo-Latn-GA': 'kzo',
        'kzo-GA': 'kzo',
        'kzo-Latn': 'kzo',
        'kzp': 'kzp',
        'kzp-Latn-ID': 'kzp',
        'kzp-ID': 'kzp',
        'kzp-Latn': 'kzp',
        'kzq': 'kzq',
        'kzq-Zyyy-NP': 'kzq',
        'kzq-NP': 'kzq',
        'kzq-Zyyy': 'kzq',
        'kzr': 'kzr',
        'kzr-Latn-CM': 'kzr',
        'kzr-CM': 'kzr',
        'kzr-Latn': 'kzr',
        'kzs': 'kzs',
        'kzs-Latn-MY': 'kzs',
        'kzs-Latn': 'kzs',
        'kzs-MY': 'kzs',
        'kzu': 'kzu',
        'kzu-Latn-ID': 'kzu',
        'kzu-ID': 'kzu',
        'kzu-Latn': 'kzu',
        'kzv': 'kzv',
        'kzv-Latn-ID': 'kzv',
        'kzv-ID': 'kzv',
        'kzv-Latn': 'kzv',
        'kzw': 'kzw',
        'kzw-Latn-BR': 'kzw',
        'kzw-BR': 'kzw',
        'kzw-Latn': 'kzw',
        'kzx': 'kzx',
        'kzx-Latn-ID': 'kzx',
        'kzx-ID': 'kzx',
        'kzx-Latn': 'kzx',
        'kzy': 'kzy',
        'kzy-Latn-CD': 'kzy',
        'kzy-CD': 'kzy',
        'kzy-Latn': 'kzy',
        'kzz': 'kzz',
        'kzz-Latn-ID': 'kzz',
        'kzz-ID': 'kzz',
        'kzz-Latn': 'kzz',
        'la': 'la',
        'la-Latn-VA': 'la',
        'la-Latn': 'la',
        'la-VA': 'la',
        'laa': 'laa',
        'laa-Latn-PH': 'laa',
        'laa-Latn': 'laa',
        'laa-PH': 'laa',
        'lab': 'lab',
        'lab-Lina-GR': 'lab',
        'lab-GR': 'lab',
        'lab-Lina': 'lab',
        'lac': 'lac',
        'lac-Latn-MX': 'lac',
        'lac-Latn': 'lac',
        'lac-MX': 'lac',
        'lad': 'lad',
        'lad-Hebr-IL': 'lad',
        'lad-Hebr': 'lad',
        'lad-IL': 'lad',
        'lad-Cyrl': 'lad-Cyrl',
        'lad-Cyrl-TR': 'lad-Cyrl',
        'lad-Latn': 'lad-Latn',
        'lad-Latn-TR': 'lad-Latn',
        'lae': 'lae',
        'lae-Deva-IN': 'lae',
        'lae-Deva': 'lae',
        'lae-IN': 'lae',
        'lae-Tibt': 'lae-Tibt',
        'lae-Tibt-IN': 'lae-Tibt',
        'laf': 'laf',
        'laf-Zyyy-SD': 'laf',
        'laf-SD': 'laf',
        'laf-Zyyy': 'laf',
        'lag': 'lag',
        'lag-Latn-TZ': 'lag',
        'lag-Latn': 'lag',
        'lag-TZ': 'lag',
        'lah': 'lah',
        'lah-Arab-PK': 'lah',
        'lah-Arab': 'lah',
        'lah-PK': 'lah',
        'pnb': 'lah',
        'pnb-Arab': 'lah',
        'pnb-Arab-PK': 'lah',
        'pnb-PK': 'lah',
        'lah-Khoj': 'lah-Khoj',
        'lah-Khoj-PK': 'lah-Khoj',
        'pnb-Khoj': 'lah-Khoj',
        'pnb-Khoj-PK': 'lah-Khoj',
        'lah-Latn': 'lah-Latn',
        'lah-Latn-PK': 'lah-Latn',
        'pnb-Latn': 'lah-Latn',
        'pnb-Latn-PK': 'lah-Latn',
        'lah-Mahj-IN': 'lah-Mahj-IN',
        'pnb-Mahj': 'lah-Mahj-IN',
        'pnb-Mahj-IN': 'lah-Mahj-IN',
        'lah-Zzzz-PK': 'lah-Zzzz-PK',
        'pnb-Zzzz-PK-x-landa': 'lah-Zzzz-PK',
        'pnb-Zzzz-x-landa': 'lah-Zzzz-PK',
        'lai': 'lai',
        'lai-Latn-MW': 'lai',
        'lai-Latn': 'lai',
        'lai-MW': 'lai',
        'laj': 'laj',
        'laj-Latn-UG': 'laj',
        'laj-Latn': 'laj',
        'laj-UG': 'laj',
        'lak': 'lak',
        'lak-Latn-NG': 'lak',
        'lak-Latn': 'lak',
        'lak-NG': 'lak',
        'lal': 'lal',
        'lal-Latn-CD': 'lal',
        'lal-CD': 'lal',
        'lal-Latn': 'lal',
        'lam': 'lam',
        'lam-Latn-ZM': 'lam',
        'lam-Latn': 'lam',
        'lam-ZM': 'lam',
        'lan': 'lan',
        'lan-Latn-NG': 'lan',
        'lan-Latn': 'lan',
        'lan-NG': 'lan',
        'lap': 'lap',
        'lap-Latn-TD': 'lap',
        'lap-Latn': 'lap',
        'lap-TD': 'lap',
        'laq': 'laq',
        'laq-Latn-VN': 'laq',
        'laq-Latn': 'laq',
        'laq-VN': 'laq',
        'lar': 'lar',
        'lar-Latn-GH': 'lar',
        'lar-GH': 'lar',
        'lar-Latn': 'lar',
        'las': 'las',
        'las-Latn-TG': 'las',
        'las-Latn': 'las',
        'las-TG': 'las',
        'lau': 'lau',
        'lau-Latn-ID': 'lau',
        'lau-ID': 'lau',
        'lau-Latn': 'lau',
        'law': 'law',
        'law-Latn-ID': 'law',
        'law-ID': 'law',
        'law-Latn': 'law',
        'lax-Beng': 'lax-Beng',
        'lax-Beng-IN': 'lax-Beng',
        'lax-Latn': 'lax-Latn',
        'lax-Latn-IN': 'lax-Latn',
        'lay': 'lay',
        'lay-Zyyy-CN': 'lay',
        'lay-CN': 'lay',
        'lay-Zyyy': 'lay',
        'laz': 'laz',
        'laz-Latn-PG': 'laz',
        'laz-Latn': 'laz',
        'laz-PG': 'laz',
        'lb': 'lb',
        'lb-Latn-LU': 'lb',
        'lb-LU': 'lb',
        'lb-Latn': 'lb',
        'lba': 'lba',
        'lba-Zyyy-IN': 'lba',
        'lba-IN': 'lba',
        'lba-Zyyy': 'lba',
        'lbb': 'lbb',
        'lbb-Latn-PG': 'lbb',
        'lbb-Latn': 'lbb',
        'lbb-PG': 'lbb',
        'lbc': 'lbc',
        'lbc-Lisu-CN': 'lbc',
        'lbc-CN': 'lbc',
        'lbc-Lisu': 'lbc',
        'lbe': 'lbe',
        'lbe-Cyrl-RU': 'lbe',
        'lbe-Cyrl': 'lbe',
        'lbe-RU': 'lbe',
        'lbf-Deva': 'lbf-Deva',
        'lbf-Deva-IN': 'lbf-Deva',
        'lbf-IN': 'lbf-Deva',
        'lbf-Tibt': 'lbf-Tibt',
        'lbf-Tibt-CN': 'lbf-Tibt',
        'lbf-CN': 'lbf-Tibt',
        'lbg': 'lbg',
        'lbg-Zyyy-LA': 'lbg',
        'lbg-LA': 'lbg',
        'lbg-Zyyy': 'lbg',
        'lbi': 'lbi',
        'lbi-Latn-CM': 'lbi',
        'lbi-CM': 'lbi',
        'lbi-Latn': 'lbi',
        'lbj': 'lbj',
        'lbj-Tibt-IN': 'lbj',
        'lbj-IN': 'lbj',
        'lbj-Tibt': 'lbj',
        'lbl': 'lbl',
        'lbl-Latn-PH': 'lbl',
        'lbl-Latn': 'lbl',
        'lbl-PH': 'lbl',
        'lbm': 'lbm',
        'lbm-Deva-IN': 'lbm',
        'lbm-Deva': 'lbm',
        'lbm-IN': 'lbm',
        'lbn-Laoo': 'lbn-Laoo',
        'lbn-Laoo-LA': 'lbn-Laoo',
        'lbn-Latn': 'lbn-Latn',
        'lbn-Latn-LA': 'lbn-Latn',
        'lbo': 'lbo',
        'lbo-Zyyy-LA': 'lbo',
        'lbo-LA': 'lbo',
        'lbo-Zyyy': 'lbo',
        'lbq': 'lbq',
        'lbq-Latn-PG': 'lbq',
        'lbq-Latn': 'lbq',
        'lbq-PG': 'lbq',
        'lbr': 'lbr',
        'lbr-Deva-NP': 'lbr',
        'lbr-Deva': 'lbr',
        'lbr-NP': 'lbr',
        'lbs': 'lbs',
        'lbs-Zxxx-LY': 'lbs',
        'lbs-LY': 'lbs',
        'lbs-Zxxx': 'lbs',
        'sgn-lbs': 'lbs',
        'sgn-lbs-LY': 'lbs',
        'lbt': 'lbt',
        'lbt-Latn-VN': 'lbt',
        'lbt-Latn': 'lbt',
        'lbt-VN': 'lbt',
        'lbu': 'lbu',
        'lbu-Latn-PG': 'lbu',
        'lbu-Latn': 'lbu',
        'lbu-PG': 'lbu',
        'lbv': 'lbv',
        'lbv-Latn-PG': 'lbv',
        'lbv-Latn': 'lbv',
        'lbv-PG': 'lbv',
        'lbw': 'lbw',
        'lbw-Latn-ID': 'lbw',
        'lbw-ID': 'lbw',
        'lbw-Latn': 'lbw',
        'lbx': 'lbx',
        'lbx-Latn-ID': 'lbx',
        'lbx-ID': 'lbx',
        'lbx-Latn': 'lbx',
        'lby': 'lby',
        'lby-Latn-AU': 'lby',
        'lby-AU': 'lby',
        'lby-Latn': 'lby',
        'lbz': 'lbz',
        'lbz-Latn-AU': 'lbz',
        'lbz-AU': 'lbz',
        'lbz-Latn': 'lbz',
        'lcc': 'lcc',
        'lcc-Latn-ID': 'lcc',
        'lcc-ID': 'lcc',
        'lcc-Latn': 'lcc',
        'lcd': 'lcd',
        'lcd-Latn-ID': 'lcd',
        'lcd-ID': 'lcd',
        'lcd-Latn': 'lcd',
        'lce': 'lce',
        'lce-Latn-ID': 'lce',
        'lce-ID': 'lce',
        'lce-Latn': 'lce',
        'ms-lce': 'lce',
        'ms-lce-ID': 'lce',
        'lcf': 'lcf',
        'lcf-Latn-ID': 'lcf',
        'lcf-ID': 'lcf',
        'lcf-Latn': 'lcf',
        'ms-lcf': 'lcf',
        'ms-lcf-ID': 'lcf',
        'lch': 'lch',
        'lch-Latn-AO': 'lch',
        'lch-AO': 'lch',
        'lch-Latn': 'lch',
        'lcl': 'lcl',
        'lcl-Latn-ID': 'lcl',
        'lcl-ID': 'lcl',
        'lcl-Latn': 'lcl',
        'lcm': 'lcm',
        'lcm-Latn-PG': 'lcm',
        'lcm-Latn': 'lcm',
        'lcm-PG': 'lcm',
        'lcp': 'lcp',
        'lcp-Thai-CN': 'lcp',
        'lcp-CN': 'lcp',
        'lcp-Thai': 'lcp',
        'lcq': 'lcq',
        'lcq-Latn-ID': 'lcq',
        'lcq-ID': 'lcq',
        'lcq-Latn': 'lcq',
        'ppr': 'lcq',
        'ppr-ID': 'lcq',
        'ppr-Latn': 'lcq',
        'ppr-Latn-ID': 'lcq',
        'lcs': 'lcs',
        'lcs-Latn-ID': 'lcs',
        'lcs-ID': 'lcs',
        'lcs-Latn': 'lcs',
        'lda': 'lda',
        'lda-Latn-CI': 'lda',
        'lda-CI': 'lda',
        'lda-Latn': 'lda',
        'ldb': 'ldb',
        'ldb-Latn-NG': 'ldb',
        'ldb-Latn': 'ldb',
        'ldb-NG': 'ldb',
        'ldd': 'ldd',
        'ldd-Latn-NG': 'ldd',
        'ldd-Latn': 'ldd',
        'ldd-NG': 'ldd',
        'ldg': 'ldg',
        'ldg-Latn-NG': 'ldg',
        'ldg-Latn': 'ldg',
        'ldg-NG': 'ldg',
        'ldh': 'ldh',
        'ldh-Latn-NG': 'ldh',
        'ldh-Latn': 'ldh',
        'ldh-NG': 'ldh',
        'ldi': 'ldi',
        'ldi-Latn-CG': 'ldi',
        'ldi-CG': 'ldi',
        'ldi-Latn': 'ldi',
        'ldj': 'ldj',
        'ldj-Latn-NG': 'ldj',
        'ldj-Latn': 'ldj',
        'ldj-NG': 'ldj',
        'ldk': 'ldk',
        'ldk-Latn-NG': 'ldk',
        'ldk-Latn': 'ldk',
        'ldk-NG': 'ldk',
        'ldl': 'ldl',
        'ldl-Latn-NG': 'ldl',
        'ldl-Latn': 'ldl',
        'ldl-NG': 'ldl',
        'ldm': 'ldm',
        'ldm-Latn-GN': 'ldm',
        'ldm-GN': 'ldm',
        'ldm-Latn': 'ldm',
        'ldn': 'ldn',
        'ldn-Zyyy-001': 'ldn',
        'ldn-001': 'ldn',
        'ldn-Zyyy': 'ldn',
        'ldo': 'ldo',
        'ldo-Latn-NG': 'ldo',
        'ldo-Latn': 'ldo',
        'ldo-NG': 'ldo',
        'ldp': 'ldp',
        'ldp-Latn-NG': 'ldp',
        'ldp-Latn': 'ldp',
        'ldp-NG': 'ldp',
        'ldq': 'ldq',
        'ldq-Latn-NG': 'ldq',
        'ldq-Latn': 'ldq',
        'ldq-NG': 'ldq',
        'lea': 'lea',
        'lea-Latn-CD': 'lea',
        'lea-CD': 'lea',
        'lea-Latn': 'lea',
        'leb': 'leb',
        'leb-Latn-ZM': 'leb',
        'leb-Latn': 'leb',
        'leb-ZM': 'leb',
        'lec': 'lec',
        'lec-Latn-BO': 'lec',
        'lec-BO': 'lec',
        'lec-Latn': 'lec',
        'led': 'led',
        'led-Latn-CD': 'led',
        'led-CD': 'led',
        'led-Latn': 'led',
        'lee': 'lee',
        'lee-Latn-BF': 'lee',
        'lee-BF': 'lee',
        'lee-Latn': 'lee',
        'lef': 'lef',
        'lef-Latn-GH': 'lef',
        'lef-GH': 'lef',
        'lef-Latn': 'lef',
        'leh': 'leh',
        'leh-Latn-ZM': 'leh',
        'leh-Latn': 'leh',
        'leh-ZM': 'leh',
        'lei': 'lei',
        'lei-Latn-PG': 'lei',
        'lei-Latn': 'lei',
        'lei-PG': 'lei',
        'lej': 'lej',
        'lej-Latn-CD': 'lej',
        'lej-CD': 'lej',
        'lej-Latn': 'lej',
        'lek': 'lek',
        'lek-Latn-PG': 'lek',
        'lek-Latn': 'lek',
        'lek-PG': 'lek',
        'lel': 'lel',
        'lel-Latn-CD': 'lel',
        'lel-CD': 'lel',
        'lel-Latn': 'lel',
        'lem': 'lem',
        'lem-Latn-CM': 'lem',
        'lem-CM': 'lem',
        'lem-Latn': 'lem',
        'len': 'len',
        'len-Latn-HN': 'len',
        'len-HN': 'len',
        'len-Latn': 'len',
        'leo': 'leo',
        'leo-Latn-CM': 'leo',
        'leo-CM': 'leo',
        'leo-Latn': 'leo',
        'lep': 'lep',
        'lep-Lepc-IN': 'lep',
        'lep-IN': 'lep',
        'lep-Lepc': 'lep',
        'lep-Tibt': 'lep-Tibt',
        'lep-Tibt-IN': 'lep-Tibt',
        'leq': 'leq',
        'leq-Latn-PG': 'leq',
        'leq-Latn': 'leq',
        'leq-PG': 'leq',
        'ler': 'ler',
        'ler-Latn-PG': 'ler',
        'ler-Latn': 'ler',
        'ler-PG': 'ler',
        'les': 'les',
        'les-Latn-CD': 'les',
        'les-CD': 'les',
        'les-Latn': 'les',
        'let': 'let',
        'let-Latn-PG': 'let',
        'let-Latn': 'let',
        'let-PG': 'let',
        'leu': 'leu',
        'leu-Latn-PG': 'leu',
        'leu-Latn': 'leu',
        'leu-PG': 'leu',
        'lev': 'lev',
        'lev-Latn-ID': 'lev',
        'lev-ID': 'lev',
        'lev-Latn': 'lev',
        'lew': 'lew',
        'lew-Latn-ID': 'lew',
        'lew-ID': 'lew',
        'lew-Latn': 'lew',
        'lex': 'lex',
        'lex-Latn-ID': 'lex',
        'lex-ID': 'lex',
        'lex-Latn': 'lex',
        'ley': 'ley',
        'ley-Latn-ID': 'ley',
        'ley-ID': 'ley',
        'ley-Latn': 'ley',
        'lez': 'lez',
        'lez-Cyrl-RU': 'lez',
        'lez-Cyrl': 'lez',
        'lez-RU': 'lez',
        'lez-Aghb': 'lez-Aghb',
        'lez-Aghb-AZ': 'lez-Aghb',
        'lez-AZ': 'lez-Aghb',
        'lfa': 'lfa',
        'lfa-Latn-CM': 'lfa',
        'lfa-CM': 'lfa',
        'lfa-Latn': 'lfa',
        'lfn': 'lfn',
        'lfn-Latn-001': 'lfn',
        'lfn-001': 'lfn',
        'lfn-Latn': 'lfn',
        'lfn-Cyrl': 'lfn-Cyrl',
        'lfn-Cyrl-001': 'lfn-Cyrl',
        'lg': 'lg',
        'lg-Latn-UG': 'lg',
        'lg-Latn': 'lg',
        'lg-UG': 'lg',
        'lg-Arab': 'lg-Arab',
        'lg-Arab-UG': 'lg-Arab',
        'lga': 'lga',
        'lga-Latn-SB': 'lga',
        'lga-Latn': 'lga',
        'lga-SB': 'lga',
        'lgb': 'lgb',
        'lgb-Latn-SB': 'lgb',
        'lgb-Latn': 'lgb',
        'lgb-SB': 'lgb',
        'lgg': 'lgg',
        'lgg-Latn-UG': 'lgg',
        'lgg-Latn': 'lgg',
        'lgg-UG': 'lgg',
        'lgg-Arab': 'lgg-Arab',
        'lgg-Arab-UG': 'lgg-Arab',
        'lgh': 'lgh',
        'lgh-Latn-VN': 'lgh',
        'lgh-Latn': 'lgh',
        'lgh-VN': 'lgh',
        'lgi': 'lgi',
        'lgi-Latn-ID': 'lgi',
        'lgi-ID': 'lgi',
        'lgi-Latn': 'lgi',
        'lgk': 'lgk',
        'lgk-Latn-VU': 'lgk',
        'lgk-Latn': 'lgk',
        'lgk-VU': 'lgk',
        'lgl': 'lgl',
        'lgl-Latn-SB': 'lgl',
        'lgl-Latn': 'lgl',
        'lgl-SB': 'lgl',
        'lgm': 'lgm',
        'lgm-Latn-CD': 'lgm',
        'lgm-CD': 'lgm',
        'lgm-Latn': 'lgm',
        'lgn': 'lgn',
        'lgn-Latn-ET': 'lgn',
        'lgn-ET': 'lgn',
        'lgn-Latn': 'lgn',
        'lgq': 'lgq',
        'lgq-Latn-GH': 'lgq',
        'lgq-GH': 'lgq',
        'lgq-Latn': 'lgq',
        'lgr': 'lgr',
        'lgr-Latn-SB': 'lgr',
        'lgr-Latn': 'lgr',
        'lgr-SB': 'lgr',
        'lgt': 'lgt',
        'lgt-Latn-PG': 'lgt',
        'lgt-Latn': 'lgt',
        'lgt-PG': 'lgt',
        'lgu': 'lgu',
        'lgu-Latn-SB': 'lgu',
        'lgu-Latn': 'lgu',
        'lgu-SB': 'lgu',
        'lgz': 'lgz',
        'lgz-Latn-CD': 'lgz',
        'lgz-CD': 'lgz',
        'lgz-Latn': 'lgz',
        'lha': 'lha',
        'lha-Latn-VN': 'lha',
        'lha-Latn': 'lha',
        'lha-VN': 'lha',
        'lhh': 'lhh',
        'lhh-Latn-ID': 'lhh',
        'lhh-ID': 'lhh',
        'lhh-Latn': 'lhh',
        'lhi': 'lhi',
        'lhi-Latn-CN': 'lhi',
        'lhi-CN': 'lhi',
        'lhi-Latn': 'lhi',
        'lhl': 'lhl',
        'lhl-Zyyy-IN': 'lhl',
        'lhl-IN': 'lhl',
        'lhl-Zyyy': 'lhl',
        'lhm': 'lhm',
        'lhm-Deva-NP': 'lhm',
        'lhm-Deva': 'lhm',
        'lhm-NP': 'lhm',
        'lhn': 'lhn',
        'lhn-Latn-MY': 'lhn',
        'lhn-Latn': 'lhn',
        'lhn-MY': 'lhn',
        'lhp': 'lhp',
        'lhp-Zyyy-BT': 'lhp',
        'lhp-BT': 'lhp',
        'lhp-Zyyy': 'lhp',
        'lhs': 'lhs',
        'lhs-Syrc-SY': 'lhs',
        'lhs-SY': 'lhs',
        'lhs-Syrc': 'lhs',
        'lht': 'lht',
        'lht-Latn-VU': 'lht',
        'lht-Latn': 'lht',
        'lht-VU': 'lht',
        'lhu': 'lhu',
        'lhu-Latn-CN': 'lhu',
        'lhu-CN': 'lhu',
        'lhu-Latn': 'lhu',
        'li': 'li',
        'li-Latn-NL': 'li',
        'li-Latn': 'li',
        'li-NL': 'li',
        'lia': 'lia',
        'lia-Latn-SL': 'lia',
        'lia-Latn': 'lia',
        'lia-SL': 'lia',
        'lib': 'lib',
        'lib-Latn-PG': 'lib',
        'lib-Latn': 'lib',
        'lib-PG': 'lib',
        'lic': 'lic',
        'lic-Latn-CN': 'lic',
        'lic-CN': 'lic',
        'lic-Latn': 'lic',
        'lid': 'lid',
        'lid-Latn-PG': 'lid',
        'lid-Latn': 'lid',
        'lid-PG': 'lid',
        'lie': 'lie',
        'lie-Latn-CD': 'lie',
        'lie-CD': 'lie',
        'lie-Latn': 'lie',
        'lif': 'lif',
        'lif-Deva-NP': 'lif',
        'lif-Deva': 'lif',
        'lif-NP': 'lif',
        'lif-Limb': 'lif-Limb',
        'lif-Limb-IN': 'lif-Limb',
        'lif-IN': 'lif-Limb',
        'lig': 'lig',
        'lig-Latn-GH': 'lig',
        'lig-GH': 'lig',
        'lig-Latn': 'lig',
        'lih': 'lih',
        'lih-Latn-PG': 'lih',
        'lih-Latn': 'lih',
        'lih-PG': 'lih',
        'lij': 'lij',
        'lij-Latn-IT': 'lij',
        'lij-IT': 'lij',
        'lij-Latn': 'lij',
        'lik': 'lik',
        'lik-Latn-CD': 'lik',
        'lik-CD': 'lik',
        'lik-Latn': 'lik',
        'lil': 'lil',
        'lil-Latn-CA': 'lil',
        'lil-CA': 'lil',
        'lil-Latn': 'lil',
        'lil-Dupl': 'lil-Dupl',
        'lil-Dupl-CA': 'lil-Dupl',
        'lio': 'lio',
        'lio-Latn-ID': 'lio',
        'lio-ID': 'lio',
        'lio-Latn': 'lio',
        'lip': 'lip',
        'lip-Latn-GH': 'lip',
        'lip-GH': 'lip',
        'lip-Latn': 'lip',
        'liq': 'liq',
        'liq-Latn-ET': 'liq',
        'liq-ET': 'liq',
        'liq-Latn': 'liq',
        'lir': 'lir',
        'lir-Latn-LR': 'lir',
        'lir-LR': 'lir',
        'lir-Latn': 'lir',
        'lis': 'lis',
        'lis-Lisu-CN': 'lis',
        'lis-CN': 'lis',
        'lis-Lisu': 'lis',
        'lis-Latn': 'lis-Latn',
        'lis-Latn-CN': 'lis-Latn',
        'liu': 'liu',
        'liu-Latn-SD': 'liu',
        'liu-Latn': 'liu',
        'liu-SD': 'liu',
        'liv': 'liv',
        'liv-Latn-LV': 'liv',
        'liv-LV': 'liv',
        'liv-Latn': 'liv',
        'liw': 'liw',
        'liw-Latn-ID': 'liw',
        'liw-ID': 'liw',
        'liw-Latn': 'liw',
        'ms-liw': 'liw',
        'ms-liw-ID': 'liw',
        'lix': 'lix',
        'lix-Latn-ID': 'lix',
        'lix-ID': 'lix',
        'lix-Latn': 'lix',
        'liy': 'liy',
        'liy-Latn-CF': 'liy',
        'liy-CF': 'liy',
        'liy-Latn': 'liy',
        'liz': 'liz',
        'liz-Latn-CD': 'liz',
        'liz-CD': 'liz',
        'liz-Latn': 'liz',
        'lja': 'lja',
        'lja-Latn-AU': 'lja',
        'lja-AU': 'lja',
        'lja-Latn': 'lja',
        'lje': 'lje',
        'lje-Latn-ID': 'lje',
        'lje-ID': 'lje',
        'lje-Latn': 'lje',
        'lji': 'lji',
        'lji-Latn-ID': 'lji',
        'lji-ID': 'lji',
        'lji-Latn': 'lji',
        'ljl': 'ljl',
        'ljl-Latn-ID': 'ljl',
        'ljl-ID': 'ljl',
        'ljl-Latn': 'ljl',
        'ljp': 'ljp',
        'ljp-Latn-ID': 'ljp',
        'ljp-ID': 'ljp',
        'ljp-Latn': 'ljp',
        'ljp-Rjng': 'ljp-Rjng',
        'ljp-Rjng-ID': 'ljp-Rjng',
        'ljw': 'ljw',
        'ljw-Latn-AU': 'ljw',
        'ljw-AU': 'ljw',
        'ljw-Latn': 'ljw',
        'ljx': 'ljx',
        'ljx-Latn-AU': 'ljx',
        'ljx-AU': 'ljx',
        'ljx-Latn': 'ljx',
        'lka': 'lka',
        'lka-Latn-TL': 'lka',
        'lka-Latn': 'lka',
        'lka-TL': 'lka',
        'lkb': 'lkb',
        'lkb-Latn-KE': 'lkb',
        'lkb-KE': 'lkb',
        'lkb-Latn': 'lkb',
        'lkc': 'lkc',
        'lkc-Latn-VN': 'lkc',
        'lkc-Latn': 'lkc',
        'lkc-VN': 'lkc',
        'lkd': 'lkd',
        'lkd-Latn-BR': 'lkd',
        'lkd-BR': 'lkd',
        'lkd-Latn': 'lkd',
        'lke': 'lke',
        'lke-Latn-UG': 'lke',
        'lke-Latn': 'lke',
        'lke-UG': 'lke',
        'lkh': 'lkh',
        'lkh-Zyyy-BT': 'lkh',
        'lkh-BT': 'lkh',
        'lkh-Zyyy': 'lkh',
        'lki': 'lki',
        'lki-Arab-IR': 'lki',
        'lki-Arab': 'lki',
        'lki-IR': 'lki',
        'lkj': 'lkj',
        'lkj-Latn-MY': 'lkj',
        'lkj-Latn': 'lkj',
        'lkj-MY': 'lkj',
        'lkl': 'lkl',
        'lkl-Latn-PG': 'lkl',
        'lkl-Latn': 'lkl',
        'lkl-PG': 'lkl',
        'lkm': 'lkm',
        'lkm-Latn-AU': 'lkm',
        'lkm-AU': 'lkm',
        'lkm-Latn': 'lkm',
        'lkn': 'lkn',
        'lkn-Latn-VU': 'lkn',
        'lkn-Latn': 'lkn',
        'lkn-VU': 'lkn',
        'lko': 'lko',
        'lko-Latn-KE': 'lko',
        'lko-KE': 'lko',
        'lko-Latn': 'lko',
        'lkr': 'lkr',
        'lkr-Latn-SS': 'lkr',
        'lkr-Latn': 'lkr',
        'lkr-SS': 'lkr',
        'lks': 'lks',
        'lks-Latn-KE': 'lks',
        'lks-KE': 'lks',
        'lks-Latn': 'lks',
        'lkt': 'lkt',
        'lkt-Latn-US': 'lkt',
        'lkt-Latn': 'lkt',
        'lkt-US': 'lkt',
        'lku': 'lku',
        'lku-Latn-AU': 'lku',
        'lku-AU': 'lku',
        'lku-Latn': 'lku',
        'lky': 'lky',
        'lky-Latn-SS': 'lky',
        'lky-Latn': 'lky',
        'lky-SS': 'lky',
        'lla': 'lla',
        'lla-Latn-NG': 'lla',
        'lla-Latn': 'lla',
        'lla-NG': 'lla',
        'llb': 'llb',
        'llb-Latn-MZ': 'llb',
        'llb-Latn': 'llb',
        'llb-MZ': 'llb',
        'llc': 'llc',
        'llc-Latn-GN': 'llc',
        'llc-GN': 'llc',
        'llc-Latn': 'llc',
        'lld': 'lld',
        'lld-Latn-IT': 'lld',
        'lld-IT': 'lld',
        'lld-Latn': 'lld',
        'lle': 'lle',
        'lle-Latn-PG': 'lle',
        'lle-Latn': 'lle',
        'lle-PG': 'lle',
        'llf': 'llf',
        'llf-Latn-PG': 'llf',
        'llf-Latn': 'llf',
        'llf-PG': 'llf',
        'llg': 'llg',
        'llg-Latn-ID': 'llg',
        'llg-ID': 'llg',
        'llg-Latn': 'llg',
        'llh': 'llh',
        'llh-Zyyy-CN': 'llh',
        'llh-CN': 'llh',
        'llh-Zyyy': 'llh',
        'lli': 'lli',
        'lli-Latn-CG': 'lli',
        'lli-CG': 'lli',
        'lli-Latn': 'lli',
        'llj': 'llj',
        'llj-Latn-AU': 'llj',
        'llj-AU': 'llj',
        'llj-Latn': 'llj',
        'llk': 'llk',
        'llk-Latn-MY': 'llk',
        'llk-Latn': 'llk',
        'llk-MY': 'llk',
        'lll': 'lll',
        'lll-Latn-PG': 'lll',
        'lll-Latn': 'lll',
        'lll-PG': 'lll',
        'llm': 'llm',
        'llm-Latn-ID': 'llm',
        'llm-ID': 'llm',
        'llm-Latn': 'llm',
        'lln': 'lln',
        'lln-Latn-TD': 'lln',
        'lln-Latn': 'lln',
        'lln-TD': 'lln',
        'llp': 'llp',
        'llp-Latn-VU': 'llp',
        'llp-Latn': 'llp',
        'llp-VU': 'llp',
        'llq': 'llq',
        'llq-Latn-ID': 'llq',
        'llq-ID': 'llq',
        'llq-Latn': 'llq',
        'lls': 'lls',
        'lls-Zxxx-LT': 'lls',
        'lls-LT': 'lls',
        'lls-Zxxx': 'lls',
        'sgn-lls': 'lls',
        'sgn-lls-LT': 'lls',
        'llu': 'llu',
        'llu-Latn-SB': 'llu',
        'llu-Latn': 'llu',
        'llu-SB': 'llu',
        'llx': 'llx',
        'llx-Latn-FJ': 'llx',
        'llx-FJ': 'llx',
        'llx-Latn': 'llx',
        'lma': 'lma',
        'lma-Latn-GN': 'lma',
        'lma-GN': 'lma',
        'lma-Latn': 'lma',
        'lmb': 'lmb',
        'lmb-Latn-VU': 'lmb',
        'lmb-Latn': 'lmb',
        'lmb-VU': 'lmb',
        'lmc': 'lmc',
        'lmc-Latn-AU': 'lmc',
        'lmc-AU': 'lmc',
        'lmc-Latn': 'lmc',
        'lmd': 'lmd',
        'lmd-Latn-SD': 'lmd',
        'lmd-Latn': 'lmd',
        'lmd-SD': 'lmd',
        'lme': 'lme',
        'lme-Latn-TD': 'lme',
        'lme-Latn': 'lme',
        'lme-TD': 'lme',
        'lmf': 'lmf',
        'lmf-Latn-ID': 'lmf',
        'lmf-ID': 'lmf',
        'lmf-Latn': 'lmf',
        'lmg': 'lmg',
        'lmg-Latn-PG': 'lmg',
        'lmg-Latn': 'lmg',
        'lmg-PG': 'lmg',
        'lmh': 'lmh',
        'lmh-Zyyy-NP': 'lmh',
        'lmh-NP': 'lmh',
        'lmh-Zyyy': 'lmh',
        'lmi': 'lmi',
        'lmi-Latn-CD': 'lmi',
        'lmi-CD': 'lmi',
        'lmi-Latn': 'lmi',
        'lmj': 'lmj',
        'lmj-Latn-ID': 'lmj',
        'lmj-ID': 'lmj',
        'lmj-Latn': 'lmj',
        'lmk': 'lmk',
        'lmk-Latn-IN': 'lmk',
        'lmk-IN': 'lmk',
        'lmk-Latn': 'lmk',
        'lmk-Mymr': 'lmk-Mymr',
        'lmk-Mymr-IN': 'lmk-Mymr',
        'lml': 'lml',
        'lml-Latn-VU': 'lml',
        'lml-Latn': 'lml',
        'lml-VU': 'lml',
        'lmn': 'lmn',
        'lmn-Telu-IN': 'lmn',
        'lmn-IN': 'lmn',
        'lmn-Telu': 'lmn',
        'lmn-Deva': 'lmn-Deva',
        'lmn-Deva-IN': 'lmn-Deva',
        'lmn-Knda': 'lmn-Knda',
        'lmn-Knda-IN': 'lmn-Knda',
        'lmo': 'lmo',
        'lmo-Latn-IT': 'lmo',
        'lmo-IT': 'lmo',
        'lmo-Latn': 'lmo',
        'lmp': 'lmp',
        'lmp-Latn-CM': 'lmp',
        'lmp-CM': 'lmp',
        'lmp-Latn': 'lmp',
        'lmq': 'lmq',
        'lmq-Latn-ID': 'lmq',
        'lmq-ID': 'lmq',
        'lmq-Latn': 'lmq',
        'lmr': 'lmr',
        'lmr-Latn-ID': 'lmr',
        'lmr-ID': 'lmr',
        'lmr-Latn': 'lmr',
        'lmu': 'lmu',
        'lmu-Latn-VU': 'lmu',
        'lmu-Latn': 'lmu',
        'lmu-VU': 'lmu',
        'lmv': 'lmv',
        'lmv-Latn-FJ': 'lmv',
        'lmv-FJ': 'lmv',
        'lmv-Latn': 'lmv',
        'lmw': 'lmw',
        'lmw-Latn-US': 'lmw',
        'lmw-Latn': 'lmw',
        'lmw-US': 'lmw',
        'lmx': 'lmx',
        'lmx-Latn-CM': 'lmx',
        'lmx-CM': 'lmx',
        'lmx-Latn': 'lmx',
        'lmy': 'lmy',
        'lmy-Latn-ID': 'lmy',
        'lmy-ID': 'lmy',
        'lmy-Latn': 'lmy',
        'lmz': 'lmz',
        'lmz-Zyyy-US': 'lmz',
        'lmz-US': 'lmz',
        'lmz-Zyyy': 'lmz',
        'ln': 'ln',
        'ln-Latn-CD': 'ln',
        'ln-CD': 'ln',
        'ln-Latn': 'ln',
        'ln-AO': 'ln-AO',
        'ln-Latn-AO': 'ln-AO',
        'lna': 'lna',
        'lna-Latn-CF': 'lna',
        'lna-CF': 'lna',
        'lna-Latn': 'lna',
        'lnb': 'lnb',
        'lnb-Latn-NA': 'lnb',
        'lnb-Latn': 'lnb',
        'lnb-NA': 'lnb',
        'lnd': 'lnd',
        'lnd-Latn-ID': 'lnd',
        'lnd-ID': 'lnd',
        'lnd-Latn': 'lnd',
        'lng': 'lng',
        'lng-Zyyy-HU': 'lng',
        'lng-HU': 'lng',
        'lng-Zyyy': 'lng',
        'lnh': 'lnh',
        'lnh-Latn-MY': 'lnh',
        'lnh-Latn': 'lnh',
        'lnh-MY': 'lnh',
        'lni': 'lni',
        'lni-Latn-PG': 'lni',
        'lni-Latn': 'lni',
        'lni-PG': 'lni',
        'lnj': 'lnj',
        'lnj-Latn-AU': 'lnj',
        'lnj-AU': 'lnj',
        'lnj-Latn': 'lnj',
        'lnl': 'lnl',
        'lnl-Latn-CF': 'lnl',
        'lnl-CF': 'lnl',
        'lnl-Latn': 'lnl',
        'lnm': 'lnm',
        'lnm-Latn-PG': 'lnm',
        'lnm-Latn': 'lnm',
        'lnm-PG': 'lnm',
        'lnn': 'lnn',
        'lnn-Latn-VU': 'lnn',
        'lnn-Latn': 'lnn',
        'lnn-VU': 'lnn',
        'lno': 'lno',
        'lno-Latn-SS': 'lno',
        'lno-Latn': 'lno',
        'lno-SS': 'lno',
        'lns': 'lns',
        'lns-Latn-CM': 'lns',
        'lns-CM': 'lns',
        'lns-Latn': 'lns',
        'lnu': 'lnu',
        'lnu-Latn-NG': 'lnu',
        'lnu-Latn': 'lnu',
        'lnu-NG': 'lnu',
        'lnw': 'lnw',
        'lnw-Latn-AU': 'lnw',
        'lnw-AU': 'lnw',
        'lnw-Latn': 'lnw',
        'lnz': 'lnz',
        'lnz-Latn-CD': 'lnz',
        'lnz-CD': 'lnz',
        'lnz-Latn': 'lnz',
        'lo': 'lo',
        'lo-Laoo-LA': 'lo',
        'lo-LA': 'lo',
        'lo-Laoo': 'lo',
        'loa': 'loa',
        'loa-Latn-ID': 'loa',
        'loa-ID': 'loa',
        'loa-Latn': 'loa',
        'lob': 'lob',
        'lob-Latn-BF': 'lob',
        'lob-BF': 'lob',
        'lob-Latn': 'lob',
        'loc': 'loc',
        'loc-Latn-PH': 'loc',
        'loc-Latn': 'loc',
        'loc-PH': 'loc',
        'loe': 'loe',
        'loe-Latn-ID': 'loe',
        'loe-ID': 'loe',
        'loe-Latn': 'loe',
        'lof': 'lof',
        'lof-Zyyy-SD': 'lof',
        'lof-SD': 'lof',
        'lof-Zyyy': 'lof',
        'log': 'log',
        'log-Latn-CD': 'log',
        'log-CD': 'log',
        'log-Latn': 'log',
        'loh': 'loh',
        'loh-Latn-SS': 'loh',
        'loh-Latn': 'loh',
        'loh-SS': 'loh',
        'loi': 'loi',
        'loi-Latn-CI': 'loi',
        'loi-CI': 'loi',
        'loi-Latn': 'loi',
        'loj': 'loj',
        'loj-Latn-PG': 'loj',
        'loj-Latn': 'loj',
        'loj-PG': 'loj',
        'lok': 'lok',
        'lok-Latn-SL': 'lok',
        'lok-Latn': 'lok',
        'lok-SL': 'lok',
        'lol': 'lol',
        'lol-Latn-CD': 'lol',
        'lol-CD': 'lol',
        'lol-Latn': 'lol',
        'lom': 'lom',
        'lom-Latn-LR': 'lom',
        'lom-LR': 'lom',
        'lom-Latn': 'lom',
        'lom-Loma': 'lom-Loma',
        'lom-Loma-LR': 'lom-Loma',
        'lon': 'lon',
        'lon-Latn-MW': 'lon',
        'lon-Latn': 'lon',
        'lon-MW': 'lon',
        'loo': 'loo',
        'loo-Latn-CD': 'loo',
        'loo-CD': 'loo',
        'loo-Latn': 'loo',
        'lop': 'lop',
        'lop-Latn-NG': 'lop',
        'lop-Latn': 'lop',
        'lop-NG': 'lop',
        'loq': 'loq',
        'loq-Latn-CD': 'loq',
        'loq-CD': 'loq',
        'loq-Latn': 'loq',
        'lor': 'lor',
        'lor-Latn-CI': 'lor',
        'lor-CI': 'lor',
        'lor-Latn': 'lor',
        'los': 'los',
        'los-Latn-PG': 'los',
        'los-Latn': 'los',
        'los-PG': 'los',
        'lot': 'lot',
        'lot-Latn-SS': 'lot',
        'lot-Latn': 'lot',
        'lot-SS': 'lot',
        'lot-Arab': 'lot-Arab',
        'lot-Arab-SS': 'lot-Arab',
        'lou': 'lou',
        'lou-Latn-US': 'lou',
        'lou-Latn': 'lou',
        'lou-US': 'lou',
        'lov': 'lov',
        'lov-Zyyy-CN': 'lov',
        'lov-CN': 'lov',
        'lov-Zyyy': 'lov',
        'low': 'low',
        'low-Latn-MY': 'low',
        'low-Latn': 'low',
        'low-MY': 'low',
        'lox': 'lox',
        'lox-Latn-ID': 'lox',
        'lox-ID': 'lox',
        'lox-Latn': 'lox',
        'loy': 'loy',
        'loy-Deva-NP': 'loy',
        'loy-Deva': 'loy',
        'loy-NP': 'loy',
        'loy-Tibt': 'loy-Tibt',
        'loy-Tibt-NP': 'loy-Tibt',
        'loz': 'loz',
        'loz-Latn-ZM': 'loz',
        'loz-Latn': 'loz',
        'loz-ZM': 'loz',
        'lpa': 'lpa',
        'lpa-Latn-VU': 'lpa',
        'lpa-Latn': 'lpa',
        'lpa-VU': 'lpa',
        'lpe': 'lpe',
        'lpe-Latn-ID': 'lpe',
        'lpe-ID': 'lpe',
        'lpe-Latn': 'lpe',
        'lpn': 'lpn',
        'lpn-Latn-MM': 'lpn',
        'lpn-Latn': 'lpn',
        'lpn-MM': 'lpn',
        'lpo': 'lpo',
        'lpo-Plrd-CN': 'lpo',
        'lpo-CN': 'lpo',
        'lpo-Plrd': 'lpo',
        'lpo-Lisu': 'lpo-Lisu',
        'lpo-Lisu-CN': 'lpo-Lisu',
        'lpx': 'lpx',
        'lpx-Latn-SS': 'lpx',
        'lpx-Latn': 'lpx',
        'lpx-SS': 'lpx',
        'lra': 'lra',
        'lra-Latn-MY': 'lra',
        'lra-Latn': 'lra',
        'lra-MY': 'lra',
        'lrc': 'lrc',
        'lrc-Arab-IR': 'lrc',
        'lrc-Arab': 'lrc',
        'lrc-IR': 'lrc',
        'lrc-IQ': 'lrc-IQ',
        'lrc-Arab-IQ': 'lrc-IQ',
        'lre': 'lre',
        'lre-Zyyy-US': 'lre',
        'lre-US': 'lre',
        'lre-Zyyy': 'lre',
        'lrg': 'lrg',
        'lrg-Latn-AU': 'lrg',
        'lrg-AU': 'lrg',
        'lrg-Latn': 'lrg',
        'lri': 'lri',
        'lri-Latn-KE': 'lri',
        'lri-KE': 'lri',
        'lri-Latn': 'lri',
        'lrk': 'lrk',
        'lrk-Arab-PK': 'lrk',
        'lrk-Arab': 'lrk',
        'lrk-PK': 'lrk',
        'lrl': 'lrl',
        'lrl-Arab-IR': 'lrl',
        'lrl-Arab': 'lrl',
        'lrl-IR': 'lrl',
        'lrm': 'lrm',
        'lrm-Latn-KE': 'lrm',
        'lrm-KE': 'lrm',
        'lrm-Latn': 'lrm',
        'lrn': 'lrn',
        'lrn-Latn-ID': 'lrn',
        'lrn-ID': 'lrn',
        'lrn-Latn': 'lrn',
        'lro': 'lro',
        'lro-Latn-SD': 'lro',
        'lro-Latn': 'lro',
        'lro-SD': 'lro',
        'lrr': 'lrr',
        'lrr-Zyyy-NP': 'lrr',
        'lrr-NP': 'lrr',
        'lrr-Zyyy': 'lrr',
        'yma': 'lrr',
        'yma-NP': 'lrr',
        'yma-Zyyy': 'lrr',
        'yma-Zyyy-NP': 'lrr',
        'lrt': 'lrt',
        'lrt-Latn-ID': 'lrt',
        'lrt-ID': 'lrt',
        'lrt-Latn': 'lrt',
        'lrv': 'lrv',
        'lrv-Latn-VU': 'lrv',
        'lrv-Latn': 'lrv',
        'lrv-VU': 'lrv',
        'lrz': 'lrz',
        'lrz-Latn-VU': 'lrz',
        'lrz-Latn': 'lrz',
        'lrz-VU': 'lrz',
        'lsa': 'lsa',
        'lsa-Arab-IR': 'lsa',
        'lsa-Arab': 'lsa',
        'lsa-IR': 'lsa',
        'lsd': 'lsd',
        'lsd-Hebr-IL': 'lsd',
        'lsd-Hebr': 'lsd',
        'lsd-IL': 'lsd',
        'lse': 'lse',
        'lse-Latn-CD': 'lse',
        'lse-CD': 'lse',
        'lse-Latn': 'lse',
        'lsg': 'lsg',
        'lsg-Zxxx-FR': 'lsg',
        'lsg-FR': 'lsg',
        'lsg-Zxxx': 'lsg',
        'sgn-lsg': 'lsg',
        'sgn-lsg-FR': 'lsg',
        'lsh': 'lsh',
        'lsh-Zyyy-IN': 'lsh',
        'lsh-IN': 'lsh',
        'lsh-Zyyy': 'lsh',
        'lsi': 'lsi',
        'lsi-Latn-MM': 'lsi',
        'lsi-Latn': 'lsi',
        'lsi-MM': 'lsi',
        'lsl': 'lsl',
        'lsl-Zxxx-LV': 'lsl',
        'lsl-LV': 'lsl',
        'lsl-Zxxx': 'lsl',
        'sgn-lsl': 'lsl',
        'sgn-lsl-LV': 'lsl',
        'lsm': 'lsm',
        'lsm-Latn-UG': 'lsm',
        'lsm-Latn': 'lsm',
        'lsm-UG': 'lsm',
        'lsn': 'lsn',
        'lsn-Zxxx-CN': 'lsn',
        'lsn-CN': 'lsn',
        'lsn-Zxxx': 'lsn',
        'sgn-lsn': 'lsn',
        'sgn-lsn-CN': 'lsn',
        'lso': 'lso',
        'lso-Zxxx-LA': 'lso',
        'lso-LA': 'lso',
        'lso-Zxxx': 'lso',
        'sgn-lso': 'lso',
        'sgn-lso-LA': 'lso',
        'lsp': 'lsp',
        'lsp-Zxxx-PA': 'lsp',
        'lsp-PA': 'lsp',
        'lsp-Zxxx': 'lsp',
        'sgn-lsp': 'lsp',
        'sgn-lsp-PA': 'lsp',
        'lsr': 'lsr',
        'lsr-Latn-PG': 'lsr',
        'lsr-Latn': 'lsr',
        'lsr-PG': 'lsr',
        'lss': 'lss',
        'lss-Arab-PK': 'lss',
        'lss-Arab': 'lss',
        'lss-PK': 'lss',
        'lst': 'lst',
        'lst-Zxxx-TT': 'lst',
        'lst-TT': 'lst',
        'lst-Zxxx': 'lst',
        'sgn-lst': 'lst',
        'sgn-lst-TT': 'lst',
        'lsv': 'lsv',
        'lsv-Zxxx-PE': 'lsv',
        'lsv-PE': 'lsv',
        'lsv-Zxxx': 'lsv',
        'sgn-lsv': 'lsv',
        'sgn-lsv-PE': 'lsv',
        'lsy': 'lsy',
        'lsy-Zxxx-MU': 'lsy',
        'lsy-MU': 'lsy',
        'lsy-Zxxx': 'lsy',
        'sgn-lsy': 'lsy',
        'sgn-lsy-MU': 'lsy',
        'lt': 'lt',
        'lt-Latn-LT': 'lt',
        'lt-LT': 'lt',
        'lt-Latn': 'lt',
        'lt-Latf': 'lt-Latf',
        'lt-Latf-LT': 'lt-Latf',
        'ltc': 'ltc',
        'ltc-Zyyy-CN': 'ltc',
        'ltc-CN': 'ltc',
        'ltc-Zyyy': 'ltc',
        'ltg': 'ltg',
        'ltg-Latn-LV': 'ltg',
        'ltg-LV': 'ltg',
        'ltg-Latn': 'ltg',
        'lv-ltg': 'ltg',
        'lv-ltg-LV': 'ltg',
        'lth': 'lth',
        'lth-Latn-UG': 'lth',
        'lth-Latn': 'lth',
        'lth-UG': 'lth',
        'lti': 'lti',
        'lti-Latn-ID': 'lti',
        'lti-ID': 'lti',
        'lti-Latn': 'lti',
        'ltn': 'ltn',
        'ltn-Latn-BR': 'ltn',
        'ltn-BR': 'ltn',
        'ltn-Latn': 'ltn',
        'lto': 'lto',
        'lto-Latn-KE': 'lto',
        'lto-KE': 'lto',
        'lto-Latn': 'lto',
        'lts': 'lts',
        'lts-Latn-KE': 'lts',
        'lts-KE': 'lts',
        'lts-Latn': 'lts',
        'ltu': 'ltu',
        'ltu-Latn-ID': 'ltu',
        'ltu-ID': 'ltu',
        'ltu-Latn': 'ltu',
        'lu': 'lu',
        'lu-Latn-CD': 'lu',
        'lu-CD': 'lu',
        'lu-Latn': 'lu',
        'lua': 'lua',
        'lua-Latn-CD': 'lua',
        'lua-CD': 'lua',
        'lua-Latn': 'lua',
        'luc': 'luc',
        'luc-Latn-UG': 'luc',
        'luc-Latn': 'luc',
        'luc-UG': 'luc',
        'lud': 'lud',
        'lud-Latn-RU': 'lud',
        'lud-Latn': 'lud',
        'lud-RU': 'lud',
        'lue': 'lue',
        'lue-Latn-ZM': 'lue',
        'lue-Latn': 'lue',
        'lue-ZM': 'lue',
        'luf': 'luf',
        'luf-Latn-PG': 'luf',
        'luf-Latn': 'luf',
        'luf-PG': 'luf',
        'lui': 'lui',
        'lui-Latn-US': 'lui',
        'lui-Latn': 'lui',
        'lui-US': 'lui',
        'luj': 'luj',
        'luj-Latn-CD': 'luj',
        'luj-CD': 'luj',
        'luj-Latn': 'luj',
        'luk': 'luk',
        'luk-Zyyy-BT': 'luk',
        'luk-BT': 'luk',
        'luk-Zyyy': 'luk',
        'lul': 'lul',
        'lul-Latn-SS': 'lul',
        'lul-Latn': 'lul',
        'lul-SS': 'lul',
        'lum': 'lum',
        'lum-Latn-AO': 'lum',
        'lum-AO': 'lum',
        'lum-Latn': 'lum',
        'lun': 'lun',
        'lun-Latn-ZM': 'lun',
        'lun-Latn': 'lun',
        'lun-ZM': 'lun',
        'luo': 'luo',
        'luo-Latn-KE': 'luo',
        'luo-KE': 'luo',
        'luo-Latn': 'luo',
        'lup': 'lup',
        'lup-Latn-GA': 'lup',
        'lup-GA': 'lup',
        'lup-Latn': 'lup',
        'luq': 'luq',
        'luq-Latn-CU': 'luq',
        'luq-CU': 'luq',
        'luq-Latn': 'luq',
        'lur': 'lur',
        'lur-Latn-ID': 'lur',
        'lur-ID': 'lur',
        'lur-Latn': 'lur',
        'lus': 'lus',
        'lus-Latn-IN': 'lus',
        'lus-IN': 'lus',
        'lus-Latn': 'lus',
        'lus-Beng': 'lus-Beng',
        'lus-Beng-BD': 'lus-Beng',
        'lus-BD': 'lus-Beng',
        'lus-Brai': 'lus-Brai',
        'lus-Brai-IN': 'lus-Brai',
        'lut': 'lut',
        'lut-Latn-US': 'lut',
        'lut-Latn': 'lut',
        'lut-US': 'lut',
        'luu': 'luu',
        'luu-Zyyy-NP': 'luu',
        'luu-NP': 'luu',
        'luu-Zyyy': 'luu',
        'luv': 'luv',
        'luv-Zyyy-OM': 'luv',
        'luv-OM': 'luv',
        'luv-Zyyy': 'luv',
        'luw': 'luw',
        'luw-Latn-CM': 'luw',
        'luw-CM': 'luw',
        'luw-Latn': 'luw',
        'luy': 'luy',
        'luy-Latn-KE': 'luy',
        'bxk': 'luy',
        'bxk-KE': 'luy',
        'bxk-Latn': 'luy',
        'bxk-Latn-KE': 'luy',
        'luy-KE': 'luy',
        'luy-Latn': 'luy',
        'luz': 'luz',
        'luz-Arab-IR': 'luz',
        'luz-Arab': 'luz',
        'luz-IR': 'luz',
        'lv': 'lv',
        'lv-Latn-LV': 'lv',
        'lv-LV': 'lv',
        'lv-Latn': 'lv',
        'lv-lvs': 'lv',
        'lv-lvs-LV': 'lv',
        'lvs': 'lv',
        'lvs-LV': 'lv',
        'lvs-Latn': 'lv',
        'lvs-Latn-LV': 'lv',
        'lv-Brai': 'lv-Brai',
        'lv-Brai-LV': 'lv-Brai',
        'lva': 'lva',
        'lva-Latn-TL': 'lva',
        'lva-Latn': 'lva',
        'lva-TL': 'lva',
        'lvi': 'lvi',
        'lvi-Zyyy-LA': 'lvi',
        'lvi-LA': 'lvi',
        'lvi-Zyyy': 'lvi',
        'lvk': 'lvk',
        'lvk-Latn-SB': 'lvk',
        'lvk-Latn': 'lvk',
        'lvk-SB': 'lvk',
        'lvu': 'lvu',
        'lvu-Latn-ID': 'lvu',
        'lvu-ID': 'lvu',
        'lvu-Latn': 'lvu',
        'lwa': 'lwa',
        'lwa-Latn-CD': 'lwa',
        'lwa-CD': 'lwa',
        'lwa-Latn': 'lwa',
        'lwe': 'lwe',
        'lwe-Latn-ID': 'lwe',
        'lwe-ID': 'lwe',
        'lwe-Latn': 'lwe',
        'lwg': 'lwg',
        'lwg-Latn-KE': 'lwg',
        'lwg-KE': 'lwg',
        'lwg-Latn': 'lwg',
        'lwh': 'lwh',
        'lwh-Latn-VN': 'lwh',
        'lwh-Latn': 'lwh',
        'lwh-VN': 'lwh',
        'lwl': 'lwl',
        'lwl-Thai-TH': 'lwl',
        'lwl-TH': 'lwl',
        'lwl-Thai': 'lwl',
        'lwm': 'lwm',
        'lwm-Thai-CN': 'lwm',
        'lwm-CN': 'lwm',
        'lwm-Thai': 'lwm',
        'lwo': 'lwo',
        'lwo-Latn-SS': 'lwo',
        'lwo-Latn': 'lwo',
        'lwo-SS': 'lwo',
        'lwo-ZA': 'lwo-ZA',
        'lwo-Latn-ZA': 'lwo-ZA',
        'lws': 'lws',
        'lws-Zxxx-MW': 'lws',
        'lws-MW': 'lws',
        'lws-Zxxx': 'lws',
        'sgn-lws': 'lws',
        'sgn-lws-MW': 'lws',
        'lwt': 'lwt',
        'lwt-Latn-ID': 'lwt',
        'lwt-ID': 'lwt',
        'lwt-Latn': 'lwt',
        'lwu': 'lwu',
        'lwu-Zyyy-CN': 'lwu',
        'lwu-CN': 'lwu',
        'lwu-Zyyy': 'lwu',
        'lww': 'lww',
        'lww-Latn-VU': 'lww',
        'lww-Latn': 'lww',
        'lww-VU': 'lww',
        'lya': 'lya',
        'lya-Zyyy-BT': 'lya',
        'lya-BT': 'lya',
        'lya-Zyyy': 'lya',
        'lyg': 'lyg',
        'lyg-Zyyy-IN': 'lyg',
        'lyg-IN': 'lyg',
        'lyg-Zyyy': 'lyg',
        'lyn': 'lyn',
        'lyn-Latn-ZM': 'lyn',
        'lyn-Latn': 'lyn',
        'lyn-ZM': 'lyn',
        'lzh': 'lzh',
        'lzh-Hans-CN': 'lzh',
        'lzh-CN': 'lzh',
        'lzh-Hans': 'lzh',
        'zh-lzh': 'lzh',
        'zh-lzh-CN': 'lzh',
        'lzh-Hant': 'lzh-Hant',
        'lzh-Hant-CN': 'lzh-Hant',
        'lzl': 'lzl',
        'lzl-Latn-VU': 'lzl',
        'lzl-Latn': 'lzl',
        'lzl-VU': 'lzl',
        'lzn': 'lzn',
        'lzn-Latn-MM': 'lzn',
        'lzn-Latn': 'lzn',
        'lzn-MM': 'lzn',
        'lzz': 'lzz',
        'lzz-Latn-TR': 'lzz',
        'lzz-Latn': 'lzz',
        'lzz-TR': 'lzz',
        'lzz-Geor': 'lzz-Geor',
        'lzz-Geor-TR': 'lzz-Geor',
        'maa': 'maa',
        'maa-Latn-MX': 'maa',
        'maa-Latn': 'maa',
        'maa-MX': 'maa',
        'mab': 'mab',
        'mab-Latn-MX': 'mab',
        'mab-Latn': 'mab',
        'mab-MX': 'mab',
        'mad': 'mad',
        'mad-Latn-ID': 'mad',
        'mad-ID': 'mad',
        'mad-Latn': 'mad',
        'mae': 'mae',
        'mae-Latn-NG': 'mae',
        'mae-Latn': 'mae',
        'mae-NG': 'mae',
        'maf': 'maf',
        'maf-Latn-CM': 'maf',
        'maf-CM': 'maf',
        'maf-Latn': 'maf',
        'mag': 'mag',
        'mag-Deva-IN': 'mag',
        'mag-Deva': 'mag',
        'mag-IN': 'mag',
        'mai': 'mai',
        'mai-Deva-IN': 'mai',
        'mai-Deva': 'mai',
        'mai-IN': 'mai',
        'mai-Kthi': 'mai-Kthi',
        'mai-Kthi-IN': 'mai-Kthi',
        'mai-Newa': 'mai-Newa',
        'mai-Newa-IN': 'mai-Newa',
        'mai-Tirh': 'mai-Tirh',
        'mai-Tirh-IN': 'mai-Tirh',
        'maj': 'maj',
        'maj-Latn-MX': 'maj',
        'maj-Latn': 'maj',
        'maj-MX': 'maj',
        'mak': 'mak',
        'mak-Latn-ID': 'mak',
        'mak-ID': 'mak',
        'mak-Latn': 'mak',
        'mak-Bugi': 'mak-Bugi',
        'mak-Bugi-ID': 'mak-Bugi',
        'mak-Maka': 'mak-Maka',
        'mak-Maka-ID': 'mak-Maka',
        'mam': 'mam',
        'mam-Latn-GT': 'mam',
        'mam-GT': 'mam',
        'mam-Latn': 'mam',
        'man': 'man',
        'man-Latn-GM': 'man',
        'man-GM': 'man',
        'man-Latn': 'man',
        'mnk': 'man',
        'mnk-GM': 'man',
        'mnk-Latn': 'man',
        'mnk-Latn-GM': 'man',
        'myq': 'man',
        'myq-GM': 'man',
        'myq-Latn': 'man',
        'myq-Latn-GM': 'man',
        'man-Arab': 'man-Arab',
        'man-Arab-GN': 'man-Arab',
        'emk-Arab': 'man-Arab',
        'emk-Arab-GN': 'man-Arab',
        'mnk-Arab': 'man-Arab',
        'mnk-Arab-GN': 'man-Arab',
        'man-GN': 'man-GN',
        'man-Nkoo-GN': 'man-GN',
        'emk-Nkoo': 'man-GN',
        'emk-Nkoo-GN': 'man-GN',
        'man-Nkoo': 'man-GN',
        'man-Latn-GN': 'man-Latn-GN',
        'emk-Latn': 'man-Latn-GN',
        'emk-Latn-GN': 'man-Latn-GN',
        'maq': 'maq',
        'maq-Latn-MX': 'maq',
        'maq-Latn': 'maq',
        'maq-MX': 'maq',
        'mas': 'mas',
        'mas-Latn-KE': 'mas',
        'mas-KE': 'mas',
        'mas-Latn': 'mas',
        'mas-TZ': 'mas-TZ',
        'mas-Latn-TZ': 'mas-TZ',
        'mat': 'mat',
        'mat-Latn-MX': 'mat',
        'mat-Latn': 'mat',
        'mat-MX': 'mat',
        'mau': 'mau',
        'mau-Latn-MX': 'mau',
        'mau-Latn': 'mau',
        'mau-MX': 'mau',
        'mav': 'mav',
        'mav-Latn-BR': 'mav',
        'mav-BR': 'mav',
        'mav-Latn': 'mav',
        'maw': 'maw',
        'maw-Latn-GH': 'maw',
        'maw-GH': 'maw',
        'maw-Latn': 'maw',
        'maw-Arab': 'maw-Arab',
        'maw-Arab-GH': 'maw-Arab',
        'max': 'max',
        'max-Latn-ID': 'max',
        'max-ID': 'max',
        'max-Latn': 'max',
        'ms-max': 'max',
        'ms-max-ID': 'max',
        'maz': 'maz',
        'maz-Latn-MX': 'maz',
        'maz-Latn': 'maz',
        'maz-MX': 'maz',
        'mba': 'mba',
        'mba-Latn-PH': 'mba',
        'mba-Latn': 'mba',
        'mba-PH': 'mba',
        'mbb': 'mbb',
        'mbb-Latn-PH': 'mbb',
        'mbb-Latn': 'mbb',
        'mbb-PH': 'mbb',
        'mbc': 'mbc',
        'mbc-Latn-BR': 'mbc',
        'mbc-BR': 'mbc',
        'mbc-Latn': 'mbc',
        'mbd': 'mbd',
        'mbd-Latn-PH': 'mbd',
        'mbd-Latn': 'mbd',
        'mbd-PH': 'mbd',
        'mbe': 'mbe',
        'mbe-Zyyy-US': 'mbe',
        'mbe-US': 'mbe',
        'mbe-Zyyy': 'mbe',
        'mbf': 'mbf',
        'mbf-Latn-SG': 'mbf',
        'mbf-Latn': 'mbf',
        'mbf-SG': 'mbf',
        'mbh': 'mbh',
        'mbh-Latn-PG': 'mbh',
        'mbh-Latn': 'mbh',
        'mbh-PG': 'mbh',
        'mbi': 'mbi',
        'mbi-Latn-PH': 'mbi',
        'mbi-Latn': 'mbi',
        'mbi-PH': 'mbi',
        'mbj': 'mbj',
        'mbj-Latn-BR': 'mbj',
        'mbj-BR': 'mbj',
        'mbj-Latn': 'mbj',
        'mbk': 'mbk',
        'mbk-Latn-PG': 'mbk',
        'mbk-Latn': 'mbk',
        'mbk-PG': 'mbk',
        'mbl': 'mbl',
        'mbl-Latn-BR': 'mbl',
        'mbl-BR': 'mbl',
        'mbl-Latn': 'mbl',
        'mbm': 'mbm',
        'mbm-Latn-CG': 'mbm',
        'mbm-CG': 'mbm',
        'mbm-Latn': 'mbm',
        'mbn': 'mbn',
        'mbn-Latn-CO': 'mbn',
        'mbn-CO': 'mbn',
        'mbn-Latn': 'mbn',
        'mbo': 'mbo',
        'mbo-Latn-CM': 'mbo',
        'mbo-CM': 'mbo',
        'mbo-Latn': 'mbo',
        'mbp': 'mbp',
        'mbp-Latn-CO': 'mbp',
        'mbp-CO': 'mbp',
        'mbp-Latn': 'mbp',
        'mbq': 'mbq',
        'mbq-Latn-PG': 'mbq',
        'mbq-Latn': 'mbq',
        'mbq-PG': 'mbq',
        'mbr': 'mbr',
        'mbr-Latn-CO': 'mbr',
        'mbr-CO': 'mbr',
        'mbr-Latn': 'mbr',
        'mbs': 'mbs',
        'mbs-Latn-PH': 'mbs',
        'mbs-Latn': 'mbs',
        'mbs-PH': 'mbs',
        'mbt': 'mbt',
        'mbt-Latn-PH': 'mbt',
        'mbt-Latn': 'mbt',
        'mbt-PH': 'mbt',
        'mbu': 'mbu',
        'mbu-Latn-NG': 'mbu',
        'mbu-Latn': 'mbu',
        'mbu-NG': 'mbu',
        'mbv': 'mbv',
        'mbv-Latn-GN': 'mbv',
        'mbv-GN': 'mbv',
        'mbv-Latn': 'mbv',
        'mbw': 'mbw',
        'mbw-Latn-PG': 'mbw',
        'mbw-Latn': 'mbw',
        'mbw-PG': 'mbw',
        'mbx': 'mbx',
        'mbx-Latn-PG': 'mbx',
        'mbx-Latn': 'mbx',
        'mbx-PG': 'mbx',
        'mby': 'mby',
        'mby-Arab-PK': 'mby',
        'mby-Arab': 'mby',
        'mby-PK': 'mby',
        'mbz': 'mbz',
        'mbz-Latn-MX': 'mbz',
        'mbz-Latn': 'mbz',
        'mbz-MX': 'mbz',
        'mca': 'mca',
        'mca-Latn-PY': 'mca',
        'mca-Latn': 'mca',
        'mca-PY': 'mca',
        'mcb': 'mcb',
        'mcb-Latn-PE': 'mcb',
        'mcb-Latn': 'mcb',
        'mcb-PE': 'mcb',
        'mcc': 'mcc',
        'mcc-Latn-PG': 'mcc',
        'mcc-Latn': 'mcc',
        'mcc-PG': 'mcc',
        'mcd': 'mcd',
        'mcd-Latn-PE': 'mcd',
        'mcd-Latn': 'mcd',
        'mcd-PE': 'mcd',
        'mce': 'mce',
        'mce-Latn-MX': 'mce',
        'mce-Latn': 'mce',
        'mce-MX': 'mce',
        'mcf': 'mcf',
        'mcf-Latn-PE': 'mcf',
        'mcf-Latn': 'mcf',
        'mcf-PE': 'mcf',
        'mcg': 'mcg',
        'mcg-Latn-VE': 'mcg',
        'mcg-Latn': 'mcg',
        'mcg-VE': 'mcg',
        'mch': 'mch',
        'mch-Latn-VE': 'mch',
        'mch-Latn': 'mch',
        'mch-VE': 'mch',
        'mci': 'mci',
        'mci-Latn-PG': 'mci',
        'mci-Latn': 'mci',
        'mci-PG': 'mci',
        'mcj': 'mcj',
        'mcj-Latn-NG': 'mcj',
        'mcj-Latn': 'mcj',
        'mcj-NG': 'mcj',
        'mck': 'mck',
        'mck-Latn-AO': 'mck',
        'mck-AO': 'mck',
        'mck-Latn': 'mck',
        'mcl': 'mcl',
        'mcl-Latn-CO': 'mcl',
        'mcl-CO': 'mcl',
        'mcl-Latn': 'mcl',
        'mcm': 'mcm',
        'mcm-Latn-MY': 'mcm',
        'mcm-Latn': 'mcm',
        'mcm-MY': 'mcm',
        'mcn': 'mcn',
        'mcn-Latn-TD': 'mcn',
        'mcn-Latn': 'mcn',
        'mcn-TD': 'mcn',
        'mco': 'mco',
        'mco-Latn-MX': 'mco',
        'mco-Latn': 'mco',
        'mco-MX': 'mco',
        'mcp': 'mcp',
        'mcp-Latn-CM': 'mcp',
        'mcp-CM': 'mcp',
        'mcp-Latn': 'mcp',
        'mcq': 'mcq',
        'mcq-Latn-PG': 'mcq',
        'mcq-Latn': 'mcq',
        'mcq-PG': 'mcq',
        'mcr': 'mcr',
        'mcr-Latn-PG': 'mcr',
        'mcr-Latn': 'mcr',
        'mcr-PG': 'mcr',
        'mcs': 'mcs',
        'mcs-Latn-CM': 'mcs',
        'mcs-CM': 'mcs',
        'mcs-Latn': 'mcs',
        'mct': 'mct',
        'mct-Latn-CM': 'mct',
        'mct-CM': 'mct',
        'mct-Latn': 'mct',
        'mcu': 'mcu',
        'mcu-Latn-CM': 'mcu',
        'mcu-CM': 'mcu',
        'mcu-Latn': 'mcu',
        'mcu-Laoo-CM': 'mcu-Laoo-CM',
        'mcv': 'mcv',
        'mcv-Latn-PG': 'mcv',
        'mcv-Latn': 'mcv',
        'mcv-PG': 'mcv',
        'mcw': 'mcw',
        'mcw-Latn-TD': 'mcw',
        'mcw-Latn': 'mcw',
        'mcw-TD': 'mcw',
        'mcx': 'mcx',
        'mcx-Latn-CF': 'mcx',
        'mcx-CF': 'mcx',
        'mcx-Latn': 'mcx',
        'mcy': 'mcy',
        'mcy-Latn-PG': 'mcy',
        'mcy-Latn': 'mcy',
        'mcy-PG': 'mcy',
        'mcz': 'mcz',
        'mcz-Latn-PG': 'mcz',
        'mcz-Latn': 'mcz',
        'mcz-PG': 'mcz',
        'mda': 'mda',
        'mda-Latn-NG': 'mda',
        'mda-Latn': 'mda',
        'mda-NG': 'mda',
        'mdb': 'mdb',
        'mdb-Latn-PG': 'mdb',
        'mdb-Latn': 'mdb',
        'mdb-PG': 'mdb',
        'mdc': 'mdc',
        'mdc-Latn-PG': 'mdc',
        'mdc-Latn': 'mdc',
        'mdc-PG': 'mdc',
        'mdd': 'mdd',
        'mdd-Latn-CM': 'mdd',
        'mdd-CM': 'mdd',
        'mdd-Latn': 'mdd',
        'mde': 'mde',
        'mde-Arab-TD': 'mde',
        'mde-Arab': 'mde',
        'mde-TD': 'mde',
        'mde-Latn': 'mde-Latn',
        'mde-Latn-TD': 'mde-Latn',
        'mdf': 'mdf',
        'mdf-Cyrl-RU': 'mdf',
        'mdf-Cyrl': 'mdf',
        'mdf-RU': 'mdf',
        'mdg': 'mdg',
        'mdg-Latn-TD': 'mdg',
        'mdg-Latn': 'mdg',
        'mdg-TD': 'mdg',
        'mdh': 'mdh',
        'mdh-Latn-PH': 'mdh',
        'mdh-Latn': 'mdh',
        'mdh-PH': 'mdh',
        'mdi': 'mdi',
        'mdi-Latn-CD': 'mdi',
        'mdi-CD': 'mdi',
        'mdi-Latn': 'mdi',
        'mdj': 'mdj',
        'mdj-Latn-CD': 'mdj',
        'mdj-CD': 'mdj',
        'mdj-Latn': 'mdj',
        'mdk': 'mdk',
        'mdk-Latn-CD': 'mdk',
        'mdk-CD': 'mdk',
        'mdk-Latn': 'mdk',
        'mdl': 'mdl',
        'mdl-Zxxx-MT': 'mdl',
        'mdl-MT': 'mdl',
        'mdl-Zxxx': 'mdl',
        'sgn-mdl': 'mdl',
        'sgn-mdl-MT': 'mdl',
        'mdm': 'mdm',
        'mdm-Latn-CD': 'mdm',
        'mdm-CD': 'mdm',
        'mdm-Latn': 'mdm',
        'mdn': 'mdn',
        'mdn-Latn-CF': 'mdn',
        'mdn-CF': 'mdn',
        'mdn-Latn': 'mdn',
        'mdp': 'mdp',
        'mdp-Latn-CD': 'mdp',
        'mdp-CD': 'mdp',
        'mdp-Latn': 'mdp',
        'mdq': 'mdq',
        'mdq-Latn-CD': 'mdq',
        'mdq-CD': 'mdq',
        'mdq-Latn': 'mdq',
        'mdr': 'mdr',
        'mdr-Latn-ID': 'mdr',
        'mdr-ID': 'mdr',
        'mdr-Latn': 'mdr',
        'mdr-Bugi': 'mdr-Bugi',
        'mdr-Bugi-ID': 'mdr-Bugi',
        'mds': 'mds',
        'mds-Latn-PG': 'mds',
        'mds-Latn': 'mds',
        'mds-PG': 'mds',
        'mdt': 'mdt',
        'mdt-Latn-CG': 'mdt',
        'mdt-CG': 'mdt',
        'mdt-Latn': 'mdt',
        'mdu': 'mdu',
        'mdu-Latn-CG': 'mdu',
        'mdu-CG': 'mdu',
        'mdu-Latn': 'mdu',
        'mdv': 'mdv',
        'mdv-Latn-MX': 'mdv',
        'mdv-Latn': 'mdv',
        'mdv-MX': 'mdv',
        'mdw': 'mdw',
        'mdw-Latn-CG': 'mdw',
        'mdw-CG': 'mdw',
        'mdw-Latn': 'mdw',
        'mdx': 'mdx',
        'mdx-Ethi-ET': 'mdx',
        'mdx-ET': 'mdx',
        'mdx-Ethi': 'mdx',
        'mdx-Latn': 'mdx-Latn',
        'mdx-Latn-ET': 'mdx-Latn',
        'mdy': 'mdy',
        'mdy-Ethi-ET': 'mdy',
        'mdy-ET': 'mdy',
        'mdy-Ethi': 'mdy',
        'mdy-Latn': 'mdy-Latn',
        'mdy-Latn-ET': 'mdy-Latn',
        'mdz': 'mdz',
        'mdz-Latn-BR': 'mdz',
        'mdz-BR': 'mdz',
        'mdz-Latn': 'mdz',
        'mea': 'mea',
        'mea-Latn-CM': 'mea',
        'mea-CM': 'mea',
        'mea-Latn': 'mea',
        'meb': 'meb',
        'meb-Latn-PG': 'meb',
        'meb-Latn': 'meb',
        'meb-PG': 'meb',
        'mec': 'mec',
        'mec-Latn-AU': 'mec',
        'mec-AU': 'mec',
        'mec-Latn': 'mec',
        'med': 'med',
        'med-Latn-PG': 'med',
        'med-Latn': 'med',
        'med-PG': 'med',
        'mee': 'mee',
        'mee-Latn-PG': 'mee',
        'mee-Latn': 'mee',
        'mee-PG': 'mee',
        'mef': 'mef',
        'mef-Zyyy-BD': 'mef',
        'mef-BD': 'mef',
        'mef-Zyyy': 'mef',
        'meh': 'meh',
        'meh-Latn-MX': 'meh',
        'meh-Latn': 'meh',
        'meh-MX': 'meh',
        'mei': 'mei',
        'mei-Zyyy-SD': 'mei',
        'mei-SD': 'mei',
        'mei-Zyyy': 'mei',
        'mej': 'mej',
        'mej-Latn-ID': 'mej',
        'mej-ID': 'mej',
        'mej-Latn': 'mej',
        'mek': 'mek',
        'mek-Latn-PG': 'mek',
        'mek-Latn': 'mek',
        'mek-PG': 'mek',
        'mel': 'mel',
        'mel-Latn-MY': 'mel',
        'mel-Latn': 'mel',
        'mel-MY': 'mel',
        'mem': 'mem',
        'mem-Latn-AU': 'mem',
        'mem-AU': 'mem',
        'mem-Latn': 'mem',
        'men': 'men',
        'men-Latn-SL': 'men',
        'men-Latn': 'men',
        'men-SL': 'men',
        'men-Mend': 'men-Mend',
        'men-Mend-SL': 'men-Mend',
        'meo': 'meo',
        'meo-Latn-MY': 'meo',
        'meo-Latn': 'meo',
        'meo-MY': 'meo',
        'ms-meo': 'meo',
        'ms-meo-MY': 'meo',
        'meo-Arab': 'meo-Arab',
        'meo-Arab-MY': 'meo-Arab',
        'mep': 'mep',
        'mep-Latn-AU': 'mep',
        'mep-AU': 'mep',
        'mep-Latn': 'mep',
        'meq': 'meq',
        'meq-Latn-CM': 'meq',
        'meq-CM': 'meq',
        'meq-Latn': 'meq',
        'mer': 'mer',
        'mer-Latn-KE': 'mer',
        'mer-KE': 'mer',
        'mer-Latn': 'mer',
        'mes': 'mes',
        'mes-Latn-TD': 'mes',
        'mes-Latn': 'mes',
        'mes-TD': 'mes',
        'met': 'met',
        'met-Latn-PG': 'met',
        'met-Latn': 'met',
        'met-PG': 'met',
        'meu': 'meu',
        'meu-Latn-PG': 'meu',
        'meu-Latn': 'meu',
        'meu-PG': 'meu',
        'mev': 'mev',
        'mev-Latn-LR': 'mev',
        'mev-LR': 'mev',
        'mev-Latn': 'mev',
        'mew': 'mew',
        'mew-Latn-NG': 'mew',
        'mew-Latn': 'mew',
        'mew-NG': 'mew',
        'mey': 'mey',
        'mey-Latn-MR': 'mey',
        'mey-Latn': 'mey',
        'mey-MR': 'mey',
        'mey-Arab': 'mey-Arab',
        'mey-Arab-MR': 'mey-Arab',
        'mez': 'mez',
        'mez-Latn-US': 'mez',
        'mez-Latn': 'mez',
        'mez-US': 'mez',
        'mfa': 'mfa',
        'mfa-Arab-TH': 'mfa',
        'mfa-Arab': 'mfa',
        'mfa-TH': 'mfa',
        'ms-mfa': 'mfa',
        'ms-mfa-TH': 'mfa',
        'mfa-Thai': 'mfa-Thai',
        'mfa-Thai-TH': 'mfa-Thai',
        'mfb': 'mfb',
        'mfb-Latn-ID': 'mfb',
        'mfb-ID': 'mfb',
        'mfb-Latn': 'mfb',
        'ms-mfb': 'mfb',
        'ms-mfb-ID': 'mfb',
        'mfc': 'mfc',
        'mfc-Latn-CD': 'mfc',
        'mfc-CD': 'mfc',
        'mfc-Latn': 'mfc',
        'mfd': 'mfd',
        'mfd-Latn-CM': 'mfd',
        'mfd-CM': 'mfd',
        'mfd-Latn': 'mfd',
        'mfe': 'mfe',
        'mfe-Latn-MU': 'mfe',
        'mfe-Latn': 'mfe',
        'mfe-MU': 'mfe',
        'mff': 'mff',
        'mff-Latn-CM': 'mff',
        'mff-CM': 'mff',
        'mff-Latn': 'mff',
        'mfg': 'mfg',
        'mfg-Arab-GN': 'mfg',
        'mfg-Arab': 'mfg',
        'mfg-GN': 'mfg',
        'mfh': 'mfh',
        'mfh-Latn-CM': 'mfh',
        'mfh-CM': 'mfh',
        'mfh-Latn': 'mfh',
        'mfi': 'mfi',
        'mfi-Arab-CM': 'mfi',
        'mfi-Arab': 'mfi',
        'mfi-CM': 'mfi',
        'mfi-Latn': 'mfi-Latn',
        'mfi-Latn-CM': 'mfi-Latn',
        'mfj': 'mfj',
        'mfj-Latn-CM': 'mfj',
        'mfj-CM': 'mfj',
        'mfj-Latn': 'mfj',
        'mfk': 'mfk',
        'mfk-Latn-CM': 'mfk',
        'mfk-CM': 'mfk',
        'mfk-Latn': 'mfk',
        'mfl': 'mfl',
        'mfl-Latn-NG': 'mfl',
        'mfl-Latn': 'mfl',
        'mfl-NG': 'mfl',
        'mfm': 'mfm',
        'mfm-Latn-NG': 'mfm',
        'mfm-Latn': 'mfm',
        'mfm-NG': 'mfm',
        'mfn': 'mfn',
        'mfn-Latn-NG': 'mfn',
        'mfn-Latn': 'mfn',
        'mfn-NG': 'mfn',
        'mfo': 'mfo',
        'mfo-Latn-NG': 'mfo',
        'mfo-Latn': 'mfo',
        'mfo-NG': 'mfo',
        'mfp': 'mfp',
        'mfp-Latn-ID': 'mfp',
        'mfp-ID': 'mfp',
        'mfp-Latn': 'mfp',
        'mfq': 'mfq',
        'mfq-Latn-TG': 'mfq',
        'mfq-Latn': 'mfq',
        'mfq-TG': 'mfq',
        'mfr': 'mfr',
        'mfr-Latn-AU': 'mfr',
        'mfr-AU': 'mfr',
        'mfr-Latn': 'mfr',
        'mfs': 'mfs',
        'mfs-Zxxx-MX': 'mfs',
        'mfs-MX': 'mfs',
        'mfs-Zxxx': 'mfs',
        'sgn-mfs': 'mfs',
        'sgn-mfs-MX': 'mfs',
        'mft': 'mft',
        'mft-Latn-PG': 'mft',
        'mft-Latn': 'mft',
        'mft-PG': 'mft',
        'mfu': 'mfu',
        'mfu-Latn-AO': 'mfu',
        'mfu-AO': 'mfu',
        'mfu-Latn': 'mfu',
        'mfv': 'mfv',
        'mfv-Latn-GW': 'mfv',
        'mfv-GW': 'mfv',
        'mfv-Latn': 'mfv',
        'mfw': 'mfw',
        'mfw-Latn-PG': 'mfw',
        'mfw-Latn': 'mfw',
        'mfw-PG': 'mfw',
        'mfx': 'mfx',
        'mfx-Zyyy-ET': 'mfx',
        'mfx-ET': 'mfx',
        'mfx-Zyyy': 'mfx',
        'mfy': 'mfy',
        'mfy-Latn-MX': 'mfy',
        'mfy-Latn': 'mfy',
        'mfy-MX': 'mfy',
        'mfz': 'mfz',
        'mfz-Latn-SS': 'mfz',
        'mfz-Latn': 'mfz',
        'mfz-SS': 'mfz',
        'mg': 'mg',
        'mg-Latn-MG': 'mg',
        'bjq': 'mg',
        'bjq-Latn': 'mg',
        'bjq-Latn-MG': 'mg',
        'bjq-MG': 'mg',
        'mg-Latn': 'mg',
        'mg-MG': 'mg',
        'plt': 'mg',
        'plt-Latn': 'mg',
        'plt-Latn-MG': 'mg',
        'plt-MG': 'mg',
        'mg-Arab': 'mg-Arab',
        'mg-Arab-MG': 'mg-Arab',
        'mg-Brai': 'mg-Brai',
        'mg-Brai-MG': 'mg-Brai',
        'plt-Brai': 'mg-Brai',
        'plt-Brai-MG': 'mg-Brai',
        'mga': 'mga',
        'mga-Latg-IE': 'mga',
        'mga-IE': 'mga',
        'mga-Latg': 'mga',
        'mgb': 'mgb',
        'mgb-Latn-TD': 'mgb',
        'mgb-Latn': 'mgb',
        'mgb-TD': 'mgb',
        'mgc': 'mgc',
        'mgc-Latn-SS': 'mgc',
        'mgc-Latn': 'mgc',
        'mgc-SS': 'mgc',
        'mgd': 'mgd',
        'mgd-Latn-SS': 'mgd',
        'mgd-Latn': 'mgd',
        'mgd-SS': 'mgd',
        'mgd-Arab': 'mgd-Arab',
        'mgd-Arab-SS': 'mgd-Arab',
        'mge': 'mge',
        'mge-Latn-TD': 'mge',
        'mge-Latn': 'mge',
        'mge-TD': 'mge',
        'mgf': 'mgf',
        'mgf-Latn-ID': 'mgf',
        'mgf-ID': 'mgf',
        'mgf-Latn': 'mgf',
        'mgg': 'mgg',
        'mgg-Latn-CM': 'mgg',
        'mgg-CM': 'mgg',
        'mgg-Latn': 'mgg',
        'mgh': 'mgh',
        'mgh-Latn-MZ': 'mgh',
        'mgh-Latn': 'mgh',
        'mgh-MZ': 'mgh',
        'mgi': 'mgi',
        'mgi-Latn-NG': 'mgi',
        'mgi-Latn': 'mgi',
        'mgi-NG': 'mgi',
        'mgj': 'mgj',
        'mgj-Latn-NG': 'mgj',
        'mgj-Latn': 'mgj',
        'mgj-NG': 'mgj',
        'mgk': 'mgk',
        'mgk-Latn-ID': 'mgk',
        'mgk-ID': 'mgk',
        'mgk-Latn': 'mgk',
        'mgl': 'mgl',
        'mgl-Latn-PG': 'mgl',
        'mgl-Latn': 'mgl',
        'mgl-PG': 'mgl',
        'mgm': 'mgm',
        'mgm-Latn-TL': 'mgm',
        'mgm-Latn': 'mgm',
        'mgm-TL': 'mgm',
        'mgn': 'mgn',
        'mgn-Latn-CF': 'mgn',
        'mgn-CF': 'mgn',
        'mgn-Latn': 'mgn',
        'mgo': 'mgo',
        'mgo-Latn-CM': 'mgo',
        'mgo-CM': 'mgo',
        'mgo-Latn': 'mgo',
        'mgp': 'mgp',
        'mgp-Deva-NP': 'mgp',
        'mgp-Deva': 'mgp',
        'mgp-NP': 'mgp',
        'mgp-Brah-x-akkha': 'mgp-Brah-x-akkha',
        'mgp-Brah-NP-x-akkha': 'mgp-Brah-x-akkha',
        'mgp-NP-x-akkha': 'mgp-Brah-x-akkha',
        'mgq': 'mgq',
        'mgq-Latn-TZ': 'mgq',
        'mgq-Latn': 'mgq',
        'mgq-TZ': 'mgq',
        'mgr': 'mgr',
        'mgr-Latn-ZM': 'mgr',
        'mgr-Latn': 'mgr',
        'mgr-ZM': 'mgr',
        'mgs': 'mgs',
        'mgs-Latn-TZ': 'mgs',
        'mgs-Latn': 'mgs',
        'mgs-TZ': 'mgs',
        'mgt': 'mgt',
        'mgt-Latn-PG': 'mgt',
        'mgt-Latn': 'mgt',
        'mgt-PG': 'mgt',
        'mgu': 'mgu',
        'mgu-Latn-PG': 'mgu',
        'mgu-Latn': 'mgu',
        'mgu-PG': 'mgu',
        'mgv': 'mgv',
        'mgv-Latn-TZ': 'mgv',
        'mgv-Latn': 'mgv',
        'mgv-TZ': 'mgv',
        'mgw': 'mgw',
        'mgw-Latn-TZ': 'mgw',
        'mgw-Latn': 'mgw',
        'mgw-TZ': 'mgw',
        'mgy': 'mgy',
        'mgy-Latn-TZ': 'mgy',
        'mgy-Latn': 'mgy',
        'mgy-TZ': 'mgy',
        'mgz': 'mgz',
        'mgz-Latn-TZ': 'mgz',
        'mgz-Latn': 'mgz',
        'mgz-TZ': 'mgz',
        'mh': 'mh',
        'mh-Latn-MH': 'mh',
        'mh-Latn': 'mh',
        'mh-MH': 'mh',
        'mha': 'mha',
        'mha-Zyyy-IN': 'mha',
        'mha-IN': 'mha',
        'mha-Zyyy': 'mha',
        'mhb': 'mhb',
        'mhb-Latn-GA': 'mhb',
        'mhb-GA': 'mhb',
        'mhb-Latn': 'mhb',
        'mhc': 'mhc',
        'mhc-Latn-MX': 'mhc',
        'mhc-Latn': 'mhc',
        'mhc-MX': 'mhc',
        'mhd': 'mhd',
        'mhd-Latn-TZ': 'mhd',
        'mhd-Latn': 'mhd',
        'mhd-TZ': 'mhd',
        'mhe': 'mhe',
        'mhe-Latn-MY': 'mhe',
        'mhe-Latn': 'mhe',
        'mhe-MY': 'mhe',
        'mhf': 'mhf',
        'mhf-Latn-PG': 'mhf',
        'mhf-Latn': 'mhf',
        'mhf-PG': 'mhf',
        'mhg': 'mhg',
        'mhg-Latn-AU': 'mhg',
        'mhg-AU': 'mhg',
        'mhg-Latn': 'mhg',
        'mhi': 'mhi',
        'mhi-Latn-UG': 'mhi',
        'mhi-Latn': 'mhi',
        'mhi-UG': 'mhi',
        'mhj': 'mhj',
        'mhj-Arab-AF': 'mhj',
        'mhj-AF': 'mhj',
        'mhj-Arab': 'mhj',
        'mhk': 'mhk',
        'mhk-Latn-CM': 'mhk',
        'mhk-CM': 'mhk',
        'mhk-Latn': 'mhk',
        'mhl': 'mhl',
        'mhl-Latn-PG': 'mhl',
        'mhl-Latn': 'mhl',
        'mhl-PG': 'mhl',
        'mhm': 'mhm',
        'mhm-Latn-MZ': 'mhm',
        'mhm-Latn': 'mhm',
        'mhm-MZ': 'mhm',
        'mhn': 'mhn',
        'mhn-Latn-IT': 'mhn',
        'mhn-IT': 'mhn',
        'mhn-Latn': 'mhn',
        'mho': 'mho',
        'mho-Latn-ZM': 'mho',
        'mho-Latn': 'mho',
        'mho-ZM': 'mho',
        'mhp': 'mhp',
        'mhp-Latn-ID': 'mhp',
        'mhp-ID': 'mhp',
        'mhp-Latn': 'mhp',
        'mhq': 'mhq',
        'mhq-Latn-US': 'mhq',
        'mhq-Latn': 'mhq',
        'mhq-US': 'mhq',
        'mhs': 'mhs',
        'mhs-Latn-ID': 'mhs',
        'mhs-ID': 'mhs',
        'mhs-Latn': 'mhs',
        'mht': 'mht',
        'mht-Latn-VE': 'mht',
        'mht-Latn': 'mht',
        'mht-VE': 'mht',
        'mhu': 'mhu',
        'mhu-Latn-IN': 'mhu',
        'mhu-IN': 'mhu',
        'mhu-Latn': 'mhu',
        'mhw': 'mhw',
        'mhw-Latn-BW': 'mhw',
        'mhw-BW': 'mhw',
        'mhw-Latn': 'mhw',
        'mhx': 'mhx',
        'mhx-Latn-MM': 'mhx',
        'mhx-Latn': 'mhx',
        'mhx-MM': 'mhx',
        'mhy': 'mhy',
        'mhy-Latn-ID': 'mhy',
        'mhy-ID': 'mhy',
        'mhy-Latn': 'mhy',
        'mhz': 'mhz',
        'mhz-Latn-ID': 'mhz',
        'mhz-ID': 'mhz',
        'mhz-Latn': 'mhz',
        'mi': 'mi',
        'mi-Latn-NZ': 'mi',
        'mi-Latn': 'mi',
        'mi-NZ': 'mi',
        'mia': 'mia',
        'mia-Latn-US': 'mia',
        'mia-Latn': 'mia',
        'mia-US': 'mia',
        'mib': 'mib',
        'mib-Latn-MX': 'mib',
        'mib-Latn': 'mib',
        'mib-MX': 'mib',
        'mic': 'mic',
        'mic-Latn-CA': 'mic',
        'mic-CA': 'mic',
        'mic-Latn': 'mic',
        'mic-Zzzz-x-kauder': 'mic-Zzzz-x-kauder',
        'mic-Zzzz-CA-x-kauder': 'mic-Zzzz-x-kauder',
        'mic-CA-x-kauder': 'mic-Zzzz-x-kauder',
        'mid': 'mid',
        'mid-Mand-IQ': 'mid',
        'mid-IQ': 'mid',
        'mid-Mand': 'mid',
        'mie': 'mie',
        'mie-Latn-MX': 'mie',
        'mie-Latn': 'mie',
        'mie-MX': 'mie',
        'mif': 'mif',
        'mif-Latn-CM': 'mif',
        'mif-CM': 'mif',
        'mif-Latn': 'mif',
        'mig': 'mig',
        'mig-Latn-MX': 'mig',
        'mig-Latn': 'mig',
        'mig-MX': 'mig',
        'mih': 'mih',
        'mih-Latn-MX': 'mih',
        'mih-Latn': 'mih',
        'mih-MX': 'mih',
        'mii': 'mii',
        'mii-Latn-MX': 'mii',
        'mii-Latn': 'mii',
        'mii-MX': 'mii',
        'mij': 'mij',
        'mij-Latn-CM': 'mij',
        'mij-CM': 'mij',
        'mij-Latn': 'mij',
        'mik': 'mik',
        'mik-Latn-US': 'mik',
        'mik-Latn': 'mik',
        'mik-US': 'mik',
        'mil': 'mil',
        'mil-Latn-MX': 'mil',
        'mil-Latn': 'mil',
        'mil-MX': 'mil',
        'mim': 'mim',
        'mim-Latn-MX': 'mim',
        'mim-Latn': 'mim',
        'mim-MX': 'mim',
        'min': 'min',
        'min-Latn-ID': 'min',
        'min-ID': 'min',
        'min-Latn': 'min',
        'ms-min': 'min',
        'ms-min-ID': 'min',
        'min-Arab': 'min-Arab',
        'min-Arab-ID': 'min-Arab',
        'mio': 'mio',
        'mio-Latn-MX': 'mio',
        'mio-Latn': 'mio',
        'mio-MX': 'mio',
        'mip': 'mip',
        'mip-Latn-MX': 'mip',
        'mip-Latn': 'mip',
        'mip-MX': 'mip',
        'miq': 'miq',
        'miq-Latn-NI': 'miq',
        'miq-Latn': 'miq',
        'miq-NI': 'miq',
        'mir': 'mir',
        'mir-Latn-MX': 'mir',
        'mir-Latn': 'mir',
        'mir-MX': 'mir',
        'mis': 'mis',
        'mis-Hatr-IQ': 'mis',
        'mis-Hatr': 'mis',
        'mis-IQ': 'mis',
        'mit': 'mit',
        'mit-Latn-MX': 'mit',
        'mit-Latn': 'mit',
        'mit-MX': 'mit',
        'miu': 'miu',
        'miu-Latn-MX': 'miu',
        'miu-Latn': 'miu',
        'miu-MX': 'miu',
        'miw': 'miw',
        'miw-Latn-PG': 'miw',
        'miw-Latn': 'miw',
        'miw-PG': 'miw',
        'mix': 'mix',
        'mix-Latn-MX': 'mix',
        'mix-Latn': 'mix',
        'mix-MX': 'mix',
        'miy': 'miy',
        'miy-Latn-MX': 'miy',
        'miy-Latn': 'miy',
        'miy-MX': 'miy',
        'miz': 'miz',
        'miz-Latn-MX': 'miz',
        'miz-Latn': 'miz',
        'miz-MX': 'miz',
        'mjb': 'mjb',
        'mjb-Latn-TL': 'mjb',
        'mjb-Latn': 'mjb',
        'mjb-TL': 'mjb',
        'mjc': 'mjc',
        'mjc-Latn-MX': 'mjc',
        'mjc-Latn': 'mjc',
        'mjc-MX': 'mjc',
        'mjd': 'mjd',
        'mjd-Latn-US': 'mjd',
        'mjd-Latn': 'mjd',
        'mjd-US': 'mjd',
        'mje': 'mje',
        'mje-Latn-TD': 'mje',
        'mje-Latn': 'mje',
        'mje-TD': 'mje',
        'mjg': 'mjg',
        'mjg-Latn-CN': 'mjg',
        'mjg-CN': 'mjg',
        'mjg-Latn': 'mjg',
        'mjh': 'mjh',
        'mjh-Latn-TZ': 'mjh',
        'mjh-Latn': 'mjh',
        'mjh-TZ': 'mjh',
        'mji': 'mji',
        'mji-Latn-CN': 'mji',
        'mji-CN': 'mji',
        'mji-Latn': 'mji',
        'mjj': 'mjj',
        'mjj-Latn-PG': 'mjj',
        'mjj-Latn': 'mjj',
        'mjj-PG': 'mjj',
        'mjk': 'mjk',
        'mjk-Latn-PG': 'mjk',
        'mjk-Latn': 'mjk',
        'mjk-PG': 'mjk',
        'mjl': 'mjl',
        'mjl-Deva-IN': 'mjl',
        'mjl-Deva': 'mjl',
        'mjl-IN': 'mjl',
        'mjl-Takr': 'mjl-Takr',
        'mjl-Takr-IN': 'mjl-Takr',
        'mjm': 'mjm',
        'mjm-Latn-PG': 'mjm',
        'mjm-Latn': 'mjm',
        'mjm-PG': 'mjm',
        'mjn': 'mjn',
        'mjn-Latn-PG': 'mjn',
        'mjn-Latn': 'mjn',
        'mjn-PG': 'mjn',
        'mjo': 'mjo',
        'mjo-Zyyy-IN': 'mjo',
        'mjo-IN': 'mjo',
        'mjo-Zyyy': 'mjo',
        'mjp': 'mjp',
        'mjp-Zyyy-IN': 'mjp',
        'mjp-IN': 'mjp',
        'mjp-Zyyy': 'mjp',
        'mjq': 'mjq',
        'mjq-Zyyy-IN': 'mjq',
        'mjq-IN': 'mjq',
        'mjq-Zyyy': 'mjq',
        'mjr': 'mjr',
        'mjr-Zyyy-IN': 'mjr',
        'mjr-IN': 'mjr',
        'mjr-Zyyy': 'mjr',
        'mjs': 'mjs',
        'mjs-Latn-NG': 'mjs',
        'mjs-Latn': 'mjs',
        'mjs-NG': 'mjs',
        'mjt': 'mjt',
        'mjt-Deva-IN': 'mjt',
        'mjt-Deva': 'mjt',
        'mjt-IN': 'mjt',
        'mjt-Beng': 'mjt-Beng',
        'mjt-Beng-BD': 'mjt-Beng',
        'mjt-BD': 'mjt-Beng',
        'mju': 'mju',
        'mju-Telu-IN': 'mju',
        'mju-IN': 'mju',
        'mju-Telu': 'mju',
        'mjv': 'mjv',
        'mjv-Mlym-IN': 'mjv',
        'mjv-IN': 'mjv',
        'mjv-Mlym': 'mjv',
        'mjw': 'mjw',
        'mjw-Latn-IN': 'mjw',
        'mjw-IN': 'mjw',
        'mjw-Latn': 'mjw',
        'mjx': 'mjx',
        'mjx-Latn-BD': 'mjx',
        'mjx-BD': 'mjx',
        'mjx-Latn': 'mjx',
        'mjy': 'mjy',
        'mjy-Zyyy-US': 'mjy',
        'mjy-US': 'mjy',
        'mjy-Zyyy': 'mjy',
        'mjz': 'mjz',
        'mjz-Deva-NP': 'mjz',
        'mjz-Deva': 'mjz',
        'mjz-NP': 'mjz',
        'mk': 'mk',
        'mk-Cyrl-MK': 'mk',
        'mk-Cyrl': 'mk',
        'mk-MK': 'mk',
        'mk-Brai': 'mk-Brai',
        'mk-Brai-MK': 'mk-Brai',
        'mka': 'mka',
        'mka-Latn-CI': 'mka',
        'mka-CI': 'mka',
        'mka-Latn': 'mka',
        'mkb': 'mkb',
        'mkb-Deva-IN': 'mkb',
        'mkb-Deva': 'mkb',
        'mkb-IN': 'mkb',
        'mkc': 'mkc',
        'mkc-Latn-PG': 'mkc',
        'mkc-Latn': 'mkc',
        'mkc-PG': 'mkc',
        'mke': 'mke',
        'mke-Deva-IN': 'mke',
        'mke-Deva': 'mke',
        'mke-IN': 'mke',
        'mkf': 'mkf',
        'mkf-Latn-NG': 'mkf',
        'mkf-Latn': 'mkf',
        'mkf-NG': 'mkf',
        'mkg': 'mkg',
        'mkg-Zyyy-CN': 'mkg',
        'mkg-CN': 'mkg',
        'mkg-Zyyy': 'mkg',
        'mki': 'mki',
        'mki-Arab-PK': 'mki',
        'mki-Arab': 'mki',
        'mki-PK': 'mki',
        'mkj': 'mkj',
        'mkj-Latn-FM': 'mkj',
        'mkj-FM': 'mkj',
        'mkj-Latn': 'mkj',
        'mkk': 'mkk',
        'mkk-Latn-CM': 'mkk',
        'mkk-CM': 'mkk',
        'mkk-Latn': 'mkk',
        'mkl': 'mkl',
        'mkl-Latn-BJ': 'mkl',
        'mkl-BJ': 'mkl',
        'mkl-Latn': 'mkl',
        'mkm': 'mkm',
        'mkm-Thai-TH': 'mkm',
        'mkm-TH': 'mkm',
        'mkm-Thai': 'mkm',
        'mkn': 'mkn',
        'mkn-Latn-ID': 'mkn',
        'mkn-ID': 'mkn',
        'mkn-Latn': 'mkn',
        'mko': 'mko',
        'mko-Latn-NG': 'mko',
        'mko-Latn': 'mko',
        'mko-NG': 'mko',
        'mkp': 'mkp',
        'mkp-Latn-PG': 'mkp',
        'mkp-Latn': 'mkp',
        'mkp-PG': 'mkp',
        'mkq': 'mkq',
        'mkq-Zyyy-US': 'mkq',
        'mkq-US': 'mkq',
        'mkq-Zyyy': 'mkq',
        'mkr': 'mkr',
        'mkr-Latn-PG': 'mkr',
        'mkr-Latn': 'mkr',
        'mkr-PG': 'mkr',
        'mks': 'mks',
        'mks-Latn-MX': 'mks',
        'mks-Latn': 'mks',
        'mks-MX': 'mks',
        'mkt': 'mkt',
        'mkt-Latn-NC': 'mkt',
        'mkt-Latn': 'mkt',
        'mkt-NC': 'mkt',
        'mku': 'mku',
        'mku-Latn-GN': 'mku',
        'mku-GN': 'mku',
        'mku-Latn': 'mku',
        'mkv': 'mkv',
        'mkv-Latn-VU': 'mkv',
        'mkv-Latn': 'mkv',
        'mkv-VU': 'mkv',
        'mkw': 'mkw',
        'mkw-Latn-CG': 'mkw',
        'mkw-CG': 'mkw',
        'mkw-Latn': 'mkw',
        'mkx': 'mkx',
        'mkx-Latn-PH': 'mkx',
        'mkx-Latn': 'mkx',
        'mkx-PH': 'mkx',
        'mky': 'mky',
        'mky-Latn-ID': 'mky',
        'mky-ID': 'mky',
        'mky-Latn': 'mky',
        'mkz': 'mkz',
        'mkz-Latn-TL': 'mkz',
        'mkz-Latn': 'mkz',
        'mkz-TL': 'mkz',
        'ml': 'ml',
        'ml-Mlym-IN': 'ml',
        'ml-IN': 'ml',
        'ml-Mlym': 'ml',
        'ml-Arab': 'ml-Arab',
        'ml-Arab-IN': 'ml-Arab',
        'ml-Brai': 'ml-Brai',
        'ml-Brai-IN': 'ml-Brai',
        'mla': 'mla',
        'mla-Latn-VU': 'mla',
        'mla-Latn': 'mla',
        'mla-VU': 'mla',
        'mlb': 'mlb',
        'mlb-Latn-CM': 'mlb',
        'mlb-CM': 'mlb',
        'mlb-Latn': 'mlb',
        'mlc': 'mlc',
        'mlc-Latn-VN': 'mlc',
        'mlc-Latn': 'mlc',
        'mlc-VN': 'mlc',
        'mle': 'mle',
        'mle-Latn-PG': 'mle',
        'mle-Latn': 'mle',
        'mle-PG': 'mle',
        'mlf': 'mlf',
        'mlf-Thai-LA': 'mlf',
        'mlf-LA': 'mlf',
        'mlf-Thai': 'mlf',
        'mlf-Latn': 'mlf-Latn',
        'mlf-Latn-LA': 'mlf-Latn',
        'mlh': 'mlh',
        'mlh-Latn-PG': 'mlh',
        'mlh-Latn': 'mlh',
        'mlh-PG': 'mlh',
        'mli': 'mli',
        'mli-Latn-ID': 'mli',
        'mli-ID': 'mli',
        'mli-Latn': 'mli',
        'mlj': 'mlj',
        'mlj-Latn-TD': 'mlj',
        'mlj-Latn': 'mlj',
        'mlj-TD': 'mlj',
        'mlk': 'mlk',
        'mlk-Latn-KE': 'mlk',
        'mlk-KE': 'mlk',
        'mlk-Latn': 'mlk',
        'mll': 'mll',
        'mll-Latn-VU': 'mll',
        'mll-Latn': 'mll',
        'mll-VU': 'mll',
        'mlm': 'mlm',
        'mlm-Zyyy-CN': 'mlm',
        'mlm-CN': 'mlm',
        'mlm-Zyyy': 'mlm',
        'mln': 'mln',
        'mln-Latn-SB': 'mln',
        'mln-Latn': 'mln',
        'mln-SB': 'mln',
        'mlo': 'mlo',
        'mlo-Latn-SN': 'mlo',
        'mlo-Latn': 'mlo',
        'mlo-SN': 'mlo',
        'mlp': 'mlp',
        'mlp-Latn-PG': 'mlp',
        'mlp-Latn': 'mlp',
        'mlp-PG': 'mlp',
        'mlq-Arab': 'mlq-Arab',
        'mlq-Arab-SN': 'mlq-Arab',
        'mlq-Latn': 'mlq-Latn',
        'mlq-Latn-SN': 'mlq-Latn',
        'mlr': 'mlr',
        'mlr-Latn-CM': 'mlr',
        'mlr-CM': 'mlr',
        'mlr-Latn': 'mlr',
        'mls': 'mls',
        'mls-Latn-SD': 'mls',
        'mls-Latn': 'mls',
        'mls-SD': 'mls',
        'mlu': 'mlu',
        'mlu-Latn-SB': 'mlu',
        'mlu-Latn': 'mlu',
        'mlu-SB': 'mlu',
        'mlv': 'mlv',
        'mlv-Latn-VU': 'mlv',
        'mlv-Latn': 'mlv',
        'mlv-VU': 'mlv',
        'mlw': 'mlw',
        'mlw-Latn-CM': 'mlw',
        'mlw-CM': 'mlw',
        'mlw-Latn': 'mlw',
        'mlx': 'mlx',
        'mlx-Latn-VU': 'mlx',
        'mlx-Latn': 'mlx',
        'mlx-VU': 'mlx',
        'mlz': 'mlz',
        'mlz-Latn-PH': 'mlz',
        'mlz-Latn': 'mlz',
        'mlz-PH': 'mlz',
        'mma': 'mma',
        'mma-Latn-NG': 'mma',
        'mma-Latn': 'mma',
        'mma-NG': 'mma',
        'mmb': 'mmb',
        'mmb-Latn-ID': 'mmb',
        'mmb-ID': 'mmb',
        'mmb-Latn': 'mmb',
        'mmc': 'mmc',
        'mmc-Latn-MX': 'mmc',
        'mmc-Latn': 'mmc',
        'mmc-MX': 'mmc',
        'mmd': 'mmd',
        'mmd-Latn-CN': 'mmd',
        'mmd-CN': 'mmd',
        'mmd-Latn': 'mmd',
        'mmd-Hans': 'mmd-Hans',
        'mmd-Hans-CN': 'mmd-Hans',
        'mmd-Hant': 'mmd-Hant',
        'mmd-Hant-CN': 'mmd-Hant',
        'mme': 'mme',
        'mme-Latn-VU': 'mme',
        'mme-Latn': 'mme',
        'mme-VU': 'mme',
        'mmf': 'mmf',
        'mmf-Latn-NG': 'mmf',
        'mmf-Latn': 'mmf',
        'mmf-NG': 'mmf',
        'mmg': 'mmg',
        'mmg-Latn-VU': 'mmg',
        'mmg-Latn': 'mmg',
        'mmg-VU': 'mmg',
        'mmh': 'mmh',
        'mmh-Latn-BR': 'mmh',
        'mmh-BR': 'mmh',
        'mmh-Latn': 'mmh',
        'mmi': 'mmi',
        'mmi-Latn-PG': 'mmi',
        'mmi-Latn': 'mmi',
        'mmi-PG': 'mmi',
        'mmj': 'mmj',
        'mmj-Zyyy-IN': 'mmj',
        'mmj-IN': 'mmj',
        'mmj-Zyyy': 'mmj',
        'mmk': 'mmk',
        'mmk-Zyyy-IN': 'mmk',
        'mmk-IN': 'mmk',
        'mmk-Zyyy': 'mmk',
        'mml': 'mml',
        'mml-Zyyy-CN': 'mml',
        'mml-CN': 'mml',
        'mml-Zyyy': 'mml',
        'mmm': 'mmm',
        'mmm-Latn-VU': 'mmm',
        'mmm-Latn': 'mmm',
        'mmm-VU': 'mmm',
        'mmn': 'mmn',
        'mmn-Latn-PH': 'mmn',
        'mmn-Latn': 'mmn',
        'mmn-PH': 'mmn',
        'mmo': 'mmo',
        'mmo-Latn-PG': 'mmo',
        'mmo-Latn': 'mmo',
        'mmo-PG': 'mmo',
        'mmp': 'mmp',
        'mmp-Latn-PG': 'mmp',
        'mmp-Latn': 'mmp',
        'mmp-PG': 'mmp',
        'mmq': 'mmq',
        'mmq-Latn-PG': 'mmq',
        'mmq-Latn': 'mmq',
        'mmq-PG': 'mmq',
        'mmr': 'mmr',
        'mmr-Latn-CN': 'mmr',
        'mmr-CN': 'mmr',
        'mmr-Latn': 'mmr',
        'mmt': 'mmt',
        'mmt-Latn-PG': 'mmt',
        'mmt-Latn': 'mmt',
        'mmt-PG': 'mmt',
        'mmu': 'mmu',
        'mmu-Latn-CM': 'mmu',
        'mmu-CM': 'mmu',
        'mmu-Latn': 'mmu',
        'mmv': 'mmv',
        'mmv-Latn-BR': 'mmv',
        'mmv-BR': 'mmv',
        'mmv-Latn': 'mmv',
        'mmw': 'mmw',
        'mmw-Latn-VU': 'mmw',
        'mmw-Latn': 'mmw',
        'mmw-VU': 'mmw',
        'mmx': 'mmx',
        'mmx-Latn-PG': 'mmx',
        'mmx-Latn': 'mmx',
        'mmx-PG': 'mmx',
        'mmy': 'mmy',
        'mmy-Latn-TD': 'mmy',
        'mmy-Latn': 'mmy',
        'mmy-TD': 'mmy',
        'mmz': 'mmz',
        'mmz-Latn-CD': 'mmz',
        'mmz-CD': 'mmz',
        'mmz-Latn': 'mmz',
        'mn': 'mn',
        'mn-Cyrl-MN': 'mn',
        'drh': 'mn',
        'drh-Cyrl': 'mn',
        'drh-Cyrl-MN': 'mn',
        'drh-MN': 'mn',
        'khk': 'mn',
        'khk-Cyrl': 'mn',
        'khk-Cyrl-MN': 'mn',
        'khk-MN': 'mn',
        'mn-Cyrl': 'mn',
        'mn-MN': 'mn',
        'mn-Brai': 'mn-Brai',
        'mn-Brai-MN': 'mn-Brai',
        'khk-Brai': 'mn-Brai',
        'khk-Brai-MN': 'mn-Brai',
        'mn-CN': 'mn-CN',
        'mn-Mong-CN': 'mn-CN',
        'mn-Mong': 'mn-CN',
        'mn-Mong-MN': 'mn-Mong-MN',
        'khk-Mong': 'mn-Mong-MN',
        'khk-Mong-MN': 'mn-Mong-MN',
        'mn-Phag': 'mn-Phag',
        'mn-Phag-CN': 'mn-Phag',
        'mn-Phag-MN': 'mn-Phag-MN',
        'khk-Phag': 'mn-Phag-MN',
        'khk-Phag-MN': 'mn-Phag-MN',
        'mn-Tibt': 'mn-Tibt',
        'mn-Tibt-CN': 'mn-Tibt',
        'khk-Tibt': 'mn-Tibt',
        'khk-Tibt-CN': 'mn-Tibt',
        'mna': 'mna',
        'mna-Latn-PG': 'mna',
        'mna-Latn': 'mna',
        'mna-PG': 'mna',
        'mnb': 'mnb',
        'mnb-Latn-ID': 'mnb',
        'mnb-ID': 'mnb',
        'mnb-Latn': 'mnb',
        'mnc-Mong': 'mnc-Mong',
        'mnc-Mong-CN': 'mnc-Mong',
        'mnc-CN': 'mnc-Mong',
        'mnc-Mong-x-manchu': 'mnc-Mong-x-manchu',
        'mnc-Mong-CN-x-manchu': 'mnc-Mong-x-manchu',
        'mnc-CN-x-manchu': 'mnc-Mong-x-manchu',
        'mnc-Mong-x-olmanchu': 'mnc-Mong-x-olmanchu',
        'mnc-Mong-CN-x-olmanchu': 'mnc-Mong-x-olmanchu',
        'mnc-CN-x-olmanchu': 'mnc-Mong-x-olmanchu',
        'mnd': 'mnd',
        'mnd-Latn-BR': 'mnd',
        'mnd-BR': 'mnd',
        'mnd-Latn': 'mnd',
        'mne': 'mne',
        'mne-Latn-TD': 'mne',
        'mne-Latn': 'mne',
        'mne-TD': 'mne',
        'mnf': 'mnf',
        'mnf-Latn-CM': 'mnf',
        'mnf-CM': 'mnf',
        'mnf-Latn': 'mnf',
        'mng': 'mng',
        'mng-Latn-VN': 'mng',
        'mng-Latn': 'mng',
        'mng-VN': 'mng',
        'mnh': 'mnh',
        'mnh-Latn-CD': 'mnh',
        'mnh-CD': 'mnh',
        'mnh-Latn': 'mnh',
        'mni': 'mni',
        'mni-Beng-IN': 'mni',
        'mni-Beng': 'mni',
        'mni-IN': 'mni',
        'mni-Brai': 'mni-Brai',
        'mni-Brai-IN': 'mni-Brai',
        'mni-Mtei': 'mni-Mtei',
        'mni-Mtei-IN': 'mni-Mtei',
        'mnj-Arab': 'mnj-Arab',
        'mnj-Arab-AF': 'mnj-Arab',
        'mnj-AF': 'mnj-Arab',
        'mnl': 'mnl',
        'mnl-Latn-VU': 'mnl',
        'mnl-Latn': 'mnl',
        'mnl-VU': 'mnl',
        'mnm': 'mnm',
        'mnm-Latn-PG': 'mnm',
        'mnm-Latn': 'mnm',
        'mnm-PG': 'mnm',
        'mnn': 'mnn',
        'mnn-Latn-VN': 'mnn',
        'mnn-Latn': 'mnn',
        'mnn-VN': 'mnn',
        'mnp': 'mnp',
        'mnp-Latn-CN': 'mnp',
        'mnp-CN': 'mnp',
        'mnp-Latn': 'mnp',
        'zh-mnp': 'mnp',
        'zh-mnp-CN': 'mnp',
        'mnq': 'mnq',
        'mnq-Latn-MY': 'mnq',
        'mnq-Latn': 'mnq',
        'mnq-MY': 'mnq',
        'mnr': 'mnr',
        'mnr-Latn-US': 'mnr',
        'mnr-Latn': 'mnr',
        'mnr-US': 'mnr',
        'mns': 'mns',
        'mns-Cyrl-RU': 'mns',
        'mns-Cyrl': 'mns',
        'mns-RU': 'mns',
        'mnu': 'mnu',
        'mnu-Latn-ID': 'mnu',
        'mnu-ID': 'mnu',
        'mnu-Latn': 'mnu',
        'mnv': 'mnv',
        'mnv-Latn-SB': 'mnv',
        'mnv-Latn': 'mnv',
        'mnv-SB': 'mnv',
        'mnw': 'mnw',
        'mnw-Mymr-MM': 'mnw',
        'mnw-MM': 'mnw',
        'mnw-Mymr': 'mnw',
        'mnx': 'mnx',
        'mnx-Latn-ID': 'mnx',
        'mnx-ID': 'mnx',
        'mnx-Latn': 'mnx',
        'mny': 'mny',
        'mny-Latn-MZ': 'mny',
        'mny-Latn': 'mny',
        'mny-MZ': 'mny',
        'mnz': 'mnz',
        'mnz-Latn-ID': 'mnz',
        'mnz-ID': 'mnz',
        'mnz-Latn': 'mnz',
        'moa': 'moa',
        'moa-Latn-CI': 'moa',
        'moa-CI': 'moa',
        'moa-Latn': 'moa',
        'moc': 'moc',
        'moc-Latn-AR': 'moc',
        'moc-AR': 'moc',
        'moc-Latn': 'moc',
        'mod': 'mod',
        'mod-Zyyy-US': 'mod',
        'mod-US': 'mod',
        'mod-Zyyy': 'mod',
        'moe': 'moe',
        'moe-Latn-CA': 'moe',
        'moe-CA': 'moe',
        'moe-Latn': 'moe',
        'mog': 'mog',
        'mog-Latn-ID': 'mog',
        'mog-ID': 'mog',
        'mog-Latn': 'mog',
        'moh': 'moh',
        'moh-Latn-CA': 'moh',
        'moh-CA': 'moh',
        'moh-Latn': 'moh',
        'moi': 'moi',
        'moi-Latn-NG': 'moi',
        'moi-Latn': 'moi',
        'moi-NG': 'moi',
        'moj': 'moj',
        'moj-Latn-CG': 'moj',
        'moj-CG': 'moj',
        'moj-Latn': 'moj',
        'mok': 'mok',
        'mok-Latn-ID': 'mok',
        'mok-ID': 'mok',
        'mok-Latn': 'mok',
        'mom': 'mom',
        'mom-Latn-NI': 'mom',
        'cjr': 'mom',
        'cjr-Latn': 'mom',
        'cjr-Latn-NI': 'mom',
        'cjr-NI': 'mom',
        'mom-Latn': 'mom',
        'mom-NI': 'mom',
        'moo': 'moo',
        'moo-Latn-VN': 'moo',
        'moo-Latn': 'moo',
        'moo-VN': 'moo',
        'mop': 'mop',
        'mop-Latn-BZ': 'mop',
        'mop-BZ': 'mop',
        'mop-Latn': 'mop',
        'moq': 'moq',
        'moq-Latn-ID': 'moq',
        'moq-ID': 'moq',
        'moq-Latn': 'moq',
        'mor': 'mor',
        'mor-Latn-SD': 'mor',
        'mor-Latn': 'mor',
        'mor-SD': 'mor',
        'mos': 'mos',
        'mos-Latn-BF': 'mos',
        'mos-BF': 'mos',
        'mos-Latn': 'mos',
        'mos-Brai': 'mos-Brai',
        'mos-Brai-BF': 'mos-Brai',
        'mot': 'mot',
        'mot-Latn-CO': 'mot',
        'mot-CO': 'mot',
        'mot-Latn': 'mot',
        'mou': 'mou',
        'mou-Latn-TD': 'mou',
        'mou-Latn': 'mou',
        'mou-TD': 'mou',
        'mov': 'mov',
        'mov-Latn-US': 'mov',
        'mov-Latn': 'mov',
        'mov-US': 'mov',
        'mow': 'mow',
        'mow-Latn-CG': 'mow',
        'mow-CG': 'mow',
        'mow-Latn': 'mow',
        'mox': 'mox',
        'mox-Latn-PG': 'mox',
        'mox-Latn': 'mox',
        'mox-PG': 'mox',
        'moy': 'moy',
        'moy-Latn-ET': 'moy',
        'moy-ET': 'moy',
        'moy-Latn': 'moy',
        'moz': 'moz',
        'moz-Latn-TD': 'moz',
        'moz-Latn': 'moz',
        'moz-TD': 'moz',
        'mpa': 'mpa',
        'mpa-Latn-TZ': 'mpa',
        'mpa-Latn': 'mpa',
        'mpa-TZ': 'mpa',
        'mpb': 'mpb',
        'mpb-Latn-AU': 'mpb',
        'mpb-AU': 'mpb',
        'mpb-Latn': 'mpb',
        'mpc': 'mpc',
        'mpc-Latn-AU': 'mpc',
        'mpc-AU': 'mpc',
        'mpc-Latn': 'mpc',
        'mpd': 'mpd',
        'mpd-Latn-BR': 'mpd',
        'mpd-BR': 'mpd',
        'mpd-Latn': 'mpd',
        'mpe': 'mpe',
        'mpe-Latn-ET': 'mpe',
        'mpe-ET': 'mpe',
        'mpe-Latn': 'mpe',
        'mpe-Ethi': 'mpe-Ethi',
        'mpe-Ethi-ET': 'mpe-Ethi',
        'mpg': 'mpg',
        'mpg-Latn-TD': 'mpg',
        'mpg-Latn': 'mpg',
        'mpg-TD': 'mpg',
        'mph': 'mph',
        'mph-Latn-AU': 'mph',
        'mph-AU': 'mph',
        'mph-Latn': 'mph',
        'mpi': 'mpi',
        'mpi-Latn-CM': 'mpi',
        'mpi-CM': 'mpi',
        'mpi-Latn': 'mpi',
        'mpj': 'mpj',
        'mpj-Latn-AU': 'mpj',
        'mpj-AU': 'mpj',
        'mpj-Latn': 'mpj',
        'mpk': 'mpk',
        'mpk-Latn-TD': 'mpk',
        'mpk-Latn': 'mpk',
        'mpk-TD': 'mpk',
        'mpl': 'mpl',
        'mpl-Latn-PG': 'mpl',
        'mpl-Latn': 'mpl',
        'mpl-PG': 'mpl',
        'mpm': 'mpm',
        'mpm-Latn-MX': 'mpm',
        'mpm-Latn': 'mpm',
        'mpm-MX': 'mpm',
        'mpn': 'mpn',
        'mpn-Latn-PG': 'mpn',
        'mpn-Latn': 'mpn',
        'mpn-PG': 'mpn',
        'mpo': 'mpo',
        'mpo-Latn-PG': 'mpo',
        'mpo-Latn': 'mpo',
        'mpo-PG': 'mpo',
        'mpp': 'mpp',
        'mpp-Latn-PG': 'mpp',
        'mpp-Latn': 'mpp',
        'mpp-PG': 'mpp',
        'mpq': 'mpq',
        'mpq-Latn-BR': 'mpq',
        'mpq-BR': 'mpq',
        'mpq-Latn': 'mpq',
        'mpr': 'mpr',
        'mpr-Latn-SB': 'mpr',
        'mpr-Latn': 'mpr',
        'mpr-SB': 'mpr',
        'mps': 'mps',
        'mps-Latn-PG': 'mps',
        'mps-Latn': 'mps',
        'mps-PG': 'mps',
        'mpt': 'mpt',
        'mpt-Latn-PG': 'mpt',
        'mpt-Latn': 'mpt',
        'mpt-PG': 'mpt',
        'mpu': 'mpu',
        'mpu-Latn-BR': 'mpu',
        'mpu-BR': 'mpu',
        'mpu-Latn': 'mpu',
        'mpv': 'mpv',
        'mpv-Latn-PG': 'mpv',
        'mpv-Latn': 'mpv',
        'mpv-PG': 'mpv',
        'mpw': 'mpw',
        'mpw-Latn-BR': 'mpw',
        'mpw-BR': 'mpw',
        'mpw-Latn': 'mpw',
        'mpx': 'mpx',
        'mpx-Latn-PG': 'mpx',
        'mpx-Latn': 'mpx',
        'mpx-PG': 'mpx',
        'mpy': 'mpy',
        'mpy-Latn-ID': 'mpy',
        'mpy-ID': 'mpy',
        'mpy-Latn': 'mpy',
        'mpz': 'mpz',
        'mpz-Thai-TH': 'mpz',
        'mpz-TH': 'mpz',
        'mpz-Thai': 'mpz',
        'mqa': 'mqa',
        'mqa-Latn-ID': 'mqa',
        'mqa-ID': 'mqa',
        'mqa-Latn': 'mqa',
        'mqb': 'mqb',
        'mqb-Latn-CM': 'mqb',
        'mqb-CM': 'mqb',
        'mqb-Latn': 'mqb',
        'mqc': 'mqc',
        'mqc-Latn-ID': 'mqc',
        'mqc-ID': 'mqc',
        'mqc-Latn': 'mqc',
        'mqe': 'mqe',
        'mqe-Latn-PG': 'mqe',
        'mqe-Latn': 'mqe',
        'mqe-PG': 'mqe',
        'mqf': 'mqf',
        'mqf-Latn-ID': 'mqf',
        'mqf-ID': 'mqf',
        'mqf-Latn': 'mqf',
        'mqg': 'mqg',
        'mqg-Latn-ID': 'mqg',
        'mqg-ID': 'mqg',
        'mqg-Latn': 'mqg',
        'ms-mqg': 'mqg',
        'ms-mqg-ID': 'mqg',
        'mqh': 'mqh',
        'mqh-Latn-MX': 'mqh',
        'mqh-Latn': 'mqh',
        'mqh-MX': 'mqh',
        'mqi': 'mqi',
        'mqi-Latn-ID': 'mqi',
        'mqi-ID': 'mqi',
        'mqi-Latn': 'mqi',
        'mqj': 'mqj',
        'mqj-Latn-ID': 'mqj',
        'mqj-ID': 'mqj',
        'mqj-Latn': 'mqj',
        'mqk': 'mqk',
        'mqk-Latn-PH': 'mqk',
        'mqk-Latn': 'mqk',
        'mqk-PH': 'mqk',
        'mql': 'mql',
        'mql-Latn-BJ': 'mql',
        'mql-BJ': 'mql',
        'mql-Latn': 'mql',
        'mqm': 'mqm',
        'mqm-Latn-PF': 'mqm',
        'mqm-Latn': 'mqm',
        'mqm-PF': 'mqm',
        'mqn': 'mqn',
        'mqn-Latn-ID': 'mqn',
        'mqn-ID': 'mqn',
        'mqn-Latn': 'mqn',
        'mqo': 'mqo',
        'mqo-Latn-ID': 'mqo',
        'mqo-ID': 'mqo',
        'mqo-Latn': 'mqo',
        'mqp': 'mqp',
        'mqp-Latn-ID': 'mqp',
        'mqp-ID': 'mqp',
        'mqp-Latn': 'mqp',
        'mqq': 'mqq',
        'mqq-Latn-MY': 'mqq',
        'mqq-Latn': 'mqq',
        'mqq-MY': 'mqq',
        'mqr': 'mqr',
        'mqr-Latn-ID': 'mqr',
        'mqr-ID': 'mqr',
        'mqr-Latn': 'mqr',
        'mqs': 'mqs',
        'mqs-Latn-ID': 'mqs',
        'mqs-ID': 'mqs',
        'mqs-Latn': 'mqs',
        'mqt': 'mqt',
        'mqt-Zyyy-TH': 'mqt',
        'mqt-TH': 'mqt',
        'mqt-Zyyy': 'mqt',
        'mqu': 'mqu',
        'mqu-Latn-SS': 'mqu',
        'mqu-Latn': 'mqu',
        'mqu-SS': 'mqu',
        'mqv': 'mqv',
        'mqv-Latn-PG': 'mqv',
        'mqv-Latn': 'mqv',
        'mqv-PG': 'mqv',
        'mqw': 'mqw',
        'mqw-Latn-PG': 'mqw',
        'mqw-Latn': 'mqw',
        'mqw-PG': 'mqw',
        'mqx': 'mqx',
        'mqx-Latn-ID': 'mqx',
        'mqx-ID': 'mqx',
        'mqx-Latn': 'mqx',
        'mqx-Bugi': 'mqx-Bugi',
        'mqx-Bugi-ID': 'mqx-Bugi',
        'mqy': 'mqy',
        'mqy-Latn-ID': 'mqy',
        'mqy-ID': 'mqy',
        'mqy-Latn': 'mqy',
        'mqz': 'mqz',
        'mqz-Latn-PG': 'mqz',
        'mqz-Latn': 'mqz',
        'mqz-PG': 'mqz',
        'mr': 'mr',
        'mr-Deva-IN': 'mr',
        'mr-Deva': 'mr',
        'mr-IN': 'mr',
        'mr-Brai': 'mr-Brai',
        'mr-Brai-IN': 'mr-Brai',
        'mr-Modi': 'mr-Modi',
        'mr-Modi-IN': 'mr-Modi',
        'mra': 'mra',
        'mra-Thai-TH': 'mra',
        'mra-TH': 'mra',
        'mra-Thai': 'mra',
        'mrb': 'mrb',
        'mrb-Latn-VU': 'mrb',
        'mrb-Latn': 'mrb',
        'mrb-VU': 'mrb',
        'mrc': 'mrc',
        'mrc-Latn-US': 'mrc',
        'mrc-Latn': 'mrc',
        'mrc-US': 'mrc',
        'mrd': 'mrd',
        'mrd-Deva-NP': 'mrd',
        'mrd-Deva': 'mrd',
        'mrd-NP': 'mrd',
        'mre': 'mre',
        'mre-Zxxx-US': 'mre',
        'mre-US': 'mre',
        'mre-Zxxx': 'mre',
        'sgn-mre': 'mre',
        'sgn-mre-US': 'mre',
        'mrf': 'mrf',
        'mrf-Latn-ID': 'mrf',
        'mrf-ID': 'mrf',
        'mrf-Latn': 'mrf',
        'mrg': 'mrg',
        'mrg-Latn-IN': 'mrg',
        'mrg-IN': 'mrg',
        'mrg-Latn': 'mrg',
        'mrg-Beng': 'mrg-Beng',
        'mrg-Beng-IN': 'mrg-Beng',
        'mrg-Deva': 'mrg-Deva',
        'mrg-Deva-IN': 'mrg-Deva',
        'mrh': 'mrh',
        'mrh-Latn-IN': 'mrh',
        'mrh-IN': 'mrh',
        'mrh-Latn': 'mrh',
        'mrj': 'mrj',
        'mrj-Cyrl-RU': 'mrj',
        'mrj-Cyrl': 'mrj',
        'mrj-RU': 'mrj',
        'mrk': 'mrk',
        'mrk-Latn-NC': 'mrk',
        'mrk-Latn': 'mrk',
        'mrk-NC': 'mrk',
        'mrl': 'mrl',
        'mrl-Latn-FM': 'mrl',
        'mrl-FM': 'mrl',
        'mrl-Latn': 'mrl',
        'mrm': 'mrm',
        'mrm-Latn-VU': 'mrm',
        'mrm-Latn': 'mrm',
        'mrm-VU': 'mrm',
        'mrn': 'mrn',
        'mrn-Latn-SB': 'mrn',
        'mrn-Latn': 'mrn',
        'mrn-SB': 'mrn',
        'mro': 'mro',
        'mro-Mroo-BD': 'mro',
        'mro-BD': 'mro',
        'mro-Mroo': 'mro',
        'mro-Latn': 'mro-Latn',
        'mro-Latn-BD': 'mro-Latn',
        'mrp': 'mrp',
        'mrp-Latn-VU': 'mrp',
        'mrp-Latn': 'mrp',
        'mrp-VU': 'mrp',
        'mrq': 'mrq',
        'mrq-Latn-PF': 'mrq',
        'mrq-Latn': 'mrq',
        'mrq-PF': 'mrq',
        'mrr': 'mrr',
        'mrr-Deva-IN': 'mrr',
        'mrr-Deva': 'mrr',
        'mrr-IN': 'mrr',
        'mrs': 'mrs',
        'mrs-Latn-VU': 'mrs',
        'mrs-Latn': 'mrs',
        'mrs-VU': 'mrs',
        'mrt': 'mrt',
        'mrt-Latn-NG': 'mrt',
        'mrt-Latn': 'mrt',
        'mrt-NG': 'mrt',
        'mru': 'mru',
        'mru-Latn-CM': 'mru',
        'mru-CM': 'mru',
        'mru-Latn': 'mru',
        'mrv': 'mrv',
        'mrv-Latn-PF': 'mrv',
        'mrv-Latn': 'mrv',
        'mrv-PF': 'mrv',
        'mrw': 'mrw',
        'mrw-Latn-PH': 'mrw',
        'mrw-Latn': 'mrw',
        'mrw-PH': 'mrw',
        'mrx': 'mrx',
        'mrx-Latn-ID': 'mrx',
        'mrx-ID': 'mrx',
        'mrx-Latn': 'mrx',
        'mry': 'mry',
        'mry-Latn-PH': 'mry',
        'mry-Latn': 'mry',
        'mry-PH': 'mry',
        'mst': 'mry',
        'mst-Latn': 'mry',
        'mst-Latn-PH': 'mry',
        'mst-PH': 'mry',
        'myt': 'mry',
        'myt-Latn': 'mry',
        'myt-Latn-PH': 'mry',
        'myt-PH': 'mry',
        'mrz': 'mrz',
        'mrz-Latn-ID': 'mrz',
        'mrz-ID': 'mrz',
        'mrz-Latn': 'mrz',
        'ms': 'ms',
        'ms-Latn-MY': 'ms',
        'ms-Latn': 'ms',
        'ms-MY': 'ms',
        'ms-zsm': 'ms',
        'ms-zsm-MY': 'ms',
        'zsm': 'ms',
        'zsm-Latn': 'ms',
        'zsm-Latn-MY': 'ms',
        'zsm-MY': 'ms',
        'ms-Arab': 'ms-Arab',
        'ms-Arab-MY': 'ms-Arab',
        'zsm-Arab': 'ms-Arab',
        'zsm-Arab-MY': 'ms-Arab',
        'ms-BN': 'ms-BN',
        'ms-Latn-BN': 'ms-BN',
        'ms-Brai': 'ms-Brai',
        'ms-Brai-MY': 'ms-Brai',
        'zsm-Brai': 'ms-Brai',
        'zsm-Brai-MY': 'ms-Brai',
        'ms-CC': 'ms-CC',
        'ms-Arab-CC': 'ms-CC',
        'ms-ID': 'ms-ID',
        'ms-Arab-ID': 'ms-ID',
        'ms-SG': 'ms-SG',
        'ms-Latn-SG': 'ms-SG',
        'msb': 'msb',
        'msb-Latn-PH': 'msb',
        'msb-Latn': 'msb',
        'msb-PH': 'msb',
        'msc': 'msc',
        'msc-Latn-GN': 'msc',
        'msc-GN': 'msc',
        'msc-Latn': 'msc',
        'msd': 'msd',
        'msd-Zxxx-MX': 'msd',
        'msd-MX': 'msd',
        'msd-Zxxx': 'msd',
        'sgn-msd': 'msd',
        'sgn-msd-MX': 'msd',
        'mse': 'mse',
        'mse-Latn-TD': 'mse',
        'mse-Latn': 'mse',
        'mse-TD': 'mse',
        'msf': 'msf',
        'msf-Latn-ID': 'msf',
        'msf-ID': 'msf',
        'msf-Latn': 'msf',
        'msg': 'msg',
        'msg-Latn-ID': 'msg',
        'msg-ID': 'msg',
        'msg-Latn': 'msg',
        'msh': 'msh',
        'msh-Latn-MG': 'msh',
        'msh-Latn': 'msh',
        'msh-MG': 'msh',
        'msi': 'msi',
        'msi-Latn-MY': 'msi',
        'ms-msi': 'msi',
        'ms-msi-MY': 'msi',
        'msi-Latn': 'msi',
        'msi-MY': 'msi',
        'msj': 'msj',
        'msj-Latn-CD': 'msj',
        'msj-CD': 'msj',
        'msj-Latn': 'msj',
        'msk': 'msk',
        'msk-Latn-PH': 'msk',
        'msk-Latn': 'msk',
        'msk-PH': 'msk',
        'msl': 'msl',
        'msl-Latn-ID': 'msl',
        'msl-ID': 'msl',
        'msl-Latn': 'msl',
        'msm': 'msm',
        'msm-Latn-PH': 'msm',
        'msm-Latn': 'msm',
        'msm-PH': 'msm',
        'msn': 'msn',
        'msn-Latn-VU': 'msn',
        'msn-Latn': 'msn',
        'msn-VU': 'msn',
        'mso': 'mso',
        'mso-Latn-ID': 'mso',
        'mso-ID': 'mso',
        'mso-Latn': 'mso',
        'msp': 'msp',
        'msp-Latn-BR': 'msp',
        'msp-BR': 'msp',
        'msp-Latn': 'msp',
        'msq': 'msq',
        'msq-Latn-NC': 'msq',
        'msq-Latn': 'msq',
        'msq-NC': 'msq',
        'msr': 'msr',
        'msr-Zxxx-MN': 'msr',
        'msr-MN': 'msr',
        'msr-Zxxx': 'msr',
        'sgn-msr': 'msr',
        'sgn-msr-MN': 'msr',
        'mss': 'mss',
        'mss-Latn-ID': 'mss',
        'mss-ID': 'mss',
        'mss-Latn': 'mss',
        'msu': 'msu',
        'msu-Latn-PG': 'msu',
        'msu-Latn': 'msu',
        'msu-PG': 'msu',
        'msv': 'msv',
        'msv-Latn-CM': 'msv',
        'msv-CM': 'msv',
        'msv-Latn': 'msv',
        'msw': 'msw',
        'msw-Latn-GW': 'msw',
        'msw-GW': 'msw',
        'msw-Latn': 'msw',
        'msx': 'msx',
        'msx-Latn-PG': 'msx',
        'msx-Latn': 'msx',
        'msx-PG': 'msx',
        'msy': 'msy',
        'msy-Latn-PG': 'msy',
        'msy-Latn': 'msy',
        'msy-PG': 'msy',
        'msz': 'msz',
        'msz-Latn-PG': 'msz',
        'msz-Latn': 'msz',
        'msz-PG': 'msz',
        'mt': 'mt',
        'mt-Latn-MT': 'mt',
        'mt-Latn': 'mt',
        'mt-MT': 'mt',
        'mt-Arab': 'mt-Arab',
        'mt-Arab-MT': 'mt-Arab',
        'mt-Brai': 'mt-Brai',
        'mt-Brai-MT': 'mt-Brai',
        'mta': 'mta',
        'mta-Latn-PH': 'mta',
        'mta-Latn': 'mta',
        'mta-PH': 'mta',
        'mtb': 'mtb',
        'mtb-Latn-CI': 'mtb',
        'mtb-CI': 'mtb',
        'mtb-Latn': 'mtb',
        'mtc': 'mtc',
        'mtc-Latn-PG': 'mtc',
        'mtc-Latn': 'mtc',
        'mtc-PG': 'mtc',
        'mtd': 'mtd',
        'mtd-Latn-ID': 'mtd',
        'mtd-ID': 'mtd',
        'mtd-Latn': 'mtd',
        'mte': 'mte',
        'mte-Latn-SB': 'mte',
        'mte-Latn': 'mte',
        'mte-SB': 'mte',
        'mtf': 'mtf',
        'mtf-Latn-PG': 'mtf',
        'mtf-Latn': 'mtf',
        'mtf-PG': 'mtf',
        'mtg': 'mtg',
        'mtg-Latn-ID': 'mtg',
        'mtg-ID': 'mtg',
        'mtg-Latn': 'mtg',
        'mth': 'mth',
        'mth-Latn-ID': 'mth',
        'mth-ID': 'mth',
        'mth-Latn': 'mth',
        'mti': 'mti',
        'mti-Latn-PG': 'mti',
        'mti-Latn': 'mti',
        'mti-PG': 'mti',
        'mtj': 'mtj',
        'mtj-Latn-ID': 'mtj',
        'mtj-ID': 'mtj',
        'mtj-Latn': 'mtj',
        'mtk': 'mtk',
        'mtk-Latn-CM': 'mtk',
        'mtk-CM': 'mtk',
        'mtk-Latn': 'mtk',
        'mtl': 'mtl',
        'mtl-Latn-NG': 'mtl',
        'mtl-Latn': 'mtl',
        'mtl-NG': 'mtl',
        'mtm': 'mtm',
        'mtm-Cyrl-RU': 'mtm',
        'mtm-Cyrl': 'mtm',
        'mtm-RU': 'mtm',
        'ymt': 'mtm',
        'ymt-Cyrl': 'mtm',
        'ymt-Cyrl-RU': 'mtm',
        'ymt-RU': 'mtm',
        'mtn': 'mtn',
        'mtn-Latn-NI': 'mtn',
        'mtn-Latn': 'mtn',
        'mtn-NI': 'mtn',
        'mto': 'mto',
        'mto-Latn-MX': 'mto',
        'mto-Latn': 'mto',
        'mto-MX': 'mto',
        'mtp': 'mtp',
        'mtp-Latn-BO': 'mtp',
        'mtp-BO': 'mtp',
        'mtp-Latn': 'mtp',
        'mtq': 'mtq',
        'mtq-Latn-VN': 'mtq',
        'mtq-Latn': 'mtq',
        'mtq-VN': 'mtq',
        'mtr': 'mtr',
        'mtr-Deva-IN': 'mtr',
        'mtr-Deva': 'mtr',
        'mtr-IN': 'mtr',
        'mts': 'mts',
        'mts-Latn-PE': 'mts',
        'mts-Latn': 'mts',
        'mts-PE': 'mts',
        'mtt': 'mtt',
        'mtt-Latn-VU': 'mtt',
        'mtt-Latn': 'mtt',
        'mtt-VU': 'mtt',
        'mtu': 'mtu',
        'mtu-Latn-MX': 'mtu',
        'mtu-Latn': 'mtu',
        'mtu-MX': 'mtu',
        'mtv': 'mtv',
        'mtv-Latn-PG': 'mtv',
        'mtv-Latn': 'mtv',
        'mtv-PG': 'mtv',
        'mtw': 'mtw',
        'mtw-Latn-PH': 'mtw',
        'mtw-Latn': 'mtw',
        'mtw-PH': 'mtw',
        'mtx': 'mtx',
        'mtx-Latn-MX': 'mtx',
        'mtx-Latn': 'mtx',
        'mtx-MX': 'mtx',
        'mty': 'mty',
        'mty-Latn-PG': 'mty',
        'mty-Latn': 'mty',
        'mty-PG': 'mty',
        'mua': 'mua',
        'mua-Latn-CM': 'mua',
        'mua-CM': 'mua',
        'mua-Latn': 'mua',
        'mub': 'mub',
        'mub-Latn-TD': 'mub',
        'mub-Latn': 'mub',
        'mub-TD': 'mub',
        'muc': 'muc',
        'muc-Latn-CM': 'muc',
        'muc-CM': 'muc',
        'muc-Latn': 'muc',
        'mud': 'mud',
        'mud-Cyrl-RU': 'mud',
        'mud-Cyrl': 'mud',
        'mud-RU': 'mud',
        'mue': 'mue',
        'mue-Latn-EC': 'mue',
        'mue-EC': 'mue',
        'mue-Latn': 'mue',
        'mug': 'mug',
        'mug-Latn-CM': 'mug',
        'mug-CM': 'mug',
        'mug-Latn': 'mug',
        'muh': 'muh',
        'muh-Latn-SS': 'muh',
        'muh-Latn': 'muh',
        'muh-SS': 'muh',
        'mui': 'mui',
        'mui-Latn-ID': 'mui',
        'ms-mui': 'mui',
        'ms-mui-ID': 'mui',
        'mui-ID': 'mui',
        'mui-Latn': 'mui',
        'muj': 'muj',
        'muj-Latn-TD': 'muj',
        'muj-Latn': 'muj',
        'muj-TD': 'muj',
        'muk': 'muk',
        'muk-Tibt-NP': 'muk',
        'muk-NP': 'muk',
        'muk-Tibt': 'muk',
        'mul': 'mul',
        'mul-Zyyy-001': 'mul',
        'mul-001': 'mul',
        'mul-Zyyy': 'mul',
        'mum': 'mum',
        'mum-Latn-PG': 'mum',
        'mum-Latn': 'mum',
        'mum-PG': 'mum',
        'muo': 'muo',
        'muo-Latn-CM': 'muo',
        'muo-CM': 'muo',
        'muo-Latn': 'muo',
        'muq': 'muq',
        'muq-Zyyy-CN': 'muq',
        'muq-CN': 'muq',
        'muq-Zyyy': 'muq',
        'mur': 'mur',
        'mur-Latn-SS': 'mur',
        'mur-Latn': 'mur',
        'mur-SS': 'mur',
        'mur-Arab': 'mur-Arab',
        'mur-Arab-SS': 'mur-Arab',
        'mus': 'mus',
        'mus-Latn-US': 'mus',
        'mus-Latn': 'mus',
        'mus-US': 'mus',
        'mut': 'mut',
        'mut-Deva-IN': 'mut',
        'mut-Deva': 'mut',
        'mut-IN': 'mut',
        'muu': 'muu',
        'muu-Latn-KE': 'muu',
        'muu-KE': 'muu',
        'muu-Latn': 'muu',
        'muv': 'muv',
        'muv-Taml-IN': 'muv',
        'muv-IN': 'muv',
        'muv-Taml': 'muv',
        'mux': 'mux',
        'mux-Latn-PG': 'mux',
        'mux-Latn': 'mux',
        'mux-PG': 'mux',
        'muy': 'muy',
        'muy-Latn-CM': 'muy',
        'muy-CM': 'muy',
        'muy-Latn': 'muy',
        'muz': 'muz',
        'muz-Ethi-ET': 'muz',
        'muz-ET': 'muz',
        'muz-Ethi': 'muz',
        'muz-Latn': 'muz-Latn',
        'muz-Latn-ET': 'muz-Latn',
        'mva': 'mva',
        'mva-Latn-PG': 'mva',
        'mva-Latn': 'mva',
        'mva-PG': 'mva',
        'mvb': 'mvb',
        'mvb-Zyyy-US': 'mvb',
        'mvb-US': 'mvb',
        'mvb-Zyyy': 'mvb',
        'mvd': 'mvd',
        'mvd-Latn-ID': 'mvd',
        'mvd-ID': 'mvd',
        'mvd-Latn': 'mvd',
        'mve-Arab': 'mve-Arab',
        'mve-Arab-PK-x-sindhi': 'mve-Arab',
        'mve-Arab-PK': 'mve-Arab',
        'mve-Arab-x-sindhi': 'mve-Arab',
        'mve-PK-x-sindhi': 'mve-Arab',
        'mve-Arab-x-urdu': 'mve-Arab-x-urdu',
        'mve-Arab-PK-x-urdu': 'mve-Arab-x-urdu',
        'mve-PK-x-urdu': 'mve-Arab-x-urdu',
        'mvf': 'mvf',
        'mvf-Mong-CN': 'mvf',
        'mvf-CN': 'mvf',
        'mvf-Mong': 'mvf',
        'mvf-Phag': 'mvf-Phag',
        'mvf-Phag-CN': 'mvf-Phag',
        'mvg': 'mvg',
        'mvg-Latn-MX': 'mvg',
        'mvg-Latn': 'mvg',
        'mvg-MX': 'mvg',
        'mvh': 'mvh',
        'mvh-Latn-TD': 'mvh',
        'mvh-Latn': 'mvh',
        'mvh-TD': 'mvh',
        'mvi': 'mvi',
        'mvi-Zyyy-JP': 'mvi',
        'mvi-JP': 'mvi',
        'mvi-Zyyy': 'mvi',
        'mvk': 'mvk',
        'mvk-Latn-PG': 'mvk',
        'mvk-Latn': 'mvk',
        'mvk-PG': 'mvk',
        'mvl': 'mvl',
        'mvl-Latn-AU': 'mvl',
        'mvl-AU': 'mvl',
        'mvl-Latn': 'mvl',
        'mvm': 'mvm',
        'mvm-Zyyy-CN': 'mvm',
        'mvm-CN': 'mvm',
        'mvm-Zyyy': 'mvm',
        'mvn': 'mvn',
        'mvn-Latn-PG': 'mvn',
        'mvn-Latn': 'mvn',
        'mvn-PG': 'mvn',
        'mvo': 'mvo',
        'mvo-Latn-SB': 'mvo',
        'mvo-Latn': 'mvo',
        'mvo-SB': 'mvo',
        'mvp': 'mvp',
        'mvp-Latn-ID': 'mvp',
        'mvp-ID': 'mvp',
        'mvp-Latn': 'mvp',
        'mvq': 'mvq',
        'mvq-Latn-PG': 'mvq',
        'mvq-Latn': 'mvq',
        'mvq-PG': 'mvq',
        'mvr': 'mvr',
        'mvr-Latn-ID': 'mvr',
        'mvr-ID': 'mvr',
        'mvr-Latn': 'mvr',
        'mvs': 'mvs',
        'mvs-Latn-ID': 'mvs',
        'mvs-ID': 'mvs',
        'mvs-Latn': 'mvs',
        'mvt': 'mvt',
        'mvt-Latn-VU': 'mvt',
        'mvt-Latn': 'mvt',
        'mvt-VU': 'mvt',
        'mvu': 'mvu',
        'mvu-Latn-TD': 'mvu',
        'mvu-Latn': 'mvu',
        'mvu-TD': 'mvu',
        'mvv': 'mvv',
        'mvv-Latn-MY': 'mvv',
        'mvv-Latn': 'mvv',
        'mvv-MY': 'mvv',
        'mvw': 'mvw',
        'mvw-Latn-TZ': 'mvw',
        'mvw-Latn': 'mvw',
        'mvw-TZ': 'mvw',
        'mvx': 'mvx',
        'mvx-Latn-ID': 'mvx',
        'mvx-ID': 'mvx',
        'mvx-Latn': 'mvx',
        'mvy': 'mvy',
        'mvy-Arab-PK': 'mvy',
        'mvy-Arab': 'mvy',
        'mvy-PK': 'mvy',
        'mvz-Arab': 'mvz-Arab',
        'mvz-Arab-ET': 'mvz-Arab',
        'mvz-ET': 'mvz-Arab',
        'mwa': 'mwa',
        'mwa-Latn-PG': 'mwa',
        'mwa-Latn': 'mwa',
        'mwa-PG': 'mwa',
        'mwb': 'mwb',
        'mwb-Latn-PG': 'mwb',
        'mwb-Latn': 'mwb',
        'mwb-PG': 'mwb',
        'mwc': 'mwc',
        'mwc-Latn-PG': 'mwc',
        'mwc-Latn': 'mwc',
        'mwc-PG': 'mwc',
        'mwe': 'mwe',
        'mwe-Latn-TZ': 'mwe',
        'mwe-Latn': 'mwe',
        'mwe-TZ': 'mwe',
        'mwf': 'mwf',
        'mwf-Latn-AU': 'mwf',
        'mwf-AU': 'mwf',
        'mwf-Latn': 'mwf',
        'mwg': 'mwg',
        'mwg-Latn-PG': 'mwg',
        'mwg-Latn': 'mwg',
        'mwg-PG': 'mwg',
        'mwh': 'mwh',
        'mwh-Latn-PG': 'mwh',
        'mwh-Latn': 'mwh',
        'mwh-PG': 'mwh',
        'mwi': 'mwi',
        'mwi-Latn-VU': 'mwi',
        'mwi-Latn': 'mwi',
        'mwi-VU': 'mwi',
        'mwk': 'mwk',
        'mwk-Latn-ML': 'mwk',
        'mwk-Latn': 'mwk',
        'mwk-ML': 'mwk',
        'mwl': 'mwl',
        'mwl-Latn-PT': 'mwl',
        'mwl-Latn': 'mwl',
        'mwl-PT': 'mwl',
        'mwm': 'mwm',
        'mwm-Latn-TD': 'mwm',
        'mwm-Latn': 'mwm',
        'mwm-TD': 'mwm',
        'mwn': 'mwn',
        'mwn-Latn-ZM': 'mwn',
        'mwn-Latn': 'mwn',
        'mwn-ZM': 'mwn',
        'mwo': 'mwo',
        'mwo-Latn-VU': 'mwo',
        'mwo-Latn': 'mwo',
        'mwo-VU': 'mwo',
        'mwp': 'mwp',
        'mwp-Latn-AU': 'mwp',
        'mwp-AU': 'mwp',
        'mwp-Latn': 'mwp',
        'mwq': 'mwq',
        'mwq-Latn-MM': 'mwq',
        'mwq-Latn': 'mwq',
        'mwq-MM': 'mwq',
        'mwr': 'mwr',
        'mwr-Deva-IN': 'mwr',
        'dhd': 'mwr',
        'dhd-Deva': 'mwr',
        'dhd-Deva-IN': 'mwr',
        'dhd-IN': 'mwr',
        'mwr-Deva': 'mwr',
        'mwr-IN': 'mwr',
        'mwr-Mahj': 'mwr-Mahj',
        'mwr-Mahj-IN': 'mwr-Mahj',
        'mws': 'mws',
        'mws-Latn-KE': 'mws',
        'mws-KE': 'mws',
        'mws-Latn': 'mws',
        'mwt': 'mwt',
        'mwt-Mymr-MM': 'mwt',
        'mwt-MM': 'mwt',
        'mwt-Mymr': 'mwt',
        'mwt-Thai': 'mwt-Thai',
        'mwt-Thai-TH': 'mwt-Thai',
        'mwt-TH': 'mwt-Thai',
        'mwu': 'mwu',
        'mwu-Latn-SS': 'mwu',
        'mwu-Latn': 'mwu',
        'mwu-SS': 'mwu',
        'mwv': 'mwv',
        'mwv-Latn-ID': 'mwv',
        'mwv-ID': 'mwv',
        'mwv-Latn': 'mwv',
        'mww': 'mww',
        'mww-Latn-CN': 'mww',
        'mww-CN': 'mww',
        'mww-Latn': 'mww',
        'mww-Hmng': 'mww-Hmng',
        'mww-Hmng-CN': 'mww-Hmng',
        'mww-Laoo': 'mww-Laoo',
        'mww-Laoo-LA': 'mww-Laoo',
        'mww-LA': 'mww-Laoo',
        'mww-Plrd': 'mww-Plrd',
        'mww-Plrd-CN': 'mww-Plrd',
        'mww-Thai': 'mww-Thai',
        'mww-Thai-TH': 'mww-Thai',
        'mww-TH': 'mww-Thai',
        'mwx': 'mwx',
        'mwx-Latn-TZ': 'mwx',
        'mwx-Latn': 'mwx',
        'mwx-TZ': 'mwx',
        'mwy': 'mwy',
        'mwy-Latn-TZ': 'mwy',
        'mwy-Latn': 'mwy',
        'mwy-TZ': 'mwy',
        'mwz': 'mwz',
        'mwz-Latn-CD': 'mwz',
        'mwz-CD': 'mwz',
        'mwz-Latn': 'mwz',
        'mxa': 'mxa',
        'mxa-Latn-MX': 'mxa',
        'mxa-Latn': 'mxa',
        'mxa-MX': 'mxa',
        'mxb': 'mxb',
        'mxb-Latn-MX': 'mxb',
        'mxb-Latn': 'mxb',
        'mxb-MX': 'mxb',
        'mxc': 'mxc',
        'mxc-Latn-ZW': 'mxc',
        'mxc-Latn': 'mxc',
        'mxc-ZW': 'mxc',
        'mxd': 'mxd',
        'mxd-Latn-ID': 'mxd',
        'mxd-ID': 'mxd',
        'mxd-Latn': 'mxd',
        'mxe': 'mxe',
        'mxe-Latn-VU': 'mxe',
        'mxe-Latn': 'mxe',
        'mxe-VU': 'mxe',
        'mxf': 'mxf',
        'mxf-Latn-CM': 'mxf',
        'mxf-CM': 'mxf',
        'mxf-Latn': 'mxf',
        'mxg': 'mxg',
        'mxg-Latn-AO': 'mxg',
        'mxg-AO': 'mxg',
        'mxg-Latn': 'mxg',
        'mxh': 'mxh',
        'mxh-Latn-CD': 'mxh',
        'mxh-CD': 'mxh',
        'mxh-Latn': 'mxh',
        'mxi': 'mxi',
        'mxi-Latn-ES': 'mxi',
        'mxi-ES': 'mxi',
        'mxi-Latn': 'mxi',
        'mxj': 'mxj',
        'mxj-Latn-IN': 'mxj',
        'mxj-IN': 'mxj',
        'mxj-Latn': 'mxj',
        'mxk': 'mxk',
        'mxk-Latn-PG': 'mxk',
        'mxk-Latn': 'mxk',
        'mxk-PG': 'mxk',
        'mxl': 'mxl',
        'mxl-Latn-BJ': 'mxl',
        'mxl-BJ': 'mxl',
        'mxl-Latn': 'mxl',
        'mxm': 'mxm',
        'mxm-Latn-PG': 'mxm',
        'mxm-Latn': 'mxm',
        'mxm-PG': 'mxm',
        'mxn': 'mxn',
        'mxn-Latn-ID': 'mxn',
        'mxn-ID': 'mxn',
        'mxn-Latn': 'mxn',
        'mxo': 'mxo',
        'mxo-Latn-ZM': 'mxo',
        'mxo-Latn': 'mxo',
        'mxo-ZM': 'mxo',
        'mxp': 'mxp',
        'mxp-Latn-MX': 'mxp',
        'mxp-Latn': 'mxp',
        'mxp-MX': 'mxp',
        'mxq': 'mxq',
        'mxq-Latn-MX': 'mxq',
        'mxq-Latn': 'mxq',
        'mxq-MX': 'mxq',
        'mxr': 'mxr',
        'mxr-Latn-MY': 'mxr',
        'mxr-Latn': 'mxr',
        'mxr-MY': 'mxr',
        'mxs': 'mxs',
        'mxs-Latn-MX': 'mxs',
        'mxs-Latn': 'mxs',
        'mxs-MX': 'mxs',
        'mxt': 'mxt',
        'mxt-Latn-MX': 'mxt',
        'mxt-Latn': 'mxt',
        'mxt-MX': 'mxt',
        'mxu': 'mxu',
        'mxu-Latn-CM': 'mxu',
        'mxu-CM': 'mxu',
        'mxu-Latn': 'mxu',
        'mxv': 'mxv',
        'mxv-Latn-MX': 'mxv',
        'mxv-Latn': 'mxv',
        'mxv-MX': 'mxv',
        'mxw': 'mxw',
        'mxw-Latn-PG': 'mxw',
        'mxw-Latn': 'mxw',
        'mxw-PG': 'mxw',
        'mxx': 'mxx',
        'mxx-Latn-CI': 'mxx',
        'mxx-CI': 'mxx',
        'mxx-Latn': 'mxx',
        'mxy': 'mxy',
        'mxy-Latn-MX': 'mxy',
        'mxy-Latn': 'mxy',
        'mxy-MX': 'mxy',
        'mxz': 'mxz',
        'mxz-Latn-ID': 'mxz',
        'mxz-ID': 'mxz',
        'mxz-Latn': 'mxz',
        'my': 'my',
        'my-Mymr-MM': 'my',
        'my-MM': 'my',
        'my-Mymr': 'my',
        'my-Brai': 'my-Brai',
        'my-Brai-MM': 'my-Brai',
        'myb': 'myb',
        'myb-Latn-TD': 'myb',
        'myb-Latn': 'myb',
        'myb-TD': 'myb',
        'myc': 'myc',
        'myc-Latn-CD': 'myc',
        'myc-CD': 'myc',
        'myc-Latn': 'myc',
        'mye': 'mye',
        'mye-Latn-GA': 'mye',
        'mye-GA': 'mye',
        'mye-Latn': 'mye',
        'myf': 'myf',
        'myf-Latn-ET': 'myf',
        'myf-ET': 'myf',
        'myf-Latn': 'myf',
        'myg': 'myg',
        'myg-Latn-CM': 'myg',
        'myg-CM': 'myg',
        'myg-Latn': 'myg',
        'myh': 'myh',
        'myh-Latn-US': 'myh',
        'myh-Latn': 'myh',
        'myh-US': 'myh',
        'myi': 'myi',
        'myi-Zyyy-IN': 'myi',
        'myi-IN': 'myi',
        'myi-Zyyy': 'myi',
        'myj': 'myj',
        'myj-Latn-SS': 'myj',
        'myj-Latn': 'myj',
        'myj-SS': 'myj',
        'myk': 'myk',
        'myk-Latn-ML': 'myk',
        'myk-Latn': 'myk',
        'myk-ML': 'myk',
        'myl': 'myl',
        'myl-Latn-ID': 'myl',
        'myl-ID': 'myl',
        'myl-Latn': 'myl',
        'mym': 'mym',
        'mym-Ethi-ET': 'mym',
        'mym-ET': 'mym',
        'mym-Ethi': 'mym',
        'mym-Latn': 'mym-Latn',
        'mym-Latn-ET': 'mym-Latn',
        'myo': 'myo',
        'myo-Zyyy-ET': 'myo',
        'myo-ET': 'myo',
        'myo-Zyyy': 'myo',
        'myp': 'myp',
        'myp-Latn-BR': 'myp',
        'myp-BR': 'myp',
        'myp-Latn': 'myp',
        'myr': 'myr',
        'myr-Latn-PE': 'myr',
        'myr-Latn': 'myr',
        'myr-PE': 'myr',
        'mys': 'mys',
        'mys-Zyyy-ET': 'mys',
        'mys-ET': 'mys',
        'mys-Zyyy': 'mys',
        'myu': 'myu',
        'myu-Latn-BR': 'myu',
        'myu-BR': 'myu',
        'myu-Latn': 'myu',
        'myv': 'myv',
        'myv-Cyrl-RU': 'myv',
        'myv-Cyrl': 'myv',
        'myv-RU': 'myv',
        'myw': 'myw',
        'myw-Latn-PG': 'myw',
        'myw-Latn': 'myw',
        'myw-PG': 'myw',
        'myx': 'myx',
        'myx-Latn-UG': 'myx',
        'myx-Latn': 'myx',
        'myx-UG': 'myx',
        'myy': 'myy',
        'myy-Latn-CO': 'myy',
        'myy-CO': 'myy',
        'myy-Latn': 'myy',
        'myz': 'myz',
        'myz-Mand-IR': 'myz',
        'myz-IR': 'myz',
        'myz-Mand': 'myz',
        'mza': 'mza',
        'mza-Latn-MX': 'mza',
        'mza-Latn': 'mza',
        'mza-MX': 'mza',
        'mzb-Arab': 'mzb-Arab',
        'mzb-Arab-DZ': 'mzb-Arab',
        'mzb-Latn': 'mzb-Latn',
        'mzb-Latn-DZ': 'mzb-Latn',
        'mzb-Tfng': 'mzb-Tfng',
        'mzb-Tfng-DZ': 'mzb-Tfng',
        'mzc': 'mzc',
        'mzc-Zxxx-MG': 'mzc',
        'mzc-MG': 'mzc',
        'mzc-Zxxx': 'mzc',
        'sgn-mzc': 'mzc',
        'sgn-mzc-MG': 'mzc',
        'mzd': 'mzd',
        'mzd-Latn-CM': 'mzd',
        'mzd-CM': 'mzd',
        'mzd-Latn': 'mzd',
        'mze': 'mze',
        'mze-Latn-PG': 'mze',
        'mze-Latn': 'mze',
        'mze-PG': 'mze',
        'mzg': 'mzg',
        'mzg-Zxxx-VA': 'mzg',
        'mzg-VA': 'mzg',
        'mzg-Zxxx': 'mzg',
        'sgn-mzg': 'mzg',
        'sgn-mzg-VA': 'mzg',
        'mzh': 'mzh',
        'mzh-Latn-AR': 'mzh',
        'mzh-AR': 'mzh',
        'mzh-Latn': 'mzh',
        'mzi': 'mzi',
        'mzi-Latn-MX': 'mzi',
        'mzi-Latn': 'mzi',
        'mzi-MX': 'mzi',
        'mzj': 'mzj',
        'mzj-Latn-LR': 'mzj',
        'mzj-LR': 'mzj',
        'mzj-Latn': 'mzj',
        'mzk': 'mzk',
        'mzk-Latn-NG': 'mzk',
        'mzk-Latn': 'mzk',
        'mzk-NG': 'mzk',
        'mzl': 'mzl',
        'mzl-Latn-MX': 'mzl',
        'mzl-Latn': 'mzl',
        'mzl-MX': 'mzl',
        'mzm': 'mzm',
        'mzm-Latn-NG': 'mzm',
        'mzm-Latn': 'mzm',
        'mzm-NG': 'mzm',
        'mzn': 'mzn',
        'mzn-Arab-IR': 'mzn',
        'mzn-Arab': 'mzn',
        'mzn-IR': 'mzn',
        'mzo': 'mzo',
        'mzo-Latn-BR': 'mzo',
        'mzo-BR': 'mzo',
        'mzo-Latn': 'mzo',
        'mzp': 'mzp',
        'mzp-Latn-BO': 'mzp',
        'mzp-BO': 'mzp',
        'mzp-Latn': 'mzp',
        'mzq': 'mzq',
        'mzq-Latn-ID': 'mzq',
        'mzq-ID': 'mzq',
        'mzq-Latn': 'mzq',
        'mzr': 'mzr',
        'mzr-Latn-BR': 'mzr',
        'mzr-BR': 'mzr',
        'mzr-Latn': 'mzr',
        'mzs': 'mzs',
        'mzs-Zyyy-MO': 'mzs',
        'mzs-MO': 'mzs',
        'mzs-Zyyy': 'mzs',
        'mzt': 'mzt',
        'mzt-Latn-MY': 'mzt',
        'mzt-Latn': 'mzt',
        'mzt-MY': 'mzt',
        'mzu': 'mzu',
        'mzu-Latn-PG': 'mzu',
        'mzu-Latn': 'mzu',
        'mzu-PG': 'mzu',
        'mzv': 'mzv',
        'mzv-Latn-CF': 'mzv',
        'mzv-CF': 'mzv',
        'mzv-Latn': 'mzv',
        'mzw': 'mzw',
        'mzw-Latn-GH': 'mzw',
        'mzw-GH': 'mzw',
        'mzw-Latn': 'mzw',
        'mzx': 'mzx',
        'mzx-Latn-GY': 'mzx',
        'mzx-GY': 'mzx',
        'mzx-Latn': 'mzx',
        'mzy': 'mzy',
        'mzy-Zxxx-MZ': 'mzy',
        'mzy-MZ': 'mzy',
        'mzy-Zxxx': 'mzy',
        'sgn-mzy': 'mzy',
        'sgn-mzy-MZ': 'mzy',
        'mzz': 'mzz',
        'mzz-Latn-PG': 'mzz',
        'mzz-Latn': 'mzz',
        'mzz-PG': 'mzz',
        'na': 'na',
        'na-Latn-NR': 'na',
        'na-Latn': 'na',
        'na-NR': 'na',
        'naa': 'naa',
        'naa-Latn-ID': 'naa',
        'naa-ID': 'naa',
        'naa-Latn': 'naa',
        'nab': 'nab',
        'nab-Latn-BR': 'nab',
        'nab-BR': 'nab',
        'nab-Latn': 'nab',
        'nac': 'nac',
        'nac-Latn-PG': 'nac',
        'nac-Latn': 'nac',
        'nac-PG': 'nac',
        'nae': 'nae',
        'nae-Latn-ID': 'nae',
        'nae-ID': 'nae',
        'nae-Latn': 'nae',
        'naf': 'naf',
        'naf-Latn-PG': 'naf',
        'naf-Latn': 'naf',
        'naf-PG': 'naf',
        'nag': 'nag',
        'nag-Latn-IN': 'nag',
        'nag-IN': 'nag',
        'nag-Latn': 'nag',
        'naj': 'naj',
        'naj-Latn-GN': 'naj',
        'naj-GN': 'naj',
        'naj-Latn': 'naj',
        'nak': 'nak',
        'nak-Latn-PG': 'nak',
        'nak-Latn': 'nak',
        'nak-PG': 'nak',
        'nal': 'nal',
        'nal-Latn-PG': 'nal',
        'nal-Latn': 'nal',
        'nal-PG': 'nal',
        'nam': 'nam',
        'nam-Latn-AU': 'nam',
        'nam-AU': 'nam',
        'nam-Latn': 'nam',
        'nan': 'nan',
        'nan-Hans-CN': 'nan',
        'nan-CN': 'nan',
        'nan-Hans': 'nan',
        'zh-nan': 'nan',
        'zh-nan-CN': 'nan',
        'nan-Bopo': 'nan-Bopo',
        'nan-Bopo-TW': 'nan-Bopo',
        'nan-Kana': 'nan-Kana',
        'nan-Kana-TW': 'nan-Kana',
        'nan-Latn': 'nan-Latn',
        'nan-Latn-TW': 'nan-Latn',
        'nan-Latn-x-transpoj': 'nan-Latn-x-transpoj',
        'nan-Latn-TW-x-transpoj': 'nan-Latn-x-transpoj',
        'nan-TW-x-transpoj': 'nan-Latn-x-transpoj',
        'zh-nan-TW-x-transpoj': 'nan-Latn-x-transpoj',
        'nao': 'nao',
        'nao-Zyyy-NP': 'nao',
        'nao-NP': 'nao',
        'nao-Zyyy': 'nao',
        'nap': 'nap',
        'nap-Latn-IT': 'nap',
        'nap-IT': 'nap',
        'nap-Latn': 'nap',
        'naq': 'naq',
        'naq-Latn-NA': 'naq',
        'naq-Latn': 'naq',
        'naq-NA': 'naq',
        'nar': 'nar',
        'nar-Latn-NG': 'nar',
        'nar-Latn': 'nar',
        'nar-NG': 'nar',
        'nas': 'nas',
        'nas-Latn-PG': 'nas',
        'nas-Latn': 'nas',
        'nas-PG': 'nas',
        'nat': 'nat',
        'nat-Latn-NG': 'nat',
        'nat-Latn': 'nat',
        'nat-NG': 'nat',
        'naw': 'naw',
        'naw-Latn-GH': 'naw',
        'naw-GH': 'naw',
        'naw-Latn': 'naw',
        'nax': 'nax',
        'nax-Latn-PG': 'nax',
        'nax-Latn': 'nax',
        'nax-PG': 'nax',
        'nay': 'nay',
        'nay-Latn-AU': 'nay',
        'nay-AU': 'nay',
        'nay-Latn': 'nay',
        'naz': 'naz',
        'naz-Latn-MX': 'naz',
        'naz-Latn': 'naz',
        'naz-MX': 'naz',
        'nb': 'nb',
        'nb-Latn-NO': 'nb',
        'nb-Latn': 'nb',
        'nb-NO': 'nb',
        'nba': 'nba',
        'nba-Latn-AO': 'nba',
        'nba-AO': 'nba',
        'nba-Latn': 'nba',
        'nbb': 'nbb',
        'nbb-Latn-NG': 'nbb',
        'nbb-Latn': 'nbb',
        'nbb-NG': 'nbb',
        'nbc': 'nbc',
        'nbc-Latn-IN': 'nbc',
        'nbc-IN': 'nbc',
        'nbc-Latn': 'nbc',
        'nbd': 'nbd',
        'nbd-Latn-CD': 'nbd',
        'nbd-CD': 'nbd',
        'nbd-Latn': 'nbd',
        'nbe': 'nbe',
        'nbe-Latn-IN': 'nbe',
        'nbe-IN': 'nbe',
        'nbe-Latn': 'nbe',
        'nbg': 'nbg',
        'nbg-Zyyy-IN': 'nbg',
        'nbg-IN': 'nbg',
        'nbg-Zyyy': 'nbg',
        'nbh': 'nbh',
        'nbh-Latn-NG': 'nbh',
        'nbh-Latn': 'nbh',
        'nbh-NG': 'nbh',
        'nbi': 'nbi',
        'nbi-Latn-IN': 'nbi',
        'nbi-IN': 'nbi',
        'nbi-Latn': 'nbi',
        'nbj': 'nbj',
        'nbj-Latn-AU': 'nbj',
        'nbj-AU': 'nbj',
        'nbj-Latn': 'nbj',
        'nbk': 'nbk',
        'nbk-Latn-PG': 'nbk',
        'nbk-Latn': 'nbk',
        'nbk-PG': 'nbk',
        'nbm': 'nbm',
        'nbm-Latn-CF': 'nbm',
        'nbm-CF': 'nbm',
        'nbm-Latn': 'nbm',
        'nbn': 'nbn',
        'nbn-Latn-ID': 'nbn',
        'nbn-ID': 'nbn',
        'nbn-Latn': 'nbn',
        'nbo': 'nbo',
        'nbo-Latn-NG': 'nbo',
        'nbo-Latn': 'nbo',
        'nbo-NG': 'nbo',
        'nbp': 'nbp',
        'nbp-Latn-NG': 'nbp',
        'nbp-Latn': 'nbp',
        'nbp-NG': 'nbp',
        'nbq': 'nbq',
        'nbq-Latn-ID': 'nbq',
        'nbq-ID': 'nbq',
        'nbq-Latn': 'nbq',
        'nbr': 'nbr',
        'nbr-Latn-NG': 'nbr',
        'nbr-Latn': 'nbr',
        'nbr-NG': 'nbr',
        'nns': 'nbr',
        'nns-Latn': 'nbr',
        'nns-Latn-NG': 'nbr',
        'nns-NG': 'nbr',
        'nbs': 'nbs',
        'nbs-Zxxx-NA': 'nbs',
        'nbs-NA': 'nbs',
        'nbs-Zxxx': 'nbs',
        'sgn-nbs': 'nbs',
        'sgn-nbs-NA': 'nbs',
        'nbt-Deva': 'nbt-Deva',
        'nbt-Deva-IN': 'nbt-Deva',
        'nbt-Latn': 'nbt-Latn',
        'nbt-Latn-IN': 'nbt-Latn',
        'nbu': 'nbu',
        'nbu-Latn-IN': 'nbu',
        'nbu-IN': 'nbu',
        'nbu-Latn': 'nbu',
        'nbv': 'nbv',
        'nbv-Latn-CM': 'nbv',
        'nbv-CM': 'nbv',
        'nbv-Latn': 'nbv',
        'nbw': 'nbw',
        'nbw-Latn-CD': 'nbw',
        'nbw-CD': 'nbw',
        'nbw-Latn': 'nbw',
        'nby': 'nby',
        'nby-Latn-PG': 'nby',
        'nby-Latn': 'nby',
        'nby-PG': 'nby',
        'nca': 'nca',
        'nca-Latn-PG': 'nca',
        'nca-Latn': 'nca',
        'nca-PG': 'nca',
        'ncb-Deva': 'ncb-Deva',
        'ncb-Deva-IN': 'ncb-Deva',
        'ncb-Latn': 'ncb-Latn',
        'ncb-Latn-IN': 'ncb-Latn',
        'ncc': 'ncc',
        'ncc-Latn-PG': 'ncc',
        'ncc-Latn': 'ncc',
        'ncc-PG': 'ncc',
        'ncd': 'ncd',
        'ncd-Deva-NP': 'ncd',
        'ncd-Deva': 'ncd',
        'ncd-NP': 'ncd',
        'nce': 'nce',
        'nce-Latn-PG': 'nce',
        'nce-Latn': 'nce',
        'nce-PG': 'nce',
        'ncf': 'ncf',
        'ncf-Latn-PG': 'ncf',
        'ncf-Latn': 'ncf',
        'ncf-PG': 'ncf',
        'ncg': 'ncg',
        'ncg-Latn-CA': 'ncg',
        'ncg-CA': 'ncg',
        'ncg-Latn': 'ncg',
        'nch': 'nch',
        'nch-Latn-MX': 'nch',
        'nch-Latn': 'nch',
        'nch-MX': 'nch',
        'nci': 'nci',
        'nci-Latn-MX': 'nci',
        'nci-Latn': 'nci',
        'nci-MX': 'nci',
        'ncj': 'ncj',
        'ncj-Latn-MX': 'ncj',
        'ncj-Latn': 'ncj',
        'ncj-MX': 'ncj',
        'nck': 'nck',
        'nck-Latn-AU': 'nck',
        'nck-AU': 'nck',
        'nck-Latn': 'nck',
        'ncl': 'ncl',
        'ncl-Latn-MX': 'ncl',
        'ncl-Latn': 'ncl',
        'ncl-MX': 'ncl',
        'ncm': 'ncm',
        'ncm-Latn-PG': 'ncm',
        'ncm-Latn': 'ncm',
        'ncm-PG': 'ncm',
        'ncn': 'ncn',
        'ncn-Latn-PG': 'ncn',
        'ncn-Latn': 'ncn',
        'ncn-PG': 'ncn',
        'nco': 'nco',
        'nco-Latn-PG': 'nco',
        'nco-Latn': 'nco',
        'nco-PG': 'nco',
        'ncq': 'ncq',
        'ncq-Laoo-LA': 'ncq',
        'ncq-LA': 'ncq',
        'ncq-Laoo': 'ncq',
        'ncq-Thai': 'ncq-Thai',
        'ncq-Thai-LA': 'ncq-Thai',
        'ncr': 'ncr',
        'ncr-Latn-CM': 'ncr',
        'ncr-CM': 'ncr',
        'ncr-Latn': 'ncr',
        'ncs': 'ncs',
        'ncs-Zxxx-NI': 'ncs',
        'ncs-NI': 'ncs',
        'ncs-Zxxx': 'ncs',
        'sgn-ncs': 'ncs',
        'sgn-ncs-NI': 'ncs',
        'nct-Beng': 'nct-Beng',
        'nct-Beng-IN': 'nct-Beng',
        'nct-Latn': 'nct-Latn',
        'nct-Latn-IN': 'nct-Latn',
        'ncu': 'ncu',
        'ncu-Latn-GH': 'ncu',
        'ncu-GH': 'ncu',
        'ncu-Latn': 'ncu',
        'ncx': 'ncx',
        'ncx-Latn-MX': 'ncx',
        'ncx-Latn': 'ncx',
        'ncx-MX': 'ncx',
        'ncz': 'ncz',
        'ncz-Zyyy-US': 'ncz',
        'ncz-US': 'ncz',
        'ncz-Zyyy': 'ncz',
        'nd': 'nd',
        'nd-Latn-ZW': 'nd',
        'nd-Latn': 'nd',
        'nd-ZW': 'nd',
        'nda': 'nda',
        'nda-Latn-CG': 'nda',
        'nda-CG': 'nda',
        'nda-Latn': 'nda',
        'ndb': 'ndb',
        'ndb-Latn-CM': 'ndb',
        'ndb-CM': 'ndb',
        'ndb-Latn': 'ndb',
        'ndc': 'ndc',
        'ndc-Latn-MZ': 'ndc',
        'ndc-Latn': 'ndc',
        'ndc-MZ': 'ndc',
        'ndd': 'ndd',
        'ndd-Latn-NG': 'ndd',
        'ndd-Latn': 'ndd',
        'ndd-NG': 'ndd',
        'ndf': 'ndf',
        'ndf-Cyrl-RU': 'ndf',
        'ndf-Cyrl': 'ndf',
        'ndf-RU': 'ndf',
        'ndg': 'ndg',
        'ndg-Latn-TZ': 'ndg',
        'ndg-Latn': 'ndg',
        'ndg-TZ': 'ndg',
        'ndh': 'ndh',
        'ndh-Latn-TZ': 'ndh',
        'ndh-Latn': 'ndh',
        'ndh-TZ': 'ndh',
        'ndi': 'ndi',
        'ndi-Latn-NG': 'ndi',
        'ndi-Latn': 'ndi',
        'ndi-NG': 'ndi',
        'ndj': 'ndj',
        'ndj-Latn-TZ': 'ndj',
        'ndj-Latn': 'ndj',
        'ndj-TZ': 'ndj',
        'ndk': 'ndk',
        'ndk-Latn-CD': 'ndk',
        'ndk-CD': 'ndk',
        'ndk-Latn': 'ndk',
        'ndl': 'ndl',
        'ndl-Latn-CD': 'ndl',
        'ndl-CD': 'ndl',
        'ndl-Latn': 'ndl',
        'ndm': 'ndm',
        'ndm-Latn-TD': 'ndm',
        'ndm-Latn': 'ndm',
        'ndm-TD': 'ndm',
        'ndn': 'ndn',
        'ndn-Latn-CG': 'ndn',
        'ndn-CG': 'ndn',
        'ndn-Latn': 'ndn',
        'ndp': 'ndp',
        'ndp-Latn-UG': 'ndp',
        'ndp-Latn': 'ndp',
        'ndp-UG': 'ndp',
        'ndq': 'ndq',
        'ndq-Latn-AO': 'ndq',
        'ndq-AO': 'ndq',
        'ndq-Latn': 'ndq',
        'ndr': 'ndr',
        'ndr-Latn-NG': 'ndr',
        'ndr-Latn': 'ndr',
        'ndr-NG': 'ndr',
        'nds': 'nds',
        'nds-Latn-DE': 'nds',
        'nds-DE': 'nds',
        'nds-Latn': 'nds',
        'nds-NL': 'nds-NL',
        'nds-Latn-NL': 'nds-NL',
        'ndt': 'ndt',
        'ndt-Latn-CD': 'ndt',
        'ndt-CD': 'ndt',
        'ndt-Latn': 'ndt',
        'ndu': 'ndu',
        'ndu-Latn-CM': 'ndu',
        'ndu-CM': 'ndu',
        'ndu-Latn': 'ndu',
        'ndv': 'ndv',
        'ndv-Latn-SN': 'ndv',
        'ndv-Latn': 'ndv',
        'ndv-SN': 'ndv',
        'ndw': 'ndw',
        'ndw-Latn-CD': 'ndw',
        'ndw-CD': 'ndw',
        'ndw-Latn': 'ndw',
        'ndx': 'ndx',
        'ndx-Latn-ID': 'ndx',
        'ndx-ID': 'ndx',
        'ndx-Latn': 'ndx',
        'ndy': 'ndy',
        'ndy-Latn-CF': 'ndy',
        'ndy-CF': 'ndy',
        'ndy-Latn': 'ndy',
        'ndy-TD': 'ndy-TD',
        'ndy-Latn-TD': 'ndy-TD',
        'ndz': 'ndz',
        'ndz-Latn-SS': 'ndz',
        'ndz-Latn': 'ndz',
        'ndz-SS': 'ndz',
        'ne': 'ne',
        'ne-Deva-NP': 'ne',
        'ne-Deva': 'ne',
        'ne-NP': 'ne',
        'npi': 'ne',
        'npi-Deva': 'ne',
        'npi-Deva-NP': 'ne',
        'npi-NP': 'ne',
        'ne-Brai': 'ne-Brai',
        'ne-Brai-NP': 'ne-Brai',
        'npi-Brai': 'ne-Brai',
        'npi-Brai-NP': 'ne-Brai',
        'ne-IN': 'ne-IN',
        'ne-Deva-IN': 'ne-IN',
        'ne-Newa': 'ne-Newa',
        'ne-Newa-NP': 'ne-Newa',
        'nea': 'nea',
        'nea-Latn-ID': 'nea',
        'nea-ID': 'nea',
        'nea-Latn': 'nea',
        'neb': 'neb',
        'neb-Latn-CI': 'neb',
        'neb-CI': 'neb',
        'neb-Latn': 'neb',
        'nec': 'nec',
        'nec-Latn-ID': 'nec',
        'nec-ID': 'nec',
        'nec-Latn': 'nec',
        'ned': 'ned',
        'ned-Latn-NG': 'ned',
        'ned-Latn': 'ned',
        'ned-NG': 'ned',
        'nee': 'nee',
        'nee-Latn-NC': 'nee',
        'nee-Latn': 'nee',
        'nee-NC': 'nee',
        'nef': 'nef',
        'nef-Zyyy-IN': 'nef',
        'nef-IN': 'nef',
        'nef-Zyyy': 'nef',
        'neg': 'neg',
        'neg-Cyrl-RU': 'neg',
        'neg-Cyrl': 'neg',
        'neg-RU': 'neg',
        'neh': 'neh',
        'neh-Zyyy-BT': 'neh',
        'neh-BT': 'neh',
        'neh-Zyyy': 'neh',
        'nei': 'nei',
        'nei-Zyyy-TR': 'nei',
        'nei-TR': 'nei',
        'nei-Zyyy': 'nei',
        'nej': 'nej',
        'nej-Latn-PG': 'nej',
        'nej-Latn': 'nej',
        'nej-PG': 'nej',
        'nek': 'nek',
        'nek-Latn-NC': 'nek',
        'nek-Latn': 'nek',
        'nek-NC': 'nek',
        'nem': 'nem',
        'nem-Latn-NC': 'nem',
        'nem-Latn': 'nem',
        'nem-NC': 'nem',
        'nen': 'nen',
        'nen-Latn-NC': 'nen',
        'nen-Latn': 'nen',
        'nen-NC': 'nen',
        'neo': 'neo',
        'neo-Latn-VN': 'neo',
        'neo-Latn': 'neo',
        'neo-VN': 'neo',
        'neq': 'neq',
        'neq-Latn-MX': 'neq',
        'neq-Latn': 'neq',
        'neq-MX': 'neq',
        'ner': 'ner',
        'ner-Latn-ID': 'ner',
        'ner-ID': 'ner',
        'ner-Latn': 'ner',
        'nes': 'nes',
        'nes-Zyyy-IN': 'nes',
        'nes-IN': 'nes',
        'nes-Zyyy': 'nes',
        'net': 'net',
        'net-Latn-PG': 'net',
        'net-Latn': 'net',
        'net-PG': 'net',
        'neu': 'neu',
        'neu-Latn-001': 'neu',
        'neu-001': 'neu',
        'neu-Latn': 'neu',
        'nev': 'nev',
        'nev-Zyyy-LA': 'nev',
        'nev-LA': 'nev',
        'nev-Zyyy': 'nev',
        'new': 'new',
        'new-Deva-NP': 'new',
        'new-Deva': 'new',
        'new-NP': 'new',
        'new-Newa': 'new-Newa',
        'new-Newa-NP': 'new-Newa',
        'new-Zzzz-x-ranjana': 'new-Zzzz-x-ranjana',
        'new-Zzzz-NP-x-ranjana': 'new-Zzzz-x-ranjana',
        'new-NP-x-ranjana': 'new-Zzzz-x-ranjana',
        'nex': 'nex',
        'nex-Latn-PG': 'nex',
        'nex-Latn': 'nex',
        'nex-PG': 'nex',
        'ney': 'ney',
        'ney-Latn-CI': 'ney',
        'ney-CI': 'ney',
        'ney-Latn': 'ney',
        'nez': 'nez',
        'nez-Latn-US': 'nez',
        'nez-Latn': 'nez',
        'nez-US': 'nez',
        'nfa': 'nfa',
        'nfa-Latn-ID': 'nfa',
        'nfa-ID': 'nfa',
        'nfa-Latn': 'nfa',
        'nfd': 'nfd',
        'nfd-Latn-NG': 'nfd',
        'nfd-Latn': 'nfd',
        'nfd-NG': 'nfd',
        'nfl': 'nfl',
        'nfl-Latn-SB': 'nfl',
        'nfl-Latn': 'nfl',
        'nfl-SB': 'nfl',
        'nfr': 'nfr',
        'nfr-Latn-GH': 'nfr',
        'nfr-GH': 'nfr',
        'nfr-Latn': 'nfr',
        'nfu': 'nfu',
        'nfu-Latn-CM': 'nfu',
        'nfu-CM': 'nfu',
        'nfu-Latn': 'nfu',
        'ng': 'ng',
        'ng-Latn-NA': 'ng',
        'ng-Latn': 'ng',
        'ng-NA': 'ng',
        'nga': 'nga',
        'nga-Latn-CD': 'nga',
        'nga-CD': 'nga',
        'nga-Latn': 'nga',
        'ngb': 'ngb',
        'ngb-Latn-CD': 'ngb',
        'ngb-CD': 'ngb',
        'ngb-Latn': 'ngb',
        'ngc': 'ngc',
        'ngc-Latn-CD': 'ngc',
        'ngc-CD': 'ngc',
        'ngc-Latn': 'ngc',
        'ngd': 'ngd',
        'ngd-Latn-CF': 'ngd',
        'ngd-CF': 'ngd',
        'ngd-Latn': 'ngd',
        'nge': 'nge',
        'nge-Latn-CM': 'nge',
        'nge-CM': 'nge',
        'nge-Latn': 'nge',
        'ngg': 'ngg',
        'ngg-Latn-CF': 'ngg',
        'ngg-CF': 'ngg',
        'ngg-Latn': 'ngg',
        'ngh': 'ngh',
        'ngh-Latn-ZA': 'ngh',
        'ngh-Latn': 'ngh',
        'ngh-ZA': 'ngh',
        'ngi': 'ngi',
        'ngi-Latn-NG': 'ngi',
        'ngi-Latn': 'ngi',
        'ngi-NG': 'ngi',
        'ngj': 'ngj',
        'ngj-Latn-CM': 'ngj',
        'ngj-CM': 'ngj',
        'ngj-Latn': 'ngj',
        'ngk': 'ngk',
        'ngk-Latn-AU': 'ngk',
        'ngk-AU': 'ngk',
        'ngk-Latn': 'ngk',
        'ngl': 'ngl',
        'ngl-Latn-MZ': 'ngl',
        'ngl-Latn': 'ngl',
        'ngl-MZ': 'ngl',
        'ngm': 'ngm',
        'ngm-Latn-FM': 'ngm',
        'ngm-FM': 'ngm',
        'ngm-Latn': 'ngm',
        'ngn': 'ngn',
        'ngn-Latn-CM': 'ngn',
        'ngn-CM': 'ngn',
        'ngn-Latn': 'ngn',
        'ngo': 'ngo',
        'ngo-Latn-TZ': 'ngo',
        'ngo-Latn': 'ngo',
        'ngo-TZ': 'ngo',
        'ngp': 'ngp',
        'ngp-Latn-TZ': 'ngp',
        'ngp-Latn': 'ngp',
        'ngp-TZ': 'ngp',
        'ngq': 'ngq',
        'ngq-Latn-TZ': 'ngq',
        'ngq-Latn': 'ngq',
        'ngq-TZ': 'ngq',
        'ngr': 'ngr',
        'ngr-Latn-SB': 'ngr',
        'ngr-Latn': 'ngr',
        'ngr-SB': 'ngr',
        'ngs': 'ngs',
        'ngs-Latn-NG': 'ngs',
        'ngs-Latn': 'ngs',
        'ngs-NG': 'ngs',
        'ngt': 'ngt',
        'ngt-Laoo-LA': 'ngt',
        'llo': 'ngt',
        'llo-LA': 'ngt',
        'llo-Laoo': 'ngt',
        'llo-Laoo-LA': 'ngt',
        'ngt-LA': 'ngt',
        'ngt-Laoo': 'ngt',
        'ngu': 'ngu',
        'ngu-Latn-MX': 'ngu',
        'ngu-Latn': 'ngu',
        'ngu-MX': 'ngu',
        'ngv': 'ngv',
        'ngv-Latn-CM': 'ngv',
        'ngv-CM': 'ngv',
        'ngv-Latn': 'ngv',
        'nnx': 'ngv',
        'nnx-CM': 'ngv',
        'nnx-Latn': 'ngv',
        'nnx-Latn-CM': 'ngv',
        'ngw': 'ngw',
        'ngw-Latn-NG': 'ngw',
        'ngw-Latn': 'ngw',
        'ngw-NG': 'ngw',
        'ngx': 'ngx',
        'ngx-Latn-NG': 'ngx',
        'ngx-Latn': 'ngx',
        'ngx-NG': 'ngx',
        'ngy': 'ngy',
        'ngy-Latn-CM': 'ngy',
        'ngy-CM': 'ngy',
        'ngy-Latn': 'ngy',
        'ngz': 'ngz',
        'ngz-Latn-CG': 'ngz',
        'ngz-CG': 'ngz',
        'ngz-Latn': 'ngz',
        'nha': 'nha',
        'nha-Latn-AU': 'nha',
        'nha-AU': 'nha',
        'nha-Latn': 'nha',
        'nhb': 'nhb',
        'nhb-Latn-CI': 'nhb',
        'nhb-CI': 'nhb',
        'nhb-Latn': 'nhb',
        'nhc': 'nhc',
        'nhc-Latn-MX': 'nhc',
        'nhc-Latn': 'nhc',
        'nhc-MX': 'nhc',
        'nhd': 'nhd',
        'nhd-Latn-PY': 'nhd',
        'nhd-Latn': 'nhd',
        'nhd-PY': 'nhd',
        'nhe': 'nhe',
        'nhe-Latn-MX': 'nhe',
        'nhe-Latn': 'nhe',
        'nhe-MX': 'nhe',
        'nhf': 'nhf',
        'nhf-Latn-AU': 'nhf',
        'nhf-AU': 'nhf',
        'nhf-Latn': 'nhf',
        'nhg': 'nhg',
        'nhg-Latn-MX': 'nhg',
        'nhg-Latn': 'nhg',
        'nhg-MX': 'nhg',
        'nhh': 'nhh',
        'nhh-Zyyy-IN': 'nhh',
        'nhh-IN': 'nhh',
        'nhh-Zyyy': 'nhh',
        'nhi': 'nhi',
        'nhi-Latn-MX': 'nhi',
        'nhi-Latn': 'nhi',
        'nhi-MX': 'nhi',
        'nhk': 'nhk',
        'nhk-Latn-MX': 'nhk',
        'nhk-Latn': 'nhk',
        'nhk-MX': 'nhk',
        'nhm': 'nhm',
        'nhm-Latn-MX': 'nhm',
        'nhm-Latn': 'nhm',
        'nhm-MX': 'nhm',
        'nhn': 'nhn',
        'nhn-Latn-MX': 'nhn',
        'nhn-Latn': 'nhn',
        'nhn-MX': 'nhn',
        'nho': 'nho',
        'nho-Latn-PG': 'nho',
        'nho-Latn': 'nho',
        'nho-PG': 'nho',
        'nhp': 'nhp',
        'nhp-Latn-MX': 'nhp',
        'nhp-Latn': 'nhp',
        'nhp-MX': 'nhp',
        'nhq': 'nhq',
        'nhq-Latn-MX': 'nhq',
        'nhq-Latn': 'nhq',
        'nhq-MX': 'nhq',
        'nhr': 'nhr',
        'nhr-Latn-BW': 'nhr',
        'nhr-BW': 'nhr',
        'nhr-Latn': 'nhr',
        'nht': 'nht',
        'nht-Latn-MX': 'nht',
        'nht-Latn': 'nht',
        'nht-MX': 'nht',
        'nhu': 'nhu',
        'nhu-Latn-CM': 'nhu',
        'nhu-CM': 'nhu',
        'nhu-Latn': 'nhu',
        'nhv': 'nhv',
        'nhv-Latn-MX': 'nhv',
        'nhv-Latn': 'nhv',
        'nhv-MX': 'nhv',
        'nhw': 'nhw',
        'nhw-Latn-MX': 'nhw',
        'nhw-Latn': 'nhw',
        'nhw-MX': 'nhw',
        'nhx': 'nhx',
        'nhx-Latn-MX': 'nhx',
        'nhx-Latn': 'nhx',
        'nhx-MX': 'nhx',
        'nhy': 'nhy',
        'nhy-Latn-MX': 'nhy',
        'nhy-Latn': 'nhy',
        'nhy-MX': 'nhy',
        'nhz': 'nhz',
        'nhz-Latn-MX': 'nhz',
        'nhz-Latn': 'nhz',
        'nhz-MX': 'nhz',
        'nia': 'nia',
        'nia-Latn-ID': 'nia',
        'nia-ID': 'nia',
        'nia-Latn': 'nia',
        'nib': 'nib',
        'nib-Latn-PG': 'nib',
        'nib-Latn': 'nib',
        'nib-PG': 'nib',
        'nid': 'nid',
        'nid-Latn-AU': 'nid',
        'nid-AU': 'nid',
        'nid-Latn': 'nid',
        'nie': 'nie',
        'nie-Latn-TD': 'nie',
        'nie-Latn': 'nie',
        'nie-TD': 'nie',
        'nif': 'nif',
        'nif-Latn-PG': 'nif',
        'nif-Latn': 'nif',
        'nif-PG': 'nif',
        'nig': 'nig',
        'nig-Latn-AU': 'nig',
        'nig-AU': 'nig',
        'nig-Latn': 'nig',
        'nih': 'nih',
        'nih-Latn-TZ': 'nih',
        'nih-Latn': 'nih',
        'nih-TZ': 'nih',
        'nii': 'nii',
        'nii-Latn-PG': 'nii',
        'nii-Latn': 'nii',
        'nii-PG': 'nii',
        'nij': 'nij',
        'nij-Latn-ID': 'nij',
        'nij-ID': 'nij',
        'nij-Latn': 'nij',
        'nik': 'nik',
        'nik-Zyyy-IN': 'nik',
        'nik-IN': 'nik',
        'nik-Zyyy': 'nik',
        'nil': 'nil',
        'nil-Latn-ID': 'nil',
        'nil-ID': 'nil',
        'nil-Latn': 'nil',
        'nim': 'nim',
        'nim-Latn-TZ': 'nim',
        'nim-Latn': 'nim',
        'nim-TZ': 'nim',
        'nin': 'nin',
        'nin-Latn-NG': 'nin',
        'nin-Latn': 'nin',
        'nin-NG': 'nin',
        'nio': 'nio',
        'nio-Cyrl-RU': 'nio',
        'nio-Cyrl': 'nio',
        'nio-RU': 'nio',
        'niq': 'niq',
        'niq-Latn-KE': 'niq',
        'niq-KE': 'niq',
        'niq-Latn': 'niq',
        'nir': 'nir',
        'nir-Latn-ID': 'nir',
        'nir-ID': 'nir',
        'nir-Latn': 'nir',
        'nis': 'nis',
        'nis-Latn-PG': 'nis',
        'nis-Latn': 'nis',
        'nis-PG': 'nis',
        'nit': 'nit',
        'nit-Telu-IN': 'nit',
        'nit-IN': 'nit',
        'nit-Telu': 'nit',
        'niu': 'niu',
        'niu-Latn-NU': 'niu',
        'niu-Latn': 'niu',
        'niu-NU': 'niu',
        'niv': 'niv',
        'niv-Cyrl-RU': 'niv',
        'niv-Cyrl': 'niv',
        'niv-RU': 'niv',
        'niv-Latn': 'niv-Latn',
        'niv-Latn-RU': 'niv-Latn',
        'niw': 'niw',
        'niw-Latn-PG': 'niw',
        'niw-Latn': 'niw',
        'niw-PG': 'niw',
        'nix': 'nix',
        'nix-Latn-CD': 'nix',
        'nix-CD': 'nix',
        'nix-Latn': 'nix',
        'niy': 'niy',
        'niy-Latn-CD': 'niy',
        'niy-CD': 'niy',
        'niy-Latn': 'niy',
        'niz': 'niz',
        'niz-Latn-PG': 'niz',
        'niz-Latn': 'niz',
        'niz-PG': 'niz',
        'nja': 'nja',
        'nja-Latn-NG': 'nja',
        'nja-Latn': 'nja',
        'nja-NG': 'nja',
        'njb': 'njb',
        'njb-Latn-IN': 'njb',
        'njb-IN': 'njb',
        'njb-Latn': 'njb',
        'njd': 'njd',
        'njd-Latn-TZ': 'njd',
        'njd-Latn': 'njd',
        'njd-TZ': 'njd',
        'njh': 'njh',
        'njh-Latn-IN': 'njh',
        'njh-IN': 'njh',
        'njh-Latn': 'njh',
        'nji': 'nji',
        'nji-Latn-AU': 'nji',
        'nji-AU': 'nji',
        'nji-Latn': 'nji',
        'njj': 'njj',
        'njj-Latn-CM': 'njj',
        'njj-CM': 'njj',
        'njj-Latn': 'njj',
        'njl': 'njl',
        'njl-Latn-SS': 'njl',
        'njl-Latn': 'njl',
        'njl-SS': 'njl',
        'njm': 'njm',
        'njm-Latn-IN': 'njm',
        'njm-IN': 'njm',
        'njm-Latn': 'njm',
        'njn': 'njn',
        'njn-Latn-IN': 'njn',
        'njn-IN': 'njn',
        'njn-Latn': 'njn',
        'njo': 'njo',
        'njo-Latn-IN': 'njo',
        'njo-IN': 'njo',
        'njo-Latn': 'njo',
        'njr': 'njr',
        'njr-Latn-NG': 'njr',
        'njr-Latn': 'njr',
        'njr-NG': 'njr',
        'njs': 'njs',
        'njs-Latn-ID': 'njs',
        'njs-ID': 'njs',
        'njs-Latn': 'njs',
        'njt': 'njt',
        'njt-Latn-SR': 'njt',
        'njt-Latn': 'njt',
        'njt-SR': 'njt',
        'nju': 'nju',
        'nju-Latn-AU': 'nju',
        'nju-AU': 'nju',
        'nju-Latn': 'nju',
        'njx': 'njx',
        'njx-Latn-CG': 'njx',
        'njx-CG': 'njx',
        'njx-Latn': 'njx',
        'njy': 'njy',
        'njy-Latn-CM': 'njy',
        'njy-CM': 'njy',
        'njy-Latn': 'njy',
        'njz-Beng': 'njz-Beng',
        'njz-Beng-IN': 'njz-Beng',
        'dap-Beng': 'njz-Beng',
        'dap-Beng-IN': 'njz-Beng',
        'njz-Latn': 'njz-Latn',
        'njz-Latn-IN': 'njz-Latn',
        'dap-Latn': 'njz-Latn',
        'dap-Latn-IN': 'njz-Latn',
        'nka': 'nka',
        'nka-Latn-ZM': 'nka',
        'nka-Latn': 'nka',
        'nka-ZM': 'nka',
        'nkb': 'nkb',
        'nkb-Latn-IN': 'nkb',
        'nkb-IN': 'nkb',
        'nkb-Latn': 'nkb',
        'nkc': 'nkc',
        'nkc-Latn-CM': 'nkc',
        'nkc-CM': 'nkc',
        'nkc-Latn': 'nkc',
        'nkd': 'nkd',
        'nkd-Latn-IN': 'nkd',
        'nkd-IN': 'nkd',
        'nkd-Latn': 'nkd',
        'nke': 'nke',
        'nke-Latn-SB': 'nke',
        'nke-Latn': 'nke',
        'nke-SB': 'nke',
        'nkf': 'nkf',
        'nkf-Latn-IN': 'nkf',
        'nkf-IN': 'nkf',
        'nkf-Latn': 'nkf',
        'nkg': 'nkg',
        'nkg-Latn-PG': 'nkg',
        'nkg-Latn': 'nkg',
        'nkg-PG': 'nkg',
        'nkh': 'nkh',
        'nkh-Latn-IN': 'nkh',
        'nkh-IN': 'nkh',
        'nkh-Latn': 'nkh',
        'nki-Beng': 'nki-Beng',
        'nki-Beng-IN': 'nki-Beng',
        'nki-Latn': 'nki-Latn',
        'nki-Latn-IN': 'nki-Latn',
        'nkj': 'nkj',
        'nkj-Latn-ID': 'nkj',
        'nkj-ID': 'nkj',
        'nkj-Latn': 'nkj',
        'nkk': 'nkk',
        'nkk-Latn-VU': 'nkk',
        'nkk-Latn': 'nkk',
        'nkk-VU': 'nkk',
        'nkm': 'nkm',
        'nkm-Latn-PG': 'nkm',
        'nkm-Latn': 'nkm',
        'nkm-PG': 'nkm',
        'nkn': 'nkn',
        'nkn-Latn-AO': 'nkn',
        'nkn-AO': 'nkn',
        'nkn-Latn': 'nkn',
        'nko': 'nko',
        'nko-Latn-GH': 'nko',
        'nko-GH': 'nko',
        'nko-Latn': 'nko',
        'nkp': 'nkp',
        'nkp-Zyyy-TO': 'nkp',
        'nkp-TO': 'nkp',
        'nkp-Zyyy': 'nkp',
        'nkq': 'nkq',
        'nkq-Latn-GH': 'nkq',
        'nkq-GH': 'nkq',
        'nkq-Latn': 'nkq',
        'nkr': 'nkr',
        'nkr-Latn-FM': 'nkr',
        'nkr-FM': 'nkr',
        'nkr-Latn': 'nkr',
        'nks': 'nks',
        'nks-Latn-ID': 'nks',
        'nks-ID': 'nks',
        'nks-Latn': 'nks',
        'nkt': 'nkt',
        'nkt-Latn-TZ': 'nkt',
        'nkt-Latn': 'nkt',
        'nkt-TZ': 'nkt',
        'nku': 'nku',
        'nku-Latn-CI': 'nku',
        'nku-CI': 'nku',
        'nku-Latn': 'nku',
        'nkv': 'nkv',
        'nkv-Latn-MW': 'nkv',
        'nkv-Latn': 'nkv',
        'nkv-MW': 'nkv',
        'nkw': 'nkw',
        'nkw-Latn-CD': 'nkw',
        'nkw-CD': 'nkw',
        'nkw-Latn': 'nkw',
        'nkx': 'nkx',
        'nkx-Latn-NG': 'nkx',
        'nkx-Latn': 'nkx',
        'nkx-NG': 'nkx',
        'nkz': 'nkz',
        'nkz-Latn-NG': 'nkz',
        'nkz-Latn': 'nkz',
        'nkz-NG': 'nkz',
        'nl': 'nl',
        'nl-Latn-NL': 'nl',
        'nl-Latn': 'nl',
        'nl-NL': 'nl',
        'nl-AW': 'nl-AW',
        'nl-Latn-AW': 'nl-AW',
        'nl-BE': 'nl-BE',
        'nl-Latn-BE': 'nl-BE',
        'nl-BQ': 'nl-BQ',
        'nl-Latn-BQ': 'nl-BQ',
        'nl-Brai': 'nl-Brai',
        'nl-Brai-NL': 'nl-Brai',
        'nl-CW': 'nl-CW',
        'nl-Latn-CW': 'nl-CW',
        'nl-SR': 'nl-SR',
        'nl-Latn-SR': 'nl-SR',
        'nl-SX': 'nl-SX',
        'nl-Latn-SX': 'nl-SX',
        'nla': 'nla',
        'nla-Latn-CM': 'nla',
        'nla-CM': 'nla',
        'nla-Latn': 'nla',
        'nlc': 'nlc',
        'nlc-Latn-ID': 'nlc',
        'nlc-ID': 'nlc',
        'nlc-Latn': 'nlc',
        'nle': 'nle',
        'nle-Latn-KE': 'nle',
        'nle-KE': 'nle',
        'nle-Latn': 'nle',
        'nlg': 'nlg',
        'nlg-Latn-SB': 'nlg',
        'nlg-Latn': 'nlg',
        'nlg-SB': 'nlg',
        'nli': 'nli',
        'nli-Arab-AF': 'nli',
        'nli-AF': 'nli',
        'nli-Arab': 'nli',
        'nlj': 'nlj',
        'nlj-Latn-CD': 'nlj',
        'nlj-CD': 'nlj',
        'nlj-Latn': 'nlj',
        'nlk': 'nlk',
        'nlk-Latn-ID': 'nlk',
        'nlk-ID': 'nlk',
        'nlk-Latn': 'nlk',
        'nll': 'nll',
        'nll-Zyyy-IN': 'nll',
        'nll-IN': 'nll',
        'nll-Zyyy': 'nll',
        'nlm': 'nlm',
        'nlm-Arab-PK': 'nlm',
        'nlm-Arab': 'nlm',
        'nlm-PK': 'nlm',
        'nlo': 'nlo',
        'nlo-Latn-CD': 'nlo',
        'nlo-CD': 'nlo',
        'nlo-Latn': 'nlo',
        'nlq': 'nlq',
        'nlq-Latn-MM': 'nlq',
        'nlq-Latn': 'nlq',
        'nlq-MM': 'nlq',
        'nlu': 'nlu',
        'nlu-Latn-GH': 'nlu',
        'nlu-GH': 'nlu',
        'nlu-Latn': 'nlu',
        'nlv': 'nlv',
        'nlv-Latn-MX': 'nlv',
        'nlv-Latn': 'nlv',
        'nlv-MX': 'nlv',
        'nlw': 'nlw',
        'nlw-Latn-AU': 'nlw',
        'nlw-AU': 'nlw',
        'nlw-Latn': 'nlw',
        'nlx': 'nlx',
        'nlx-Zyyy-IN': 'nlx',
        'nlx-IN': 'nlx',
        'nlx-Zyyy': 'nlx',
        'nly': 'nly',
        'nly-Latn-AU': 'nly',
        'nly-AU': 'nly',
        'nly-Latn': 'nly',
        'nlz': 'nlz',
        'nlz-Latn-SB': 'nlz',
        'nlz-Latn': 'nlz',
        'nlz-SB': 'nlz',
        'nma': 'nma',
        'nma-Latn-IN': 'nma',
        'nma-IN': 'nma',
        'nma-Latn': 'nma',
        'nmb': 'nmb',
        'nmb-Latn-VU': 'nmb',
        'nmb-Latn': 'nmb',
        'nmb-VU': 'nmb',
        'nmc': 'nmc',
        'nmc-Latn-TD': 'nmc',
        'nmc-Latn': 'nmc',
        'nmc-TD': 'nmc',
        'nmd': 'nmd',
        'nmd-Latn-GA': 'nmd',
        'nmd-GA': 'nmd',
        'nmd-Latn': 'nmd',
        'nme': 'nme',
        'nme-Latn-IN': 'nme',
        'nme-IN': 'nme',
        'nme-Latn': 'nme',
        'nmf': 'nmf',
        'nmf-Latn-IN': 'nmf',
        'nmf-IN': 'nmf',
        'nmf-Latn': 'nmf',
        'nmg': 'nmg',
        'nmg-Latn-CM': 'nmg',
        'nmg-CM': 'nmg',
        'nmg-Latn': 'nmg',
        'nmg-GQ': 'nmg-GQ',
        'nmg-Latn-GQ': 'nmg-GQ',
        'nmh': 'nmh',
        'nmh-Latn-IN': 'nmh',
        'nmh-IN': 'nmh',
        'nmh-Latn': 'nmh',
        'nmi': 'nmi',
        'nmi-Latn-NG': 'nmi',
        'nmi-Latn': 'nmi',
        'nmi-NG': 'nmi',
        'nmj': 'nmj',
        'nmj-Latn-CF': 'nmj',
        'nmj-CF': 'nmj',
        'nmj-Latn': 'nmj',
        'nmk': 'nmk',
        'nmk-Latn-VU': 'nmk',
        'nmk-Latn': 'nmk',
        'nmk-VU': 'nmk',
        'nml': 'nml',
        'nml-Latn-CM': 'nml',
        'nml-CM': 'nml',
        'nml-Latn': 'nml',
        'nmm': 'nmm',
        'nmm-Deva-NP': 'nmm',
        'nmm-Deva': 'nmm',
        'nmm-NP': 'nmm',
        'nmm-Tibt': 'nmm-Tibt',
        'nmm-Tibt-NP': 'nmm-Tibt',
        'nmn': 'nmn',
        'nmn-Latn-BW': 'nmn',
        'nmn-BW': 'nmn',
        'nmn-Latn': 'nmn',
        'nmo-Beng': 'nmo-Beng',
        'nmo-Beng-IN': 'nmo-Beng',
        'nmo-Latn': 'nmo-Latn',
        'nmo-Latn-IN': 'nmo-Latn',
        'nmp': 'nmp',
        'nmp-Latn-AU': 'nmp',
        'nmp-AU': 'nmp',
        'nmp-Latn': 'nmp',
        'nmq': 'nmq',
        'nmq-Latn-ZW': 'nmq',
        'nmq-Latn': 'nmq',
        'nmq-ZW': 'nmq',
        'nmr': 'nmr',
        'nmr-Latn-CM': 'nmr',
        'nmr-CM': 'nmr',
        'nmr-Latn': 'nmr',
        'nms': 'nms',
        'nms-Latn-VU': 'nms',
        'nms-Latn': 'nms',
        'nms-VU': 'nms',
        'nmt': 'nmt',
        'nmt-Latn-FM': 'nmt',
        'nmt-FM': 'nmt',
        'nmt-Latn': 'nmt',
        'nmu': 'nmu',
        'nmu-Latn-US': 'nmu',
        'nmu-Latn': 'nmu',
        'nmu-US': 'nmu',
        'nmv': 'nmv',
        'nmv-Latn-AU': 'nmv',
        'nmv-AU': 'nmv',
        'nmv-Latn': 'nmv',
        'nmw': 'nmw',
        'nmw-Latn-PG': 'nmw',
        'nmw-Latn': 'nmw',
        'nmw-PG': 'nmw',
        'nmx': 'nmx',
        'nmx-Latn-PG': 'nmx',
        'nmx-Latn': 'nmx',
        'nmx-PG': 'nmx',
        'nmy': 'nmy',
        'nmy-Zyyy-CN': 'nmy',
        'nmy-CN': 'nmy',
        'nmy-Zyyy': 'nmy',
        'nmz': 'nmz',
        'nmz-Latn-TG': 'nmz',
        'nmz-Latn': 'nmz',
        'nmz-TG': 'nmz',
        'nn': 'nn',
        'nn-Latn-NO': 'nn',
        'nn-Latn': 'nn',
        'nn-NO': 'nn',
        'nna': 'nna',
        'nna-Latn-AU': 'nna',
        'nna-AU': 'nna',
        'nna-Latn': 'nna',
        'nnb': 'nnb',
        'nnb-Latn-CD': 'nnb',
        'nnb-CD': 'nnb',
        'nnb-Latn': 'nnb',
        'nnc': 'nnc',
        'nnc-Latn-TD': 'nnc',
        'nnc-Latn': 'nnc',
        'nnc-TD': 'nnc',
        'nnd': 'nnd',
        'nnd-Latn-VU': 'nnd',
        'nnd-Latn': 'nnd',
        'nnd-VU': 'nnd',
        'nne': 'nne',
        'nne-Latn-AO': 'nne',
        'nne-AO': 'nne',
        'nne-Latn': 'nne',
        'nnf': 'nnf',
        'nnf-Latn-PG': 'nnf',
        'nnf-Latn': 'nnf',
        'nnf-PG': 'nnf',
        'nng-Beng': 'nng-Beng',
        'nng-Beng-IN': 'nng-Beng',
        'nng-Latn': 'nng-Latn',
        'nng-Latn-IN': 'nng-Latn',
        'nnh': 'nnh',
        'nnh-Latn-CM': 'nnh',
        'nnh-CM': 'nnh',
        'nnh-Latn': 'nnh',
        'nni': 'nni',
        'nni-Latn-ID': 'nni',
        'nni-ID': 'nni',
        'nni-Latn': 'nni',
        'nnj': 'nnj',
        'nnj-Latn-ET': 'nnj',
        'nnj-ET': 'nnj',
        'nnj-Latn': 'nnj',
        'nnk': 'nnk',
        'nnk-Latn-PG': 'nnk',
        'nnk-Latn': 'nnk',
        'nnk-PG': 'nnk',
        'nnl': 'nnl',
        'nnl-Latn-IN': 'nnl',
        'nnl-IN': 'nnl',
        'nnl-Latn': 'nnl',
        'nnm': 'nnm',
        'nnm-Latn-PG': 'nnm',
        'nnm-Latn': 'nnm',
        'nnm-PG': 'nnm',
        'nnn': 'nnn',
        'nnn-Latn-TD': 'nnn',
        'nnn-Latn': 'nnn',
        'nnn-TD': 'nnn',
        'nnp-Deva': 'nnp-Deva',
        'nnp-Deva-IN': 'nnp-Deva',
        'nnp-Latn': 'nnp-Latn',
        'nnp-Latn-IN': 'nnp-Latn',
        'nnp-Wcho': 'nnp-Wcho',
        'nnp-Wcho-IN': 'nnp-Wcho',
        'nnq': 'nnq',
        'nnq-Latn-TZ': 'nnq',
        'nnq-Latn': 'nnq',
        'nnq-TZ': 'nnq',
        'nnr': 'nnr',
        'nnr-Latn-AU': 'nnr',
        'nnr-AU': 'nnr',
        'nnr-Latn': 'nnr',
        'nnt': 'nnt',
        'nnt-Zyyy-US': 'nnt',
        'nnt-US': 'nnt',
        'nnt-Zyyy': 'nnt',
        'nnu': 'nnu',
        'nnu-Latn-GH': 'nnu',
        'nnu-GH': 'nnu',
        'nnu-Latn': 'nnu',
        'nnv': 'nnv',
        'nnv-Latn-AU': 'nnv',
        'nnv-AU': 'nnv',
        'nnv-Latn': 'nnv',
        'nnw': 'nnw',
        'nnw-Latn-BF': 'nnw',
        'nnw-BF': 'nnw',
        'nnw-Latn': 'nnw',
        'nny': 'nny',
        'nny-Latn-AU': 'nny',
        'nny-AU': 'nny',
        'nny-Latn': 'nny',
        'nnz': 'nnz',
        'nnz-Latn-CM': 'nnz',
        'nnz-CM': 'nnz',
        'nnz-Latn': 'nnz',
        'no': 'no',
        'no-Latn-NO': 'no',
        'no-Latn': 'no',
        'no-NO': 'no',
        'noa': 'noa',
        'noa-Latn-CO': 'noa',
        'noa-CO': 'noa',
        'noa-Latn': 'noa',
        'noc': 'noc',
        'noc-Latn-PG': 'noc',
        'noc-Latn': 'noc',
        'noc-PG': 'noc',
        'nod': 'nod',
        'nod-Lana-TH': 'nod',
        'nod-Lana': 'nod',
        'nod-TH': 'nod',
        'nod-Thai': 'nod-Thai',
        'nod-Thai-TH': 'nod-Thai',
        'noe': 'noe',
        'noe-Deva-IN': 'noe',
        'noe-Deva': 'noe',
        'noe-IN': 'noe',
        'nof': 'nof',
        'nof-Latn-PG': 'nof',
        'nof-Latn': 'nof',
        'nof-PG': 'nof',
        'nog': 'nog',
        'nog-Cyrl-RU': 'nog',
        'nog-Cyrl': 'nog',
        'nog-RU': 'nog',
        'noh': 'noh',
        'noh-Latn-PG': 'noh',
        'noh-Latn': 'noh',
        'noh-PG': 'noh',
        'noi': 'noi',
        'noi-Deva-IN': 'noi',
        'noi-Deva': 'noi',
        'noi-IN': 'noi',
        'noj': 'noj',
        'noj-Latn-CO': 'noj',
        'noj-CO': 'noj',
        'noj-Latn': 'noj',
        'nok': 'nok',
        'nok-Zyyy-US': 'nok',
        'nok-US': 'nok',
        'nok-Zyyy': 'nok',
        'nol': 'nol',
        'nol-Zyyy-US': 'nol',
        'nol-US': 'nol',
        'nol-Zyyy': 'nol',
        'nom': 'nom',
        'nom-Latn-PE': 'nom',
        'nom-Latn': 'nom',
        'nom-PE': 'nom',
        'non': 'non',
        'non-Runr-SE': 'non',
        'non-Runr': 'non',
        'non-SE': 'non',
        'nop': 'nop',
        'nop-Latn-PG': 'nop',
        'nop-Latn': 'nop',
        'nop-PG': 'nop',
        'noq': 'noq',
        'noq-Latn-CD': 'noq',
        'noq-CD': 'noq',
        'noq-Latn': 'noq',
        'nos': 'nos',
        'nos-Yiii-CN': 'nos',
        'nos-CN': 'nos',
        'nos-Yiii': 'nos',
        'not': 'not',
        'not-Latn-PE': 'not',
        'not-Latn': 'not',
        'not-PE': 'not',
        'nou': 'nou',
        'nou-Latn-PG': 'nou',
        'nou-Latn': 'nou',
        'nou-PG': 'nou',
        'nov': 'nov',
        'nov-Latn-001': 'nov',
        'nov-001': 'nov',
        'nov-Latn': 'nov',
        'now': 'now',
        'now-Latn-TZ': 'now',
        'now-Latn': 'now',
        'now-TZ': 'now',
        'noy': 'noy',
        'noy-Latn-TD': 'noy',
        'noy-Latn': 'noy',
        'noy-TD': 'noy',
        'noz': 'noz',
        'noz-Zyyy-ET': 'noz',
        'noz-ET': 'noz',
        'noz-Zyyy': 'noz',
        'npa': 'npa',
        'npa-Zyyy-NP': 'npa',
        'npa-NP': 'npa',
        'npa-Zyyy': 'npa',
        'npb': 'npb',
        'npb-Zyyy-BT': 'npb',
        'npb-BT': 'npb',
        'npb-Zyyy': 'npb',
        'npg': 'npg',
        'npg-Latn-MM': 'npg',
        'npg-Latn': 'npg',
        'npg-MM': 'npg',
        'nph': 'nph',
        'nph-Latn-IN': 'nph',
        'nph-IN': 'nph',
        'nph-Latn': 'nph',
        'npl': 'npl',
        'npl-Latn-MX': 'npl',
        'npl-Latn': 'npl',
        'npl-MX': 'npl',
        'npn': 'npn',
        'npn-Latn-PG': 'npn',
        'npn-Latn': 'npn',
        'npn-PG': 'npn',
        'npo': 'npo',
        'npo-Latn-IN': 'npo',
        'npo-IN': 'npo',
        'npo-Latn': 'npo',
        'nps': 'nps',
        'nps-Latn-ID': 'nps',
        'nps-ID': 'nps',
        'nps-Latn': 'nps',
        'npu': 'npu',
        'npu-Latn-IN': 'npu',
        'npu-IN': 'npu',
        'npu-Latn': 'npu',
        'npx': 'npx',
        'npx-Latn-SB': 'npx',
        'npx-Latn': 'npx',
        'npx-SB': 'npx',
        'npy': 'npy',
        'npy-Latn-ID': 'npy',
        'npy-ID': 'npy',
        'npy-Latn': 'npy',
        'nqg': 'nqg',
        'nqg-Latn-BJ': 'nqg',
        'nqg-BJ': 'nqg',
        'nqg-Latn': 'nqg',
        'nqk': 'nqk',
        'nqk-Latn-BJ': 'nqk',
        'nqk-BJ': 'nqk',
        'nqk-Latn': 'nqk',
        'nql': 'nql',
        'nql-Latn-AO': 'nql',
        'nql-AO': 'nql',
        'nql-Latn': 'nql',
        'nqm': 'nqm',
        'nqm-Latn-ID': 'nqm',
        'nqm-ID': 'nqm',
        'nqm-Latn': 'nqm',
        'nqn': 'nqn',
        'nqn-Latn-PG': 'nqn',
        'nqn-Latn': 'nqn',
        'nqn-PG': 'nqn',
        'nqo': 'nqo',
        'nqo-Nkoo-GN': 'nqo',
        'nqo-GN': 'nqo',
        'nqo-Nkoo': 'nqo',
        'nqq': 'nqq',
        'nqq-Latn-MM': 'nqq',
        'nqq-Latn': 'nqq',
        'nqq-MM': 'nqq',
        'nqy': 'nqy',
        'nqy-Latn-MM': 'nqy',
        'nqy-Latn': 'nqy',
        'nqy-MM': 'nqy',
        'nr': 'nr',
        'nr-Latn-ZA': 'nr',
        'nr-Latn': 'nr',
        'nr-ZA': 'nr',
        'nr-Brai': 'nr-Brai',
        'nr-Brai-ZA': 'nr-Brai',
        'nra': 'nra',
        'nra-Latn-GA': 'nra',
        'nra-GA': 'nra',
        'nra-Latn': 'nra',
        'nrb': 'nrb',
        'nrb-Latn-ER': 'nrb',
        'nrb-ER': 'nrb',
        'nrb-Latn': 'nrb',
        'nrc': 'nrc',
        'nrc-Zyyy-XX': 'nrc',
        'nrc-XX': 'nrc',
        'nrc-Zyyy': 'nrc',
        'nre': 'nre',
        'nre-Latn-IN': 'nre',
        'nre-IN': 'nre',
        'nre-Latn': 'nre',
        'nrf': 'nrf',
        'nrf-Latn-JE': 'nrf',
        'nrf-JE': 'nrf',
        'nrf-Latn': 'nrf',
        'nrg': 'nrg',
        'nrg-Latn-VU': 'nrg',
        'nrg-Latn': 'nrg',
        'nrg-VU': 'nrg',
        'nri': 'nri',
        'nri-Latn-IN': 'nri',
        'nri-IN': 'nri',
        'nri-Latn': 'nri',
        'nrk': 'nrk',
        'nrk-Latn-AU': 'nrk',
        'nrk-AU': 'nrk',
        'nrk-Latn': 'nrk',
        'nrl': 'nrl',
        'nrl-Latn-AU': 'nrl',
        'nrl-AU': 'nrl',
        'nrl-Latn': 'nrl',
        'nrm': 'nrm',
        'nrm-Latn-MY': 'nrm',
        'nrm-Latn': 'nrm',
        'nrm-MY': 'nrm',
        'nrn': 'nrn',
        'nrn-Zyyy-GB': 'nrn',
        'nrn-GB': 'nrn',
        'nrn-Zyyy': 'nrn',
        'nrp': 'nrp',
        'nrp-Latn-IT': 'nrp',
        'nrp-IT': 'nrp',
        'nrp-Latn': 'nrp',
        'nrr': 'nrr',
        'nrr-Zyyy-IN': 'nrr',
        'nrr-IN': 'nrr',
        'nrr-Zyyy': 'nrr',
        'nrt': 'nrt',
        'nrt-Zyyy-US': 'nrt',
        'nrt-US': 'nrt',
        'nrt-Zyyy': 'nrt',
        'nru': 'nru',
        'nru-Zyyy-CN': 'nru',
        'nru-CN': 'nru',
        'nru-Zyyy': 'nru',
        'nrx': 'nrx',
        'nrx-Latn-AU': 'nrx',
        'nrx-AU': 'nrx',
        'nrx-Latn': 'nrx',
        'nrz': 'nrz',
        'nrz-Latn-PG': 'nrz',
        'nrz-Latn': 'nrz',
        'nrz-PG': 'nrz',
        'nsa': 'nsa',
        'nsa-Latn-IN': 'nsa',
        'nsa-IN': 'nsa',
        'nsa-Latn': 'nsa',
        'nsb': 'nsb',
        'nsb-Latn-ZA': 'nsb',
        'nsb-Latn': 'nsb',
        'nsb-ZA': 'nsb',
        'nsc': 'nsc',
        'nsc-Latn-NG': 'nsc',
        'nsc-Latn': 'nsc',
        'nsc-NG': 'nsc',
        'nsd': 'nsd',
        'nsd-Yiii-CN': 'nsd',
        'nsd-CN': 'nsd',
        'nsd-Yiii': 'nsd',
        'nse': 'nse',
        'nse-Latn-ZM': 'nse',
        'nse-Latn': 'nse',
        'nse-ZM': 'nse',
        'nsf': 'nsf',
        'nsf-Zyyy-CN': 'nsf',
        'nsf-CN': 'nsf',
        'nsf-Zyyy': 'nsf',
        'nsg': 'nsg',
        'nsg-Latn-TZ': 'nsg',
        'nsg-Latn': 'nsg',
        'nsg-TZ': 'nsg',
        'nsh': 'nsh',
        'nsh-Latn-CM': 'nsh',
        'nsh-CM': 'nsh',
        'nsh-Latn': 'nsh',
        'nsi': 'nsi',
        'nsi-Zxxx-NG': 'nsi',
        'nsi-NG': 'nsi',
        'nsi-Zxxx': 'nsi',
        'sgn-nsi': 'nsi',
        'sgn-nsi-NG': 'nsi',
        'nsk': 'nsk',
        'nsk-Cans-CA': 'nsk',
        'nsk-CA': 'nsk',
        'nsk-Cans': 'nsk',
        'nsk-Latn': 'nsk-Latn',
        'nsk-Latn-CA': 'nsk-Latn',
        'nsl': 'nsl',
        'nsl-Zxxx-NO': 'nsl',
        'nsl-NO': 'nsl',
        'nsl-Zxxx': 'nsl',
        'sgn-nsl': 'nsl',
        'sgn-nsl-NO': 'nsl',
        'nsm': 'nsm',
        'nsm-Latn-IN': 'nsm',
        'nsm-IN': 'nsm',
        'nsm-Latn': 'nsm',
        'nsn': 'nsn',
        'nsn-Latn-PG': 'nsn',
        'nsn-Latn': 'nsn',
        'nsn-PG': 'nsn',
        'nso': 'nso',
        'nso-Latn-ZA': 'nso',
        'nso-Latn': 'nso',
        'nso-ZA': 'nso',
        'nso-Brai': 'nso-Brai',
        'nso-Brai-ZA': 'nso-Brai',
        'nsp': 'nsp',
        'nsp-Zxxx-NP': 'nsp',
        'nsp-NP': 'nsp',
        'nsp-Zxxx': 'nsp',
        'sgn-nsp': 'nsp',
        'sgn-nsp-NP': 'nsp',
        'nsq': 'nsq',
        'nsq-Latn-US': 'nsq',
        'nsq-Latn': 'nsq',
        'nsq-US': 'nsq',
        'nsr': 'nsr',
        'nsr-Zxxx-CA': 'nsr',
        'nsr-CA': 'nsr',
        'nsr-Zxxx': 'nsr',
        'sgn-nsr': 'nsr',
        'sgn-nsr-CA': 'nsr',
        'nss': 'nss',
        'nss-Latn-PG': 'nss',
        'nss-Latn': 'nss',
        'nss-PG': 'nss',
        'nst': 'nst',
        'nst-Latn-MM': 'nst',
        'nst-Latn': 'nst',
        'nst-MM': 'nst',
        'nst-x-moshang': 'nst-x-moshang',
        'nst-Latn-MM-x-moshang': 'nst-x-moshang',
        'nst-Latn-x-moshang': 'nst-x-moshang',
        'nst-MM-x-moshang': 'nst-x-moshang',
        'nsu': 'nsu',
        'nsu-Latn-MX': 'nsu',
        'nsu-Latn': 'nsu',
        'nsu-MX': 'nsu',
        'nsv': 'nsv',
        'nsv-Yiii-CN': 'nsv',
        'nsv-CN': 'nsv',
        'nsv-Yiii': 'nsv',
        'nsw': 'nsw',
        'nsw-Latn-VU': 'nsw',
        'nsw-Latn': 'nsw',
        'nsw-VU': 'nsw',
        'nsx': 'nsx',
        'nsx-Latn-AO': 'nsx',
        'nsx-AO': 'nsx',
        'nsx-Latn': 'nsx',
        'nsy': 'nsy',
        'nsy-Latn-ID': 'nsy',
        'nsy-ID': 'nsy',
        'nsy-Latn': 'nsy',
        'nsz': 'nsz',
        'nsz-Latn-US': 'nsz',
        'nsz-Latn': 'nsz',
        'nsz-US': 'nsz',
        'ntd': 'ntd',
        'ntd-Latn-MY': 'ntd',
        'ntd-Latn': 'ntd',
        'ntd-MY': 'ntd',
        'nte': 'nte',
        'nte-Latn-MZ': 'nte',
        'nte-Latn': 'nte',
        'nte-MZ': 'nte',
        'ntg': 'ntg',
        'ntg-Latn-AU': 'ntg',
        'ntg-AU': 'ntg',
        'ntg-Latn': 'ntg',
        'nti': 'nti',
        'nti-Latn-BF': 'nti',
        'nti-BF': 'nti',
        'nti-Latn': 'nti',
        'ntj': 'ntj',
        'ntj-Latn-AU': 'ntj',
        'ntj-AU': 'ntj',
        'ntj-Latn': 'ntj',
        'ntk': 'ntk',
        'ntk-Latn-TZ': 'ntk',
        'ntk-Latn': 'ntk',
        'ntk-TZ': 'ntk',
        'ntm': 'ntm',
        'ntm-Latn-BJ': 'ntm',
        'ntm-BJ': 'ntm',
        'ntm-Latn': 'ntm',
        'nto': 'nto',
        'nto-Latn-CD': 'nto',
        'nto-CD': 'nto',
        'nto-Latn': 'nto',
        'ntp': 'ntp',
        'ntp-Latn-MX': 'ntp',
        'ntp-Latn': 'ntp',
        'ntp-MX': 'ntp',
        'ntr': 'ntr',
        'ntr-Latn-GH': 'ntr',
        'ntr-GH': 'ntr',
        'ntr-Latn': 'ntr',
        'ntu': 'ntu',
        'ntu-Latn-SB': 'ntu',
        'ntu-Latn': 'ntu',
        'ntu-SB': 'ntu',
        'ntw': 'ntw',
        'ntw-Zyyy-US': 'ntw',
        'ntw-US': 'ntw',
        'ntw-Zyyy': 'ntw',
        'ntx': 'ntx',
        'ntx-Latn-MM': 'ntx',
        'ntx-Latn': 'ntx',
        'ntx-MM': 'ntx',
        'nty': 'nty',
        'nty-Yiii-VN': 'nty',
        'nty-VN': 'nty',
        'nty-Yiii': 'nty',
        'ntz': 'ntz',
        'ntz-Arab-IR': 'ntz',
        'ntz-Arab': 'ntz',
        'ntz-IR': 'ntz',
        'nua': 'nua',
        'nua-Latn-NC': 'nua',
        'nua-Latn': 'nua',
        'nua-NC': 'nua',
        'nuc': 'nuc',
        'nuc-Latn-BR': 'nuc',
        'nuc-BR': 'nuc',
        'nuc-Latn': 'nuc',
        'nud': 'nud',
        'nud-Latn-PG': 'nud',
        'nud-Latn': 'nud',
        'nud-PG': 'nud',
        'nue': 'nue',
        'nue-Latn-CD': 'nue',
        'nue-CD': 'nue',
        'nue-Latn': 'nue',
        'nuf': 'nuf',
        'nuf-Latn-CN': 'nuf',
        'nuf-CN': 'nuf',
        'nuf-Latn': 'nuf',
        'nug': 'nug',
        'nug-Latn-AU': 'nug',
        'nug-AU': 'nug',
        'nug-Latn': 'nug',
        'nuh': 'nuh',
        'nuh-Latn-NG': 'nuh',
        'nuh-Latn': 'nuh',
        'nuh-NG': 'nuh',
        'nui': 'nui',
        'nui-Latn-GQ': 'nui',
        'nui-GQ': 'nui',
        'nui-Latn': 'nui',
        'nuj': 'nuj',
        'nuj-Latn-UG': 'nuj',
        'nuj-Latn': 'nuj',
        'nuj-UG': 'nuj',
        'nuk': 'nuk',
        'nuk-Latn-CA': 'nuk',
        'nuk-CA': 'nuk',
        'nuk-Latn': 'nuk',
        'nul': 'nul',
        'nul-Latn-ID': 'nul',
        'nul-ID': 'nul',
        'nul-Latn': 'nul',
        'num': 'num',
        'num-Latn-TO': 'num',
        'num-Latn': 'num',
        'num-TO': 'num',
        'nun': 'nun',
        'nun-Latn-MM': 'nun',
        'ayx': 'nun',
        'ayx-Latn': 'nun',
        'ayx-Latn-MM': 'nun',
        'ayx-MM': 'nun',
        'nun-Latn': 'nun',
        'nun-MM': 'nun',
        'nuo': 'nuo',
        'nuo-Latn-VN': 'nuo',
        'nuo-Latn': 'nuo',
        'nuo-VN': 'nuo',
        'nup': 'nup',
        'nup-Latn-NG': 'nup',
        'nup-Latn': 'nup',
        'nup-NG': 'nup',
        'nup-Arab': 'nup-Arab',
        'nup-Arab-NG': 'nup-Arab',
        'nuq': 'nuq',
        'nuq-Latn-PG': 'nuq',
        'nuq-Latn': 'nuq',
        'nuq-PG': 'nuq',
        'nur': 'nur',
        'nur-Latn-PG': 'nur',
        'nur-Latn': 'nur',
        'nur-PG': 'nur',
        'nus': 'nus',
        'nus-Latn-SS': 'nus',
        'nus-Latn': 'nus',
        'nus-SS': 'nus',
        'nut': 'nut',
        'nut-Latn-VN': 'nut',
        'nut-Latn': 'nut',
        'nut-VN': 'nut',
        'nuu': 'nuu',
        'nuu-Latn-CD': 'nuu',
        'nuu-CD': 'nuu',
        'nuu-Latn': 'nuu',
        'nuv': 'nuv',
        'nuv-Latn-BF': 'nuv',
        'nuv-BF': 'nuv',
        'nuv-Latn': 'nuv',
        'nuw': 'nuw',
        'nuw-Latn-FM': 'nuw',
        'nuw-FM': 'nuw',
        'nuw-Latn': 'nuw',
        'nux': 'nux',
        'nux-Latn-PG': 'nux',
        'nux-Latn': 'nux',
        'nux-PG': 'nux',
        'nuy': 'nuy',
        'nuy-Latn-AU': 'nuy',
        'nuy-AU': 'nuy',
        'nuy-Latn': 'nuy',
        'nuz': 'nuz',
        'nuz-Latn-MX': 'nuz',
        'nuz-Latn': 'nuz',
        'nuz-MX': 'nuz',
        'nv': 'nv',
        'nv-Latn-US': 'nv',
        'nv-Latn': 'nv',
        'nv-US': 'nv',
        'nvh': 'nvh',
        'nvh-Latn-VU': 'nvh',
        'nvh-Latn': 'nvh',
        'nvh-VU': 'nvh',
        'nvm': 'nvm',
        'nvm-Latn-PG': 'nvm',
        'nvm-Latn': 'nvm',
        'nvm-PG': 'nvm',
        'nvo': 'nvo',
        'nvo-Latn-CM': 'nvo',
        'nvo-CM': 'nvo',
        'nvo-Latn': 'nvo',
        'nwa': 'nwa',
        'nwa-Zyyy-US': 'nwa',
        'nwa-US': 'nwa',
        'nwa-Zyyy': 'nwa',
        'nwb': 'nwb',
        'nwb-Latn-CI': 'nwb',
        'nwb-CI': 'nwb',
        'nwb-Latn': 'nwb',
        'nwc': 'nwc',
        'nwc-Zyyy-NP': 'nwc',
        'nwc-NP': 'nwc',
        'nwc-Zyyy': 'nwc',
        'nwe': 'nwe',
        'nwe-Latn-CM': 'nwe',
        'nwe-CM': 'nwe',
        'nwe-Latn': 'nwe',
        'nwg': 'nwg',
        'nwg-Latn-AU': 'nwg',
        'nwg-AU': 'nwg',
        'nwg-Latn': 'nwg',
        'nwi': 'nwi',
        'nwi-Latn-VU': 'nwi',
        'nwi-Latn': 'nwi',
        'nwi-VU': 'nwi',
        'nwm': 'nwm',
        'nwm-Latn-SS': 'nwm',
        'nwm-Latn': 'nwm',
        'nwm-SS': 'nwm',
        'nwo': 'nwo',
        'nwo-Latn-AU': 'nwo',
        'nwo-AU': 'nwo',
        'nwo-Latn': 'nwo',
        'nwr': 'nwr',
        'nwr-Latn-PG': 'nwr',
        'nwr-Latn': 'nwr',
        'nwr-PG': 'nwr',
        'nwx': 'nwx',
        'nwx-Deva-NP': 'nwx',
        'nwx-Deva': 'nwx',
        'nwx-NP': 'nwx',
        'nwy': 'nwy',
        'nwy-Zyyy-US': 'nwy',
        'nwy-US': 'nwy',
        'nwy-Zyyy': 'nwy',
        'nxa': 'nxa',
        'nxa-Latn-TL': 'nxa',
        'nxa-Latn': 'nxa',
        'nxa-TL': 'nxa',
        'nxd': 'nxd',
        'nxd-Latn-CD': 'nxd',
        'nxd-CD': 'nxd',
        'nxd-Latn': 'nxd',
        'nxe': 'nxe',
        'nxe-Latn-ID': 'nxe',
        'nxe-ID': 'nxe',
        'nxe-Latn': 'nxe',
        'nxg': 'nxg',
        'nxg-Latn-ID': 'nxg',
        'nxg-ID': 'nxg',
        'nxg-Latn': 'nxg',
        'nxi': 'nxi',
        'nxi-Latn-TZ': 'nxi',
        'nxi-Latn': 'nxi',
        'nxi-TZ': 'nxi',
        'nxk': 'nxk',
        'nxk-Zyyy-MM': 'nxk',
        'nxk-MM': 'nxk',
        'nxk-Zyyy': 'nxk',
        'nxl': 'nxl',
        'nxl-Latn-ID': 'nxl',
        'nxl-ID': 'nxl',
        'nxl-Latn': 'nxl',
        'nxm': 'nxm',
        'nxm-Zyyy-XX': 'nxm',
        'nxm-XX': 'nxm',
        'nxm-Zyyy': 'nxm',
        'nxn': 'nxn',
        'nxn-Latn-AU': 'nxn',
        'nxn-AU': 'nxn',
        'nxn-Latn': 'nxn',
        'nxo': 'nxo',
        'nxo-Latn-GA': 'nxo',
        'nxo-GA': 'nxo',
        'nxo-Latn': 'nxo',
        'nxq': 'nxq',
        'nxq-Latn-CN': 'nxq',
        'nbf': 'nxq',
        'nbf-CN': 'nxq',
        'nbf-Latn': 'nxq',
        'nbf-Latn-CN': 'nxq',
        'nxq-CN': 'nxq',
        'nxq-Latn': 'nxq',
        'nxq-Lisu': 'nxq-Lisu',
        'nxq-Lisu-CN': 'nxq-Lisu',
        'nxq-Nkgb': 'nxq-Nkgb',
        'nxq-Nkgb-CN': 'nxq-Nkgb',
        'nxr': 'nxr',
        'nxr-Latn-PG': 'nxr',
        'nxr-Latn': 'nxr',
        'nxr-PG': 'nxr',
        'nxx': 'nxx',
        'nxx-Latn-ID': 'nxx',
        'nxx-ID': 'nxx',
        'nxx-Latn': 'nxx',
        'ny': 'ny',
        'ny-Latn-MW': 'ny',
        'ny-Latn': 'ny',
        'ny-MW': 'ny',
        'ny-Brai': 'ny-Brai',
        'ny-Brai-MW': 'ny-Brai',
        'nyb': 'nyb',
        'nyb-Latn-GH': 'nyb',
        'nyb-GH': 'nyb',
        'nyb-Latn': 'nyb',
        'nyc': 'nyc',
        'nyc-Latn-CD': 'nyc',
        'gti': 'nyc',
        'gti-CD': 'nyc',
        'gti-Latn': 'nyc',
        'gti-Latn-CD': 'nyc',
        'nyc-CD': 'nyc',
        'nyc-Latn': 'nyc',
        'nyd': 'nyd',
        'nyd-Latn-KE': 'nyd',
        'nyd-KE': 'nyd',
        'nyd-Latn': 'nyd',
        'nye': 'nye',
        'nye-Latn-AO': 'nye',
        'nye-AO': 'nye',
        'nye-Latn': 'nye',
        'nyf': 'nyf',
        'nyf-Latn-KE': 'nyf',
        'nyf-KE': 'nyf',
        'nyf-Latn': 'nyf',
        'nyg': 'nyg',
        'nyg-Latn-CD': 'nyg',
        'nyg-CD': 'nyg',
        'nyg-Latn': 'nyg',
        'nyh': 'nyh',
        'nyh-Latn-AU': 'nyh',
        'nyh-AU': 'nyh',
        'nyh-Latn': 'nyh',
        'nyi': 'nyi',
        'nyi-Latn-SD': 'nyi',
        'nyi-Latn': 'nyi',
        'nyi-SD': 'nyi',
        'nyj': 'nyj',
        'nyj-Latn-CD': 'nyj',
        'nyj-CD': 'nyj',
        'nyj-Latn': 'nyj',
        'nyk': 'nyk',
        'nyk-Latn-AO': 'nyk',
        'nyk-AO': 'nyk',
        'nyk-Latn': 'nyk',
        'nyl': 'nyl',
        'nyl-Zyyy-TH': 'nyl',
        'nyl-TH': 'nyl',
        'nyl-Zyyy': 'nyl',
        'nym': 'nym',
        'nym-Latn-TZ': 'nym',
        'nym-Latn': 'nym',
        'nym-TZ': 'nym',
        'nyn': 'nyn',
        'nyn-Latn-UG': 'nyn',
        'nyn-Latn': 'nyn',
        'nyn-UG': 'nyn',
        'nyo': 'nyo',
        'nyo-Latn-UG': 'nyo',
        'nyo-Latn': 'nyo',
        'nyo-UG': 'nyo',
        'nyp': 'nyp',
        'nyp-Latn-UG': 'nyp',
        'nyp-Latn': 'nyp',
        'nyp-UG': 'nyp',
        'nyq': 'nyq',
        'nyq-Arab-IR': 'nyq',
        'nyq-Arab': 'nyq',
        'nyq-IR': 'nyq',
        'nyr': 'nyr',
        'nyr-Latn-MW': 'nyr',
        'nyr-Latn': 'nyr',
        'nyr-MW': 'nyr',
        'nys': 'nys',
        'nys-Latn-AU': 'nys',
        'nys-AU': 'nys',
        'nys-Latn': 'nys',
        'nyt': 'nyt',
        'nyt-Latn-AU': 'nyt',
        'nyt-AU': 'nyt',
        'nyt-Latn': 'nyt',
        'nyu': 'nyu',
        'nyu-Latn-MZ': 'nyu',
        'nyu-Latn': 'nyu',
        'nyu-MZ': 'nyu',
        'nyv': 'nyv',
        'nyv-Latn-AU': 'nyv',
        'nyv-AU': 'nyv',
        'nyv-Latn': 'nyv',
        'nyw': 'nyw',
        'nyw-Zyyy-TH': 'nyw',
        'nyw-TH': 'nyw',
        'nyw-Zyyy': 'nyw',
        'nyx': 'nyx',
        'nyx-Latn-AU': 'nyx',
        'nyx-AU': 'nyx',
        'nyx-Latn': 'nyx',
        'nyy': 'nyy',
        'nyy-Latn-TZ': 'nyy',
        'nyy-Latn': 'nyy',
        'nyy-TZ': 'nyy',
        'nza': 'nza',
        'nza-Latn-CM': 'nza',
        'nza-CM': 'nza',
        'nza-Latn': 'nza',
        'nzb': 'nzb',
        'nzb-Latn-GA': 'nzb',
        'nzb-GA': 'nzb',
        'nzb-Latn': 'nzb',
        'nzd': 'nzd',
        'nzd-Latn-CD': 'nzd',
        'nzd-CD': 'nzd',
        'nzd-Latn': 'nzd',
        'nzi': 'nzi',
        'nzi-Latn-GH': 'nzi',
        'nzi-GH': 'nzi',
        'nzi-Latn': 'nzi',
        'nzk': 'nzk',
        'nzk-Latn-CF': 'nzk',
        'nzk-CF': 'nzk',
        'nzk-Latn': 'nzk',
        'nzm': 'nzm',
        'nzm-Latn-IN': 'nzm',
        'nzm-IN': 'nzm',
        'nzm-Latn': 'nzm',
        'nzs': 'nzs',
        'nzs-Zxxx-NZ': 'nzs',
        'nzs-NZ': 'nzs',
        'nzs-Zxxx': 'nzs',
        'sgn-nzs': 'nzs',
        'sgn-nzs-NZ': 'nzs',
        'nzu': 'nzu',
        'nzu-Latn-CG': 'nzu',
        'nzu-CG': 'nzu',
        'nzu-Latn': 'nzu',
        'nzy': 'nzy',
        'nzy-Latn-TD': 'nzy',
        'nzy-Latn': 'nzy',
        'nzy-TD': 'nzy',
        'nzz': 'nzz',
        'nzz-Latn-ML': 'nzz',
        'nzz-Latn': 'nzz',
        'nzz-ML': 'nzz',
        'oaa': 'oaa',
        'oaa-Cyrl-RU': 'oaa',
        'oaa-Cyrl': 'oaa',
        'oaa-RU': 'oaa',
        'oac': 'oac',
        'oac-Cyrl-RU': 'oac',
        'oac-Cyrl': 'oac',
        'oac-RU': 'oac',
        'oar': 'oar',
        'oar-Syrc-SY': 'oar',
        'oar-SY': 'oar',
        'oar-Syrc': 'oar',
        'oav': 'oav',
        'oav-Geor-GE': 'oav',
        'oav-GE': 'oav',
        'oav-Geor': 'oav',
        'obi': 'obi',
        'obi-Zyyy-US': 'obi',
        'obi-US': 'obi',
        'obi-Zyyy': 'obi',
        'obk': 'obk',
        'obk-Latn-PH': 'obk',
        'obk-Latn': 'obk',
        'obk-PH': 'obk',
        'obl': 'obl',
        'obl-Latn-CM': 'obl',
        'obl-CM': 'obl',
        'obl-Latn': 'obl',
        'obm': 'obm',
        'obm-Phnx-JO': 'obm',
        'obm-JO': 'obm',
        'obm-Phnx': 'obm',
        'obo': 'obo',
        'obo-Latn-PH': 'obo',
        'obo-Latn': 'obo',
        'obo-PH': 'obo',
        'obr': 'obr',
        'obr-Mymr-MM': 'obr',
        'obr-MM': 'obr',
        'obr-Mymr': 'obr',
        'obt': 'obt',
        'obt-Latn-FR': 'obt',
        'obt-FR': 'obt',
        'obt-Latn': 'obt',
        'obu': 'obu',
        'obu-Latn-NG': 'obu',
        'obu-Latn': 'obu',
        'obu-NG': 'obu',
        'oc': 'oc',
        'oc-Latn-FR': 'oc',
        'oc-FR': 'oc',
        'oc-Latn': 'oc',
        'oca': 'oca',
        'oca-Latn-PE': 'oca',
        'oca-Latn': 'oca',
        'oca-PE': 'oca',
        'och': 'och',
        'och-Zyyy-CN': 'och',
        'och-CN': 'och',
        'och-Zyyy': 'och',
        'oco': 'oco',
        'oco-Latn-GB': 'oco',
        'oco-GB': 'oco',
        'oco-Latn': 'oco',
        'ocu': 'ocu',
        'ocu-Latn-MX': 'ocu',
        'ocu-Latn': 'ocu',
        'ocu-MX': 'ocu',
        'oda': 'oda',
        'oda-Latn-NG': 'oda',
        'oda-Latn': 'oda',
        'oda-NG': 'oda',
        'odk': 'odk',
        'odk-Arab-PK': 'odk',
        'odk-Arab': 'odk',
        'odk-PK': 'odk',
        'odt': 'odt',
        'odt-Latn-NL': 'odt',
        'odt-Latn': 'odt',
        'odt-NL': 'odt',
        'odu': 'odu',
        'odu-Latn-NG': 'odu',
        'odu-Latn': 'odu',
        'odu-NG': 'odu',
        'ofo': 'ofo',
        'ofo-Zyyy-US': 'ofo',
        'ofo-US': 'ofo',
        'ofo-Zyyy': 'ofo',
        'ofs': 'ofs',
        'ofs-Zyyy-NL': 'ofs',
        'ofs-NL': 'ofs',
        'ofs-Zyyy': 'ofs',
        'ofu': 'ofu',
        'ofu-Latn-NG': 'ofu',
        'ofu-Latn': 'ofu',
        'ofu-NG': 'ofu',
        'ogb': 'ogb',
        'ogb-Latn-NG': 'ogb',
        'ogb-Latn': 'ogb',
        'ogb-NG': 'ogb',
        'ogc': 'ogc',
        'ogc-Latn-NG': 'ogc',
        'ogc-Latn': 'ogc',
        'ogc-NG': 'ogc',
        'oge': 'oge',
        'oge-Geok-GE': 'oge',
        'oge-GE': 'oge',
        'oge-Geok': 'oge',
        'ogg': 'ogg',
        'ogg-Latn-NG': 'ogg',
        'ogg-Latn': 'ogg',
        'ogg-NG': 'ogg',
        'ogo': 'ogo',
        'ogo-Latn-NG': 'ogo',
        'ogo-Latn': 'ogo',
        'ogo-NG': 'ogo',
        'ogu': 'ogu',
        'ogu-Latn-NG': 'ogu',
        'ogu-Latn': 'ogu',
        'ogu-NG': 'ogu',
        'oht': 'oht',
        'oht-Zyyy-TR': 'oht',
        'oht-TR': 'oht',
        'oht-Zyyy': 'oht',
        'ohu-Hung': 'ohu-Hung',
        'ohu-Hung-HU': 'ohu-Hung',
        'ohu-Latn': 'ohu-Latn',
        'ohu-Latn-HU': 'ohu-Latn',
        'oia': 'oia',
        'oia-Latn-ID': 'oia',
        'oia-ID': 'oia',
        'oia-Latn': 'oia',
        'oin': 'oin',
        'oin-Latn-PG': 'oin',
        'oin-Latn': 'oin',
        'oin-PG': 'oin',
        'oj': 'oj',
        'oj-Latn-CA': 'oj',
        'oj-CA': 'oj',
        'oj-Latn': 'oj',
        'ojg': 'oj',
        'ojg-CA': 'oj',
        'ojg-Latn': 'oj',
        'ojg-Latn-CA': 'oj',
        'oj-Cans': 'oj-Cans',
        'oj-Cans-CA': 'oj-Cans',
        'ojg-Cans': 'oj-Cans',
        'ojg-Cans-CA': 'oj-Cans',
        'ojb': 'ojb',
        'ojb-Latn-CA': 'ojb',
        'ojb-CA': 'ojb',
        'ojb-Latn': 'ojb',
        'ojb-Cans': 'ojb-Cans',
        'ojb-Cans-CA': 'ojb-Cans',
        'ojc': 'ojc',
        'ojc-Latn-CA': 'ojc',
        'ojc-CA': 'ojc',
        'ojc-Latn': 'ojc',
        'ojp': 'ojp',
        'ojp-Zyyy-JP': 'ojp',
        'ojp-JP': 'ojp',
        'ojp-Zyyy': 'ojp',
        'ojs': 'ojs',
        'ojs-Cans-CA': 'ojs',
        'ojs-CA': 'ojs',
        'ojs-Cans': 'ojs',
        'ojs-Latn': 'ojs-Latn',
        'ojs-Latn-CA': 'ojs-Latn',
        'ojv': 'ojv',
        'ojv-Latn-SB': 'ojv',
        'ojv-Latn': 'ojv',
        'ojv-SB': 'ojv',
        'ojw': 'ojw',
        'ojw-Latn-CA': 'ojw',
        'ojw-CA': 'ojw',
        'ojw-Latn': 'ojw',
        'ojw-Cans': 'ojw-Cans',
        'ojw-Cans-CA': 'ojw-Cans',
        'oka': 'oka',
        'oka-Latn-CA': 'oka',
        'oka-CA': 'oka',
        'oka-Latn': 'oka',
        'oka-Dupl': 'oka-Dupl',
        'oka-Dupl-CA': 'oka-Dupl',
        'okb': 'okb',
        'okb-Latn-NG': 'okb',
        'okb-Latn': 'okb',
        'okb-NG': 'okb',
        'okd': 'okd',
        'okd-Latn-NG': 'okd',
        'okd-Latn': 'okd',
        'okd-NG': 'okd',
        'oke': 'oke',
        'oke-Latn-NG': 'oke',
        'oke-Latn': 'oke',
        'oke-NG': 'oke',
        'okg': 'okg',
        'okg-Latn-AU': 'okg',
        'okg-AU': 'okg',
        'okg-Latn': 'okg',
        'okh': 'okh',
        'okh-Zyyy-IR': 'okh',
        'okh-IR': 'okh',
        'okh-Zyyy': 'okh',
        'oki': 'oki',
        'oki-Latn-KE': 'oki',
        'oki-KE': 'oki',
        'oki-Latn': 'oki',
        'okj': 'okj',
        'okj-Zyyy-IN': 'okj',
        'okj-IN': 'okj',
        'okj-Zyyy': 'okj',
        'okk': 'okk',
        'okk-Latn-PG': 'okk',
        'okk-Latn': 'okk',
        'okk-PG': 'okk',
        'okl': 'okl',
        'okl-Zxxx-XX': 'okl',
        'okl-XX': 'okl',
        'okl-Zxxx': 'okl',
        'sgn-okl': 'okl',
        'sgn-okl-XX': 'okl',
        'okm': 'okm',
        'okm-Zyyy-KR': 'okm',
        'okm-KR': 'okm',
        'okm-Zyyy': 'okm',
        'okn': 'okn',
        'okn-Zyyy-JP': 'okn',
        'okn-JP': 'okn',
        'okn-Zyyy': 'okn',
        'oko': 'oko',
        'oko-Zyyy-KR': 'oko',
        'oko-KR': 'oko',
        'oko-Zyyy': 'oko',
        'okr': 'okr',
        'okr-Latn-NG': 'okr',
        'okr-Latn': 'okr',
        'okr-NG': 'okr',
        'oks': 'oks',
        'oks-Latn-NG': 'oks',
        'oks-Latn': 'oks',
        'oks-NG': 'oks',
        'oku': 'oku',
        'oku-Latn-CM': 'oku',
        'oku-CM': 'oku',
        'oku-Latn': 'oku',
        'okv': 'okv',
        'okv-Latn-PG': 'okv',
        'okv-Latn': 'okv',
        'okv-PG': 'okv',
        'okx': 'okx',
        'okx-Latn-NG': 'okx',
        'okx-Latn': 'okx',
        'okx-NG': 'okx',
        'ola': 'ola',
        'ola-Tibt-NP': 'ola',
        'ola-NP': 'ola',
        'ola-Tibt': 'ola',
        'old': 'old',
        'old-Latn-TZ': 'old',
        'old-Latn': 'old',
        'old-TZ': 'old',
        'ole': 'ole',
        'ole-Zyyy-BT': 'ole',
        'ole-BT': 'ole',
        'ole-Zyyy': 'ole',
        'olk': 'olk',
        'olk-Latn-AU': 'olk',
        'olk-AU': 'olk',
        'olk-Latn': 'olk',
        'olm': 'olm',
        'olm-Latn-NG': 'olm',
        'olm-Latn': 'olm',
        'olm-NG': 'olm',
        'olo': 'olo',
        'olo-Latn-RU': 'olo',
        'olo-Latn': 'olo',
        'olo-RU': 'olo',
        'olr': 'olr',
        'olr-Latn-VU': 'olr',
        'olr-Latn': 'olr',
        'olr-VU': 'olr',
        'olt': 'olt',
        'olt-Latn-LT': 'olt',
        'olt-LT': 'olt',
        'olt-Latn': 'olt',
        'olu': 'olu',
        'olu-Latn-AO': 'olu',
        'olu-AO': 'olu',
        'olu-Latn': 'olu',
        'om': 'om',
        'om-Latn-ET': 'om',
        'gaz': 'om',
        'gaz-ET': 'om',
        'gaz-Latn': 'om',
        'gaz-Latn-ET': 'om',
        'om-ET': 'om',
        'om-Latn': 'om',
        'om-Arab': 'om-Arab',
        'om-Arab-ET': 'om-Arab',
        'om-Ethi': 'om-Ethi',
        'om-Ethi-ET': 'om-Ethi',
        'gaz-Ethi': 'om-Ethi',
        'gaz-Ethi-ET': 'om-Ethi',
        'om-KE': 'om-KE',
        'om-Latn-KE': 'om-KE',
        'oma': 'oma',
        'oma-Latn-US': 'oma',
        'oma-Latn': 'oma',
        'oma-US': 'oma',
        'omb': 'omb',
        'omb-Latn-VU': 'omb',
        'omb-Latn': 'omb',
        'omb-VU': 'omb',
        'omc': 'omc',
        'omc-Latn-PE': 'omc',
        'omc-Latn': 'omc',
        'omc-PE': 'omc',
        'omg': 'omg',
        'omg-Latn-PE': 'omg',
        'omg-Latn': 'omg',
        'omg-PE': 'omg',
        'omi': 'omi',
        'omi-Latn-CD': 'omi',
        'omi-CD': 'omi',
        'omi-Latn': 'omi',
        'omk': 'omk',
        'omk-Cyrl-RU': 'omk',
        'omk-Cyrl': 'omk',
        'omk-RU': 'omk',
        'oml': 'oml',
        'oml-Latn-CD': 'oml',
        'oml-CD': 'oml',
        'oml-Latn': 'oml',
        'omn': 'omn',
        'omn-Lina-XX': 'omn',
        'omn-Lina': 'omn',
        'omn-XX': 'omn',
        'omo': 'omo',
        'omo-Latn-PG': 'omo',
        'omo-Latn': 'omo',
        'omo-PG': 'omo',
        'omp': 'omp',
        'omp-Mtei-IN': 'omp',
        'omp-IN': 'omp',
        'omp-Mtei': 'omp',
        'omr': 'omr',
        'omr-Modi-IN': 'omr',
        'omr-IN': 'omr',
        'omr-Modi': 'omr',
        'omt': 'omt',
        'omt-Latn-KE': 'omt',
        'omt-KE': 'omt',
        'omt-Latn': 'omt',
        'omu': 'omu',
        'omu-Latn-PE': 'omu',
        'omu-Latn': 'omu',
        'omu-PE': 'omu',
        'omw': 'omw',
        'omw-Latn-PG': 'omw',
        'omw-Latn': 'omw',
        'omw-PG': 'omw',
        'omx': 'omx',
        'omx-Zyyy-XX': 'omx',
        'omx-XX': 'omx',
        'omx-Zyyy': 'omx',
        'ona': 'ona',
        'ona-Latn-AR': 'ona',
        'ona-AR': 'ona',
        'ona-Latn': 'ona',
        'onb': 'onb',
        'onb-Zyyy-CN': 'onb',
        'onb-CN': 'onb',
        'onb-Zyyy': 'onb',
        'one': 'one',
        'one-Latn-CA': 'one',
        'one-CA': 'one',
        'one-Latn': 'one',
        'ong': 'ong',
        'ong-Latn-PG': 'ong',
        'ong-Latn': 'ong',
        'ong-PG': 'ong',
        'oni': 'oni',
        'oni-Latn-ID': 'oni',
        'oni-ID': 'oni',
        'oni-Latn': 'oni',
        'onj': 'onj',
        'onj-Latn-PG': 'onj',
        'onj-Latn': 'onj',
        'onj-PG': 'onj',
        'onk': 'onk',
        'onk-Latn-PG': 'onk',
        'onk-Latn': 'onk',
        'onk-PG': 'onk',
        'onn': 'onn',
        'onn-Latn-PG': 'onn',
        'onn-Latn': 'onn',
        'onn-PG': 'onn',
        'ono': 'ono',
        'ono-Latn-CA': 'ono',
        'ono-CA': 'ono',
        'ono-Latn': 'ono',
        'onp-Deva': 'onp-Deva',
        'onp-Deva-IN': 'onp-Deva',
        'onp-Latn': 'onp-Latn',
        'onp-Latn-IN': 'onp-Latn',
        'onr': 'onr',
        'onr-Latn-PG': 'onr',
        'onr-Latn': 'onr',
        'onr-PG': 'onr',
        'ons': 'ons',
        'ons-Latn-PG': 'ons',
        'ons-Latn': 'ons',
        'ons-PG': 'ons',
        'ont': 'ont',
        'ont-Latn-PG': 'ont',
        'ont-Latn': 'ont',
        'ont-PG': 'ont',
        'onu': 'onu',
        'onu-Latn-VU': 'onu',
        'onu-Latn': 'onu',
        'onu-VU': 'onu',
        'onw': 'onw',
        'onw-Copt-SD-x-olnubian': 'onw',
        'onw-Copt': 'onw',
        'onw-Copt-SD': 'onw',
        'onw-Copt-x-olnubian': 'onw',
        'onw-SD': 'onw',
        'onw-SD-x-olnubian': 'onw',
        'onw-x-olnubian': 'onw',
        'onx': 'onx',
        'onx-Latn-ID': 'onx',
        'onx-ID': 'onx',
        'onx-Latn': 'onx',
        'ood': 'ood',
        'ood-Latn-US': 'ood',
        'ood-Latn': 'ood',
        'ood-US': 'ood',
        'oog': 'oog',
        'oog-Zyyy-LA': 'oog',
        'oog-LA': 'oog',
        'oog-Zyyy': 'oog',
        'oon': 'oon',
        'oon-Zyyy-IN': 'oon',
        'oon-IN': 'oon',
        'oon-Zyyy': 'oon',
        'oor': 'oor',
        'oor-Latn-ZA': 'oor',
        'oor-Latn': 'oor',
        'oor-ZA': 'oor',
        'oos': 'oos',
        'oos-Zyyy-XX': 'oos',
        'oos-XX': 'oos',
        'oos-Zyyy': 'oos',
        'opa': 'opa',
        'opa-Latn-NG': 'opa',
        'ibi': 'opa',
        'ibi-Latn': 'opa',
        'ibi-Latn-NG': 'opa',
        'ibi-NG': 'opa',
        'opa-Latn': 'opa',
        'opa-NG': 'opa',
        'opk': 'opk',
        'opk-Latn-ID': 'opk',
        'opk-ID': 'opk',
        'opk-Latn': 'opk',
        'opm': 'opm',
        'opm-Latn-PG': 'opm',
        'opm-Latn': 'opm',
        'opm-PG': 'opm',
        'opo': 'opo',
        'opo-Latn-PG': 'opo',
        'opo-Latn': 'opo',
        'opo-PG': 'opo',
        'opt': 'opt',
        'opt-Latn-MX': 'opt',
        'opt-Latn': 'opt',
        'opt-MX': 'opt',
        'opy': 'opy',
        'opy-Latn-BR': 'opy',
        'opy-BR': 'opy',
        'opy-Latn': 'opy',
        'or': 'or',
        'or-Orya-IN': 'or',
        'or-IN': 'or',
        'or-Orya': 'or',
        'ory': 'or',
        'ory-IN': 'or',
        'ory-Orya': 'or',
        'ory-Orya-IN': 'or',
        'or-Brai': 'or-Brai',
        'or-Brai-IN': 'or-Brai',
        'ory-Brai': 'or-Brai',
        'ory-Brai-IN': 'or-Brai',
        'ora': 'ora',
        'ora-Latn-SB': 'ora',
        'ora-Latn': 'ora',
        'ora-SB': 'ora',
        'orc': 'orc',
        'orc-Latn-KE': 'orc',
        'orc-KE': 'orc',
        'orc-Latn': 'orc',
        'ore': 'ore',
        'ore-Latn-PE': 'ore',
        'ore-Latn': 'ore',
        'ore-PE': 'ore',
        'org': 'org',
        'org-Latn-NG': 'org',
        'org-Latn': 'org',
        'org-NG': 'org',
        'orh': 'orh',
        'orh-Zyyy-CN': 'orh',
        'orh-CN': 'orh',
        'orh-Zyyy': 'orh',
        'orn': 'orn',
        'orn-Latn-MY': 'orn',
        'ms-orn': 'orn',
        'ms-orn-MY': 'orn',
        'orn-Latn': 'orn',
        'orn-MY': 'orn',
        'oro': 'oro',
        'oro-Latn-PG': 'oro',
        'oro-Latn': 'oro',
        'oro-PG': 'oro',
        'orr': 'orr',
        'orr-Latn-NG': 'orr',
        'orr-Latn': 'orr',
        'orr-NG': 'orr',
        'ors': 'ors',
        'ors-Latn-MY': 'ors',
        'ms-ors': 'ors',
        'ms-ors-MY': 'ors',
        'ors-Latn': 'ors',
        'ors-MY': 'ors',
        'ort': 'ort',
        'ort-Telu-IN': 'ort',
        'ort-IN': 'ort',
        'ort-Telu': 'ort',
        'oru': 'oru',
        'oru-Arab-PK': 'oru',
        'oru-Arab': 'oru',
        'oru-PK': 'oru',
        'orv': 'orv',
        'orv-Cyrl-RU': 'orv',
        'orv-Cyrl': 'orv',
        'orv-RU': 'orv',
        'orw': 'orw',
        'orw-Latn-BR': 'orw',
        'orw-BR': 'orw',
        'orw-Latn': 'orw',
        'orx': 'orx',
        'orx-Latn-NG': 'orx',
        'orx-Latn': 'orx',
        'orx-NG': 'orx',
        'orz': 'orz',
        'orz-Latn-ID': 'orz',
        'orz-ID': 'orz',
        'orz-Latn': 'orz',
        'os': 'os',
        'os-Cyrl-GE': 'os',
        'os-Cyrl': 'os',
        'os-GE': 'os',
        'os-Geor': 'os-Geor',
        'os-Geor-RU': 'os-Geor',
        'os-Latn': 'os-Latn',
        'os-Latn-RU': 'os-Latn',
        'os-RU': 'os-RU',
        'os-Cyrl-RU': 'os-RU',
        'osa': 'osa',
        'osa-Osge-US': 'osa',
        'osa-Osge': 'osa',
        'osa-US': 'osa',
        'osa-Latn': 'osa-Latn',
        'osa-Latn-US': 'osa-Latn',
        'osc': 'osc',
        'osc-Ital-IT': 'osc',
        'osc-IT': 'osc',
        'osc-Ital': 'osc',
        'osc-Latn': 'osc-Latn',
        'osc-Latn-IT': 'osc-Latn',
        'osi': 'osi',
        'osi-Java-ID': 'osi',
        'osi-ID': 'osi',
        'osi-Java': 'osi',
        'oso': 'oso',
        'oso-Latn-NG': 'oso',
        'oso-Latn': 'oso',
        'oso-NG': 'oso',
        'osp': 'osp',
        'osp-Latn-ES': 'osp',
        'osp-ES': 'osp',
        'osp-Latn': 'osp',
        'ost': 'ost',
        'ost-Latn-CM': 'ost',
        'ost-CM': 'ost',
        'ost-Latn': 'ost',
        'osu': 'osu',
        'osu-Latn-PG': 'osu',
        'osu-Latn': 'osu',
        'osu-PG': 'osu',
        'osx': 'osx',
        'osx-Latn-DE': 'osx',
        'osx-DE': 'osx',
        'osx-Latn': 'osx',
        'ota': 'ota',
        'ota-Arab-TR': 'ota',
        'ota-Arab': 'ota',
        'ota-TR': 'ota',
        'otb': 'otb',
        'otb-Tibt-CN': 'otb',
        'otb-CN': 'otb',
        'otb-Tibt': 'otb',
        'otd': 'otd',
        'otd-Latn-ID': 'otd',
        'otd-ID': 'otd',
        'otd-Latn': 'otd',
        'ote': 'ote',
        'ote-Latn-MX': 'ote',
        'ote-Latn': 'ote',
        'ote-MX': 'ote',
        'oti': 'oti',
        'oti-Latn-BR': 'oti',
        'oti-BR': 'oti',
        'oti-Latn': 'oti',
        'otk': 'otk',
        'otk-Orkh-MN': 'otk',
        'otk-MN': 'otk',
        'otk-Orkh': 'otk',
        'otl': 'otl',
        'otl-Latn-MX': 'otl',
        'otl-Latn': 'otl',
        'otl-MX': 'otl',
        'otm': 'otm',
        'otm-Latn-MX': 'otm',
        'otm-Latn': 'otm',
        'otm-MX': 'otm',
        'otn': 'otn',
        'otn-Latn-MX': 'otn',
        'otn-Latn': 'otn',
        'otn-MX': 'otn',
        'otq': 'otq',
        'otq-Latn-MX': 'otq',
        'otq-Latn': 'otq',
        'otq-MX': 'otq',
        'otr': 'otr',
        'otr-Latn-SD': 'otr',
        'otr-Latn': 'otr',
        'otr-SD': 'otr',
        'ots': 'ots',
        'ots-Latn-MX': 'ots',
        'ots-Latn': 'ots',
        'ots-MX': 'ots',
        'ott': 'ott',
        'ott-Latn-MX': 'ott',
        'ott-Latn': 'ott',
        'ott-MX': 'ott',
        'otu': 'otu',
        'otu-Latn-BR': 'otu',
        'otu-BR': 'otu',
        'otu-Latn': 'otu',
        'otw': 'otw',
        'otw-Latn-CA': 'otw',
        'otw-CA': 'otw',
        'otw-Latn': 'otw',
        'otx': 'otx',
        'otx-Latn-MX': 'otx',
        'otx-Latn': 'otx',
        'otx-MX': 'otx',
        'oty': 'oty',
        'oty-Gran-IN': 'oty',
        'oty-Gran': 'oty',
        'oty-IN': 'oty',
        'otz': 'otz',
        'otz-Latn-MX': 'otz',
        'otz-Latn': 'otz',
        'otz-MX': 'otz',
        'oua': 'oua',
        'oua-Zyyy-DZ': 'oua',
        'oua-DZ': 'oua',
        'oua-Zyyy': 'oua',
        'oub': 'oub',
        'oub-Latn-LR': 'oub',
        'oub-LR': 'oub',
        'oub-Latn': 'oub',
        'oue': 'oue',
        'oue-Latn-PG': 'oue',
        'oue-Latn': 'oue',
        'oue-PG': 'oue',
        'oui': 'oui',
        'oui-Zyyy-XX': 'oui',
        'oui-XX': 'oui',
        'oui-Zyyy': 'oui',
        'oui-Mong': 'oui-Mong',
        'oui-Mong-XX': 'oui-Mong',
        'oum': 'oum',
        'oum-Latn-PG': 'oum',
        'oum-Latn': 'oum',
        'oum-PG': 'oum',
        'ovd': 'ovd',
        'ovd-Latn-SE': 'ovd',
        'ovd-Latn': 'ovd',
        'ovd-SE': 'ovd',
        'owi': 'owi',
        'owi-Latn-PG': 'owi',
        'owi-Latn': 'owi',
        'owi-PG': 'owi',
        'owl': 'owl',
        'owl-Latn-GB': 'owl',
        'owl-GB': 'owl',
        'owl-Latn': 'owl',
        'oyb': 'oyb',
        'oyb-Zyyy-LA': 'oyb',
        'jeg': 'oyb',
        'jeg-LA': 'oyb',
        'jeg-Zyyy': 'oyb',
        'jeg-Zyyy-LA': 'oyb',
        'oyb-LA': 'oyb',
        'oyb-Zyyy': 'oyb',
        'skk': 'oyb',
        'skk-LA': 'oyb',
        'skk-Zyyy': 'oyb',
        'skk-Zyyy-LA': 'oyb',
        'thx': 'oyb',
        'thx-LA': 'oyb',
        'thx-Zyyy': 'oyb',
        'thx-Zyyy-LA': 'oyb',
        'oyd': 'oyd',
        'oyd-Latn-ET': 'oyd',
        'oyd-ET': 'oyd',
        'oyd-Latn': 'oyd',
        'oym': 'oym',
        'oym-Latn-BR': 'oym',
        'oym-BR': 'oym',
        'oym-Latn': 'oym',
        'oyy': 'oyy',
        'oyy-Latn-PG': 'oyy',
        'oyy-Latn': 'oyy',
        'oyy-PG': 'oyy',
        'ozm': 'ozm',
        'ozm-Latn-CM': 'ozm',
        'ozm-CM': 'ozm',
        'ozm-Latn': 'ozm',
        'pa': 'pa',
        'pa-Guru-IN': 'pa',
        'pa-Guru': 'pa',
        'pa-IN': 'pa',
        'pa-Khoj': 'pa-Khoj',
        'pa-Khoj-IN': 'pa-Khoj',
        'pa-Mahj': 'pa-Mahj',
        'pa-Mahj-IN': 'pa-Mahj',
        'pa-PK': 'pa-PK',
        'pa-Arab-PK': 'pa-PK',
        'pa-Arab': 'pa-PK',
        'pab': 'pab',
        'pab-Latn-BR': 'pab',
        'pab-BR': 'pab',
        'pab-Latn': 'pab',
        'pac': 'pac',
        'pac-Latn-VN': 'pac',
        'pac-Latn': 'pac',
        'pac-VN': 'pac',
        'pac-Laoo-x-diacado': 'pac-Laoo-x-diacado',
        'pac-Laoo-LA-x-diacado': 'pac-Laoo-x-diacado',
        'pac-LA-x-diacado': 'pac-Laoo-x-diacado',
        'pac-x-diacado': 'pac-x-diacado',
        'pac-Latn-VN-x-diacado': 'pac-x-diacado',
        'pac-Latn-x-diacado': 'pac-x-diacado',
        'pac-VN-x-diacado': 'pac-x-diacado',
        'pad': 'pad',
        'pad-Latn-BR': 'pad',
        'pad-BR': 'pad',
        'pad-Latn': 'pad',
        'pae': 'pae',
        'pae-Latn-CD': 'pae',
        'pae-CD': 'pae',
        'pae-Latn': 'pae',
        'paf': 'paf',
        'paf-Latn-BR': 'paf',
        'paf-BR': 'paf',
        'paf-Latn': 'paf',
        'pag': 'pag',
        'pag-Latn-PH': 'pag',
        'pag-Latn': 'pag',
        'pag-PH': 'pag',
        'pag-Brai': 'pag-Brai',
        'pag-Brai-PH': 'pag-Brai',
        'pah': 'pah',
        'pah-Latn-BR': 'pah',
        'pah-BR': 'pah',
        'pah-Latn': 'pah',
        'pai': 'pai',
        'pai-Latn-NG': 'pai',
        'pai-Latn': 'pai',
        'pai-NG': 'pai',
        'pak': 'pak',
        'pak-Latn-BR': 'pak',
        'pak-BR': 'pak',
        'pak-Latn': 'pak',
        'pal': 'pal',
        'pal-Phli-IR': 'pal',
        'pal-IR': 'pal',
        'pal-Phli': 'pal',
        'pal-Phlp': 'pal-Phlp',
        'pal-Phlp-CN': 'pal-Phlp',
        'pal-CN': 'pal-Phlp',
        'pam': 'pam',
        'pam-Latn-PH': 'pam',
        'pam-Latn': 'pam',
        'pam-PH': 'pam',
        'pam-Brai': 'pam-Brai',
        'pam-Brai-PH': 'pam-Brai',
        'pao': 'pao',
        'pao-Latn-US': 'pao',
        'pao-Latn': 'pao',
        'pao-US': 'pao',
        'pap': 'pap',
        'pap-Latn-AW': 'pap',
        'pap-AW': 'pap',
        'pap-Latn': 'pap',
        'paq': 'paq',
        'paq-Zyyy-TJ': 'paq',
        'paq-TJ': 'paq',
        'paq-Zyyy': 'paq',
        'par': 'par',
        'par-Latn-US': 'par',
        'par-Latn': 'par',
        'par-US': 'par',
        'pas': 'pas',
        'pas-Latn-ID': 'pas',
        'pas-ID': 'pas',
        'pas-Latn': 'pas',
        'pat': 'pat',
        'pat-Latn-PG': 'pat',
        'pat-Latn': 'pat',
        'pat-PG': 'pat',
        'pau': 'pau',
        'pau-Latn-PW': 'pau',
        'pau-Latn': 'pau',
        'pau-PW': 'pau',
        'pav': 'pav',
        'pav-Latn-BR': 'pav',
        'pav-BR': 'pav',
        'pav-Latn': 'pav',
        'paw': 'paw',
        'paw-Latn-US': 'paw',
        'paw-Latn': 'paw',
        'paw-US': 'paw',
        'pax': 'pax',
        'pax-Latn-BR': 'pax',
        'pax-BR': 'pax',
        'pax-Latn': 'pax',
        'pay': 'pay',
        'pay-Latn-HN': 'pay',
        'pay-HN': 'pay',
        'pay-Latn': 'pay',
        'paz': 'paz',
        'paz-Latn-BR': 'paz',
        'paz-BR': 'paz',
        'paz-Latn': 'paz',
        'pbb': 'pbb',
        'pbb-Latn-CO': 'pbb',
        'pbb-CO': 'pbb',
        'pbb-Latn': 'pbb',
        'pbc': 'pbc',
        'pbc-Latn-GY': 'pbc',
        'pbc-GY': 'pbc',
        'pbc-Latn': 'pbc',
        'pbe': 'pbe',
        'pbe-Latn-MX': 'pbe',
        'pbe-Latn': 'pbe',
        'pbe-MX': 'pbe',
        'pbf': 'pbf',
        'pbf-Latn-MX': 'pbf',
        'pbf-Latn': 'pbf',
        'pbf-MX': 'pbf',
        'pbg': 'pbg',
        'pbg-Latn-VE': 'pbg',
        'pbg-Latn': 'pbg',
        'pbg-VE': 'pbg',
        'pbh': 'pbh',
        'pbh-Latn-VE': 'pbh',
        'pbh-Latn': 'pbh',
        'pbh-VE': 'pbh',
        'pbi': 'pbi',
        'pbi-Latn-CM': 'pbi',
        'pbi-CM': 'pbi',
        'pbi-Latn': 'pbi',
        'pbl': 'pbl',
        'pbl-Latn-NG': 'pbl',
        'pbl-Latn': 'pbl',
        'pbl-NG': 'pbl',
        'pbm': 'pbm',
        'pbm-Latn-MX': 'pbm',
        'pbm-Latn': 'pbm',
        'pbm-MX': 'pbm',
        'pbn': 'pbn',
        'pbn-Latn-NG': 'pbn',
        'pbn-Latn': 'pbn',
        'pbn-NG': 'pbn',
        'pbo': 'pbo',
        'pbo-Latn-GW': 'pbo',
        'pbo-GW': 'pbo',
        'pbo-Latn': 'pbo',
        'pbp': 'pbp',
        'pbp-Latn-GN': 'pbp',
        'pbp-GN': 'pbp',
        'pbp-Latn': 'pbp',
        'pbr': 'pbr',
        'pbr-Latn-TZ': 'pbr',
        'pbr-Latn': 'pbr',
        'pbr-TZ': 'pbr',
        'pbs': 'pbs',
        'pbs-Latn-MX': 'pbs',
        'pbs-Latn': 'pbs',
        'pbs-MX': 'pbs',
        'pbt': 'pbt',
        'pbt-Arab-AF': 'pbt',
        'pbt-AF': 'pbt',
        'pbt-Arab': 'pbt',
        'pbv': 'pbv',
        'pbv-Latn-IN': 'pbv',
        'pbv-IN': 'pbv',
        'pbv-Latn': 'pbv',
        'pby': 'pby',
        'pby-Latn-PG': 'pby',
        'pby-Latn': 'pby',
        'pby-PG': 'pby',
        'pca': 'pca',
        'pca-Latn-MX': 'pca',
        'pca-Latn': 'pca',
        'pca-MX': 'pca',
        'pcb': 'pcb',
        'pcb-Zyyy-KH': 'pcb',
        'pcb-KH': 'pcb',
        'pcb-Zyyy': 'pcb',
        'pcc-Hani': 'pcc-Hani',
        'pcc-Hani-CN': 'pcc-Hani',
        'pcc-Latn': 'pcc-Latn',
        'pcc-Latn-CN': 'pcc-Latn',
        'pcd': 'pcd',
        'pcd-Latn-FR': 'pcd',
        'pcd-FR': 'pcd',
        'pcd-Latn': 'pcd',
        'pce': 'pce',
        'pce-Mymr-MM': 'pce',
        'pce-MM': 'pce',
        'pce-Mymr': 'pce',
        'pcf': 'pcf',
        'pcf-Zyyy-IN': 'pcf',
        'pcf-IN': 'pcf',
        'pcf-Zyyy': 'pcf',
        'pcg-Knda': 'pcg-Knda',
        'pcg-Knda-IN': 'pcg-Knda',
        'pcg-Mlym': 'pcg-Mlym',
        'pcg-Mlym-IN': 'pcg-Mlym',
        'pcg-Taml': 'pcg-Taml',
        'pcg-Taml-IN': 'pcg-Taml',
        'pch': 'pch',
        'pch-Zyyy-IN': 'pch',
        'pch-IN': 'pch',
        'pch-Zyyy': 'pch',
        'pci-Deva': 'pci-Deva',
        'pci-Deva-IN': 'pci-Deva',
        'pci-Orya': 'pci-Orya',
        'pci-Orya-IN': 'pci-Orya',
        'pcj': 'pcj',
        'pcj-Telu-IN': 'pcj',
        'pcj-IN': 'pcj',
        'pcj-Telu': 'pcj',
        'pck': 'pck',
        'pck-Latn-IN': 'pck',
        'pck-IN': 'pck',
        'pck-Latn': 'pck',
        'pcl': 'pcl',
        'pcl-Zyyy-IN': 'pcl',
        'pcl-IN': 'pcl',
        'pcl-Zyyy': 'pcl',
        'pcm': 'pcm',
        'pcm-Latn-NG': 'pcm',
        'pcm-Latn': 'pcm',
        'pcm-NG': 'pcm',
        'pcn': 'pcn',
        'pcn-Latn-NG': 'pcn',
        'pcn-Latn': 'pcn',
        'pcn-NG': 'pcn',
        'pcp': 'pcp',
        'pcp-Latn-BO': 'pcp',
        'pcp-BO': 'pcp',
        'pcp-Latn': 'pcp',
        'pcw': 'pcw',
        'pcw-Latn-NG': 'pcw',
        'pcw-Latn': 'pcw',
        'pcw-NG': 'pcw',
        'pda': 'pda',
        'pda-Latn-PG': 'pda',
        'pda-Latn': 'pda',
        'pda-PG': 'pda',
        'pdc': 'pdc',
        'pdc-Latn-US': 'pdc',
        'pdc-Latn': 'pdc',
        'pdc-US': 'pdc',
        'pdi': 'pdi',
        'pdi-Zyyy-CN': 'pdi',
        'pdi-CN': 'pdi',
        'pdi-Zyyy': 'pdi',
        'pdn': 'pdn',
        'pdn-Latn-ID': 'pdn',
        'pdn-ID': 'pdn',
        'pdn-Latn': 'pdn',
        'pdo': 'pdo',
        'pdo-Latn-ID': 'pdo',
        'pdo-ID': 'pdo',
        'pdo-Latn': 'pdo',
        'pdt': 'pdt',
        'pdt-Latn-CA': 'pdt',
        'pdt-CA': 'pdt',
        'pdt-Latn': 'pdt',
        'pdu': 'pdu',
        'pdu-Latn-MM': 'pdu',
        'pdu-Latn': 'pdu',
        'pdu-MM': 'pdu',
        'pdu-Mymr': 'pdu-Mymr',
        'pdu-Mymr-MM': 'pdu-Mymr',
        'pea': 'pea',
        'pea-Latn-ID': 'pea',
        'pea-ID': 'pea',
        'pea-Latn': 'pea',
        'peb': 'peb',
        'peb-Zyyy-US': 'peb',
        'peb-US': 'peb',
        'peb-Zyyy': 'peb',
        'ped': 'ped',
        'ped-Latn-PG': 'ped',
        'ped-Latn': 'ped',
        'ped-PG': 'ped',
        'pee': 'pee',
        'pee-Latn-ID': 'pee',
        'pee-ID': 'pee',
        'pee-Latn': 'pee',
        'pef': 'pef',
        'pef-Zyyy-US': 'pef',
        'pef-US': 'pef',
        'pef-Zyyy': 'pef',
        'peg': 'peg',
        'peg-Orya-IN': 'peg',
        'peg-IN': 'peg',
        'peg-Orya': 'peg',
        'peh': 'peh',
        'peh-Zyyy-CN': 'peh',
        'peh-CN': 'peh',
        'peh-Zyyy': 'peh',
        'pei': 'pei',
        'pei-Latn-MX': 'pei',
        'pei-Latn': 'pei',
        'pei-MX': 'pei',
        'pej': 'pej',
        'pej-Zyyy-US': 'pej',
        'pej-US': 'pej',
        'pej-Zyyy': 'pej',
        'pek': 'pek',
        'pek-Latn-PG': 'pek',
        'pek-Latn': 'pek',
        'pek-PG': 'pek',
        'pel': 'pel',
        'pel-Latn-ID': 'pel',
        'ms-pel': 'pel',
        'ms-pel-ID': 'pel',
        'pel-ID': 'pel',
        'pel-Latn': 'pel',
        'pem': 'pem',
        'pem-Latn-CD': 'pem',
        'pem-CD': 'pem',
        'pem-Latn': 'pem',
        'peo': 'peo',
        'peo-Xpeo-IR': 'peo',
        'peo-IR': 'peo',
        'peo-Xpeo': 'peo',
        'pep': 'pep',
        'pep-Latn-PG': 'pep',
        'pep-Latn': 'pep',
        'pep-PG': 'pep',
        'peq': 'peq',
        'peq-Latn-US': 'peq',
        'peq-Latn': 'peq',
        'peq-US': 'peq',
        'pev': 'pev',
        'pev-Latn-VE': 'pev',
        'pev-Latn': 'pev',
        'pev-VE': 'pev',
        'pex': 'pex',
        'pex-Latn-PG': 'pex',
        'pex-Latn': 'pex',
        'pex-PG': 'pex',
        'pey': 'pey',
        'pey-Latn-ID': 'pey',
        'pey-ID': 'pey',
        'pey-Latn': 'pey',
        'pez': 'pez',
        'pez-Latn-MY': 'pez',
        'pez-Latn': 'pez',
        'pez-MY': 'pez',
        'pfa': 'pfa',
        'pfa-Latn-FM': 'pfa',
        'pfa-FM': 'pfa',
        'pfa-Latn': 'pfa',
        'pfe': 'pfe',
        'pfe-Latn-CM': 'pfe',
        'pfe-CM': 'pfe',
        'pfe-Latn': 'pfe',
        'pfl': 'pfl',
        'pfl-Latn-DE': 'pfl',
        'pfl-DE': 'pfl',
        'pfl-Latn': 'pfl',
        'pga': 'pga',
        'pga-Latn-SS': 'pga',
        'ar-pga': 'pga',
        'ar-pga-SS': 'pga',
        'pga-Latn': 'pga',
        'pga-SS': 'pga',
        'pgd': 'pgd',
        'pgd-Khar-PK': 'pgd',
        'pgd-Khar': 'pgd',
        'pgd-PK': 'pgd',
        'pgg': 'pgg',
        'pgg-Deva-IN': 'pgg',
        'pgg-Deva': 'pgg',
        'pgg-IN': 'pgg',
        'pgi': 'pgi',
        'pgi-Latn-PG': 'pgi',
        'pgi-Latn': 'pgi',
        'pgi-PG': 'pgi',
        'pgk': 'pgk',
        'pgk-Latn-VU': 'pgk',
        'pgk-Latn': 'pgk',
        'pgk-VU': 'pgk',
        'pgl': 'pgl',
        'pgl-Ogam-IE': 'pgl',
        'pgl-IE': 'pgl',
        'pgl-Ogam': 'pgl',
        'pgn': 'pgn',
        'pgn-Ital-IT': 'pgn',
        'pgn-IT': 'pgn',
        'pgn-Ital': 'pgn',
        'pgs': 'pgs',
        'pgs-Latn-NG': 'pgs',
        'pgs-Latn': 'pgs',
        'pgs-NG': 'pgs',
        'pgu': 'pgu',
        'pgu-Latn-ID': 'pgu',
        'pgu-ID': 'pgu',
        'pgu-Latn': 'pgu',
        'pgz': 'pgz',
        'pgz-Zxxx-PG': 'pgz',
        'pgz-PG': 'pgz',
        'pgz-Zxxx': 'pgz',
        'sgn-pgz': 'pgz',
        'sgn-pgz-PG': 'pgz',
        'pha': 'pha',
        'pha-Zyyy-CN': 'pha',
        'pha-CN': 'pha',
        'pha-Zyyy': 'pha',
        'phd': 'phd',
        'phd-Zyyy-IN': 'phd',
        'phd-IN': 'phd',
        'phd-Zyyy': 'phd',
        'phg': 'phg',
        'phg-Latn-VN': 'phg',
        'phg-Latn': 'phg',
        'phg-VN': 'phg',
        'phh': 'phh',
        'phh-Latn-VN': 'phh',
        'phh-Latn': 'phh',
        'phh-VN': 'phh',
        'phk': 'phk',
        'phk-Mymr-IN': 'phk',
        'phk-IN': 'phk',
        'phk-Mymr': 'phk',
        'phl': 'phl',
        'phl-Arab-PK': 'phl',
        'phl-Arab': 'phl',
        'phl-PK': 'phl',
        'phm': 'phm',
        'phm-Latn-MZ': 'phm',
        'phm-Latn': 'phm',
        'phm-MZ': 'phm',
        'phn': 'phn',
        'phn-Phnx-LB': 'phn',
        'phn-LB': 'phn',
        'phn-Phnx': 'phn',
        'pho': 'pho',
        'pho-Laoo-LA': 'pho',
        'pho-LA': 'pho',
        'pho-Laoo': 'pho',
        'phq': 'phq',
        'phq-Zyyy-LA': 'phq',
        'phq-LA': 'phq',
        'phq-Zyyy': 'phq',
        'phr': 'phr',
        'phr-Arab-PK': 'phr',
        'phr-Arab': 'phr',
        'phr-PK': 'phr',
        'pmu': 'phr',
        'pmu-Arab': 'phr',
        'pmu-Arab-PK': 'phr',
        'pmu-PK': 'phr',
        'pht': 'pht',
        'pht-Zyyy-TH': 'pht',
        'pht-TH': 'pht',
        'pht-Zyyy': 'pht',
        'phu': 'phu',
        'phu-Zyyy-TH': 'phu',
        'phu-TH': 'phu',
        'phu-Zyyy': 'phu',
        'phv': 'phv',
        'phv-Arab-AF': 'phv',
        'phv-AF': 'phv',
        'phv-Arab': 'phv',
        'phw': 'phw',
        'phw-Zyyy-NP': 'phw',
        'phw-NP': 'phw',
        'phw-Zyyy': 'phw',
        'pi-Deva': 'pi-Deva',
        'pi-Deva-IN': 'pi-Deva',
        'pi-Mymr': 'pi-Mymr',
        'pi-Mymr-IN': 'pi-Mymr',
        'pi-Sinh': 'pi-Sinh',
        'pi-Sinh-IN': 'pi-Sinh',
        'pi-Thai': 'pi-Thai',
        'pi-Thai-IN': 'pi-Thai',
        'pia': 'pia',
        'pia-Latn-MX': 'pia',
        'pia-Latn': 'pia',
        'pia-MX': 'pia',
        'pib': 'pib',
        'pib-Latn-PE': 'pib',
        'pib-Latn': 'pib',
        'pib-PE': 'pib',
        'pic': 'pic',
        'pic-Latn-GA': 'pic',
        'pic-GA': 'pic',
        'pic-Latn': 'pic',
        'pid': 'pid',
        'pid-Latn-VE': 'pid',
        'pid-Latn': 'pid',
        'pid-VE': 'pid',
        'pie': 'pie',
        'pie-Zyyy-US': 'pie',
        'pie-US': 'pie',
        'pie-Zyyy': 'pie',
        'pif': 'pif',
        'pif-Latn-FM': 'pif',
        'pif-FM': 'pif',
        'pif-Latn': 'pif',
        'pig': 'pig',
        'pig-Latn-PE': 'pig',
        'pig-Latn': 'pig',
        'pig-PE': 'pig',
        'pih': 'pih',
        'pih-Latn-NF': 'pih',
        'pih-Latn': 'pih',
        'pih-NF': 'pih',
        'pii': 'pii',
        'pii-Latn-AU': 'pii',
        'pii-AU': 'pii',
        'pii-Latn': 'pii',
        'pij': 'pij',
        'pij-Latn-CO': 'pij',
        'coy': 'pij',
        'coy-CO': 'pij',
        'coy-Latn': 'pij',
        'coy-Latn-CO': 'pij',
        'nts': 'pij',
        'nts-CO': 'pij',
        'nts-Latn': 'pij',
        'nts-Latn-CO': 'pij',
        'pij-CO': 'pij',
        'pij-Latn': 'pij',
        'pil': 'pil',
        'pil-Latn-BJ': 'pil',
        'pil-BJ': 'pil',
        'pil-Latn': 'pil',
        'pim': 'pim',
        'pim-Zyyy-US': 'pim',
        'pim-US': 'pim',
        'pim-Zyyy': 'pim',
        'pin': 'pin',
        'pin-Latn-PG': 'pin',
        'pin-Latn': 'pin',
        'pin-PG': 'pin',
        'pio': 'pio',
        'pio-Latn-CO': 'pio',
        'pio-CO': 'pio',
        'pio-Latn': 'pio',
        'pip': 'pip',
        'pip-Latn-NG': 'pip',
        'pip-Latn': 'pip',
        'pip-NG': 'pip',
        'pir': 'pir',
        'pir-Latn-BR': 'pir',
        'pir-BR': 'pir',
        'pir-Latn': 'pir',
        'pis': 'pis',
        'pis-Latn-SB': 'pis',
        'pis-Latn': 'pis',
        'pis-SB': 'pis',
        'pit': 'pit',
        'pit-Latn-AU': 'pit',
        'pit-AU': 'pit',
        'pit-Latn': 'pit',
        'piu': 'piu',
        'piu-Latn-AU': 'piu',
        'piu-AU': 'piu',
        'piu-Latn': 'piu',
        'piv': 'piv',
        'piv-Latn-SB': 'piv',
        'piv-Latn': 'piv',
        'piv-SB': 'piv',
        'piw': 'piw',
        'piw-Latn-TZ': 'piw',
        'piw-Latn': 'piw',
        'piw-TZ': 'piw',
        'pix': 'pix',
        'pix-Latn-PG': 'pix',
        'pix-Latn': 'pix',
        'pix-PG': 'pix',
        'piy': 'piy',
        'piy-Latn-NG': 'piy',
        'piy-Latn': 'piy',
        'piy-NG': 'piy',
        'piz': 'piz',
        'piz-Latn-NC': 'piz',
        'piz-Latn': 'piz',
        'piz-NC': 'piz',
        'pjt': 'pjt',
        'pjt-Latn-AU': 'pjt',
        'pjt-AU': 'pjt',
        'pjt-Latn': 'pjt',
        'pka': 'pka',
        'pka-Brah-IN': 'pka',
        'pka-Brah': 'pka',
        'pka-IN': 'pka',
        'pkb': 'pkb',
        'pkb-Latn-KE': 'pkb',
        'pkb-KE': 'pkb',
        'pkb-Latn': 'pkb',
        'pkc': 'pkc',
        'pkc-Zyyy-KR': 'pkc',
        'pkc-KR': 'pkc',
        'pkc-Zyyy': 'pkc',
        'pkg': 'pkg',
        'pkg-Latn-PG': 'pkg',
        'pkg-Latn': 'pkg',
        'pkg-PG': 'pkg',
        'pkh-Deva': 'pkh-Deva',
        'pkh-Deva-BD': 'pkh-Deva',
        'pkh-Latn': 'pkh-Latn',
        'pkh-Latn-BD': 'pkh-Latn',
        'pkn': 'pkn',
        'pkn-Latn-AU': 'pkn',
        'pkn-AU': 'pkn',
        'pkn-Latn': 'pkn',
        'pko': 'pko',
        'pko-Latn-KE': 'pko',
        'pko-KE': 'pko',
        'pko-Latn': 'pko',
        'pkp': 'pkp',
        'pkp-Latn-CK': 'pkp',
        'pkp-CK': 'pkp',
        'pkp-Latn': 'pkp',
        'pkr': 'pkr',
        'pkr-Mlym-IN': 'pkr',
        'pkr-IN': 'pkr',
        'pkr-Mlym': 'pkr',
        'pks': 'pks',
        'pks-Zxxx-PK': 'pks',
        'pks-PK': 'pks',
        'pks-Zxxx': 'pks',
        'sgn-pks': 'pks',
        'sgn-pks-PK': 'pks',
        'pkt': 'pkt',
        'pkt-Zyyy-LA': 'pkt',
        'pkt-LA': 'pkt',
        'pkt-Zyyy': 'pkt',
        'pku': 'pku',
        'pku-Latn-ID': 'pku',
        'pku-ID': 'pku',
        'pku-Latn': 'pku',
        'pl': 'pl',
        'pl-Latn-PL': 'pl',
        'pl-Latn': 'pl',
        'pl-PL': 'pl',
        'pl-Brai': 'pl-Brai',
        'pl-Brai-PL': 'pl-Brai',
        'pla': 'pla',
        'pla-Latn-PG': 'pla',
        'pla-Latn': 'pla',
        'pla-PG': 'pla',
        'plb': 'plb',
        'plb-Latn-VU': 'plb',
        'plb-Latn': 'plb',
        'plb-VU': 'plb',
        'plc': 'plc',
        'plc-Latn-PH': 'plc',
        'plc-Latn': 'plc',
        'plc-PH': 'plc',
        'pld': 'pld',
        'pld-Latn-GB': 'pld',
        'pld-GB': 'pld',
        'pld-Latn': 'pld',
        'ple': 'ple',
        'ple-Latn-ID': 'ple',
        'ple-ID': 'ple',
        'ple-Latn': 'ple',
        'plg': 'plg',
        'plg-Latn-AR': 'plg',
        'plg-AR': 'plg',
        'plg-Latn': 'plg',
        'plh': 'plh',
        'plh-Latn-ID': 'plh',
        'plh-ID': 'plh',
        'plh-Latn': 'plh',
        'plj': 'plj',
        'plj-Latn-NG': 'plj',
        'plj-Latn': 'plj',
        'plj-NG': 'plj',
        'plk': 'plk',
        'plk-Arab-PK': 'plk',
        'plk-Arab': 'plk',
        'plk-PK': 'plk',
        'pll': 'pll',
        'pll-Mymr-MM': 'pll',
        'pll-MM': 'pll',
        'pll-Mymr': 'pll',
        'pln': 'pln',
        'pln-Latn-CO': 'pln',
        'pln-CO': 'pln',
        'pln-Latn': 'pln',
        'plo': 'plo',
        'plo-Latn-MX': 'plo',
        'plo-Latn': 'plo',
        'plo-MX': 'plo',
        'plp': 'plp',
        'plp-Deva-NP': 'plp',
        'plp-Deva': 'plp',
        'plp-NP': 'plp',
        'plq': 'plq',
        'plq-Zyyy-TR': 'plq',
        'plq-TR': 'plq',
        'plq-Zyyy': 'plq',
        'plr': 'plr',
        'plr-Latn-CI': 'plr',
        'plr-CI': 'plr',
        'plr-Latn': 'plr',
        'pls': 'pls',
        'pls-Latn-MX': 'pls',
        'pls-Latn': 'pls',
        'pls-MX': 'pls',
        'plu': 'plu',
        'plu-Latn-BR': 'plu',
        'plu-BR': 'plu',
        'plu-Latn': 'plu',
        'plv': 'plv',
        'plv-Latn-PH': 'plv',
        'plv-Latn': 'plv',
        'plv-PH': 'plv',
        'plw': 'plw',
        'plw-Latn-PH': 'plw',
        'plw-Latn': 'plw',
        'plw-PH': 'plw',
        'ply': 'ply',
        'ply-Zyyy-CN': 'ply',
        'ply-CN': 'ply',
        'ply-Zyyy': 'ply',
        'plz': 'plz',
        'plz-Latn-MY': 'plz',
        'plz-Latn': 'plz',
        'plz-MY': 'plz',
        'pma': 'pma',
        'pma-Latn-VU': 'pma',
        'pma-Latn': 'pma',
        'pma-VU': 'pma',
        'pmb': 'pmb',
        'pmb-Latn-CD': 'pmb',
        'pmb-CD': 'pmb',
        'pmb-Latn': 'pmb',
        'pmd': 'pmd',
        'pmd-Latn-AU': 'pmd',
        'pmd-AU': 'pmd',
        'pmd-Latn': 'pmd',
        'pme': 'pme',
        'pme-Latn-NC': 'pme',
        'pme-Latn': 'pme',
        'pme-NC': 'pme',
        'pmf': 'pmf',
        'pmf-Latn-ID': 'pmf',
        'pmf-ID': 'pmf',
        'pmf-Latn': 'pmf',
        'pmh': 'pmh',
        'pmh-Zyyy-IN': 'pmh',
        'pmh-IN': 'pmh',
        'pmh-Zyyy': 'pmh',
        'pmi': 'pmi',
        'pmi-Zyyy-CN': 'pmi',
        'pmi-CN': 'pmi',
        'pmi-Zyyy': 'pmi',
        'pmj': 'pmj',
        'pmj-Zyyy-CN': 'pmj',
        'pmj-CN': 'pmj',
        'pmj-Zyyy': 'pmj',
        'pmk': 'pmk',
        'pmk-Zyyy-US': 'pmk',
        'pmk-US': 'pmk',
        'pmk-Zyyy': 'pmk',
        'pml': 'pml',
        'pml-Zyyy-TN': 'pml',
        'pml-TN': 'pml',
        'pml-Zyyy': 'pml',
        'pmm': 'pmm',
        'pmm-Latn-CM': 'pmm',
        'pmm-CM': 'pmm',
        'pmm-Latn': 'pmm',
        'pmn': 'pmn',
        'pmn-Latn-CM': 'pmn',
        'pmn-CM': 'pmn',
        'pmn-Latn': 'pmn',
        'pmo': 'pmo',
        'pmo-Latn-ID': 'pmo',
        'pmo-ID': 'pmo',
        'pmo-Latn': 'pmo',
        'pmq': 'pmq',
        'pmq-Latn-MX': 'pmq',
        'pmq-Latn': 'pmq',
        'pmq-MX': 'pmq',
        'pmr': 'pmr',
        'pmr-Latn-PG': 'pmr',
        'pmr-Latn': 'pmr',
        'pmr-PG': 'pmr',
        'pms': 'pms',
        'pms-Latn-IT': 'pms',
        'pms-IT': 'pms',
        'pms-Latn': 'pms',
        'pmt': 'pmt',
        'pmt-Latn-PF': 'pmt',
        'pmt-Latn': 'pmt',
        'pmt-PF': 'pmt',
        'pmw': 'pmw',
        'pmw-Latn-US': 'pmw',
        'pmw-Latn': 'pmw',
        'pmw-US': 'pmw',
        'pmx': 'pmx',
        'pmx-Latn-IN': 'pmx',
        'pmx-IN': 'pmx',
        'pmx-Latn': 'pmx',
        'pmy': 'pmy',
        'pmy-Latn-ID': 'pmy',
        'pmy-ID': 'pmy',
        'pmy-Latn': 'pmy',
        'pmz': 'pmz',
        'pmz-Latn-MX': 'pmz',
        'pmz-Latn': 'pmz',
        'pmz-MX': 'pmz',
        'pna': 'pna',
        'pna-Latn-MY': 'pna',
        'pna-Latn': 'pna',
        'pna-MY': 'pna',
        'pnc': 'pnc',
        'pnc-Latn-ID': 'pnc',
        'pnc-ID': 'pnc',
        'pnc-Latn': 'pnc',
        'pnd': 'pnd',
        'pnd-Latn-AO': 'pnd',
        'pnd-AO': 'pnd',
        'pnd-Latn': 'pnd',
        'pne': 'pne',
        'pne-Latn-MY': 'pne',
        'pne-Latn': 'pne',
        'pne-MY': 'pne',
        'png': 'png',
        'png-Latn-NG': 'png',
        'png-Latn': 'png',
        'png-NG': 'png',
        'pnh': 'pnh',
        'pnh-Latn-CK': 'pnh',
        'pnh-CK': 'pnh',
        'pnh-Latn': 'pnh',
        'pni': 'pni',
        'pni-Latn-ID': 'pni',
        'pni-ID': 'pni',
        'pni-Latn': 'pni',
        'pnj': 'pnj',
        'pnj-Latn-AU': 'pnj',
        'pnj-AU': 'pnj',
        'pnj-Latn': 'pnj',
        'pnk': 'pnk',
        'pnk-Latn-BO': 'pnk',
        'pnk-BO': 'pnk',
        'pnk-Latn': 'pnk',
        'pnl': 'pnl',
        'pnl-Latn-BF': 'pnl',
        'pnl-BF': 'pnl',
        'pnl-Latn': 'pnl',
        'pnm': 'pnm',
        'pnm-Latn-MY': 'pnm',
        'pnm-Latn': 'pnm',
        'pnm-MY': 'pnm',
        'pnn': 'pnn',
        'pnn-Latn-PG': 'pnn',
        'pnn-Latn': 'pnn',
        'pnn-PG': 'pnn',
        'pno': 'pno',
        'pno-Latn-PE': 'pno',
        'pno-Latn': 'pno',
        'pno-PE': 'pno',
        'pnp': 'pnp',
        'pnp-Latn-ID': 'pnp',
        'pnp-ID': 'pnp',
        'pnp-Latn': 'pnp',
        'pnq': 'pnq',
        'pnq-Latn-BF': 'pnq',
        'pnq-BF': 'pnq',
        'pnq-Latn': 'pnq',
        'pnr': 'pnr',
        'pnr-Latn-PG': 'pnr',
        'pnr-Latn': 'pnr',
        'pnr-PG': 'pnr',
        'pns': 'pns',
        'pns-Latn-ID': 'pns',
        'pns-ID': 'pns',
        'pns-Latn': 'pns',
        'pnt': 'pnt',
        'pnt-Grek-GR': 'pnt',
        'pnt-GR': 'pnt',
        'pnt-Grek': 'pnt',
        'pnt-Cyrl': 'pnt-Cyrl',
        'pnt-Cyrl-GR': 'pnt-Cyrl',
        'pnt-Latn': 'pnt-Latn',
        'pnt-Latn-TR': 'pnt-Latn',
        'pnt-TR': 'pnt-Latn',
        'pnu': 'pnu',
        'pnu-Zyyy-CN': 'pnu',
        'pnu-CN': 'pnu',
        'pnu-Zyyy': 'pnu',
        'pnv': 'pnv',
        'pnv-Latn-AU': 'pnv',
        'pnv-AU': 'pnv',
        'pnv-Latn': 'pnv',
        'pnw': 'pnw',
        'pnw-Latn-AU': 'pnw',
        'pnw-AU': 'pnw',
        'pnw-Latn': 'pnw',
        'pnx': 'pnx',
        'pnx-Zyyy-LA': 'pnx',
        'pnx-LA': 'pnx',
        'pnx-Zyyy': 'pnx',
        'pny': 'pny',
        'pny-Latn-CM': 'pny',
        'pny-CM': 'pny',
        'pny-Latn': 'pny',
        'pnz': 'pnz',
        'pnz-Latn-CF': 'pnz',
        'pnz-CF': 'pnz',
        'pnz-Latn': 'pnz',
        'poc': 'poc',
        'poc-Latn-GT': 'poc',
        'poc-GT': 'poc',
        'poc-Latn': 'poc',
        'poe': 'poe',
        'poe-Latn-MX': 'poe',
        'poe-Latn': 'poe',
        'poe-MX': 'poe',
        'pof': 'pof',
        'pof-Latn-CD': 'pof',
        'pof-CD': 'pof',
        'pof-Latn': 'pof',
        'pog': 'pog',
        'pog-Latn-BR': 'pog',
        'pog-BR': 'pog',
        'pog-Latn': 'pog',
        'poh': 'poh',
        'poh-Latn-GT': 'poh',
        'poh-GT': 'poh',
        'poh-Latn': 'poh',
        'poi': 'poi',
        'poi-Latn-MX': 'poi',
        'poi-Latn': 'poi',
        'poi-MX': 'poi',
        'pok': 'pok',
        'pok-Latn-BR': 'pok',
        'pok-BR': 'pok',
        'pok-Latn': 'pok',
        'pom': 'pom',
        'pom-Latn-US': 'pom',
        'pom-Latn': 'pom',
        'pom-US': 'pom',
        'pon': 'pon',
        'pon-Latn-FM': 'pon',
        'pon-FM': 'pon',
        'pon-Latn': 'pon',
        'poo': 'poo',
        'poo-Latn-US': 'poo',
        'poo-Latn': 'poo',
        'poo-US': 'poo',
        'pop': 'pop',
        'pop-Latn-NC': 'pop',
        'pop-Latn': 'pop',
        'pop-NC': 'pop',
        'poq': 'poq',
        'poq-Latn-MX': 'poq',
        'poq-Latn': 'poq',
        'poq-MX': 'poq',
        'pos': 'pos',
        'pos-Latn-MX': 'pos',
        'pos-Latn': 'pos',
        'pos-MX': 'pos',
        'pot': 'pot',
        'pot-Latn-US': 'pot',
        'pot-Latn': 'pot',
        'pot-US': 'pot',
        'pov': 'pov',
        'pov-Latn-GW': 'pov',
        'pov-GW': 'pov',
        'pov-Latn': 'pov',
        'pow': 'pow',
        'pow-Latn-MX': 'pow',
        'pow-Latn': 'pow',
        'pow-MX': 'pow',
        'pox': 'pox',
        'pox-Zyyy-DE': 'pox',
        'pox-DE': 'pox',
        'pox-Zyyy': 'pox',
        'poy': 'poy',
        'poy-Latn-TZ': 'poy',
        'poy-Latn': 'poy',
        'poy-TZ': 'poy',
        'ppe': 'ppe',
        'ppe-Latn-PG': 'ppe',
        'ppe-Latn': 'ppe',
        'ppe-PG': 'ppe',
        'ppi': 'ppi',
        'ppi-Latn-MX': 'ppi',
        'ppi-Latn': 'ppi',
        'ppi-MX': 'ppi',
        'ppk': 'ppk',
        'ppk-Latn-ID': 'ppk',
        'ppk-ID': 'ppk',
        'ppk-Latn': 'ppk',
        'ppl': 'ppl',
        'ppl-Latn-SV': 'ppl',
        'ppl-Latn': 'ppl',
        'ppl-SV': 'ppl',
        'ppm': 'ppm',
        'ppm-Latn-ID': 'ppm',
        'ppm-ID': 'ppm',
        'ppm-Latn': 'ppm',
        'ppn': 'ppn',
        'ppn-Latn-PG': 'ppn',
        'ppn-Latn': 'ppn',
        'ppn-PG': 'ppn',
        'ppo': 'ppo',
        'ppo-Latn-PG': 'ppo',
        'ppo-Latn': 'ppo',
        'ppo-PG': 'ppo',
        'ppp': 'ppp',
        'ppp-Latn-CD': 'ppp',
        'ppp-CD': 'ppp',
        'ppp-Latn': 'ppp',
        'ppq': 'ppq',
        'ppq-Latn-PG': 'ppq',
        'ppq-Latn': 'ppq',
        'ppq-PG': 'ppq',
        'pps': 'pps',
        'pps-Latn-MX': 'pps',
        'pps-Latn': 'pps',
        'pps-MX': 'pps',
        'ppt': 'ppt',
        'ppt-Latn-PG': 'ppt',
        'ppt-Latn': 'ppt',
        'ppt-PG': 'ppt',
        'ppu': 'ppu',
        'ppu-Zyyy-TW': 'ppu',
        'ppu-TW': 'ppu',
        'ppu-Zyyy': 'ppu',
        'pqa': 'pqa',
        'pqa-Latn-NG': 'pqa',
        'pqa-Latn': 'pqa',
        'pqa-NG': 'pqa',
        'pqm': 'pqm',
        'pqm-Latn-CA': 'pqm',
        'pqm-CA': 'pqm',
        'pqm-Latn': 'pqm',
        'pra': 'pra',
        'pra-Khar-PK': 'pra',
        'pra-Khar': 'pra',
        'pra-PK': 'pra',
        'prb': 'prb',
        'prb-Zyyy-TH': 'prb',
        'prb-TH': 'prb',
        'prb-Zyyy': 'prb',
        'prc': 'prc',
        'prc-Arab-AF': 'prc',
        'prc-AF': 'prc',
        'prc-Arab': 'prc',
        'prd': 'prd',
        'prd-Arab-IR': 'prd',
        'prd-Arab': 'prd',
        'prd-IR': 'prd',
        'pre': 'pre',
        'pre-Latn-ST': 'pre',
        'pre-Latn': 'pre',
        'pre-ST': 'pre',
        'prf': 'prf',
        'prf-Latn-PH': 'prf',
        'agp': 'prf',
        'agp-Latn': 'prf',
        'agp-Latn-PH': 'prf',
        'agp-PH': 'prf',
        'prf-Latn': 'prf',
        'prf-PH': 'prf',
        'prg': 'prg',
        'prg-Latn-001': 'prg',
        'prg-001': 'prg',
        'prg-Latn': 'prg',
        'prh': 'prh',
        'prh-Latn-PH': 'prh',
        'prh-Latn': 'prh',
        'prh-PH': 'prh',
        'pri': 'pri',
        'pri-Latn-NC': 'pri',
        'pri-Latn': 'pri',
        'pri-NC': 'pri',
        'prk': 'prk',
        'prk-Latn-MM': 'prk',
        'prk-Latn': 'prk',
        'prk-MM': 'prk',
        'prl': 'prl',
        'prl-Zxxx-PE': 'prl',
        'prl-PE': 'prl',
        'prl-Zxxx': 'prl',
        'sgn-prl': 'prl',
        'sgn-prl-PE': 'prl',
        'prm': 'prm',
        'prm-Latn-PG': 'prm',
        'prm-Latn': 'prm',
        'prm-PG': 'prm',
        'prn': 'prn',
        'prn-Arab-AF': 'prn',
        'prn-AF': 'prn',
        'prn-Arab': 'prn',
        'pro': 'pro',
        'pro-Latn-FR': 'pro',
        'pro-FR': 'pro',
        'pro-Latn': 'pro',
        'prp': 'prp',
        'prp-Zyyy-IN': 'prp',
        'prp-IN': 'prp',
        'prp-Zyyy': 'prp',
        'prq': 'prq',
        'prq-Latn-PE': 'prq',
        'prq-Latn': 'prq',
        'prq-PE': 'prq',
        'prr': 'prr',
        'prr-Latn-BR': 'prr',
        'prr-BR': 'prr',
        'prr-Latn': 'prr',
        'prs': 'prs',
        'prs-Arab-AF': 'prs',
        'drw': 'prs',
        'drw-AF': 'prs',
        'drw-Arab': 'prs',
        'drw-Arab-AF': 'prs',
        'prs-AF': 'prs',
        'prs-Arab': 'prs',
        'tnf': 'prs',
        'tnf-AF': 'prs',
        'tnf-Arab': 'prs',
        'tnf-Arab-AF': 'prs',
        'prt': 'prt',
        'prt-Thai-TH': 'prt',
        'prt-TH': 'prt',
        'prt-Thai': 'prt',
        'pry': 'prt',
        'pry-TH': 'prt',
        'pry-Thai': 'prt',
        'pry-Thai-TH': 'prt',
        'pru': 'pru',
        'pru-Latn-ID': 'pru',
        'pru-ID': 'pru',
        'pru-Latn': 'pru',
        'prw': 'prw',
        'prw-Latn-PG': 'prw',
        'prw-Latn': 'prw',
        'prw-PG': 'prw',
        'prx': 'prx',
        'prx-Arab-IN': 'prx',
        'prx-Arab': 'prx',
        'prx-IN': 'prx',
        'prx-Tibt': 'prx-Tibt',
        'prx-Tibt-IN': 'prx-Tibt',
        'prz': 'prz',
        'prz-Zxxx-CO': 'prz',
        'prz-CO': 'prz',
        'prz-Zxxx': 'prz',
        'sgn-prz': 'prz',
        'sgn-prz-CO': 'prz',
        'ps': 'ps',
        'ps-Arab-AF': 'ps',
        'pbu': 'ps',
        'pbu-AF': 'ps',
        'pbu-Arab': 'ps',
        'pbu-Arab-AF': 'ps',
        'ps-AF': 'ps',
        'ps-Arab': 'ps',
        'ps-PK': 'ps-PK',
        'ps-Arab-PK': 'ps-PK',
        'psa': 'psa',
        'psa-Latn-ID': 'psa',
        'psa-ID': 'psa',
        'psa-Latn': 'psa',
        'psc': 'psc',
        'psc-Zxxx-IR': 'psc',
        'psc-IR': 'psc',
        'psc-Zxxx': 'psc',
        'sgn-psc': 'psc',
        'sgn-psc-IR': 'psc',
        'psd': 'psd',
        'psd-Zxxx-US': 'psd',
        'psd-US': 'psd',
        'psd-Zxxx': 'psd',
        'sgn-psd': 'psd',
        'sgn-psd-US': 'psd',
        'pse': 'pse',
        'pse-Latn-ID': 'pse',
        'ms-pse': 'pse',
        'ms-pse-ID': 'pse',
        'pse-ID': 'pse',
        'pse-Latn': 'pse',
        'psg': 'psg',
        'psg-Zxxx-MY': 'psg',
        'psg-MY': 'psg',
        'psg-Zxxx': 'psg',
        'sgn-psg': 'psg',
        'sgn-psg-MY': 'psg',
        'psh': 'psh',
        'psh-Arab-AF': 'psh',
        'psh-AF': 'psh',
        'psh-Arab': 'psh',
        'psi': 'psi',
        'psi-Arab-AF': 'psi',
        'psi-AF': 'psi',
        'psi-Arab': 'psi',
        'psl': 'psl',
        'psl-Zxxx-PR': 'psl',
        'psl-PR': 'psl',
        'psl-Zxxx': 'psl',
        'sgn-psl': 'psl',
        'sgn-psl-PR': 'psl',
        'psm': 'psm',
        'psm-Latn-BO': 'psm',
        'psm-BO': 'psm',
        'psm-Latn': 'psm',
        'psn': 'psn',
        'psn-Latn-ID': 'psn',
        'psn-ID': 'psn',
        'psn-Latn': 'psn',
        'pso': 'pso',
        'pso-Zxxx-PL': 'pso',
        'pso-PL': 'pso',
        'pso-Zxxx': 'pso',
        'sgn-pso': 'pso',
        'sgn-pso-PL': 'pso',
        'psp': 'psp',
        'psp-Zxxx-PH': 'psp',
        'psp-PH': 'psp',
        'psp-Zxxx': 'psp',
        'sgn-psp': 'psp',
        'sgn-psp-PH': 'psp',
        'psq': 'psq',
        'psq-Latn-PG': 'psq',
        'psq-Latn': 'psq',
        'psq-PG': 'psq',
        'psr': 'psr',
        'psr-Zxxx-PT': 'psr',
        'psr-PT': 'psr',
        'psr-Zxxx': 'psr',
        'sgn-psr': 'psr',
        'sgn-psr-PT': 'psr',
        'pss': 'pss',
        'pss-Latn-PG': 'pss',
        'pss-Latn': 'pss',
        'pss-PG': 'pss',
        'pst': 'pst',
        'pst-Arab-PK': 'pst',
        'pst-Arab': 'pst',
        'pst-PK': 'pst',
        'psu-Brah': 'psu-Brah',
        'psu-Brah-IN': 'psu-Brah',
        'psu-Deva': 'psu-Deva',
        'psu-Deva-IN': 'psu-Deva',
        'psw': 'psw',
        'psw-Latn-VU': 'psw',
        'psw-Latn': 'psw',
        'psw-VU': 'psw',
        'psy': 'psy',
        'psy-Zyyy-US': 'psy',
        'psy-US': 'psy',
        'psy-Zyyy': 'psy',
        'pt': 'pt',
        'pt-Latn-BR': 'pt',
        'pt-BR': 'pt',
        'pt-Latn': 'pt',
        'pt-AO': 'pt-AO',
        'pt-Latn-AO': 'pt-AO',
        'pt-Brai': 'pt-Brai',
        'pt-Brai-PT': 'pt-Brai',
        'pt-CV': 'pt-CV',
        'pt-Latn-CV': 'pt-CV',
        'pt-GW': 'pt-GW',
        'pt-Latn-GW': 'pt-GW',
        'pt-LU': 'pt-LU',
        'pt-Latn-LU': 'pt-LU',
        'pt-MO': 'pt-MO',
        'pt-Latn-MO': 'pt-MO',
        'pt-MZ': 'pt-MZ',
        'pt-Latn-MZ': 'pt-MZ',
        'pt-PT': 'pt-PT',
        'pt-Latn-PT': 'pt-PT',
        'pt-ST': 'pt-ST',
        'pt-Latn-ST': 'pt-ST',
        'pt-TL': 'pt-TL',
        'pt-Latn-TL': 'pt-TL',
        'pta': 'pta',
        'pta-Latn-PY': 'pta',
        'pta-Latn': 'pta',
        'pta-PY': 'pta',
        'pth': 'pth',
        'pth-Latn-BR': 'pth',
        'pth-BR': 'pth',
        'pth-Latn': 'pth',
        'pti': 'pti',
        'pti-Latn-AU': 'pti',
        'pti-AU': 'pti',
        'pti-Latn': 'pti',
        'ptn': 'ptn',
        'ptn-Latn-ID': 'ptn',
        'ptn-ID': 'ptn',
        'ptn-Latn': 'ptn',
        'pto': 'pto',
        'pto-Latn-BR': 'pto',
        'pto-BR': 'pto',
        'pto-Latn': 'pto',
        'ptp': 'ptp',
        'ptp-Latn-PG': 'ptp',
        'ptp-Latn': 'ptp',
        'ptp-PG': 'ptp',
        'ptq': 'ptq',
        'ptq-Zyyy-IN': 'ptq',
        'ptq-IN': 'ptq',
        'ptq-Zyyy': 'ptq',
        'ptr': 'ptr',
        'ptr-Latn-VU': 'ptr',
        'ptr-Latn': 'ptr',
        'ptr-VU': 'ptr',
        'ptt': 'ptt',
        'ptt-Latn-ID': 'ptt',
        'ptt-ID': 'ptt',
        'ptt-Latn': 'ptt',
        'ptu': 'ptu',
        'ptu-Latn-ID': 'ptu',
        'ptu-ID': 'ptu',
        'ptu-Latn': 'ptu',
        'ptv': 'ptv',
        'ptv-Latn-VU': 'ptv',
        'ptv-Latn': 'ptv',
        'ptv-VU': 'ptv',
        'ptw': 'ptw',
        'ptw-Zyyy-CA': 'ptw',
        'ptw-CA': 'ptw',
        'ptw-Zyyy': 'ptw',
        'pty': 'pty',
        'pty-Zyyy-IN': 'pty',
        'pty-IN': 'pty',
        'pty-Zyyy': 'pty',
        'pua': 'pua',
        'pua-Latn-MX': 'pua',
        'pua-Latn': 'pua',
        'pua-MX': 'pua',
        'pub': 'pub',
        'pub-Latn-IN': 'pub',
        'pub-IN': 'pub',
        'pub-Latn': 'pub',
        'puz': 'pub',
        'puz-IN': 'pub',
        'puz-Latn': 'pub',
        'puz-Latn-IN': 'pub',
        'puc': 'puc',
        'puc-Latn-ID': 'puc',
        'puc-ID': 'puc',
        'puc-Latn': 'puc',
        'pud': 'pud',
        'pud-Latn-ID': 'pud',
        'pud-ID': 'pud',
        'pud-Latn': 'pud',
        'pue': 'pue',
        'pue-Latn-AR': 'pue',
        'pue-AR': 'pue',
        'pue-Latn': 'pue',
        'puf': 'puf',
        'puf-Latn-ID': 'puf',
        'puf-ID': 'puf',
        'puf-Latn': 'puf',
        'pug': 'pug',
        'pug-Latn-BF': 'pug',
        'pug-BF': 'pug',
        'pug-Latn': 'pug',
        'pui': 'pui',
        'pui-Latn-CO': 'pui',
        'pui-CO': 'pui',
        'pui-Latn': 'pui',
        'puj': 'puj',
        'puj-Latn-ID': 'puj',
        'puj-ID': 'puj',
        'puj-Latn': 'puj',
        'puk': 'puk',
        'puk-Zyyy-LA': 'puk',
        'puk-LA': 'puk',
        'puk-Zyyy': 'puk',
        'pum': 'pum',
        'pum-Deva-NP': 'pum',
        'pum-Deva': 'pum',
        'pum-NP': 'pum',
        'puo': 'puo',
        'puo-Latn-VN': 'puo',
        'puo-Latn': 'puo',
        'puo-VN': 'puo',
        'pup': 'pup',
        'pup-Latn-PG': 'pup',
        'pup-Latn': 'pup',
        'pup-PG': 'pup',
        'puq': 'puq',
        'puq-Latn-PE': 'puq',
        'puq-Latn': 'puq',
        'puq-PE': 'puq',
        'pur': 'pur',
        'pur-Latn-BR': 'pur',
        'pur-BR': 'pur',
        'pur-Latn': 'pur',
        'put': 'put',
        'put-Latn-ID': 'put',
        'put-ID': 'put',
        'put-Latn': 'put',
        'puu': 'puu',
        'puu-Latn-GA': 'puu',
        'puu-GA': 'puu',
        'puu-Latn': 'puu',
        'puw': 'puw',
        'puw-Latn-FM': 'puw',
        'puw-FM': 'puw',
        'puw-Latn': 'puw',
        'pux': 'pux',
        'pux-Latn-PG': 'pux',
        'pux-Latn': 'pux',
        'pux-PG': 'pux',
        'puy': 'puy',
        'puy-Zyyy-US': 'puy',
        'puy-US': 'puy',
        'puy-Zyyy': 'puy',
        'pwa': 'pwa',
        'pwa-Latn-PG': 'pwa',
        'pwa-Latn': 'pwa',
        'pwa-PG': 'pwa',
        'pwb': 'pwb',
        'pwb-Latn-NG': 'pwb',
        'pwb-Latn': 'pwb',
        'pwb-NG': 'pwb',
        'pwg': 'pwg',
        'pwg-Latn-PG': 'pwg',
        'pwg-Latn': 'pwg',
        'pwg-PG': 'pwg',
        'pwi': 'pwi',
        'pwi-Zyyy-US': 'pwi',
        'pwi-US': 'pwi',
        'pwi-Zyyy': 'pwi',
        'pwm': 'pwm',
        'pwm-Latn-PH': 'pwm',
        'pwm-Latn': 'pwm',
        'pwm-PH': 'pwm',
        'pwn': 'pwn',
        'pwn-Latn-TW': 'pwn',
        'pwn-Latn': 'pwn',
        'pwn-TW': 'pwn',
        'pwo': 'pwo',
        'pwo-Mymr-MM': 'pwo',
        'pwo-MM': 'pwo',
        'pwo-Mymr': 'pwo',
        'pwr': 'pwr',
        'pwr-Zyyy-IN': 'pwr',
        'pwr-IN': 'pwr',
        'pwr-Zyyy': 'pwr',
        'pww': 'pww',
        'pww-Thai-TH': 'pww',
        'pww-TH': 'pww',
        'pww-Thai': 'pww',
        'pxm': 'pxm',
        'pxm-Latn-MX': 'pxm',
        'pxm-Latn': 'pxm',
        'pxm-MX': 'pxm',
        'pye': 'pye',
        'pye-Latn-CI': 'pye',
        'pye-CI': 'pye',
        'pye-Latn': 'pye',
        'pym': 'pym',
        'pym-Latn-NG': 'pym',
        'pym-Latn': 'pym',
        'pym-NG': 'pym',
        'pyn': 'pyn',
        'pyn-Latn-BR': 'pyn',
        'pyn-BR': 'pyn',
        'pyn-Latn': 'pyn',
        'pys': 'pys',
        'pys-Zxxx-PY': 'pys',
        'pys-PY': 'pys',
        'pys-Zxxx': 'pys',
        'sgn-pys': 'pys',
        'sgn-pys-PY': 'pys',
        'pyu': 'pyu',
        'pyu-Latn-TW': 'pyu',
        'pyu-Latn': 'pyu',
        'pyu-TW': 'pyu',
        'pyu-Hani': 'pyu-Hani',
        'pyu-Hani-TW': 'pyu-Hani',
        'pyx': 'pyx',
        'pyx-Zyyy-MM': 'pyx',
        'pyx-MM': 'pyx',
        'pyx-Zyyy': 'pyx',
        'pyy': 'pyy',
        'pyy-Latn-MM': 'pyy',
        'pyy-Latn': 'pyy',
        'pyy-MM': 'pyy',
        'pzn': 'pzn',
        'pzn-Latn-MM': 'pzn',
        'pzn-Latn': 'pzn',
        'pzn-MM': 'pzn',
        'qu': 'qu',
        'qu-Latn-PE': 'qu',
        'qu-Latn': 'qu',
        'qu-PE': 'qu',
        'quz': 'qu',
        'quz-Latn': 'qu',
        'quz-Latn-PE': 'qu',
        'quz-PE': 'qu',
        'qu-BO': 'qu-BO',
        'qu-Latn-BO': 'qu-BO',
        'cqu': 'qu-BO',
        'cqu-BO': 'qu-BO',
        'cqu-Latn': 'qu-BO',
        'cqu-Latn-BO': 'qu-BO',
        'quh': 'qu-BO',
        'quh-BO': 'qu-BO',
        'quh-Latn': 'qu-BO',
        'quh-Latn-BO': 'qu-BO',
        'qu-EC': 'qu-EC',
        'qu-Latn-EC': 'qu-EC',
        'qua': 'qua',
        'qua-Latn-US': 'qua',
        'qua-Latn': 'qua',
        'qua-US': 'qua',
        'qub': 'qub',
        'qub-Latn-PE': 'qub',
        'qub-Latn': 'qub',
        'qub-PE': 'qub',
        'quc': 'quc',
        'quc-Latn-GT': 'quc',
        'quc-GT': 'quc',
        'quc-Latn': 'quc',
        'qud': 'qud',
        'qud-Latn-EC': 'qud',
        'qud-EC': 'qud',
        'qud-Latn': 'qud',
        'quf': 'quf',
        'quf-Latn-PE': 'quf',
        'quf-Latn': 'quf',
        'quf-PE': 'quf',
        'qug': 'qug',
        'qug-Latn-EC': 'qug',
        'qug-EC': 'qug',
        'qug-Latn': 'qug',
        'qui': 'qui',
        'qui-Latn-US': 'qui',
        'qui-Latn': 'qui',
        'qui-US': 'qui',
        'quk': 'quk',
        'quk-Latn-PE': 'quk',
        'quk-Latn': 'quk',
        'quk-PE': 'quk',
        'qul': 'qul',
        'qul-Latn-BO': 'qul',
        'qul-BO': 'qul',
        'qul-Latn': 'qul',
        'qum': 'qum',
        'qum-Latn-GT': 'qum',
        'qum-GT': 'qum',
        'qum-Latn': 'qum',
        'qun': 'qun',
        'qun-Latn-US': 'qun',
        'qun-Latn': 'qun',
        'qun-US': 'qun',
        'qup': 'qup',
        'qup-Latn-PE': 'qup',
        'qup-Latn': 'qup',
        'qup-PE': 'qup',
        'quq': 'quq',
        'quq-Latn-ES': 'quq',
        'quq-ES': 'quq',
        'quq-Latn': 'quq',
        'qur': 'qur',
        'qur-Latn-PE': 'qur',
        'qur-Latn': 'qur',
        'qur-PE': 'qur',
        'qus': 'qus',
        'qus-Latn-AR': 'qus',
        'qus-AR': 'qus',
        'qus-Latn': 'qus',
        'quv': 'quv',
        'quv-Latn-GT': 'quv',
        'quv-GT': 'quv',
        'quv-Latn': 'quv',
        'quw': 'quw',
        'quw-Latn-EC': 'quw',
        'quw-EC': 'quw',
        'quw-Latn': 'quw',
        'qux': 'qux',
        'qux-Latn-PE': 'qux',
        'qux-Latn': 'qux',
        'qux-PE': 'qux',
        'quy': 'quy',
        'quy-Latn-PE': 'quy',
        'quy-Latn': 'quy',
        'quy-PE': 'quy',
        'qva': 'qva',
        'qva-Latn-PE': 'qva',
        'qva-Latn': 'qva',
        'qva-PE': 'qva',
        'qvc': 'qvc',
        'qvc-Latn-PE': 'qvc',
        'qvc-Latn': 'qvc',
        'qvc-PE': 'qvc',
        'qve': 'qve',
        'qve-Latn-PE': 'qve',
        'qve-Latn': 'qve',
        'qve-PE': 'qve',
        'qvh': 'qvh',
        'qvh-Latn-PE': 'qvh',
        'qvh-Latn': 'qvh',
        'qvh-PE': 'qvh',
        'qvi': 'qvi',
        'qvi-Latn-EC': 'qvi',
        'qvi-EC': 'qvi',
        'qvi-Latn': 'qvi',
        'qvj': 'qvj',
        'qvj-Latn-EC': 'qvj',
        'qvj-EC': 'qvj',
        'qvj-Latn': 'qvj',
        'qvl': 'qvl',
        'qvl-Latn-PE': 'qvl',
        'qvl-Latn': 'qvl',
        'qvl-PE': 'qvl',
        'qvm': 'qvm',
        'qvm-Latn-PE': 'qvm',
        'qvm-Latn': 'qvm',
        'qvm-PE': 'qvm',
        'qvn': 'qvn',
        'qvn-Latn-PE': 'qvn',
        'qvn-Latn': 'qvn',
        'qvn-PE': 'qvn',
        'qvo': 'qvo',
        'qvo-Latn-PE': 'qvo',
        'qvo-Latn': 'qvo',
        'qvo-PE': 'qvo',
        'qvp': 'qvp',
        'qvp-Latn-PE': 'qvp',
        'qvp-Latn': 'qvp',
        'qvp-PE': 'qvp',
        'qvs': 'qvs',
        'qvs-Latn-PE': 'qvs',
        'qvs-Latn': 'qvs',
        'qvs-PE': 'qvs',
        'qvw': 'qvw',
        'qvw-Latn-PE': 'qvw',
        'qvw-Latn': 'qvw',
        'qvw-PE': 'qvw',
        'qvy': 'qvy',
        'qvy-Zyyy-CN': 'qvy',
        'qvy-CN': 'qvy',
        'qvy-Zyyy': 'qvy',
        'qvz': 'qvz',
        'qvz-Latn-EC': 'qvz',
        'qvz-EC': 'qvz',
        'qvz-Latn': 'qvz',
        'qwa': 'qwa',
        'qwa-Latn-PE': 'qwa',
        'qwa-Latn': 'qwa',
        'qwa-PE': 'qwa',
        'qwc': 'qwc',
        'qwc-Latn-PE': 'qwc',
        'qwc-Latn': 'qwc',
        'qwc-PE': 'qwc',
        'qwh': 'qwh',
        'qwh-Latn-PE': 'qwh',
        'qwh-Latn': 'qwh',
        'qwh-PE': 'qwh',
        'qwm': 'qwm',
        'qwm-Cyrl-RU': 'qwm',
        'qwm-Cyrl': 'qwm',
        'qwm-RU': 'qwm',
        'qws': 'qws',
        'qws-Latn-PE': 'qws',
        'qws-Latn': 'qws',
        'qws-PE': 'qws',
        'qwt': 'qwt',
        'qwt-Zyyy-US': 'qwt',
        'qwt-US': 'qwt',
        'qwt-Zyyy': 'qwt',
        'qxa': 'qxa',
        'qxa-Latn-PE': 'qxa',
        'qxa-Latn': 'qxa',
        'qxa-PE': 'qxa',
        'qxc': 'qxc',
        'qxc-Latn-PE': 'qxc',
        'qxc-Latn': 'qxc',
        'qxc-PE': 'qxc',
        'qxh': 'qxh',
        'qxh-Latn-PE': 'qxh',
        'qxh-Latn': 'qxh',
        'qxh-PE': 'qxh',
        'qxl': 'qxl',
        'qxl-Latn-EC': 'qxl',
        'qxl-EC': 'qxl',
        'qxl-Latn': 'qxl',
        'qxn': 'qxn',
        'qxn-Latn-PE': 'qxn',
        'qxn-Latn': 'qxn',
        'qxn-PE': 'qxn',
        'qxo': 'qxo',
        'qxo-Latn-PE': 'qxo',
        'qxo-Latn': 'qxo',
        'qxo-PE': 'qxo',
        'qxp': 'qxp',
        'qxp-Latn-PE': 'qxp',
        'qxp-Latn': 'qxp',
        'qxp-PE': 'qxp',
        'qxq': 'qxq',
        'qxq-Arab-IR': 'qxq',
        'qxq-Arab': 'qxq',
        'qxq-IR': 'qxq',
        'qxr': 'qxr',
        'qxr-Latn-EC': 'qxr',
        'qxr-EC': 'qxr',
        'qxr-Latn': 'qxr',
        'qxs': 'qxs',
        'qxs-Zyyy-CN': 'qxs',
        'qxs-CN': 'qxs',
        'qxs-Zyyy': 'qxs',
        'qxt': 'qxt',
        'qxt-Latn-PE': 'qxt',
        'qxt-Latn': 'qxt',
        'qxt-PE': 'qxt',
        'qxu': 'qxu',
        'qxu-Latn-PE': 'qxu',
        'qxu-Latn': 'qxu',
        'qxu-PE': 'qxu',
        'qxw': 'qxw',
        'qxw-Latn-PE': 'qxw',
        'qxw-Latn': 'qxw',
        'qxw-PE': 'qxw',
        'qya': 'qya',
        'qya-Latn-001': 'qya',
        'qya-001': 'qya',
        'qya-Latn': 'qya',
        'qya-Cirt': 'qya-Cirt',
        'qya-Cirt-001': 'qya-Cirt',
        'qya-Sara': 'qya-Sara',
        'qya-Sara-001': 'qya-Sara',
        'qya-Teng': 'qya-Teng',
        'qya-Teng-001': 'qya-Teng',
        'qyp': 'qyp',
        'qyp-Zyyy-US': 'qyp',
        'qyp-US': 'qyp',
        'qyp-Zyyy': 'qyp',
        'raa': 'raa',
        'raa-Deva-NP': 'raa',
        'raa-Deva': 'raa',
        'raa-NP': 'raa',
        'rab': 'rab',
        'rab-Deva-NP': 'rab',
        'rab-Deva': 'rab',
        'rab-NP': 'rab',
        'rac': 'rac',
        'rac-Latn-ID': 'rac',
        'rac-ID': 'rac',
        'rac-Latn': 'rac',
        'rad': 'rad',
        'rad-Latn-VN': 'rad',
        'rad-Latn': 'rad',
        'rad-VN': 'rad',
        'raf': 'raf',
        'raf-Deva-NP': 'raf',
        'raf-Deva': 'raf',
        'raf-NP': 'raf',
        'rag': 'rag',
        'rag-Latn-KE': 'rag',
        'rag-KE': 'rag',
        'rag-Latn': 'rag',
        'rah': 'rah',
        'rah-Beng-IN': 'rah',
        'rah-Beng': 'rah',
        'rah-IN': 'rah',
        'rah-Latn': 'rah-Latn',
        'rah-Latn-IN': 'rah-Latn',
        'rai': 'rai',
        'rai-Latn-PG': 'rai',
        'rai-Latn': 'rai',
        'rai-PG': 'rai',
        'raj': 'raj',
        'raj-Deva-IN': 'raj',
        'mup': 'raj',
        'mup-Deva': 'raj',
        'mup-Deva-IN': 'raj',
        'mup-IN': 'raj',
        'raj-Deva': 'raj',
        'raj-IN': 'raj',
        'raj-Latn': 'raj-Latn',
        'raj-Latn-IN': 'raj-Latn',
        'rak': 'rak',
        'rak-Latn-PG': 'rak',
        'rak-Latn': 'rak',
        'rak-PG': 'rak',
        'ral': 'ral',
        'ral-Zyyy-IN': 'ral',
        'ral-IN': 'ral',
        'ral-Zyyy': 'ral',
        'ram': 'ram',
        'ram-Latn-BR': 'ram',
        'ram-BR': 'ram',
        'ram-Latn': 'ram',
        'ran': 'ran',
        'ran-Latn-ID': 'ran',
        'ran-ID': 'ran',
        'ran-Latn': 'ran',
        'rao': 'rao',
        'rao-Latn-PG': 'rao',
        'rao-Latn': 'rao',
        'rao-PG': 'rao',
        'rap': 'rap',
        'rap-Latn-CL': 'rap',
        'rap-CL': 'rap',
        'rap-Latn': 'rap',
        'raq': 'raq',
        'raq-Zyyy-NP': 'raq',
        'lii': 'raq',
        'lii-NP': 'raq',
        'lii-Zyyy': 'raq',
        'lii-Zyyy-NP': 'raq',
        'raq-NP': 'raq',
        'raq-Zyyy': 'raq',
        'rar': 'rar',
        'rar-Latn-CK': 'rar',
        'rar-CK': 'rar',
        'rar-Latn': 'rar',
        'ras': 'ras',
        'ras-Zyyy-SD': 'ras',
        'ras-SD': 'ras',
        'ras-Zyyy': 'ras',
        'tie': 'ras',
        'tie-SD': 'ras',
        'tie-Zyyy': 'ras',
        'tie-Zyyy-SD': 'ras',
        'rat': 'rat',
        'rat-Zyyy-IR': 'rat',
        'rat-IR': 'rat',
        'rat-Zyyy': 'rat',
        'rau': 'rau',
        'rau-Zyyy-NP': 'rau',
        'rau-NP': 'rau',
        'rau-Zyyy': 'rau',
        'rav': 'rav',
        'rav-Deva-NP': 'rav',
        'rav-Deva': 'rav',
        'rav-NP': 'rav',
        'raw': 'raw',
        'raw-Latn-MM': 'raw',
        'raw-Latn': 'raw',
        'raw-MM': 'raw',
        'raw-x-daruzerw': 'raw-x-daruzerw',
        'raw-Latn-MM-x-daruzerw': 'raw-x-daruzerw',
        'raw-Latn-x-daruzerw': 'raw-x-daruzerw',
        'raw-MM-x-daruzerw': 'raw-x-daruzerw',
        'raw-x-longmin': 'raw-x-longmin',
        'raw-Latn-MM-x-longmin': 'raw-x-longmin',
        'raw-Latn-x-longmin': 'raw-x-longmin',
        'raw-MM-x-longmin': 'raw-x-longmin',
        'raw-x-longmis': 'raw-x-longmis',
        'raw-Latn-MM-x-longmis': 'raw-x-longmis',
        'raw-Latn-x-longmis': 'raw-x-longmis',
        'raw-MM-x-longmis': 'raw-x-longmis',
        'raw-x-tangsare': 'raw-x-tangsare',
        'raw-Latn-MM-x-tangsare': 'raw-x-tangsare',
        'raw-Latn-x-tangsare': 'raw-x-tangsare',
        'raw-MM-x-tangsare': 'raw-x-tangsare',
        'raw-x-tangsarw': 'raw-x-tangsarw',
        'raw-Latn-MM-x-tangsarw': 'raw-x-tangsarw',
        'raw-Latn-x-tangsarw': 'raw-x-tangsarw',
        'raw-MM-x-tangsarw': 'raw-x-tangsarw',
        'rax': 'rax',
        'rax-Latn-NG': 'rax',
        'rax-Latn': 'rax',
        'rax-NG': 'rax',
        'ray': 'ray',
        'ray-Latn-PF': 'ray',
        'ray-Latn': 'ray',
        'ray-PF': 'ray',
        'raz': 'raz',
        'raz-Latn-ID': 'raz',
        'raz-ID': 'raz',
        'raz-Latn': 'raz',
        'rbb': 'rbb',
        'rbb-Mymr-MM': 'rbb',
        'rbb-MM': 'rbb',
        'rbb-Mymr': 'rbb',
        'rbk': 'rbk',
        'rbk-Latn-PH': 'rbk',
        'rbk-Latn': 'rbk',
        'rbk-PH': 'rbk',
        'rbl': 'rbl',
        'rbl-Latn-PH': 'rbl',
        'rbl-Latn': 'rbl',
        'rbl-PH': 'rbl',
        'rbp': 'rbp',
        'rbp-Latn-AU': 'rbp',
        'rbp-AU': 'rbp',
        'rbp-Latn': 'rbp',
        'rcf': 'rcf',
        'rcf-Latn-RE': 'rcf',
        'rcf-Latn': 'rcf',
        'rcf-RE': 'rcf',
        'rdb': 'rdb',
        'rdb-Arab-IR': 'rdb',
        'rdb-Arab': 'rdb',
        'rdb-IR': 'rdb',
        'rea': 'rea',
        'rea-Latn-PG': 'rea',
        'rea-Latn': 'rea',
        'rea-PG': 'rea',
        'reb': 'reb',
        'reb-Latn-ID': 'reb',
        'reb-ID': 'reb',
        'reb-Latn': 'reb',
        'ree': 'ree',
        'ree-Latn-MY': 'ree',
        'ree-Latn': 'ree',
        'ree-MY': 'ree',
        'reg': 'reg',
        'reg-Latn-TZ': 'reg',
        'reg-Latn': 'reg',
        'reg-TZ': 'reg',
        'rei': 'rei',
        'rei-Zyyy-IN': 'rei',
        'rei-IN': 'rei',
        'rei-Zyyy': 'rei',
        'rej': 'rej',
        'rej-Latn-ID': 'rej',
        'rej-ID': 'rej',
        'rej-Latn': 'rej',
        'rej-Rjng': 'rej-Rjng',
        'rej-Rjng-ID': 'rej-Rjng',
        'rel': 'rel',
        'rel-Latn-KE': 'rel',
        'rel-KE': 'rel',
        'rel-Latn': 'rel',
        'rem': 'rem',
        'rem-Latn-PE': 'rem',
        'rem-Latn': 'rem',
        'rem-PE': 'rem',
        'ren': 'ren',
        'ren-Latn-VN': 'ren',
        'ren-Latn': 'ren',
        'ren-VN': 'ren',
        'rer': 'rer',
        'rer-Zyyy-ET': 'rer',
        'rer-ET': 'rer',
        'rer-Zyyy': 'rer',
        'res': 'res',
        'res-Latn-NG': 'res',
        'res-Latn': 'res',
        'res-NG': 'res',
        'ret': 'ret',
        'ret-Latn-ID': 'ret',
        'ret-ID': 'ret',
        'ret-Latn': 'ret',
        'rey': 'rey',
        'rey-Latn-BO': 'rey',
        'rey-BO': 'rey',
        'rey-Latn': 'rey',
        'rga': 'rga',
        'rga-Latn-VU': 'rga',
        'rga-Latn': 'rga',
        'rga-VU': 'rga',
        'rge': 'rge',
        'rge-Zyyy-GR': 'rge',
        'rge-GR': 'rge',
        'rge-Zyyy': 'rge',
        'rgk': 'rgk',
        'rgk-Zyyy-IN': 'rgk',
        'rgk-IN': 'rgk',
        'rgk-Zyyy': 'rgk',
        'rgn': 'rgn',
        'rgn-Latn-IT': 'rgn',
        'rgn-IT': 'rgn',
        'rgn-Latn': 'rgn',
        'rgr': 'rgr',
        'rgr-Latn-PE': 'rgr',
        'rgr-Latn': 'rgr',
        'rgr-PE': 'rgr',
        'rgs': 'rgs',
        'rgs-Latn-VN': 'rgs',
        'rgs-Latn': 'rgs',
        'rgs-VN': 'rgs',
        'rgu': 'rgu',
        'rgu-Latn-ID': 'rgu',
        'rgu-ID': 'rgu',
        'rgu-Latn': 'rgu',
        'rhg-Arab': 'rhg-Arab',
        'rhg-Arab-MM': 'rhg-Arab',
        'rhg-Latn': 'rhg-Latn',
        'rhg-Latn-MM': 'rhg-Latn',
        'rhg-Rohg': 'rhg-Rohg',
        'rhg-Rohg-MM': 'rhg-Rohg',
        'rhp': 'rhp',
        'rhp-Latn-PG': 'rhp',
        'rhp-Latn': 'rhp',
        'rhp-PG': 'rhp',
        'ria': 'ria',
        'ria-Latn-IN': 'ria',
        'ria-IN': 'ria',
        'ria-Latn': 'ria',
        'rie': 'rie',
        'rie-Zyyy-XX': 'rie',
        'rie-XX': 'rie',
        'rie-Zyyy': 'rie',
        'rif': 'rif',
        'rif-Tfng-MA': 'rif',
        'rif-MA': 'rif',
        'rif-Tfng': 'rif',
        'rif-Arab': 'rif-Arab',
        'rif-Arab-MA': 'rif-Arab',
        'rif-Latn': 'rif-Latn',
        'rif-Latn-MA': 'rif-Latn',
        'rif-NL': 'rif-NL',
        'rif-Latn-NL': 'rif-NL',
        'ril': 'ril',
        'ril-Latn-MM': 'ril',
        'ril-Latn': 'ril',
        'ril-MM': 'ril',
        'rim': 'rim',
        'rim-Latn-TZ': 'rim',
        'rim-Latn': 'rim',
        'rim-TZ': 'rim',
        'rin': 'rin',
        'rin-Latn-NG': 'rin',
        'rin-Latn': 'rin',
        'rin-NG': 'rin',
        'rir': 'rir',
        'rir-Latn-ID': 'rir',
        'rir-ID': 'rir',
        'rir-Latn': 'rir',
        'rit': 'rit',
        'rit-Latn-AU': 'rit',
        'rit-AU': 'rit',
        'rit-Latn': 'rit',
        'riu': 'riu',
        'riu-Latn-ID': 'riu',
        'riu-ID': 'riu',
        'riu-Latn': 'riu',
        'rjg': 'rjg',
        'rjg-Latn-ID': 'rjg',
        'rjg-ID': 'rjg',
        'rjg-Latn': 'rjg',
        'rji': 'rji',
        'rji-Deva-NP': 'rji',
        'rji-Deva': 'rji',
        'rji-NP': 'rji',
        'rjs': 'rjs',
        'rjs-Deva-NP': 'rjs',
        'rjs-Deva': 'rjs',
        'rjs-NP': 'rjs',
        'rka': 'rka',
        'rka-Zyyy-KH': 'rka',
        'rka-KH': 'rka',
        'rka-Zyyy': 'rka',
        'rkb': 'rkb',
        'rkb-Latn-BR': 'rkb',
        'rkb-BR': 'rkb',
        'rkb-Latn': 'rkb',
        'rkh': 'rkh',
        'rkh-Latn-CK': 'rkh',
        'rkh-CK': 'rkh',
        'rkh-Latn': 'rkh',
        'rki': 'rki',
        'rki-Mymr-MM': 'rki',
        'ccq': 'rki',
        'ccq-MM': 'rki',
        'ccq-Mymr': 'rki',
        'ccq-Mymr-MM': 'rki',
        'rki-MM': 'rki',
        'rki-Mymr': 'rki',
        'ybd': 'rki',
        'ybd-MM': 'rki',
        'ybd-Mymr': 'rki',
        'ybd-Mymr-MM': 'rki',
        'rkm': 'rkm',
        'rkm-Latn-BF': 'rkm',
        'rkm-BF': 'rkm',
        'rkm-Latn': 'rkm',
        'rkt': 'rkt',
        'rkt-Beng-BD': 'rkt',
        'rkt-BD': 'rkt',
        'rkt-Beng': 'rkt',
        'rkw': 'rkw',
        'rkw-Latn-AU': 'rkw',
        'rkw-AU': 'rkw',
        'rkw-Latn': 'rkw',
        'rm': 'rm',
        'rm-Latn-CH': 'rm',
        'rm-CH': 'rm',
        'rm-Latn': 'rm',
        'rma': 'rma',
        'rma-Latn-NI': 'rma',
        'rma-Latn': 'rma',
        'rma-NI': 'rma',
        'rmb': 'rmb',
        'rmb-Latn-AU': 'rmb',
        'rmb-AU': 'rmb',
        'rmb-Latn': 'rmb',
        'rmc': 'rmc',
        'rmc-Latn-SK': 'rmc',
        'rmc-Latn': 'rmc',
        'rmc-SK': 'rmc',
        'rmd': 'rmd',
        'rmd-Latn-DK': 'rmd',
        'rmd-DK': 'rmd',
        'rmd-Latn': 'rmd',
        'rme': 'rme',
        'rme-Latn-GB': 'rme',
        'rme-GB': 'rme',
        'rme-Latn': 'rme',
        'rmf': 'rmf',
        'rmf-Latn-FI': 'rmf',
        'rmf-FI': 'rmf',
        'rmf-Latn': 'rmf',
        'rmg': 'rmg',
        'rmg-Zyyy-NO': 'rmg',
        'rmg-NO': 'rmg',
        'rmg-Zyyy': 'rmg',
        'rmh': 'rmh',
        'rmh-Latn-ID': 'rmh',
        'rmh-ID': 'rmh',
        'rmh-Latn': 'rmh',
        'rmi': 'rmi',
        'rmi-Zyyy-AM': 'rmi',
        'rmi-AM': 'rmi',
        'rmi-Zyyy': 'rmi',
        'rmk': 'rmk',
        'rmk-Latn-PG': 'rmk',
        'rmk-Latn': 'rmk',
        'rmk-PG': 'rmk',
        'rml': 'rml',
        'rml-Latn-PL': 'rml',
        'rml-Latn': 'rml',
        'rml-PL': 'rml',
        'rml-Cyrl': 'rml-Cyrl',
        'rml-Cyrl-BY': 'rml-Cyrl',
        'rml-BY': 'rml-Cyrl',
        'rmm': 'rmm',
        'rmm-Latn-ID': 'rmm',
        'rmm-ID': 'rmm',
        'rmm-Latn': 'rmm',
        'rmn': 'rmn',
        'rmn-Latn-RS': 'rmn',
        'rmn-Latn': 'rmn',
        'rmn-RS': 'rmn',
        'rmn-Cyrl': 'rmn-Cyrl',
        'rmn-Cyrl-BG': 'rmn-Cyrl',
        'rmn-BG': 'rmn-Cyrl',
        'rmn-Grek': 'rmn-Grek',
        'rmn-Grek-GR': 'rmn-Grek',
        'rmn-GR': 'rmn-Grek',
        'rmo': 'rmo',
        'rmo-Latn-CH': 'rmo',
        'rmo-CH': 'rmo',
        'rmo-Latn': 'rmo',
        'rmp': 'rmp',
        'rmp-Latn-PG': 'rmp',
        'rmp-Latn': 'rmp',
        'rmp-PG': 'rmp',
        'rmq': 'rmq',
        'rmq-Latn-ES': 'rmq',
        'rmq-ES': 'rmq',
        'rmq-Latn': 'rmq',
        'rms': 'rms',
        'rms-Zxxx-RO': 'rms',
        'rms-RO': 'rms',
        'rms-Zxxx': 'rms',
        'sgn-rms': 'rms',
        'sgn-rms-RO': 'rms',
        'rmt': 'rmt',
        'rmt-Arab-IR': 'rmt',
        'rmt-Arab': 'rmt',
        'rmt-IR': 'rmt',
        'rmu': 'rmu',
        'rmu-Latn-SE': 'rmu',
        'rmu-Latn': 'rmu',
        'rmu-SE': 'rmu',
        'rmv': 'rmv',
        'rmv-Zyyy-001': 'rmv',
        'rmv-001': 'rmv',
        'rmv-Zyyy': 'rmv',
        'rmw': 'rmw',
        'rmw-Latn-GB': 'rmw',
        'rmw-GB': 'rmw',
        'rmw-Latn': 'rmw',
        'rmx': 'rmx',
        'rmx-Latn-VN': 'rmx',
        'lmm': 'rmx',
        'lmm-Latn': 'rmx',
        'lmm-Latn-VN': 'rmx',
        'lmm-VN': 'rmx',
        'rmx-Latn': 'rmx',
        'rmx-VN': 'rmx',
        'rmz': 'rmz',
        'rmz-Mymr-IN': 'rmz',
        'rmz-IN': 'rmz',
        'rmz-Mymr': 'rmz',
        'rn': 'rn',
        'rn-Latn-BI': 'rn',
        'rn-BI': 'rn',
        'rn-Latn': 'rn',
        'rn-Brai': 'rn-Brai',
        'rn-Brai-BI': 'rn-Brai',
        'rnd': 'rnd',
        'rnd-Latn-CD': 'rnd',
        'rnd-CD': 'rnd',
        'rnd-Latn': 'rnd',
        'rng': 'rng',
        'rng-Latn-MZ': 'rng',
        'rng-Latn': 'rng',
        'rng-MZ': 'rng',
        'rnl': 'rnl',
        'rnl-Latn-IN': 'rnl',
        'rnl-IN': 'rnl',
        'rnl-Latn': 'rnl',
        'rnn': 'rnn',
        'rnn-Latn-ID': 'rnn',
        'rnn-ID': 'rnn',
        'rnn-Latn': 'rnn',
        'rnp': 'rnp',
        'rnp-Zyyy-IN': 'rnp',
        'rnp-IN': 'rnp',
        'rnp-Zyyy': 'rnp',
        'rnr': 'rnr',
        'rnr-Latn-AU': 'rnr',
        'rnr-AU': 'rnr',
        'rnr-Latn': 'rnr',
        'rnw': 'rnw',
        'rnw-Latn-TZ': 'rnw',
        'rnw-Latn': 'rnw',
        'rnw-TZ': 'rnw',
        'ro': 'ro',
        'ro-Latn-RO': 'ro',
        'mo': 'ro',
        'mo-Latn': 'ro',
        'mo-Latn-RO': 'ro',
        'mo-RO': 'ro',
        'ro-Latn': 'ro',
        'ro-RO': 'ro',
        'ro-Brai': 'ro-Brai',
        'ro-Brai-RO': 'ro-Brai',
        'ro-Cyrl': 'ro-Cyrl',
        'ro-Cyrl-MD': 'ro-Cyrl',
        'ro-Dupl': 'ro-Dupl',
        'ro-Dupl-RO': 'ro-Dupl',
        'ro-MD': 'ro-MD',
        'ro-Latn-MD': 'ro-MD',
        'mo-Latn-MD': 'ro-MD',
        'mo-MD': 'ro-MD',
        'rob': 'rob',
        'rob-Latn-ID': 'rob',
        'rob-ID': 'rob',
        'rob-Latn': 'rob',
        'roc': 'roc',
        'roc-Latn-VN': 'roc',
        'roc-Latn': 'roc',
        'roc-VN': 'roc',
        'rod': 'rod',
        'rod-Latn-NG': 'rod',
        'rod-Latn': 'rod',
        'rod-NG': 'rod',
        'roe': 'roe',
        'roe-Latn-PG': 'roe',
        'roe-Latn': 'roe',
        'roe-PG': 'roe',
        'rof': 'rof',
        'rof-Latn-TZ': 'rof',
        'rof-Latn': 'rof',
        'rof-TZ': 'rof',
        'rog': 'rog',
        'rog-Latn-VN': 'rog',
        'rog-Latn': 'rog',
        'rog-VN': 'rog',
        'rol': 'rol',
        'rol-Latn-PH': 'rol',
        'rol-Latn': 'rol',
        'rol-PH': 'rol',
        'rom': 'rom',
        'rom-Latn-RO': 'rom',
        'rmy-Latn': 'rom',
        'rmy-Latn-RO': 'rom',
        'rom-Latn': 'rom',
        'rom-RO': 'rom',
        'rom-Cyrl': 'rom-Cyrl',
        'rom-Cyrl-RO': 'rom-Cyrl',
        'rom-Cyrl-BG': 'rom-Cyrl-BG',
        'rmy-Cyrl': 'rom-Cyrl-BG',
        'rmy-Cyrl-BG': 'rom-Cyrl-BG',
        'roo': 'roo',
        'roo-Latn-PG': 'roo',
        'roo-Latn': 'roo',
        'roo-PG': 'roo',
        'rop': 'rop',
        'rop-Latn-AU': 'rop',
        'rop-AU': 'rop',
        'rop-Latn': 'rop',
        'ror': 'ror',
        'ror-Latn-ID': 'ror',
        'ror-ID': 'ror',
        'ror-Latn': 'ror',
        'rou': 'rou',
        'rou-Latn-TD': 'rou',
        'rou-Latn': 'rou',
        'rou-TD': 'rou',
        'row': 'row',
        'row-Latn-ID': 'row',
        'row-ID': 'row',
        'row-Latn': 'row',
        'rpn': 'rpn',
        'rpn-Latn-VU': 'rpn',
        'rpn-Latn': 'rpn',
        'rpn-VU': 'rpn',
        'rpt': 'rpt',
        'rpt-Latn-PG': 'rpt',
        'rpt-Latn': 'rpt',
        'rpt-PG': 'rpt',
        'rri': 'rri',
        'rri-Latn-SB': 'rri',
        'rri-Latn': 'rri',
        'rri-SB': 'rri',
        'rro': 'rro',
        'rro-Latn-PG': 'rro',
        'rro-Latn': 'rro',
        'rro-PG': 'rro',
        'rrt': 'rrt',
        'rrt-Latn-AU': 'rrt',
        'rrt-AU': 'rrt',
        'rrt-Latn': 'rrt',
        'rsb': 'rsb',
        'rsb-Zyyy-RS': 'rsb',
        'rsb-RS': 'rsb',
        'rsb-Zyyy': 'rsb',
        'rsi': 'rsi',
        'rsi-Zxxx-SB': 'rsi',
        'rsi-SB': 'rsi',
        'rsi-Zxxx': 'rsi',
        'sgn-rsi': 'rsi',
        'sgn-rsi-SB': 'rsi',
        'rsl': 'rsl',
        'rsl-Zxxx-RU': 'rsl',
        'rsl-RU': 'rsl',
        'rsl-Zxxx': 'rsl',
        'sgn-rsl': 'rsl',
        'sgn-rsl-RU': 'rsl',
        'rsm': 'rsm',
        'rsm-Zxxx-AU': 'rsm',
        'rsm-AU': 'rsm',
        'rsm-Zxxx': 'rsm',
        'sgn-rsm': 'rsm',
        'sgn-rsm-AU': 'rsm',
        'rtc': 'rtc',
        'rtc-Latn-MM': 'rtc',
        'rtc-Latn': 'rtc',
        'rtc-MM': 'rtc',
        'rth': 'rth',
        'rth-Latn-ID': 'rth',
        'rth-ID': 'rth',
        'rth-Latn': 'rth',
        'rtm': 'rtm',
        'rtm-Latn-FJ': 'rtm',
        'rtm-FJ': 'rtm',
        'rtm-Latn': 'rtm',
        'rts': 'rts',
        'rts-Zyyy-XX': 'rts',
        'rts-XX': 'rts',
        'rts-Zyyy': 'rts',
        'rtw': 'rtw',
        'rtw-Zyyy-IN': 'rtw',
        'rtw-IN': 'rtw',
        'rtw-Zyyy': 'rtw',
        'ru': 'ru',
        'ru-Cyrl-RU': 'ru',
        'ru-Cyrl': 'ru',
        'ru-RU': 'ru',
        'ru-BY': 'ru-BY',
        'ru-Cyrl-BY': 'ru-BY',
        'ru-Brai': 'ru-Brai',
        'ru-Brai-RU': 'ru-Brai',
        'ru-KG': 'ru-KG',
        'ru-Cyrl-KG': 'ru-KG',
        'ru-KZ': 'ru-KZ',
        'ru-Cyrl-KZ': 'ru-KZ',
        'ru-MD': 'ru-MD',
        'ru-Cyrl-MD': 'ru-MD',
        'ru-UA': 'ru-UA',
        'ru-Cyrl-UA': 'ru-UA',
        'rub': 'rub',
        'rub-Latn-UG': 'rub',
        'rub-Latn': 'rub',
        'rub-UG': 'rub',
        'ruc': 'ruc',
        'ruc-Latn-UG': 'ruc',
        'ruc-Latn': 'ruc',
        'ruc-UG': 'ruc',
        'rue': 'rue',
        'rue-Cyrl-UA': 'rue',
        'rue-Cyrl': 'rue',
        'rue-UA': 'rue',
        'rue-Latn': 'rue-Latn',
        'rue-Latn-SK': 'rue-Latn',
        'rue-SK': 'rue-Latn',
        'ruf': 'ruf',
        'ruf-Latn-TZ': 'ruf',
        'ruf-Latn': 'ruf',
        'ruf-TZ': 'ruf',
        'rug': 'rug',
        'rug-Latn-SB': 'rug',
        'rug-Latn': 'rug',
        'rug-SB': 'rug',
        'ruh': 'ruh',
        'ruh-Zyyy-IN': 'ruh',
        'ruh-IN': 'ruh',
        'ruh-Zyyy': 'ruh',
        'rui': 'rui',
        'rui-Latn-TZ': 'rui',
        'rui-Latn': 'rui',
        'rui-TZ': 'rui',
        'ruk': 'ruk',
        'ruk-Latn-NG': 'ruk',
        'ruk-Latn': 'ruk',
        'ruk-NG': 'ruk',
        'ruo': 'ruo',
        'ruo-Latn-HR': 'ruo',
        'ruo-HR': 'ruo',
        'ruo-Latn': 'ruo',
        'rup': 'rup',
        'rup-Latn-RO': 'rup',
        'rup-Latn': 'rup',
        'rup-RO': 'rup',
        'rup-Grek': 'rup-Grek',
        'rup-Grek-GR': 'rup-Grek',
        'rup-GR': 'rup-Grek',
        'ruq': 'ruq',
        'ruq-Latn-GR': 'ruq',
        'ruq-GR': 'ruq',
        'ruq-Latn': 'ruq',
        'rut': 'rut',
        'rut-Cyrl-RU': 'rut',
        'rut-Cyrl': 'rut',
        'rut-RU': 'rut',
        'rut-Latn': 'rut-Latn',
        'rut-Latn-AZ': 'rut-Latn',
        'rut-AZ': 'rut-Latn',
        'ruu': 'ruu',
        'ruu-Latn-MY': 'ruu',
        'ruu-Latn': 'ruu',
        'ruu-MY': 'ruu',
        'ruy': 'ruy',
        'ruy-Latn-NG': 'ruy',
        'ruy-Latn': 'ruy',
        'ruy-NG': 'ruy',
        'ruz': 'ruz',
        'ruz-Latn-NG': 'ruz',
        'ruz-Latn': 'ruz',
        'ruz-NG': 'ruz',
        'rw': 'rw',
        'rw-Latn-RW': 'rw',
        'rw-Latn': 'rw',
        'rw-RW': 'rw',
        'rw-Brai': 'rw-Brai',
        'rw-Brai-RW': 'rw-Brai',
        'rwa': 'rwa',
        'rwa-Latn-PG': 'rwa',
        'rwa-Latn': 'rwa',
        'rwa-PG': 'rwa',
        'rwk': 'rwk',
        'rwk-Latn-TZ': 'rwk',
        'rwk-Latn': 'rwk',
        'rwk-TZ': 'rwk',
        'rwm': 'rwm',
        'rwm-Latn-UG': 'rwm',
        'rwm-Latn': 'rwm',
        'rwm-UG': 'rwm',
        'rwo': 'rwo',
        'rwo-Latn-PG': 'rwo',
        'rwo-Latn': 'rwo',
        'rwo-PG': 'rwo',
        'rwo-x-karo': 'rwo-x-karo',
        'rwo-Latn-PG-x-karo': 'rwo-x-karo',
        'rwo-Latn-x-karo': 'rwo-x-karo',
        'rwo-PG-x-karo': 'rwo-x-karo',
        'rwr': 'rwr',
        'rwr-Deva-IN': 'rwr',
        'rwr-Deva': 'rwr',
        'rwr-IN': 'rwr',
        'rxd': 'rxd',
        'rxd-Latn-AU': 'rxd',
        'rxd-AU': 'rxd',
        'rxd-Latn': 'rxd',
        'rxw': 'rxw',
        'rxw-Latn-AU': 'rxw',
        'rxw-AU': 'rxw',
        'rxw-Latn': 'rxw',
        'ryn': 'ryn',
        'ryn-Zyyy-JP': 'ryn',
        'ryn-JP': 'ryn',
        'ryn-Zyyy': 'ryn',
        'rys': 'rys',
        'rys-Zyyy-JP': 'rys',
        'rys-JP': 'rys',
        'rys-Zyyy': 'rys',
        'ryu': 'ryu',
        'ryu-Kana-JP': 'ryu',
        'ryu-JP': 'ryu',
        'ryu-Kana': 'ryu',
        'rzh': 'rzh',
        'rzh-Zyyy-YE': 'rzh',
        'rzh-YE': 'rzh',
        'rzh-Zyyy': 'rzh',
        'sa': 'sa',
        'sa-Deva-IN': 'sa',
        'sa-Deva': 'sa',
        'sa-IN': 'sa',
        'sa-Gran': 'sa-Gran',
        'sa-Gran-IN': 'sa-Gran',
        'sa-Mymr': 'sa-Mymr',
        'sa-Mymr-IN': 'sa-Mymr',
        'sa-Nand': 'sa-Nand',
        'sa-Nand-IN': 'sa-Nand',
        'sa-Newa': 'sa-Newa',
        'sa-Newa-IN': 'sa-Newa',
        'sa-Shrd': 'sa-Shrd',
        'sa-Shrd-IN': 'sa-Shrd',
        'sa-Sidd': 'sa-Sidd',
        'sa-Sidd-IN': 'sa-Sidd',
        'sa-Sinh': 'sa-Sinh',
        'sa-Sinh-IN': 'sa-Sinh',
        'saa': 'saa',
        'saa-Latn-TD': 'saa',
        'saa-Latn': 'saa',
        'saa-TD': 'saa',
        'sab': 'sab',
        'sab-Latn-PA': 'sab',
        'sab-Latn': 'sab',
        'sab-PA': 'sab',
        'sac': 'sac',
        'sac-Latn-US': 'sac',
        'sac-Latn': 'sac',
        'sac-US': 'sac',
        'sad': 'sad',
        'sad-Latn-TZ': 'sad',
        'sad-Latn': 'sad',
        'sad-TZ': 'sad',
        'sae': 'sae',
        'sae-Latn-BR': 'sae',
        'sae-BR': 'sae',
        'sae-Latn': 'sae',
        'saf': 'saf',
        'saf-Latn-GH': 'saf',
        'saf-GH': 'saf',
        'saf-Latn': 'saf',
        'sah': 'sah',
        'sah-Cyrl-RU': 'sah',
        'sah-Cyrl': 'sah',
        'sah-RU': 'sah',
        'saj': 'saj',
        'saj-Latn-ID': 'saj',
        'saj-ID': 'saj',
        'saj-Latn': 'saj',
        'sak': 'sak',
        'sak-Latn-GA': 'sak',
        'sak-GA': 'sak',
        'sak-Latn': 'sak',
        'sam': 'sam',
        'sam-Samr-PS': 'sam',
        'sam-PS': 'sam',
        'sam-Samr': 'sam',
        'sam-Hebr': 'sam-Hebr',
        'sam-Hebr-PS': 'sam-Hebr',
        'sam-Syrc': 'sam-Syrc',
        'sam-Syrc-PS': 'sam-Syrc',
        'sao': 'sao',
        'sao-Latn-ID': 'sao',
        'sao-ID': 'sao',
        'sao-Latn': 'sao',
        'saq': 'saq',
        'saq-Latn-KE': 'saq',
        'saq-KE': 'saq',
        'saq-Latn': 'saq',
        'sar': 'sar',
        'sar-Latn-BO': 'sar',
        'sar-BO': 'sar',
        'sar-Latn': 'sar',
        'sas': 'sas',
        'sas-Latn-ID': 'sas',
        'sas-ID': 'sas',
        'sas-Latn': 'sas',
        'sas-Bali': 'sas-Bali',
        'sas-Bali-ID': 'sas-Bali',
        'sat': 'sat',
        'sat-Latn-IN': 'sat',
        'sat-IN': 'sat',
        'sat-Latn': 'sat',
        'sat-Beng': 'sat-Beng',
        'sat-Beng-IN': 'sat-Beng',
        'sat-Deva': 'sat-Deva',
        'sat-Deva-NP': 'sat-Deva',
        'sat-NP': 'sat-Deva',
        'sat-Olck': 'sat-Olck',
        'sat-Olck-IN': 'sat-Olck',
        'sat-Orya': 'sat-Orya',
        'sat-Orya-IN': 'sat-Orya',
        'sau': 'sau',
        'sau-Latn-ID': 'sau',
        'sau-ID': 'sau',
        'sau-Latn': 'sau',
        'sav': 'sav',
        'sav-Latn-SN': 'sav',
        'sav-Latn': 'sav',
        'sav-SN': 'sav',
        'sav-Arab': 'sav-Arab',
        'sav-Arab-SN': 'sav-Arab',
        'saw': 'saw',
        'saw-Latn-ID': 'saw',
        'saw-ID': 'saw',
        'saw-Latn': 'saw',
        'sax': 'sax',
        'sax-Latn-VU': 'sax',
        'sax-Latn': 'sax',
        'sax-VU': 'sax',
        'say': 'say',
        'say-Latn-NG': 'say',
        'say-Latn': 'say',
        'say-NG': 'say',
        'saz': 'saz',
        'saz-Saur-IN': 'saz',
        'saz-IN': 'saz',
        'saz-Saur': 'saz',
        'saz-Deva': 'saz-Deva',
        'saz-Deva-IN': 'saz-Deva',
        'saz-Taml': 'saz-Taml',
        'saz-Taml-IN': 'saz-Taml',
        'saz-Telu': 'saz-Telu',
        'saz-Telu-IN': 'saz-Telu',
        'sba': 'sba',
        'sba-Latn-TD': 'sba',
        'sba-Latn': 'sba',
        'sba-TD': 'sba',
        'sbb': 'sbb',
        'sbb-Latn-SB': 'sbb',
        'sbb-Latn': 'sbb',
        'sbb-SB': 'sbb',
        'sbc': 'sbc',
        'sbc-Latn-PG': 'sbc',
        'sbc-Latn': 'sbc',
        'sbc-PG': 'sbc',
        'sbd': 'sbd',
        'sbd-Latn-BF': 'sbd',
        'sbd-BF': 'sbd',
        'sbd-Latn': 'sbd',
        'sbe': 'sbe',
        'sbe-Latn-PG': 'sbe',
        'sbe-Latn': 'sbe',
        'sbe-PG': 'sbe',
        'sbf': 'sbf',
        'sbf-Zyyy-ET': 'sbf',
        'sbf-ET': 'sbf',
        'sbf-Zyyy': 'sbf',
        'sbg': 'sbg',
        'sbg-Latn-ID': 'sbg',
        'sbg-ID': 'sbg',
        'sbg-Latn': 'sbg',
        'sbh': 'sbh',
        'sbh-Latn-PG': 'sbh',
        'sbh-Latn': 'sbh',
        'sbh-PG': 'sbh',
        'sbi': 'sbi',
        'sbi-Latn-PG': 'sbi',
        'sbi-Latn': 'sbi',
        'sbi-PG': 'sbi',
        'sbj': 'sbj',
        'sbj-Latn-TD': 'sbj',
        'sbj-Latn': 'sbj',
        'sbj-TD': 'sbj',
        'sbk': 'sbk',
        'sbk-Latn-TZ': 'sbk',
        'sbk-Latn': 'sbk',
        'sbk-TZ': 'sbk',
        'sbl': 'sbl',
        'sbl-Latn-PH': 'sbl',
        'sbl-Latn': 'sbl',
        'sbl-PH': 'sbl',
        'sbm': 'sbm',
        'sbm-Latn-TZ': 'sbm',
        'sbm-Latn': 'sbm',
        'sbm-TZ': 'sbm',
        'sbn': 'sbn',
        'sbn-Arab-PK': 'sbn',
        'sbn-Arab': 'sbn',
        'sbn-PK': 'sbn',
        'sbo': 'sbo',
        'sbo-Latn-MY': 'sbo',
        'sbo-Latn': 'sbo',
        'sbo-MY': 'sbo',
        'sbp': 'sbp',
        'sbp-Latn-TZ': 'sbp',
        'sbp-Latn': 'sbp',
        'sbp-TZ': 'sbp',
        'sbq': 'sbq',
        'sbq-Latn-PG': 'sbq',
        'sbq-Latn': 'sbq',
        'sbq-PG': 'sbq',
        'sbr': 'sbr',
        'sbr-Latn-ID': 'sbr',
        'sbr-ID': 'sbr',
        'sbr-Latn': 'sbr',
        'sbs': 'sbs',
        'sbs-Latn-NA': 'sbs',
        'sbs-Latn': 'sbs',
        'sbs-NA': 'sbs',
        'sbt': 'sbt',
        'sbt-Latn-ID': 'sbt',
        'sbt-ID': 'sbt',
        'sbt-Latn': 'sbt',
        'sbu-Deva': 'sbu-Deva',
        'sbu-Deva-IN': 'sbu-Deva',
        'sbu-Tibt': 'sbu-Tibt',
        'sbu-Tibt-IN': 'sbu-Tibt',
        'sbv': 'sbv',
        'sbv-Zyyy-XX': 'sbv',
        'sbv-XX': 'sbv',
        'sbv-Zyyy': 'sbv',
        'sbw': 'sbw',
        'sbw-Latn-GA': 'sbw',
        'sbw-GA': 'sbw',
        'sbw-Latn': 'sbw',
        'sbx': 'sbx',
        'sbx-Latn-ID': 'sbx',
        'sbx-ID': 'sbx',
        'sbx-Latn': 'sbx',
        'sby': 'sby',
        'sby-Latn-ZM': 'sby',
        'sby-Latn': 'sby',
        'sby-ZM': 'sby',
        'sbz': 'sbz',
        'sbz-Latn-CF': 'sbz',
        'sbz-CF': 'sbz',
        'sbz-Latn': 'sbz',
        'sc': 'sc',
        'sc-Latn-IT': 'sc',
        'sc-IT': 'sc',
        'sc-Latn': 'sc',
        'src': 'sc',
        'src-IT': 'sc',
        'src-Latn': 'sc',
        'src-Latn-IT': 'sc',
        'scb': 'scb',
        'scb-Latn-VN': 'scb',
        'scb-Latn': 'scb',
        'scb-VN': 'scb',
        'sce': 'sce',
        'sce-Latn-CN': 'sce',
        'sce-CN': 'sce',
        'sce-Latn': 'sce',
        'sce-Arab': 'sce-Arab',
        'sce-Arab-CN': 'sce-Arab',
        'scf': 'scf',
        'scf-Latn-PA': 'scf',
        'scf-Latn': 'scf',
        'scf-PA': 'scf',
        'scg': 'scg',
        'scg-Latn-ID': 'scg',
        'scg-ID': 'scg',
        'scg-Latn': 'scg',
        'sch': 'sch',
        'sch-Latn-IN': 'sch',
        'sch-IN': 'sch',
        'sch-Latn': 'sch',
        'sci': 'sci',
        'sci-Latn-LK': 'sci',
        'sci-LK': 'sci',
        'sci-Latn': 'sci',
        'sck': 'sck',
        'sck-Deva-IN': 'sck',
        'sck-Deva': 'sck',
        'sck-IN': 'sck',
        'sck-Beng': 'sck-Beng',
        'sck-Beng-IN': 'sck-Beng',
        'scl': 'scl',
        'scl-Arab-PK': 'scl',
        'scl-Arab': 'scl',
        'scl-PK': 'scl',
        'scl-IN': 'scl-IN',
        'scl-Arab-IN': 'scl-IN',
        'scn': 'scn',
        'scn-Latn-IT': 'scn',
        'scn-IT': 'scn',
        'scn-Latn': 'scn',
        'sco': 'sco',
        'sco-Latn-GB': 'sco',
        'sco-GB': 'sco',
        'sco-Latn': 'sco',
        'scp': 'scp',
        'scp-Deva-NP': 'scp',
        'scp-Deva': 'scp',
        'scp-NP': 'scp',
        'scq': 'scq',
        'scq-Zyyy-KH': 'scq',
        'scq-KH': 'scq',
        'scq-Zyyy': 'scq',
        'scs': 'scs',
        'scs-Latn-CA': 'scs',
        'scs-CA': 'scs',
        'scs-Latn': 'scs',
        'scs-Cans': 'scs-Cans',
        'scs-Cans-CA': 'scs-Cans',
        'sct': 'sct',
        'sct-Laoo-LA': 'sct',
        'kgd': 'sct',
        'kgd-LA': 'sct',
        'kgd-Laoo': 'sct',
        'kgd-Laoo-LA': 'sct',
        'sct-LA': 'sct',
        'sct-Laoo': 'sct',
        'scu': 'scu',
        'scu-Zyyy-IN': 'scu',
        'scu-IN': 'scu',
        'scu-Zyyy': 'scu',
        'scv': 'scv',
        'scv-Latn-NG': 'scv',
        'scv-Latn': 'scv',
        'scv-NG': 'scv',
        'scw': 'scw',
        'scw-Latn-NG': 'scw',
        'scw-Latn': 'scw',
        'scw-NG': 'scw',
        'scx': 'scx',
        'scx-Zyyy-XX': 'scx',
        'scx-XX': 'scx',
        'scx-Zyyy': 'scx',
        'sd': 'sd',
        'sd-Arab-PK': 'sd',
        'sd-Arab': 'sd',
        'sd-PK': 'sd',
        'sd-Deva': 'sd-Deva',
        'sd-Deva-IN': 'sd-Deva',
        'sd-Guru': 'sd-Guru',
        'sd-Guru-IN': 'sd-Guru',
        'sd-Khoj': 'sd-Khoj',
        'sd-Khoj-IN': 'sd-Khoj',
        'sd-Khoj-PK': 'sd-Khoj-PK',
        'sd-Sind': 'sd-Sind',
        'sd-Sind-IN': 'sd-Sind',
        'sda': 'sda',
        'sda-Latn-ID': 'sda',
        'sda-ID': 'sda',
        'sda-Latn': 'sda',
        'sdb': 'sdb',
        'sdb-Zyyy-IQ': 'sdb',
        'sdb-IQ': 'sdb',
        'sdb-Zyyy': 'sdb',
        'sdc': 'sdc',
        'sdc-Latn-IT': 'sdc',
        'sdc-IT': 'sdc',
        'sdc-Latn': 'sdc',
        'sde': 'sde',
        'sde-Latn-NG': 'sde',
        'sde-Latn': 'sde',
        'sde-NG': 'sde',
        'sdf': 'sdf',
        'sdf-Zyyy-IQ': 'sdf',
        'sdf-IQ': 'sdf',
        'sdf-Zyyy': 'sdf',
        'sdg': 'sdg',
        'sdg-Arab-AF': 'sdg',
        'sdg-AF': 'sdg',
        'sdg-Arab': 'sdg',
        'sdh': 'sdh',
        'sdh-Arab-IR': 'sdh',
        'sdh-Arab': 'sdh',
        'sdh-IR': 'sdh',
        'sdj': 'sdj',
        'sdj-Latn-CG': 'sdj',
        'sdj-CG': 'sdj',
        'sdj-Latn': 'sdj',
        'sdk': 'sdk',
        'sdk-Latn-PG': 'sdk',
        'sdk-Latn': 'sdk',
        'sdk-PG': 'sdk',
        'sdl': 'sdl',
        'sdl-Zxxx-SA': 'sdl',
        'sdl-SA': 'sdl',
        'sdl-Zxxx': 'sdl',
        'sgn-sdl': 'sdl',
        'sgn-sdl-SA': 'sdl',
        'sdm': 'sdm',
        'sdm-Latn-ID': 'sdm',
        'sdm-ID': 'sdm',
        'sdm-Latn': 'sdm',
        'sdn': 'sdn',
        'sdn-Latn-IT': 'sdn',
        'sdn-IT': 'sdn',
        'sdn-Latn': 'sdn',
        'sdo': 'sdo',
        'sdo-Latn-MY': 'sdo',
        'sdo-Latn': 'sdo',
        'sdo-MY': 'sdo',
        'sdp': 'sdp',
        'sdp-Zyyy-IN': 'sdp',
        'sdp-IN': 'sdp',
        'sdp-Zyyy': 'sdp',
        'sdq': 'sdq',
        'sdq-Latn-ID': 'sdq',
        'sdq-ID': 'sdq',
        'sdq-Latn': 'sdq',
        'sdr-Beng': 'sdr-Beng',
        'sdr-Beng-BD': 'sdr-Beng',
        'sdr-Deva': 'sdr-Deva',
        'sdr-Deva-BD': 'sdr-Deva',
        'sdr-Latn': 'sdr-Latn',
        'sdr-Latn-BD': 'sdr-Latn',
        'sds': 'sds',
        'sds-Zyyy-TN': 'sds',
        'sds-TN': 'sds',
        'sds-Zyyy': 'sds',
        'sdt': 'sdt',
        'sdt-Zyyy-FR': 'sdt',
        'sdt-FR': 'sdt',
        'sdt-Zyyy': 'sdt',
        'sdu': 'sdu',
        'sdu-Latn-ID': 'sdu',
        'sdu-ID': 'sdu',
        'sdu-Latn': 'sdu',
        'sdx': 'sdx',
        'sdx-Latn-MY': 'sdx',
        'sdx-Latn': 'sdx',
        'sdx-MY': 'sdx',
        'sdz': 'sdz',
        'sdz-Zyyy-NL': 'sdz',
        'sdz-NL': 'sdz',
        'sdz-Zyyy': 'sdz',
        'se': 'se',
        'se-Latn-NO': 'se',
        'se-Latn': 'se',
        'se-NO': 'se',
        'se-Cyrl': 'se-Cyrl',
        'se-Cyrl-NO': 'se-Cyrl',
        'se-FI': 'se-FI',
        'se-Latn-FI': 'se-FI',
        'se-SE': 'se-SE',
        'se-Latn-SE': 'se-SE',
        'sea': 'sea',
        'sea-Latn-MY': 'sea',
        'sea-Latn': 'sea',
        'sea-MY': 'sea',
        'seb': 'seb',
        'seb-Latn-CI': 'seb',
        'seb-CI': 'seb',
        'seb-Latn': 'seb',
        'sec': 'sec',
        'sec-Latn-CA': 'sec',
        'sec-CA': 'sec',
        'sec-Latn': 'sec',
        'sed': 'sed',
        'sed-Latn-VN': 'sed',
        'sed-Latn': 'sed',
        'sed-VN': 'sed',
        'see': 'see',
        'see-Latn-US': 'see',
        'see-Latn': 'see',
        'see-US': 'see',
        'sef': 'sef',
        'sef-Latn-CI': 'sef',
        'sef-CI': 'sef',
        'sef-Latn': 'sef',
        'seg': 'seg',
        'seg-Latn-TZ': 'seg',
        'seg-Latn': 'seg',
        'seg-TZ': 'seg',
        'seh': 'seh',
        'seh-Latn-MZ': 'seh',
        'seh-Latn': 'seh',
        'seh-MZ': 'seh',
        'sei': 'sei',
        'sei-Latn-MX': 'sei',
        'sei-Latn': 'sei',
        'sei-MX': 'sei',
        'sej': 'sej',
        'sej-Latn-PG': 'sej',
        'sej-Latn': 'sej',
        'sej-PG': 'sej',
        'sek': 'sek',
        'sek-Latn-CA': 'sek',
        'sek-CA': 'sek',
        'sek-Latn': 'sek',
        'sek-Cans': 'sek-Cans',
        'sek-Cans-CA': 'sek-Cans',
        'sel': 'sel',
        'sel-Cyrl-RU': 'sel',
        'sel-Cyrl': 'sel',
        'sel-RU': 'sel',
        'sen': 'sen',
        'sen-Latn-BF': 'sen',
        'sen-BF': 'sen',
        'sen-Latn': 'sen',
        'seo': 'seo',
        'seo-Latn-PG': 'seo',
        'seo-Latn': 'seo',
        'seo-PG': 'seo',
        'sep': 'sep',
        'sep-Latn-BF': 'sep',
        'sep-BF': 'sep',
        'sep-Latn': 'sep',
        'seq': 'seq',
        'seq-Latn-BF': 'seq',
        'seq-BF': 'seq',
        'seq-Latn': 'seq',
        'ser': 'ser',
        'ser-Latn-US': 'ser',
        'ser-Latn': 'ser',
        'ser-US': 'ser',
        'ses': 'ses',
        'ses-Latn-ML': 'ses',
        'ses-Latn': 'ses',
        'ses-ML': 'ses',
        'set': 'set',
        'set-Latn-ID': 'set',
        'set-ID': 'set',
        'set-Latn': 'set',
        'seu': 'seu',
        'seu-Latn-ID': 'seu',
        'seu-ID': 'seu',
        'seu-Latn': 'seu',
        'sev': 'sev',
        'sev-Latn-CI': 'sev',
        'sev-CI': 'sev',
        'sev-Latn': 'sev',
        'sew': 'sew',
        'sew-Latn-PG': 'sew',
        'sew-Latn': 'sew',
        'sew-PG': 'sew',
        'sey': 'sey',
        'sey-Latn-EC': 'sey',
        'sey-EC': 'sey',
        'sey-Latn': 'sey',
        'sez': 'sez',
        'sez-Latn-MM': 'sez',
        'sez-Latn': 'sez',
        'sez-MM': 'sez',
        'sfb': 'sfb',
        'sfb-Zxxx-BE': 'sfb',
        'sfb-BE': 'sfb',
        'sfb-Zxxx': 'sfb',
        'sgn-sfb': 'sfb',
        'sgn-sfb-BE': 'sfb',
        'sfe': 'sfe',
        'sfe-Latn-PH': 'sfe',
        'sfe-Latn': 'sfe',
        'sfe-PH': 'sfe',
        'sfm': 'sfm',
        'sfm-Plrd-CN': 'sfm',
        'sfm-CN': 'sfm',
        'sfm-Plrd': 'sfm',
        'sfs': 'sfs',
        'sfs-Zxxx-ZA': 'sfs',
        'sfs-ZA': 'sfs',
        'sfs-Zxxx': 'sfs',
        'sgn-sfs': 'sfs',
        'sgn-sfs-ZA': 'sfs',
        'sfw': 'sfw',
        'sfw-Latn-GH': 'sfw',
        'sfw-GH': 'sfw',
        'sfw-Latn': 'sfw',
        'sg': 'sg',
        'sg-Latn-CF': 'sg',
        'sg-CF': 'sg',
        'sg-Latn': 'sg',
        'sga': 'sga',
        'sga-Ogam-IE': 'sga',
        'sga-IE': 'sga',
        'sga-Ogam': 'sga',
        'sga-Latn': 'sga-Latn',
        'sga-Latn-IE': 'sga-Latn',
        'sgb': 'sgb',
        'sgb-Latn-PH': 'sgb',
        'sgb-Latn': 'sgb',
        'sgb-PH': 'sgb',
        'sgc': 'sgc',
        'sgc-Latn-KE': 'sgc',
        'sgc-KE': 'sgc',
        'sgc-Latn': 'sgc',
        'sgd': 'sgd',
        'sgd-Latn-PH': 'sgd',
        'sgd-Latn': 'sgd',
        'sgd-PH': 'sgd',
        'sul': 'sgd',
        'sul-Latn': 'sgd',
        'sul-Latn-PH': 'sgd',
        'sul-PH': 'sgd',
        'sge': 'sge',
        'sge-Latn-ID': 'sge',
        'sge-ID': 'sge',
        'sge-Latn': 'sge',
        'sgg': 'sgg',
        'sgg-Zxxx-CH': 'sgg',
        'sgg-CH': 'sgg',
        'sgg-Zxxx': 'sgg',
        'sgn-sgg': 'sgg',
        'sgn-sgg-CH': 'sgg',
        'sgh-Arab': 'sgh-Arab',
        'sgh-Arab-AF': 'sgh-Arab',
        'sgh-AF': 'sgh-Arab',
        'sgh-Cyrl': 'sgh-Cyrl',
        'sgh-Cyrl-TJ': 'sgh-Cyrl',
        'sgh-Latn': 'sgh-Latn',
        'sgh-Latn-TJ': 'sgh-Latn',
        'sgi': 'sgi',
        'sgi-Latn-CM': 'sgi',
        'sgi-CM': 'sgi',
        'sgi-Latn': 'sgi',
        'sgj': 'sgj',
        'sgj-Deva-IN': 'sgj',
        'sgj-Deva': 'sgj',
        'sgj-IN': 'sgj',
        'sgk': 'sgk',
        'sgk-Zyyy-CN': 'sgk',
        'sgk-CN': 'sgk',
        'sgk-Zyyy': 'sgk',
        'sgm': 'sgm',
        'sgm-Latn-KE': 'sgm',
        'sgm-KE': 'sgm',
        'sgm-Latn': 'sgm',
        'sgn-MM': 'sgn-MM',
        'sgn-Zxxx-MM': 'sgn-MM',
        'sgn-Zxxx': 'sgn-MM',
        'sgp': 'sgp',
        'sgp-Latn-IN': 'sgp',
        'sgp-IN': 'sgp',
        'sgp-Latn': 'sgp',
        'sgr': 'sgr',
        'sgr-Arab-IR': 'sgr',
        'sgr-Arab': 'sgr',
        'sgr-IR': 'sgr',
        'sgs': 'sgs',
        'sgs-Latn-LT': 'sgs',
        'sgs-LT': 'sgs',
        'sgs-Latn': 'sgs',
        'sgt': 'sgt',
        'sgt-Zyyy-BT': 'sgt',
        'sgt-BT': 'sgt',
        'sgt-Zyyy': 'sgt',
        'sgu': 'sgu',
        'sgu-Latn-ID': 'sgu',
        'sgu-ID': 'sgu',
        'sgu-Latn': 'sgu',
        'sgw': 'sgw',
        'sgw-Ethi-ET': 'sgw',
        'sgw-ET': 'sgw',
        'sgw-Ethi': 'sgw',
        'sgx': 'sgx',
        'sgx-Zxxx-SL': 'sgx',
        'sgn-sgx': 'sgx',
        'sgn-sgx-SL': 'sgx',
        'sgx-SL': 'sgx',
        'sgx-Zxxx': 'sgx',
        'sgy': 'sgy',
        'sgy-Arab-AF': 'sgy',
        'sgl': 'sgy',
        'sgl-AF': 'sgy',
        'sgl-Arab': 'sgy',
        'sgl-Arab-AF': 'sgy',
        'sgy-AF': 'sgy',
        'sgy-Arab': 'sgy',
        'sgz': 'sgz',
        'sgz-Latn-PG': 'sgz',
        'sgz-Latn': 'sgz',
        'sgz-PG': 'sgz',
        'sh': 'sh',
        'sh-Latn-RS': 'sh',
        'sh-Latn': 'sh',
        'sh-RS': 'sh',
        'sha': 'sha',
        'sha-Latn-NG': 'sha',
        'sha-Latn': 'sha',
        'sha-NG': 'sha',
        'shb': 'shb',
        'shb-Latn-BR': 'shb',
        'shb-BR': 'shb',
        'shb-Latn': 'shb',
        'shc': 'shc',
        'shc-Latn-CD': 'shc',
        'shc-CD': 'shc',
        'shc-Latn': 'shc',
        'shd': 'shd',
        'shd-Arab-PK': 'shd',
        'shd-Arab': 'shd',
        'shd-PK': 'shd',
        'she': 'she',
        'she-Latn-ET': 'she',
        'she-ET': 'she',
        'she-Latn': 'she',
        'shg': 'shg',
        'shg-Latn-BW': 'shg',
        'shg-BW': 'shg',
        'shg-Latn': 'shg',
        'shh': 'shh',
        'shh-Latn-US': 'shh',
        'shh-Latn': 'shh',
        'shh-US': 'shh',
        'shi': 'shi',
        'shi-Tfng-MA': 'shi',
        'shi-MA': 'shi',
        'shi-Tfng': 'shi',
        'shi-Arab': 'shi-Arab',
        'shi-Arab-MA': 'shi-Arab',
        'shi-Latn': 'shi-Latn',
        'shi-Latn-MA': 'shi-Latn',
        'shj': 'shj',
        'shj-Latn-SD': 'shj',
        'shj-Latn': 'shj',
        'shj-SD': 'shj',
        'shk': 'shk',
        'shk-Latn-SS': 'shk',
        'shk-Latn': 'shk',
        'shk-SS': 'shk',
        'shk-Arab': 'shk-Arab',
        'shk-Arab-SS': 'shk-Arab',
        'shl': 'shl',
        'shl-Zyyy-IN': 'shl',
        'shl-IN': 'shl',
        'shl-Zyyy': 'shl',
        'shm': 'shm',
        'shm-Arab-IR': 'shm',
        'shm-Arab': 'shm',
        'shm-IR': 'shm',
        'shn': 'shn',
        'shn-Mymr-MM': 'shn',
        'shn-MM': 'shn',
        'shn-Mymr': 'shn',
        'shn-Mymr-x-taimau': 'shn-Mymr-x-taimau',
        'shn-Mymr-MM-x-taimau': 'shn-Mymr-x-taimau',
        'shn-MM-x-taimau': 'shn-Mymr-x-taimau',
        'shn-Tale': 'shn-Tale',
        'shn-Tale-MM': 'shn-Tale',
        'shn-Thai': 'shn-Thai',
        'shn-Thai-TH': 'shn-Thai',
        'shn-TH': 'shn-Thai',
        'sho': 'sho',
        'sho-Latn-NG': 'sho',
        'sho-Latn': 'sho',
        'sho-NG': 'sho',
        'shp': 'shp',
        'shp-Latn-PE': 'shp',
        'shp-Latn': 'shp',
        'shp-PE': 'shp',
        'shq': 'shq',
        'shq-Latn-ZM': 'shq',
        'shq-Latn': 'shq',
        'shq-ZM': 'shq',
        'shr': 'shr',
        'shr-Latn-CD': 'shr',
        'shr-CD': 'shr',
        'shr-Latn': 'shr',
        'shs': 'shs',
        'shs-Latn-CA': 'shs',
        'shs-CA': 'shs',
        'shs-Latn': 'shs',
        'sht': 'sht',
        'sht-Zyyy-US': 'sht',
        'sht-US': 'sht',
        'sht-Zyyy': 'sht',
        'shu-Arab': 'shu-Arab',
        'shu-Arab-TD': 'shu-Arab',
        'shu-Latn': 'shu-Latn',
        'shu-Latn-TD': 'shu-Latn',
        'shv': 'shv',
        'shv-Zyyy-OM': 'shv',
        'shv-OM': 'shv',
        'shv-Zyyy': 'shv',
        'shw': 'shw',
        'shw-Latn-SD': 'shw',
        'shw-Latn': 'shw',
        'shw-SD': 'shw',
        'shx': 'shx',
        'shx-Zyyy-CN': 'shx',
        'shx-CN': 'shx',
        'shx-Zyyy': 'shx',
        'shy-Arab': 'shy-Arab',
        'shy-Arab-DZ': 'shy-Arab',
        'shy-Latn': 'shy-Latn',
        'shy-Latn-DZ': 'shy-Latn',
        'shy-Tfng': 'shy-Tfng',
        'shy-Tfng-DZ': 'shy-Tfng',
        'shz': 'shz',
        'shz-Latn-ML': 'shz',
        'shz-Latn': 'shz',
        'shz-ML': 'shz',
        'si': 'si',
        'si-Sinh-LK': 'si',
        'si-LK': 'si',
        'si-Sinh': 'si',
        'si-Brai': 'si-Brai',
        'si-Brai-LK': 'si-Brai',
        'sia': 'sia',
        'sia-Cyrl-RU': 'sia',
        'sia-Cyrl': 'sia',
        'sia-RU': 'sia',
        'sib': 'sib',
        'sib-Latn-MY': 'sib',
        'sib-Latn': 'sib',
        'sib-MY': 'sib',
        'sid': 'sid',
        'sid-Latn-ET': 'sid',
        'sid-ET': 'sid',
        'sid-Latn': 'sid',
        'sid-Ethi': 'sid-Ethi',
        'sid-Ethi-ET': 'sid-Ethi',
        'sie': 'sie',
        'sie-Latn-ZM': 'sie',
        'sie-Latn': 'sie',
        'sie-ZM': 'sie',
        'sif': 'sif',
        'sif-Latn-BF': 'sif',
        'sif-BF': 'sif',
        'sif-Latn': 'sif',
        'sig': 'sig',
        'sig-Latn-GH': 'sig',
        'sig-GH': 'sig',
        'sig-Latn': 'sig',
        'sih': 'sih',
        'sih-Latn-NC': 'sih',
        'sih-Latn': 'sih',
        'sih-NC': 'sih',
        'sii': 'sii',
        'sii-Zyyy-IN': 'sii',
        'sii-IN': 'sii',
        'sii-Zyyy': 'sii',
        'sij': 'sij',
        'sij-Latn-PG': 'sij',
        'sij-Latn': 'sij',
        'sij-PG': 'sij',
        'sik': 'sik',
        'sik-Latn-BR': 'sik',
        'sik-BR': 'sik',
        'sik-Latn': 'sik',
        'sil': 'sil',
        'sil-Latn-GH': 'sil',
        'sil-GH': 'sil',
        'sil-Latn': 'sil',
        'sim': 'sim',
        'sim-Latn-PG': 'sim',
        'sim-Latn': 'sim',
        'sim-PG': 'sim',
        'sip': 'sip',
        'sip-Tibt-IN': 'sip',
        'sip-IN': 'sip',
        'sip-Tibt': 'sip',
        'siq': 'siq',
        'siq-Latn-PG': 'siq',
        'siq-Latn': 'siq',
        'siq-PG': 'siq',
        'sir': 'sir',
        'sir-Latn-NG': 'sir',
        'sir-Latn': 'sir',
        'sir-NG': 'sir',
        'sis': 'sis',
        'sis-Zyyy-US': 'sis',
        'sis-US': 'sis',
        'sis-Zyyy': 'sis',
        'siu': 'siu',
        'siu-Latn-PG': 'siu',
        'siu-Latn': 'siu',
        'siu-PG': 'siu',
        'siv': 'siv',
        'siv-Latn-PG': 'siv',
        'siv-Latn': 'siv',
        'siv-PG': 'siv',
        'siw': 'siw',
        'siw-Latn-PG': 'siw',
        'siw-Latn': 'siw',
        'siw-PG': 'siw',
        'six': 'six',
        'six-Latn-PG': 'six',
        'six-Latn': 'six',
        'six-PG': 'six',
        'siy': 'siy',
        'siy-Zyyy-IR': 'siy',
        'siy-IR': 'siy',
        'siy-Zyyy': 'siy',
        'siz': 'siz',
        'siz-Arab-EG': 'siz',
        'siz-Arab': 'siz',
        'siz-EG': 'siz',
        'sja': 'sja',
        'sja-Latn-CO': 'sja',
        'sja-CO': 'sja',
        'sja-Latn': 'sja',
        'sjb': 'sjb',
        'sjb-Latn-ID': 'sjb',
        'sjb-ID': 'sjb',
        'sjb-Latn': 'sjb',
        'sjd': 'sjd',
        'sjd-Cyrl-RU': 'sjd',
        'sjd-Cyrl': 'sjd',
        'sjd-RU': 'sjd',
        'sje': 'sje',
        'sje-Zyyy-SE': 'sje',
        'sje-SE': 'sje',
        'sje-Zyyy': 'sje',
        'sjg': 'sjg',
        'sjg-Latn-TD': 'sjg',
        'sjg-Latn': 'sjg',
        'sjg-TD': 'sjg',
        'sjk': 'sjk',
        'sjk-Zyyy-XX': 'sjk',
        'sjk-XX': 'sjk',
        'sjk-Zyyy': 'sjk',
        'sjl': 'sjl',
        'sjl-Latn-IN': 'sjl',
        'sjl-IN': 'sjl',
        'sjl-Latn': 'sjl',
        'sjm': 'sjm',
        'sjm-Latn-PH': 'sjm',
        'sjm-Latn': 'sjm',
        'sjm-PH': 'sjm',
        'sjn': 'sjn',
        'sjn-Zyyy-001': 'sjn',
        'sjn-001': 'sjn',
        'sjn-Zyyy': 'sjn',
        'sjo': 'sjo',
        'sjo-Mong-CN-x-sibe': 'sjo',
        'sjo-CN': 'sjo',
        'sjo-CN-x-sibe': 'sjo',
        'sjo-Mong': 'sjo',
        'sjo-Mong-CN': 'sjo',
        'sjo-Mong-x-sibe': 'sjo',
        'sjo-x-sibe': 'sjo',
        'sjo-Cyrl': 'sjo-Cyrl',
        'sjo-Cyrl-CN': 'sjo-Cyrl',
        'sjo-Latn': 'sjo-Latn',
        'sjo-Latn-CN': 'sjo-Latn',
        'sjo-Mong-x-manchu': 'sjo-Mong-x-manchu',
        'sjo-Mong-CN-x-manchu': 'sjo-Mong-x-manchu',
        'sjo-CN-x-manchu': 'sjo-Mong-x-manchu',
        'sjp': 'sjp',
        'sjp-Deva-IN': 'sjp',
        'sjp-Deva': 'sjp',
        'sjp-IN': 'sjp',
        'sjr': 'sjr',
        'sjr-Latn-PG': 'sjr',
        'sjr-Latn': 'sjr',
        'sjr-PG': 'sjr',
        'sjs': 'sjs',
        'sjs-Zyyy-MA': 'sjs',
        'sjs-MA': 'sjs',
        'sjs-Zyyy': 'sjs',
        'sjt': 'sjt',
        'sjt-Cyrl-RU': 'sjt',
        'sjt-Cyrl': 'sjt',
        'sjt-RU': 'sjt',
        'sju': 'sju',
        'sju-Latn-SE': 'sju',
        'sju-Latn': 'sju',
        'sju-SE': 'sju',
        'sjw': 'sjw',
        'sjw-Latn-US': 'sjw',
        'sjw-Latn': 'sjw',
        'sjw-US': 'sjw',
        'sk': 'sk',
        'sk-Latn-SK': 'sk',
        'sk-Latn': 'sk',
        'sk-SK': 'sk',
        'sk-Brai': 'sk-Brai',
        'sk-Brai-SK': 'sk-Brai',
        'ska': 'ska',
        'ska-Latn-US': 'ska',
        'ska-Latn': 'ska',
        'ska-US': 'ska',
        'skb': 'skb',
        'skb-Zyyy-LA': 'skb',
        'skb-LA': 'skb',
        'skb-Zyyy': 'skb',
        'skc': 'skc',
        'skc-Latn-PG': 'skc',
        'skc-Latn': 'skc',
        'skc-PG': 'skc',
        'skd': 'skd',
        'skd-Latn-US': 'skd',
        'skd-Latn': 'skd',
        'skd-US': 'skd',
        'ske': 'ske',
        'ske-Latn-VU': 'ske',
        'ske-Latn': 'ske',
        'ske-VU': 'ske',
        'skf': 'skf',
        'skf-Latn-BR': 'skf',
        'skf-BR': 'skf',
        'skf-Latn': 'skf',
        'skg': 'skg',
        'skg-Latn-MG': 'skg',
        'skg-Latn': 'skg',
        'skg-MG': 'skg',
        'skh': 'skh',
        'skh-Latn-ID': 'skh',
        'skh-ID': 'skh',
        'skh-Latn': 'skh',
        'ski': 'ski',
        'ski-Latn-ID': 'ski',
        'ski-ID': 'ski',
        'ski-Latn': 'ski',
        'skj': 'skj',
        'skj-Zyyy-NP': 'skj',
        'skj-NP': 'skj',
        'skj-Zyyy': 'skj',
        'skm': 'skm',
        'skm-Latn-PG': 'skm',
        'skm-Latn': 'skm',
        'skm-PG': 'skm',
        'skn': 'skn',
        'skn-Latn-PH': 'skn',
        'skn-Latn': 'skn',
        'skn-PH': 'skn',
        'sko': 'sko',
        'sko-Latn-ID': 'sko',
        'sko-ID': 'sko',
        'sko-Latn': 'sko',
        'skp': 'skp',
        'skp-Latn-MY': 'skp',
        'skp-Latn': 'skp',
        'skp-MY': 'skp',
        'skq': 'skq',
        'skq-Latn-BF': 'skq',
        'skq-BF': 'skq',
        'skq-Latn': 'skq',
        'skr': 'skr',
        'skr-Arab-PK': 'skr',
        'skr-Arab': 'skr',
        'skr-PK': 'skr',
        'skr-Deva': 'skr-Deva',
        'skr-Deva-PK': 'skr-Deva',
        'skr-Guru': 'skr-Guru',
        'skr-Guru-PK': 'skr-Guru',
        'skr-Khoj': 'skr-Khoj',
        'skr-Khoj-PK': 'skr-Khoj',
        'sks': 'sks',
        'sks-Latn-PG': 'sks',
        'sks-Latn': 'sks',
        'sks-PG': 'sks',
        'skt': 'skt',
        'skt-Latn-CD': 'skt',
        'skt-CD': 'skt',
        'skt-Latn': 'skt',
        'sku': 'sku',
        'sku-Latn-VU': 'sku',
        'sku-Latn': 'sku',
        'sku-VU': 'sku',
        'skv': 'skv',
        'skv-Latn-ID': 'skv',
        'skv-ID': 'skv',
        'skv-Latn': 'skv',
        'skw': 'skw',
        'skw-Latn-GY': 'skw',
        'skw-GY': 'skw',
        'skw-Latn': 'skw',
        'skx': 'skx',
        'skx-Latn-ID': 'skx',
        'skx-ID': 'skx',
        'skx-Latn': 'skx',
        'sky': 'sky',
        'sky-Latn-SB': 'sky',
        'sky-Latn': 'sky',
        'sky-SB': 'sky',
        'skz': 'skz',
        'skz-Latn-ID': 'skz',
        'skz-ID': 'skz',
        'skz-Latn': 'skz',
        'sl': 'sl',
        'sl-Latn-SI': 'sl',
        'sl-Latn': 'sl',
        'sl-SI': 'sl',
        'sl-Brai': 'sl-Brai',
        'sl-Brai-SI': 'sl-Brai',
        'slc': 'slc',
        'slc-Latn-CO': 'slc',
        'slc-CO': 'slc',
        'slc-Latn': 'slc',
        'sld': 'sld',
        'sld-Latn-BF': 'sld',
        'sld-BF': 'sld',
        'sld-Latn': 'sld',
        'sle': 'sle',
        'sle-Zyyy-IN': 'sle',
        'sle-IN': 'sle',
        'sle-Zyyy': 'sle',
        'slf': 'slf',
        'slf-Zxxx-CH': 'slf',
        'sgn-slf': 'slf',
        'sgn-slf-CH': 'slf',
        'slf-CH': 'slf',
        'slf-Zxxx': 'slf',
        'slg': 'slg',
        'slg-Latn-ID': 'slg',
        'slg-ID': 'slg',
        'slg-Latn': 'slg',
        'slh': 'slh',
        'slh-Latn-US': 'slh',
        'slh-Latn': 'slh',
        'slh-US': 'slh',
        'sli': 'sli',
        'sli-Latn-PL': 'sli',
        'sli-Latn': 'sli',
        'sli-PL': 'sli',
        'slj': 'slj',
        'slj-Latn-BR': 'slj',
        'slj-BR': 'slj',
        'slj-Latn': 'slj',
        'sll': 'sll',
        'sll-Latn-PG': 'sll',
        'sll-Latn': 'sll',
        'sll-PG': 'sll',
        'slm': 'slm',
        'slm-Latn-PH': 'slm',
        'slm-Latn': 'slm',
        'slm-PH': 'slm',
        'sln': 'sln',
        'sln-Zyyy-US': 'sln',
        'sln-US': 'sln',
        'sln-Zyyy': 'sln',
        'slp': 'slp',
        'slp-Latn-ID': 'slp',
        'slp-ID': 'slp',
        'slp-Latn': 'slp',
        'slq': 'slq',
        'slq-Zyyy-IR': 'slq',
        'slq-IR': 'slq',
        'slq-Zyyy': 'slq',
        'slr': 'slr',
        'slr-Zyyy-CN': 'slr',
        'slr-CN': 'slr',
        'slr-Zyyy': 'slr',
        'sls': 'sls',
        'sls-Zxxx-SG': 'sls',
        'sgn-sls': 'sls',
        'sgn-sls-SG': 'sls',
        'sls-SG': 'sls',
        'sls-Zxxx': 'sls',
        'slt': 'slt',
        'slt-Zyyy-LA': 'slt',
        'slt-LA': 'slt',
        'slt-Zyyy': 'slt',
        'slu': 'slu',
        'slu-Latn-ID': 'slu',
        'slu-ID': 'slu',
        'slu-Latn': 'slu',
        'slw': 'slw',
        'slw-Latn-PG': 'slw',
        'slw-Latn': 'slw',
        'slw-PG': 'slw',
        'slx': 'slx',
        'slx-Latn-CD': 'slx',
        'slx-CD': 'slx',
        'slx-Latn': 'slx',
        'sly': 'sly',
        'sly-Latn-ID': 'sly',
        'sly-ID': 'sly',
        'sly-Latn': 'sly',
        'slz': 'slz',
        'slz-Latn-ID': 'slz',
        'slz-ID': 'slz',
        'slz-Latn': 'slz',
        'sm': 'sm',
        'sm-Latn-WS': 'sm',
        'sm-Latn': 'sm',
        'sm-WS': 'sm',
        'sma': 'sma',
        'sma-Latn-SE': 'sma',
        'sma-Latn': 'sma',
        'sma-SE': 'sma',
        'smb': 'smb',
        'smb-Latn-PG': 'smb',
        'smb-Latn': 'smb',
        'smb-PG': 'smb',
        'smc': 'smc',
        'smc-Latn-PG': 'smc',
        'smc-Latn': 'smc',
        'smc-PG': 'smc',
        'smd': 'smd',
        'smd-Latn-AO': 'smd',
        'smd-AO': 'smd',
        'smd-Latn': 'smd',
        'smf': 'smf',
        'smf-Latn-PG': 'smf',
        'smf-Latn': 'smf',
        'smf-PG': 'smf',
        'smg': 'smg',
        'smg-Latn-PG': 'smg',
        'smg-Latn': 'smg',
        'smg-PG': 'smg',
        'smh': 'smh',
        'smh-Yiii-CN': 'smh',
        'smh-CN': 'smh',
        'smh-Yiii': 'smh',
        'smj': 'smj',
        'smj-Latn-SE': 'smj',
        'smj-Latn': 'smj',
        'smj-SE': 'smj',
        'smk': 'smk',
        'smk-Latn-PH': 'smk',
        'smk-Latn': 'smk',
        'smk-PH': 'smk',
        'sml': 'sml',
        'sml-Latn-PH': 'sml',
        'sml-Latn': 'sml',
        'sml-PH': 'sml',
        'smm': 'smm',
        'smm-Zyyy-NP': 'smm',
        'smm-NP': 'smm',
        'smm-Zyyy': 'smm',
        'smn': 'smn',
        'smn-Latn-FI': 'smn',
        'smn-FI': 'smn',
        'smn-Latn': 'smn',
        'smp': 'smp',
        'smp-Samr-IL': 'smp',
        'smp-IL': 'smp',
        'smp-Samr': 'smp',
        'smp-Arab': 'smp-Arab',
        'smp-Arab-PS': 'smp-Arab',
        'smp-Hebr': 'smp-Hebr',
        'smp-Hebr-PS': 'smp-Hebr',
        'smq': 'smq',
        'smq-Latn-PG': 'smq',
        'smq-Latn': 'smq',
        'smq-PG': 'smq',
        'smr': 'smr',
        'smr-Latn-ID': 'smr',
        'smr-ID': 'smr',
        'smr-Latn': 'smr',
        'sms': 'sms',
        'sms-Latn-FI': 'sms',
        'sms-FI': 'sms',
        'sms-Latn': 'sms',
        'smt': 'smt',
        'smt-Latn-IN': 'smt',
        'smt-IN': 'smt',
        'smt-Latn': 'smt',
        'smu': 'smu',
        'smu-Zyyy-KH': 'smu',
        'smu-KH': 'smu',
        'smu-Zyyy': 'smu',
        'smv': 'smv',
        'smv-Zyyy-IN': 'smv',
        'smv-IN': 'smv',
        'smv-Zyyy': 'smv',
        'smw': 'smw',
        'smw-Latn-ID': 'smw',
        'smw-ID': 'smw',
        'smw-Latn': 'smw',
        'smx': 'smx',
        'smx-Latn-CD': 'smx',
        'smx-CD': 'smx',
        'smx-Latn': 'smx',
        'smy': 'smy',
        'smy-Arab-IR': 'smy',
        'smy-Arab': 'smy',
        'smy-IR': 'smy',
        'smz': 'smz',
        'smz-Latn-PG': 'smz',
        'smz-Latn': 'smz',
        'smz-PG': 'smz',
        'sn': 'sn',
        'sn-Latn-ZW': 'sn',
        'sn-Latn': 'sn',
        'sn-ZW': 'sn',
        'sn-Brai': 'sn-Brai',
        'sn-Brai-ZW': 'sn-Brai',
        'snb': 'snb',
        'snb-Latn-MY': 'snb',
        'snb-Latn': 'snb',
        'snb-MY': 'snb',
        'snc': 'snc',
        'snc-Latn-PG': 'snc',
        'snc-Latn': 'snc',
        'snc-PG': 'snc',
        'sne': 'sne',
        'sne-Latn-MY': 'sne',
        'sne-Latn': 'sne',
        'sne-MY': 'sne',
        'snf': 'snf',
        'snf-Latn-SN': 'snf',
        'snf-Latn': 'snf',
        'snf-SN': 'snf',
        'sng': 'sng',
        'sng-Latn-CD': 'sng',
        'sng-CD': 'sng',
        'sng-Latn': 'sng',
        'sng-Brai': 'sng-Brai',
        'sng-Brai-CD': 'sng-Brai',
        'snh': 'snh',
        'snh-Zyyy-XX': 'snh',
        'snh-XX': 'snh',
        'snh-Zyyy': 'snh',
        'sni': 'sni',
        'sni-Latn-PE': 'sni',
        'sni-Latn': 'sni',
        'sni-PE': 'sni',
        'snj': 'snj',
        'snj-Latn-CF': 'snj',
        'snj-CF': 'snj',
        'snj-Latn': 'snj',
        'snk': 'snk',
        'snk-Latn-ML': 'snk',
        'snk-Latn': 'snk',
        'snk-ML': 'snk',
        'snk-Arab': 'snk-Arab',
        'snk-Arab-ML': 'snk-Arab',
        'snl': 'snl',
        'snl-Latn-PH': 'snl',
        'snl-Latn': 'snl',
        'snl-PH': 'snl',
        'snm': 'snm',
        'snm-Latn-UG': 'snm',
        'snm-Latn': 'snm',
        'snm-UG': 'snm',
        'snn': 'snn',
        'snn-Latn-CO': 'snn',
        'snn-CO': 'snn',
        'snn-Latn': 'snn',
        'sno': 'sno',
        'sno-Latn-US': 'sno',
        'sno-Latn': 'sno',
        'sno-US': 'sno',
        'snp': 'snp',
        'snp-Latn-PG': 'snp',
        'snp-Latn': 'snp',
        'snp-PG': 'snp',
        'snp-x-lambau': 'snp-x-lambau',
        'snp-Latn-PG-x-lambau': 'snp-x-lambau',
        'snp-Latn-x-lambau': 'snp-x-lambau',
        'snp-PG-x-lambau': 'snp-x-lambau',
        'snq': 'snq',
        'snq-Latn-GA': 'snq',
        'snq-GA': 'snq',
        'snq-Latn': 'snq',
        'snr': 'snr',
        'snr-Latn-PG': 'snr',
        'snr-Latn': 'snr',
        'snr-PG': 'snr',
        'sns': 'sns',
        'sns-Latn-VU': 'sns',
        'sns-Latn': 'sns',
        'sns-VU': 'sns',
        'snu': 'snu',
        'snu-Latn-ID': 'snu',
        'snu-ID': 'snu',
        'snu-Latn': 'snu',
        'snv': 'snv',
        'snv-Latn-MY': 'snv',
        'snv-Latn': 'snv',
        'snv-MY': 'snv',
        'snw': 'snw',
        'snw-Latn-GH': 'snw',
        'snw-GH': 'snw',
        'snw-Latn': 'snw',
        'snx': 'snx',
        'snx-Latn-PG': 'snx',
        'snx-Latn': 'snx',
        'snx-PG': 'snx',
        'sny': 'sny',
        'sny-Latn-PG': 'sny',
        'sny-Latn': 'sny',
        'sny-PG': 'sny',
        'snz': 'snz',
        'snz-Latn-PG': 'snz',
        'asd': 'snz',
        'asd-Latn': 'snz',
        'asd-Latn-PG': 'snz',
        'asd-PG': 'snz',
        'snz-Latn': 'snz',
        'snz-PG': 'snz',
        'so': 'so',
        'so-Latn-SO': 'so',
        'so-Latn': 'so',
        'so-SO': 'so',
        'so-Arab': 'so-Arab',
        'so-Arab-SO': 'so-Arab',
        'so-DJ': 'so-DJ',
        'so-Latn-DJ': 'so-DJ',
        'so-ET': 'so-ET',
        'so-Latn-ET': 'so-ET',
        'so-KE': 'so-KE',
        'so-Latn-KE': 'so-KE',
        'so-Osma': 'so-Osma',
        'so-Osma-SO': 'so-Osma',
        'soa': 'soa',
        'soa-Tavt-TH': 'soa',
        'soa-TH': 'soa',
        'soa-Tavt': 'soa',
        'soa-Thai': 'soa-Thai',
        'soa-Thai-TH': 'soa-Thai',
        'sob': 'sob',
        'sob-Latn-ID': 'sob',
        'sob-ID': 'sob',
        'sob-Latn': 'sob',
        'soc': 'soc',
        'soc-Latn-CD': 'soc',
        'soc-CD': 'soc',
        'soc-Latn': 'soc',
        'sod': 'sod',
        'sod-Latn-CD': 'sod',
        'sod-CD': 'sod',
        'sod-Latn': 'sod',
        'soe': 'soe',
        'soe-Latn-CD': 'soe',
        'soe-CD': 'soe',
        'soe-Latn': 'soe',
        'sog-Mani': 'sog-Mani',
        'sog-Mani-XX': 'sog-Mani',
        'sog-Sogd': 'sog-Sogd',
        'sog-Sogd-XX': 'sog-Sogd',
        'sog-Sogo': 'sog-Sogo',
        'sog-Sogo-XX': 'sog-Sogo',
        'sog-Syrc': 'sog-Syrc',
        'sog-Syrc-XX': 'sog-Syrc',
        'soh': 'soh',
        'soh-Zyyy-SD': 'soh',
        'soh-SD': 'soh',
        'soh-Zyyy': 'soh',
        'soi': 'soi',
        'soi-Zyyy-NP': 'soi',
        'soi-NP': 'soi',
        'soi-Zyyy': 'soi',
        'soj': 'soj',
        'soj-Zyyy-IR': 'soj',
        'soj-IR': 'soj',
        'soj-Zyyy': 'soj',
        'sok': 'sok',
        'sok-Latn-TD': 'sok',
        'sok-Latn': 'sok',
        'sok-TD': 'sok',
        'sol': 'sol',
        'sol-Latn-PG': 'sol',
        'sol-Latn': 'sol',
        'sol-PG': 'sol',
        'soo': 'soo',
        'soo-Latn-CD': 'soo',
        'soo-CD': 'soo',
        'soo-Latn': 'soo',
        'sop': 'sop',
        'sop-Latn-CD': 'sop',
        'sop-CD': 'sop',
        'sop-Latn': 'sop',
        'soq': 'soq',
        'soq-Latn-PG': 'soq',
        'soq-Latn': 'soq',
        'soq-PG': 'soq',
        'sor': 'sor',
        'sor-Latn-TD': 'sor',
        'sor-Latn': 'sor',
        'sor-TD': 'sor',
        'sos': 'sos',
        'sos-Latn-BF': 'sos',
        'sos-BF': 'sos',
        'sos-Latn': 'sos',
        'sou': 'sou',
        'sou-Thai-TH': 'sou',
        'sou-TH': 'sou',
        'sou-Thai': 'sou',
        'sov': 'sov',
        'sov-Latn-PW': 'sov',
        'sov-Latn': 'sov',
        'sov-PW': 'sov',
        'sow': 'sow',
        'sow-Latn-PG': 'sow',
        'sow-Latn': 'sow',
        'sow-PG': 'sow',
        'sox': 'sox',
        'sox-Latn-CM': 'sox',
        'sox-CM': 'sox',
        'sox-Latn': 'sox',
        'soy': 'soy',
        'soy-Latn-BJ': 'soy',
        'soy-BJ': 'soy',
        'soy-Latn': 'soy',
        'soz': 'soz',
        'soz-Latn-TZ': 'soz',
        'soz-Latn': 'soz',
        'soz-TZ': 'soz',
        'spb': 'spb',
        'spb-Latn-ID': 'spb',
        'spb-ID': 'spb',
        'spb-Latn': 'spb',
        'spc': 'spc',
        'spc-Latn-VE': 'spc',
        'spc-Latn': 'spc',
        'spc-VE': 'spc',
        'spd': 'spd',
        'spd-Latn-PG': 'spd',
        'spd-Latn': 'spd',
        'spd-PG': 'spd',
        'spe': 'spe',
        'spe-Latn-PG': 'spe',
        'spe-Latn': 'spe',
        'spe-PG': 'spe',
        'spg': 'spg',
        'spg-Latn-MY': 'spg',
        'spg-Latn': 'spg',
        'spg-MY': 'spg',
        'spi': 'spi',
        'spi-Latn-ID': 'spi',
        'spi-ID': 'spi',
        'spi-Latn': 'spi',
        'spk': 'spk',
        'spk-Latn-PG': 'spk',
        'spk-Latn': 'spk',
        'spk-PG': 'spk',
        'spl': 'spl',
        'spl-Latn-PG': 'spl',
        'spl-Latn': 'spl',
        'spl-PG': 'spl',
        'spm': 'spm',
        'spm-Latn-PG': 'spm',
        'spm-Latn': 'spm',
        'spm-PG': 'spm',
        'spn': 'spn',
        'spn-Latn-PY': 'spn',
        'sap': 'spn',
        'sap-Latn': 'spn',
        'sap-Latn-PY': 'spn',
        'sap-PY': 'spn',
        'spn-Latn': 'spn',
        'spn-PY': 'spn',
        'spo': 'spo',
        'spo-Latn-US': 'spo',
        'spo-Latn': 'spo',
        'spo-US': 'spo',
        'spp': 'spp',
        'spp-Latn-ML': 'spp',
        'spp-Latn': 'spp',
        'spp-ML': 'spp',
        'spq': 'spq',
        'spq-Latn-PE': 'spq',
        'spq-Latn': 'spq',
        'spq-PE': 'spq',
        'spr': 'spr',
        'spr-Latn-ID': 'spr',
        'spr-ID': 'spr',
        'spr-Latn': 'spr',
        'sps': 'sps',
        'sps-Latn-PG': 'sps',
        'sps-Latn': 'sps',
        'sps-PG': 'sps',
        'spt': 'spt',
        'spt-Tibt-IN': 'spt',
        'spt-IN': 'spt',
        'spt-Tibt': 'spt',
        'spu': 'spu',
        'spu-Zyyy-LA': 'spu',
        'spu-LA': 'spu',
        'spu-Zyyy': 'spu',
        'spv': 'spv',
        'spv-Orya-IN': 'spv',
        'spv-IN': 'spv',
        'spv-Orya': 'spv',
        'spx': 'spx',
        'spx-Zyyy-XX': 'spx',
        'spx-XX': 'spx',
        'spx-Zyyy': 'spx',
        'sq': 'sq',
        'sq-Latn-AL': 'sq',
        'als': 'sq',
        'als-AL': 'sq',
        'als-Latn': 'sq',
        'als-Latn-AL': 'sq',
        'sq-AL': 'sq',
        'sq-Latn': 'sq',
        'sq-Brai': 'sq-Brai',
        'sq-Brai-AL': 'sq-Brai',
        'sq-Elba': 'sq-Elba',
        'sq-Elba-AL': 'sq-Elba',
        'als-Elba': 'sq-Elba',
        'als-Elba-AL': 'sq-Elba',
        'sq-Grek': 'sq-Grek',
        'sq-Grek-GR': 'sq-Grek',
        'als-Grek': 'sq-Grek',
        'als-Grek-GR': 'sq-Grek',
        'sq-GR': 'sq-Grek',
        'sq-MK': 'sq-MK',
        'sq-Latn-MK': 'sq-MK',
        'sq-XK': 'sq-XK',
        'sq-Latn-XK': 'sq-XK',
        'sqa': 'sqa',
        'sqa-Latn-NG': 'sqa',
        'sqa-Latn': 'sqa',
        'sqa-NG': 'sqa',
        'sqh': 'sqh',
        'sqh-Latn-NG': 'sqh',
        'sqh-Latn': 'sqh',
        'sqh-NG': 'sqh',
        'sqk': 'sqk',
        'sqk-Zxxx-AL': 'sqk',
        'sgn-sqk': 'sqk',
        'sgn-sqk-AL': 'sqk',
        'sqk-AL': 'sqk',
        'sqk-Zxxx': 'sqk',
        'sqm': 'sqm',
        'sqm-Latn-CF': 'sqm',
        'sqm-CF': 'sqm',
        'sqm-Latn': 'sqm',
        'sqn': 'sqn',
        'sqn-Zyyy-XX': 'sqn',
        'sqn-XX': 'sqn',
        'sqn-Zyyy': 'sqn',
        'sqo': 'sqo',
        'sqo-Zyyy-IR': 'sqo',
        'sqo-IR': 'sqo',
        'sqo-Zyyy': 'sqo',
        'sqq': 'sqq',
        'sqq-Zyyy-LA': 'sqq',
        'sqq-LA': 'sqq',
        'sqq-Zyyy': 'sqq',
        'sqr': 'sqr',
        'sqr-Zyyy-XX': 'sqr',
        'sqr-XX': 'sqr',
        'sqr-Zyyy': 'sqr',
        'sqs': 'sqs',
        'sqs-Zxxx-LK': 'sqs',
        'sgn-sqs': 'sqs',
        'sgn-sqs-LK': 'sqs',
        'sqs-LK': 'sqs',
        'sqs-Zxxx': 'sqs',
        'sqt': 'sqt',
        'sqt-Arab-YE': 'sqt',
        'sqt-Arab': 'sqt',
        'sqt-YE': 'sqt',
        'sqt-Latn': 'sqt-Latn',
        'sqt-Latn-YE': 'sqt-Latn',
        'squ': 'squ',
        'squ-Latn-CA': 'squ',
        'squ-CA': 'squ',
        'squ-Latn': 'squ',
        'sr': 'sr',
        'sr-Cyrl-RS': 'sr',
        'sr-Cyrl': 'sr',
        'sr-RS': 'sr',
        'sr-BA': 'sr-BA',
        'sr-Cyrl-BA': 'sr-BA',
        'sr-Brai': 'sr-Brai',
        'sr-Brai-RS': 'sr-Brai',
        'sr-Cyrl-ME': 'sr-Cyrl-ME',
        'sr-Latn': 'sr-Latn',
        'sr-Latn-RS': 'sr-Latn',
        'sr-Latn-BA': 'sr-Latn-BA',
        'sr-Latn-XK': 'sr-Latn-XK',
        'sr-ME': 'sr-ME',
        'sr-Latn-ME': 'sr-ME',
        'sr-RO': 'sr-RO',
        'sr-Latn-RO': 'sr-RO',
        'sr-RU': 'sr-RU',
        'sr-Latn-RU': 'sr-RU',
        'sr-TR': 'sr-TR',
        'sr-Latn-TR': 'sr-TR',
        'sr-XK': 'sr-XK',
        'sr-Cyrl-XK': 'sr-XK',
        'sra': 'sra',
        'sra-Latn-PG': 'sra',
        'sra-Latn': 'sra',
        'sra-PG': 'sra',
        'srb': 'srb',
        'srb-Sora-IN': 'srb',
        'srb-IN': 'srb',
        'srb-Sora': 'srb',
        'srb-Latn': 'srb-Latn',
        'srb-Latn-IN': 'srb-Latn',
        'srb-Orya': 'srb-Orya',
        'srb-Orya-IN': 'srb-Orya',
        'srb-Telu': 'srb-Telu',
        'srb-Telu-IN': 'srb-Telu',
        'sre': 'sre',
        'sre-Latn-ID': 'sre',
        'sre-ID': 'sre',
        'sre-Latn': 'sre',
        'srf': 'srf',
        'srf-Latn-PG': 'srf',
        'srf-Latn': 'srf',
        'srf-PG': 'srf',
        'srg': 'srg',
        'srg-Latn-PH': 'srg',
        'srg-Latn': 'srg',
        'srg-PH': 'srg',
        'srh': 'srh',
        'srh-Zyyy-CN': 'srh',
        'srh-CN': 'srh',
        'srh-Zyyy': 'srh',
        'sri': 'sri',
        'sri-Latn-CO': 'sri',
        'sri-CO': 'sri',
        'sri-Latn': 'sri',
        'srk': 'srk',
        'srk-Latn-MY': 'srk',
        'srk-Latn': 'srk',
        'srk-MY': 'srk',
        'srl': 'srl',
        'srl-Latn-ID': 'srl',
        'srl-ID': 'srl',
        'srl-Latn': 'srl',
        'srm': 'srm',
        'srm-Latn-SR': 'srm',
        'srm-Latn': 'srm',
        'srm-SR': 'srm',
        'srn': 'srn',
        'srn-Latn-SR': 'srn',
        'srn-Latn': 'srn',
        'srn-SR': 'srn',
        'sro': 'sro',
        'sro-Latn-IT': 'sro',
        'sro-IT': 'sro',
        'sro-Latn': 'sro',
        'srq': 'srq',
        'srq-Latn-BO': 'srq',
        'srq-BO': 'srq',
        'srq-Latn': 'srq',
        'srr': 'srr',
        'srr-Latn-SN': 'srr',
        'srr-Latn': 'srr',
        'srr-SN': 'srr',
        'srr-Arab': 'srr-Arab',
        'srr-Arab-SN': 'srr-Arab',
        'srs': 'srs',
        'srs-Latn-CA': 'srs',
        'srs-CA': 'srs',
        'srs-Latn': 'srs',
        'srt': 'srt',
        'srt-Latn-ID': 'srt',
        'srt-ID': 'srt',
        'srt-Latn': 'srt',
        'sru': 'sru',
        'sru-Latn-BR': 'sru',
        'sru-BR': 'sru',
        'sru-Latn': 'sru',
        'srv': 'srv',
        'srv-Latn-PH': 'srv',
        'srv-Latn': 'srv',
        'srv-PH': 'srv',
        'srw': 'srw',
        'srw-Latn-ID': 'srw',
        'srw-ID': 'srw',
        'srw-Latn': 'srw',
        'srx': 'srx',
        'srx-Deva-IN': 'srx',
        'srx-Deva': 'srx',
        'srx-IN': 'srx',
        'srx-Takr': 'srx-Takr',
        'srx-Takr-IN': 'srx-Takr',
        'sry': 'sry',
        'sry-Latn-PG': 'sry',
        'sry-Latn': 'sry',
        'sry-PG': 'sry',
        'srz': 'srz',
        'srz-Arab-IR': 'srz',
        'srz-Arab': 'srz',
        'srz-IR': 'srz',
        'ss': 'ss',
        'ss-Latn-ZA': 'ss',
        'ss-Latn': 'ss',
        'ss-ZA': 'ss',
        'ssb': 'ssb',
        'ssb-Latn-PH': 'ssb',
        'ssb-Latn': 'ssb',
        'ssb-PH': 'ssb',
        'ssc': 'ssc',
        'ssc-Latn-TZ': 'ssc',
        'ssc-Latn': 'ssc',
        'ssc-TZ': 'ssc',
        'ssd': 'ssd',
        'ssd-Latn-PG': 'ssd',
        'ssd-Latn': 'ssd',
        'ssd-PG': 'ssd',
        'sse': 'sse',
        'sse-Latn-PH': 'sse',
        'sse-Latn': 'sse',
        'sse-PH': 'sse',
        'sse-Arab': 'sse-Arab',
        'sse-Arab-PH': 'sse-Arab',
        'ssf': 'ssf',
        'ssf-Latn-TW': 'ssf',
        'ssf-Latn': 'ssf',
        'ssf-TW': 'ssf',
        'ssg': 'ssg',
        'ssg-Latn-PG': 'ssg',
        'ssg-Latn': 'ssg',
        'ssg-PG': 'ssg',
        'ssh': 'ssh',
        'ssh-Arab-AE': 'ssh',
        'ar-ssh': 'ssh',
        'ar-ssh-AE': 'ssh',
        'ssh-AE': 'ssh',
        'ssh-Arab': 'ssh',
        'ssi': 'ssi',
        'ssi-Zyyy-IN': 'ssi',
        'ssi-IN': 'ssi',
        'ssi-Zyyy': 'ssi',
        'ssj': 'ssj',
        'ssj-Latn-PG': 'ssj',
        'ssj-Latn': 'ssj',
        'ssj-PG': 'ssj',
        'ssk': 'ssk',
        'ssk-Zyyy-IN': 'ssk',
        'ssk-IN': 'ssk',
        'ssk-Zyyy': 'ssk',
        'ssl': 'ssl',
        'ssl-Latn-GH': 'ssl',
        'ssl-GH': 'ssl',
        'ssl-Latn': 'ssl',
        'ssm': 'ssm',
        'ssm-Latn-MY': 'ssm',
        'ssm-Latn': 'ssm',
        'ssm-MY': 'ssm',
        'ssn': 'ssn',
        'ssn-Latn-KE': 'ssn',
        'ssn-KE': 'ssn',
        'ssn-Latn': 'ssn',
        'sso': 'sso',
        'sso-Latn-PG': 'sso',
        'sso-Latn': 'sso',
        'sso-PG': 'sso',
        'ssp': 'ssp',
        'ssp-Zxxx-ES': 'ssp',
        'sgn-ssp': 'ssp',
        'sgn-ssp-ES': 'ssp',
        'ssp-ES': 'ssp',
        'ssp-Zxxx': 'ssp',
        'ssq': 'ssq',
        'ssq-Latn-ID': 'ssq',
        'ssq-ID': 'ssq',
        'ssq-Latn': 'ssq',
        'ssr': 'ssr',
        'ssr-Zxxx-CH': 'ssr',
        'sgn-ssr': 'ssr',
        'sgn-ssr-CH': 'ssr',
        'ssr-CH': 'ssr',
        'ssr-Zxxx': 'ssr',
        'sss': 'sss',
        'sss-Laoo-LA': 'sss',
        'sss-LA': 'sss',
        'sss-Laoo': 'sss',
        'sss-Thai': 'sss-Thai',
        'sss-Thai-TH': 'sss-Thai',
        'sss-TH': 'sss-Thai',
        'sst': 'sst',
        'sst-Latn-PG': 'sst',
        'sst-Latn': 'sst',
        'sst-PG': 'sst',
        'ssu': 'ssu',
        'ssu-Latn-PG': 'ssu',
        'ssu-Latn': 'ssu',
        'ssu-PG': 'ssu',
        'ssv': 'ssv',
        'ssv-Latn-VU': 'ssv',
        'ssv-Latn': 'ssv',
        'ssv-VU': 'ssv',
        'ssx': 'ssx',
        'ssx-Latn-PG': 'ssx',
        'ssx-Latn': 'ssx',
        'ssx-PG': 'ssx',
        'ssy': 'ssy',
        'ssy-Latn-ER': 'ssy',
        'ssy-ER': 'ssy',
        'ssy-Latn': 'ssy',
        'ssy-Ethi': 'ssy-Ethi',
        'ssy-Ethi-ET': 'ssy-Ethi',
        'ssy-ET': 'ssy-Ethi',
        'ssz': 'ssz',
        'ssz-Latn-PG': 'ssz',
        'ssz-Latn': 'ssz',
        'ssz-PG': 'ssz',
        'st': 'st',
        'st-Latn-ZA': 'st',
        'st-Latn': 'st',
        'st-ZA': 'st',
        'st-LS': 'st-LS',
        'st-Latn-LS': 'st-LS',
        'sta': 'sta',
        'sta-Latn-ZM': 'sta',
        'sta-Latn': 'sta',
        'sta-ZM': 'sta',
        'stb': 'stb',
        'stb-Latn-PH': 'stb',
        'stb-Latn': 'stb',
        'stb-PH': 'stb',
        'std': 'std',
        'std-Zyyy-IN': 'std',
        'std-IN': 'std',
        'std-Zyyy': 'std',
        'ste': 'ste',
        'ste-Latn-ID': 'ste',
        'ste-ID': 'ste',
        'ste-Latn': 'ste',
        'stf': 'stf',
        'stf-Latn-PG': 'stf',
        'stf-Latn': 'stf',
        'stf-PG': 'stf',
        'stg': 'stg',
        'stg-Latn-VN': 'stg',
        'stg-Latn': 'stg',
        'stg-VN': 'stg',
        'sth': 'sth',
        'sth-Latn-IE': 'sth',
        'sth-IE': 'sth',
        'sth-Latn': 'sth',
        'sti': 'sti',
        'sti-Latn-VN': 'sti',
        'sti-Latn': 'sti',
        'sti-VN': 'sti',
        'sti-KH': 'sti-KH',
        'sti-Latn-KH': 'sti-KH',
        'stj': 'stj',
        'stj-Latn-BF': 'stj',
        'stj-BF': 'stj',
        'stj-Latn': 'stj',
        'stk': 'stk',
        'stk-Latn-PG': 'stk',
        'stk-Latn': 'stk',
        'stk-PG': 'stk',
        'stl': 'stl',
        'stl-Latn-NL': 'stl',
        'stl-Latn': 'stl',
        'stl-NL': 'stl',
        'stm': 'stm',
        'stm-Latn-PG': 'stm',
        'stm-Latn': 'stm',
        'stm-PG': 'stm',
        'stn': 'stn',
        'stn-Latn-SB': 'stn',
        'stn-Latn': 'stn',
        'stn-SB': 'stn',
        'sto': 'sto',
        'sto-Latn-CA': 'sto',
        'sto-CA': 'sto',
        'sto-Latn': 'sto',
        'stp': 'stp',
        'stp-Latn-MX': 'stp',
        'stp-Latn': 'stp',
        'stp-MX': 'stp',
        'stq': 'stq',
        'stq-Latn-DE': 'stq',
        'stq-DE': 'stq',
        'stq-Latn': 'stq',
        'str': 'str',
        'str-Latn-CA': 'str',
        'str-CA': 'str',
        'str-Latn': 'str',
        'sts': 'sts',
        'sts-Arab-AF': 'sts',
        'sts-AF': 'sts',
        'sts-Arab': 'sts',
        'stt': 'stt',
        'stt-Latn-VN': 'stt',
        'stt-Latn': 'stt',
        'stt-VN': 'stt',
        'stu': 'stu',
        'stu-Zyyy-MM': 'stu',
        'stu-MM': 'stu',
        'stu-Zyyy': 'stu',
        'stv': 'stv',
        'stv-Ethi-ET': 'stv',
        'stv-ET': 'stv',
        'stv-Ethi': 'stv',
        'stv-Arab': 'stv-Arab',
        'stv-Arab-ET': 'stv-Arab',
        'stw': 'stw',
        'stw-Latn-FM': 'stw',
        'stw-FM': 'stw',
        'stw-Latn': 'stw',
        'sty': 'sty',
        'sty-Cyrl-RU': 'sty',
        'sty-Cyrl': 'sty',
        'sty-RU': 'sty',
        'su': 'su',
        'su-Latn-ID': 'su',
        'su-ID': 'su',
        'su-Latn': 'su',
        'su-Arab': 'su-Arab',
        'su-Arab-ID': 'su-Arab',
        'su-Java': 'su-Java',
        'su-Java-ID': 'su-Java',
        'su-Sund': 'su-Sund',
        'su-Sund-ID': 'su-Sund',
        'sua': 'sua',
        'sua-Latn-PG': 'sua',
        'sua-Latn': 'sua',
        'sua-PG': 'sua',
        'sub': 'sub',
        'sub-Latn-CD': 'sub',
        'sub-CD': 'sub',
        'sub-Latn': 'sub',
        'suc': 'suc',
        'suc-Latn-PH': 'suc',
        'suc-Latn': 'suc',
        'suc-PH': 'suc',
        'sue': 'sue',
        'sue-Latn-PG': 'sue',
        'sue-Latn': 'sue',
        'sue-PG': 'sue',
        'sug': 'sug',
        'sug-Latn-PG': 'sug',
        'sug-Latn': 'sug',
        'sug-PG': 'sug',
        'sui': 'sui',
        'sui-Latn-PG': 'sui',
        'sui-Latn': 'sui',
        'sui-PG': 'sui',
        'suj': 'suj',
        'suj-Latn-TZ': 'suj',
        'suj-Latn': 'suj',
        'suj-TZ': 'suj',
        'xsj': 'suj',
        'xsj-Latn': 'suj',
        'xsj-Latn-TZ': 'suj',
        'xsj-TZ': 'suj',
        'suk': 'suk',
        'suk-Latn-TZ': 'suk',
        'suk-Latn': 'suk',
        'suk-TZ': 'suk',
        'suq': 'suq',
        'suq-Latn-ET': 'suq',
        'suq-ET': 'suq',
        'suq-Latn': 'suq',
        'suq-Ethi': 'suq-Ethi',
        'suq-Ethi-ET': 'suq-Ethi',
        'sur': 'sur',
        'sur-Latn-NG': 'sur',
        'sur-Latn': 'sur',
        'sur-NG': 'sur',
        'sus': 'sus',
        'sus-Latn-GN': 'sus',
        'sus-GN': 'sus',
        'sus-Latn': 'sus',
        'sus-Arab': 'sus-Arab',
        'sus-Arab-GN': 'sus-Arab',
        'sut': 'sut',
        'sut-Latn-NI': 'sut',
        'sut-Latn': 'sut',
        'sut-NI': 'sut',
        'suv': 'suv',
        'suv-Latn-IN': 'suv',
        'suv-IN': 'suv',
        'suv-Latn': 'suv',
        'suv-Beng': 'suv-Beng',
        'suv-Beng-IN': 'suv-Beng',
        'suv-Deva': 'suv-Deva',
        'suv-Deva-IN': 'suv-Deva',
        'suw': 'suw',
        'suw-Latn-TZ': 'suw',
        'suw-Latn': 'suw',
        'suw-TZ': 'suw',
        'sux': 'sux',
        'sux-Zyyy-XX': 'sux',
        'sux-XX': 'sux',
        'sux-Zyyy': 'sux',
        'suy': 'suy',
        'suy-Latn-BR': 'suy',
        'suy-BR': 'suy',
        'suy-Latn': 'suy',
        'suz': 'suz',
        'suz-Deva-NP': 'suz',
        'suz-Deva': 'suz',
        'suz-NP': 'suz',
        'sv': 'sv',
        'sv-Latn-SE': 'sv',
        'sv-Latn': 'sv',
        'sv-SE': 'sv',
        'sv-Brai': 'sv-Brai',
        'sv-Brai-SE': 'sv-Brai',
        'sv-FI': 'sv-FI',
        'sv-Latn-FI': 'sv-FI',
        'sva': 'sva',
        'sva-Geor-GE': 'sva',
        'sva-GE': 'sva',
        'sva-Geor': 'sva',
        'sva-Cyrl': 'sva-Cyrl',
        'sva-Cyrl-GE': 'sva-Cyrl',
        'sva-Latn': 'sva-Latn',
        'sva-Latn-GE': 'sva-Latn',
        'svb': 'svb',
        'svb-Latn-PG': 'svb',
        'svb-Latn': 'svb',
        'svb-PG': 'svb',
        'svc': 'svc',
        'svc-Latn-VC': 'svc',
        'svc-Latn': 'svc',
        'svc-VC': 'svc',
        'sve': 'sve',
        'sve-Latn-ID': 'sve',
        'sve-ID': 'sve',
        'sve-Latn': 'sve',
        'svk': 'svk',
        'svk-Zxxx-SK': 'svk',
        'sgn-svk': 'svk',
        'sgn-svk-SK': 'svk',
        'svk-SK': 'svk',
        'svk-Zxxx': 'svk',
        'svm': 'svm',
        'svm-Latn-IT': 'svm',
        'svm-IT': 'svm',
        'svm-Latn': 'svm',
        'svs': 'svs',
        'svs-Latn-SB': 'svs',
        'svs-Latn': 'svs',
        'svs-SB': 'svs',
        'svx': 'svx',
        'svx-Zyyy-XX': 'svx',
        'svx-XX': 'svx',
        'svx-Zyyy': 'svx',
        'sw': 'sw',
        'sw-Latn-TZ': 'sw',
        'sw-Latn': 'sw',
        'sw-TZ': 'sw',
        'sw-swh': 'sw',
        'sw-swh-TZ': 'sw',
        'swh': 'sw',
        'swh-Latn': 'sw',
        'swh-Latn-TZ': 'sw',
        'swh-TZ': 'sw',
        'sw-Arab': 'sw-Arab',
        'sw-Arab-TZ': 'sw-Arab',
        'sw-CD': 'sw-CD',
        'sw-Latn-CD': 'sw-CD',
        'sw-KE': 'sw-KE',
        'sw-Latn-KE': 'sw-KE',
        'sw-UG': 'sw-UG',
        'sw-Latn-UG': 'sw-UG',
        'swb': 'swb',
        'swb-Arab-YT': 'swb',
        'swb-Arab': 'swb',
        'swb-YT': 'swb',
        'swb-Latn': 'swb-Latn',
        'swb-Latn-YT': 'swb-Latn',
        'swc': 'swc',
        'swc-Latn-CD': 'swc',
        'sw-swc': 'swc',
        'sw-swc-CD': 'swc',
        'swc-CD': 'swc',
        'swc-Latn': 'swc',
        'swc-Arab': 'swc-Arab',
        'swc-Arab-CD': 'swc-Arab',
        'swf': 'swf',
        'swf-Latn-CD': 'swf',
        'swf-CD': 'swf',
        'swf-Latn': 'swf',
        'swg': 'swg',
        'swg-Latn-DE': 'swg',
        'swg-DE': 'swg',
        'swg-Latn': 'swg',
        'swh-Arab': 'swh-Arab',
        'swh-Arab-TZ': 'swh-Arab',
        'swh-Brai': 'swh-Brai',
        'swh-Brai-TZ': 'swh-Brai',
        'swi': 'swi',
        'swi-Hani-CN': 'swi',
        'swi-CN': 'swi',
        'swi-Hani': 'swi',
        'swj': 'swj',
        'swj-Latn-GA': 'swj',
        'swj-GA': 'swj',
        'swj-Latn': 'swj',
        'swk': 'swk',
        'swk-Latn-MW': 'swk',
        'swk-Latn': 'swk',
        'swk-MW': 'swk',
        'swl': 'swl',
        'swl-Zxxx-SE': 'swl',
        'sgn-swl': 'swl',
        'sgn-swl-SE': 'swl',
        'swl-SE': 'swl',
        'swl-Zxxx': 'swl',
        'swm': 'swm',
        'swm-Latn-PG': 'swm',
        'swm-Latn': 'swm',
        'swm-PG': 'swm',
        'swn': 'swn',
        'swn-Zyyy-LY': 'swn',
        'swn-LY': 'swn',
        'swn-Zyyy': 'swn',
        'swo': 'swo',
        'swo-Latn-BR': 'swo',
        'swo-BR': 'swo',
        'swo-Latn': 'swo',
        'swp': 'swp',
        'swp-Latn-PG': 'swp',
        'swp-Latn': 'swp',
        'swp-PG': 'swp',
        'swq': 'swq',
        'swq-Latn-CM': 'swq',
        'swq-CM': 'swq',
        'swq-Latn': 'swq',
        'swr': 'swr',
        'swr-Latn-ID': 'swr',
        'swr-ID': 'swr',
        'swr-Latn': 'swr',
        'sws': 'sws',
        'sws-Latn-ID': 'sws',
        'sws-ID': 'sws',
        'sws-Latn': 'sws',
        'swt': 'swt',
        'swt-Latn-ID': 'swt',
        'swt-ID': 'swt',
        'swt-Latn': 'swt',
        'swu': 'swu',
        'swu-Latn-ID': 'swu',
        'swu-ID': 'swu',
        'swu-Latn': 'swu',
        'swv': 'swv',
        'swv-Deva-IN': 'swv',
        'swv-Deva': 'swv',
        'swv-IN': 'swv',
        'sww': 'sww',
        'sww-Latn-VU': 'sww',
        'sww-Latn': 'sww',
        'sww-VU': 'sww',
        'swx': 'swx',
        'swx-Latn-BR': 'swx',
        'swx-BR': 'swx',
        'swx-Latn': 'swx',
        'swy': 'swy',
        'swy-Latn-TD': 'swy',
        'swy-Latn': 'swy',
        'swy-TD': 'swy',
        'sxb': 'sxb',
        'sxb-Latn-KE': 'sxb',
        'sxb-KE': 'sxb',
        'sxb-Latn': 'sxb',
        'sxc': 'sxc',
        'sxc-Zyyy-XX': 'sxc',
        'sxc-XX': 'sxc',
        'sxc-Zyyy': 'sxc',
        'sxe': 'sxe',
        'sxe-Latn-GA': 'sxe',
        'sxe-GA': 'sxe',
        'sxe-Latn': 'sxe',
        'sxg': 'sxg',
        'sxg-Zyyy-CN': 'sxg',
        'sxg-CN': 'sxg',
        'sxg-Zyyy': 'sxg',
        'sxk': 'sxk',
        'sxk-Zyyy-XX': 'sxk',
        'sxk-XX': 'sxk',
        'sxk-Zyyy': 'sxk',
        'sxl': 'sxl',
        'sxl-Zyyy-XX': 'sxl',
        'sxl-XX': 'sxl',
        'sxl-Zyyy': 'sxl',
        'sxm': 'sxm',
        'sxm-Zyyy-KH': 'sxm',
        'sxm-KH': 'sxm',
        'sxm-Zyyy': 'sxm',
        'sxn': 'sxn',
        'sxn-Latn-ID': 'sxn',
        'sxn-ID': 'sxn',
        'sxn-Latn': 'sxn',
        'sxo': 'sxo',
        'sxo-Zyyy-XX': 'sxo',
        'sxo-XX': 'sxo',
        'sxo-Zyyy': 'sxo',
        'sxr': 'sxr',
        'sxr-Zyyy-TW': 'sxr',
        'sxr-TW': 'sxr',
        'sxr-Zyyy': 'sxr',
        'sxs': 'sxs',
        'sxs-Latn-NG': 'sxs',
        'sxs-Latn': 'sxs',
        'sxs-NG': 'sxs',
        'sxu': 'sxu',
        'sxu-Latn-DE': 'sxu',
        'sxu-DE': 'sxu',
        'sxu-Latn': 'sxu',
        'sxw': 'sxw',
        'sxw-Latn-BJ': 'sxw',
        'sxw-BJ': 'sxw',
        'sxw-Latn': 'sxw',
        'sya': 'sya',
        'sya-Latn-ID': 'sya',
        'sya-ID': 'sya',
        'sya-Latn': 'sya',
        'syb': 'syb',
        'syb-Latn-PH': 'syb',
        'syb-Latn': 'syb',
        'syb-PH': 'syb',
        'syc': 'syc',
        'syc-Syrc-TR': 'syc',
        'syc-Syrc': 'syc',
        'syc-TR': 'syc',
        'syi': 'syi',
        'syi-Latn-GA': 'syi',
        'syi-GA': 'syi',
        'syi-Latn': 'syi',
        'syk': 'syk',
        'syk-Latn-NG': 'syk',
        'syk-Latn': 'syk',
        'syk-NG': 'syk',
        'syl': 'syl',
        'syl-Beng-BD': 'syl',
        'syl-BD': 'syl',
        'syl-Beng': 'syl',
        'syl-Latn': 'syl-Latn',
        'syl-Latn-BD': 'syl-Latn',
        'syl-Sylo': 'syl-Sylo',
        'syl-Sylo-BD': 'syl-Sylo',
        'sym': 'sym',
        'sym-Latn-BF': 'sym',
        'sym-BF': 'sym',
        'sym-Latn': 'sym',
        'syn': 'syn',
        'syn-Syrc-IR': 'syn',
        'syn-IR': 'syn',
        'syn-Syrc': 'syn',
        'syo': 'syo',
        'syo-Latn-KH': 'syo',
        'syo-KH': 'syo',
        'syo-Latn': 'syo',
        'syr': 'syr',
        'syr-Syrc-IQ': 'syr',
        'cld': 'syr',
        'cld-IQ': 'syr',
        'cld-Syrc': 'syr',
        'cld-Syrc-IQ': 'syr',
        'syr-IQ': 'syr',
        'syr-Syrc': 'syr',
        'sys': 'sys',
        'sys-Latn-TD': 'sys',
        'sys-Latn': 'sys',
        'sys-TD': 'sys',
        'syw': 'syw',
        'syw-Deva-NP': 'syw',
        'syw-Deva': 'syw',
        'syw-NP': 'syw',
        'syx': 'syx',
        'syx-Latn-GA': 'syx',
        'syx-GA': 'syx',
        'syx-Latn': 'syx',
        'syy': 'syy',
        'syy-Zxxx-IL': 'syy',
        'sgn-syy': 'syy',
        'sgn-syy-IL': 'syy',
        'syy-IL': 'syy',
        'syy-Zxxx': 'syy',
        'sza': 'sza',
        'sza-Latn-MY': 'sza',
        'sza-Latn': 'sza',
        'sza-MY': 'sza',
        'szb': 'szb',
        'szb-Latn-ID': 'szb',
        'szb-ID': 'szb',
        'szb-Latn': 'szb',
        'szc': 'szc',
        'szc-Latn-MY': 'szc',
        'szc-Latn': 'szc',
        'szc-MY': 'szc',
        'szd': 'szd',
        'szd-Latn-MY': 'szd',
        'szd-Latn': 'szd',
        'szd-MY': 'szd',
        'sze': 'sze',
        'sze-Zyyy-ET': 'sze',
        'sze-ET': 'sze',
        'sze-Zyyy': 'sze',
        'szg': 'szg',
        'szg-Latn-CD': 'szg',
        'szg-CD': 'szg',
        'szg-Latn': 'szg',
        'szl': 'szl',
        'szl-Latn-PL': 'szl',
        'szl-Latn': 'szl',
        'szl-PL': 'szl',
        'szn': 'szn',
        'szn-Latn-ID': 'szn',
        'szn-ID': 'szn',
        'szn-Latn': 'szn',
        'szp': 'szp',
        'szp-Latn-ID': 'szp',
        'szp-ID': 'szp',
        'szp-Latn': 'szp',
        'szs': 'szs',
        'szs-Latn-SB': 'szs',
        'sgn-szs': 'szs',
        'sgn-szs-SB': 'szs',
        'szs-Latn': 'szs',
        'szs-SB': 'szs',
        'szs-Zxxx': 'szs-Zxxx',
        'szs-Zxxx-SB': 'szs-Zxxx',
        'szv': 'szv',
        'szv-Latn-CM': 'szv',
        'szv-CM': 'szv',
        'szv-Latn': 'szv',
        'szw': 'szw',
        'szw-Latn-ID': 'szw',
        'szw-ID': 'szw',
        'szw-Latn': 'szw',
        'szy': 'szy',
        'szy-Latn-TW': 'szy',
        'szy-Latn': 'szy',
        'szy-TW': 'szy',
        'ta': 'ta',
        'ta-Taml-IN': 'ta',
        'ta-IN': 'ta',
        'ta-Taml': 'ta',
        'ta-Brai': 'ta-Brai',
        'ta-Brai-IN': 'ta-Brai',
        'ta-LK': 'ta-LK',
        'ta-Taml-LK': 'ta-LK',
        'ta-MY': 'ta-MY',
        'ta-Taml-MY': 'ta-MY',
        'ta-SG': 'ta-SG',
        'ta-Taml-SG': 'ta-SG',
        'taa': 'taa',
        'taa-Latn-US': 'taa',
        'taa-Latn': 'taa',
        'taa-US': 'taa',
        'tab': 'tab',
        'tab-Cyrl-RU': 'tab',
        'tab-Cyrl': 'tab',
        'tab-RU': 'tab',
        'tac': 'tac',
        'tac-Latn-MX': 'tac',
        'tac-Latn': 'tac',
        'tac-MX': 'tac',
        'tad': 'tad',
        'tad-Latn-ID': 'tad',
        'tad-ID': 'tad',
        'tad-Latn': 'tad',
        'tae': 'tae',
        'tae-Latn-BR': 'tae',
        'tae-BR': 'tae',
        'tae-Latn': 'tae',
        'taf': 'taf',
        'taf-Latn-BR': 'taf',
        'taf-BR': 'taf',
        'taf-Latn': 'taf',
        'tag': 'tag',
        'tag-Zyyy-SD': 'tag',
        'tag-SD': 'tag',
        'tag-Zyyy': 'tag',
        'taj': 'taj',
        'taj-Deva-NP': 'taj',
        'taj-Deva': 'taj',
        'taj-NP': 'taj',
        'tsf': 'taj',
        'tsf-Deva': 'taj',
        'tsf-Deva-NP': 'taj',
        'tsf-NP': 'taj',
        'taj-Tibt': 'taj-Tibt',
        'taj-Tibt-BT': 'taj-Tibt',
        'taj-BT': 'taj-Tibt',
        'tsf-BT': 'taj-Tibt',
        'taj-Tibt-x-tamhig': 'taj-Tibt-x-tamhig',
        'taj-Tibt-BT-x-tamhig': 'taj-Tibt-x-tamhig',
        'taj-BT-x-tamhig': 'taj-Tibt-x-tamhig',
        'tsf-BT-x-tamhig': 'taj-Tibt-x-tamhig',
        'tak': 'tak',
        'tak-Latn-NG': 'tak',
        'tak-Latn': 'tak',
        'tak-NG': 'tak',
        'tal': 'tal',
        'tal-Latn-NG': 'tal',
        'tal-Latn': 'tal',
        'tal-NG': 'tal',
        'tan': 'tan',
        'tan-Latn-NG': 'tan',
        'tan-Latn': 'tan',
        'tan-NG': 'tan',
        'tao': 'tao',
        'tao-Latn-TW': 'tao',
        'tao-Latn': 'tao',
        'tao-TW': 'tao',
        'tap': 'tap',
        'tap-Latn-CD': 'tap',
        'tap-CD': 'tap',
        'tap-Latn': 'tap',
        'taq-Latn': 'taq-Latn',
        'taq-Latn-ML': 'taq-Latn',
        'taq-Tfng': 'taq-Tfng',
        'taq-Tfng-ML': 'taq-Tfng',
        'tar': 'tar',
        'tar-Latn-MX': 'tar',
        'tar-Latn': 'tar',
        'tar-MX': 'tar',
        'tas': 'tas',
        'tas-Latn-VN': 'tas',
        'tas-Latn': 'tas',
        'tas-VN': 'tas',
        'tau': 'tau',
        'tau-Latn-US': 'tau',
        'tau-Latn': 'tau',
        'tau-US': 'tau',
        'tav': 'tav',
        'tav-Latn-CO': 'tav',
        'tav-CO': 'tav',
        'tav-Latn': 'tav',
        'taw': 'taw',
        'taw-Latn-PG': 'taw',
        'taw-Latn': 'taw',
        'taw-PG': 'taw',
        'tax': 'tax',
        'tax-Latn-TD': 'tax',
        'tax-Latn': 'tax',
        'tax-TD': 'tax',
        'tay': 'tay',
        'tay-Latn-TW': 'tay',
        'tay-Latn': 'tay',
        'tay-TW': 'tay',
        'tay-Hans': 'tay-Hans',
        'tay-Hans-TW': 'tay-Hans',
        'tay-Hant': 'tay-Hant',
        'tay-Hant-TW': 'tay-Hant',
        'taz': 'taz',
        'taz-Latn-SD': 'taz',
        'taz-Latn': 'taz',
        'taz-SD': 'taz',
        'tba': 'tba',
        'tba-Latn-BR': 'tba',
        'tba-BR': 'tba',
        'tba-Latn': 'tba',
        'tbb': 'tbb',
        'tbb-Latn-BR': 'tbb',
        'tbb-BR': 'tbb',
        'tbb-Latn': 'tbb',
        'tbc': 'tbc',
        'tbc-Latn-PG': 'tbc',
        'tbc-Latn': 'tbc',
        'tbc-PG': 'tbc',
        'tbd': 'tbd',
        'tbd-Latn-PG': 'tbd',
        'tbd-Latn': 'tbd',
        'tbd-PG': 'tbd',
        'tbe': 'tbe',
        'tbe-Latn-SB': 'tbe',
        'tbe-Latn': 'tbe',
        'tbe-SB': 'tbe',
        'tbf': 'tbf',
        'tbf-Latn-PG': 'tbf',
        'tbf-Latn': 'tbf',
        'tbf-PG': 'tbf',
        'tbg': 'tbg',
        'tbg-Latn-PG': 'tbg',
        'tbg-Latn': 'tbg',
        'tbg-PG': 'tbg',
        'tbh': 'tbh',
        'tbh-Latn-AU': 'tbh',
        'tbh-AU': 'tbh',
        'tbh-Latn': 'tbh',
        'tbi': 'tbi',
        'tbi-Latn-SD': 'tbi',
        'tbi-Latn': 'tbi',
        'tbi-SD': 'tbi',
        'tbj': 'tbj',
        'tbj-Latn-PG': 'tbj',
        'tbj-Latn': 'tbj',
        'tbj-PG': 'tbj',
        'tbk': 'tbk',
        'tbk-Tagb-PH': 'tbk',
        'tbk-PH': 'tbk',
        'tbk-Tagb': 'tbk',
        'tbk-Latn': 'tbk-Latn',
        'tbk-Latn-PH': 'tbk-Latn',
        'tbl': 'tbl',
        'tbl-Latn-PH': 'tbl',
        'tbl-Latn': 'tbl',
        'tbl-PH': 'tbl',
        'tbm': 'tbm',
        'tbm-Latn-CD': 'tbm',
        'tbm-CD': 'tbm',
        'tbm-Latn': 'tbm',
        'tbn': 'tbn',
        'tbn-Latn-CO': 'tbn',
        'tbn-CO': 'tbn',
        'tbn-Latn': 'tbn',
        'tbo': 'tbo',
        'tbo-Latn-PG': 'tbo',
        'tbo-Latn': 'tbo',
        'tbo-PG': 'tbo',
        'tbp': 'tbp',
        'tbp-Latn-ID': 'tbp',
        'tbp-ID': 'tbp',
        'tbp-Latn': 'tbp',
        'tbr': 'tbr',
        'tbr-Zyyy-SD': 'tbr',
        'tbr-SD': 'tbr',
        'tbr-Zyyy': 'tbr',
        'tbs': 'tbs',
        'tbs-Latn-PG': 'tbs',
        'tbs-Latn': 'tbs',
        'tbs-PG': 'tbs',
        'tbt': 'tbt',
        'tbt-Latn-CD': 'tbt',
        'tbt-CD': 'tbt',
        'tbt-Latn': 'tbt',
        'tbu': 'tbu',
        'tbu-Latn-MX': 'tbu',
        'tbu-Latn': 'tbu',
        'tbu-MX': 'tbu',
        'tbv': 'tbv',
        'tbv-Latn-PG': 'tbv',
        'tbv-Latn': 'tbv',
        'tbv-PG': 'tbv',
        'tbw': 'tbw',
        'tbw-Latn-PH': 'tbw',
        'tbw-Latn': 'tbw',
        'tbw-PH': 'tbw',
        'tbw-Tagb': 'tbw-Tagb',
        'tbw-Tagb-PH': 'tbw-Tagb',
        'tbx': 'tbx',
        'tbx-Latn-PG': 'tbx',
        'tbx-Latn': 'tbx',
        'tbx-PG': 'tbx',
        'tby': 'tby',
        'tby-Latn-ID': 'tby',
        'tby-ID': 'tby',
        'tby-Latn': 'tby',
        'tbz': 'tbz',
        'tbz-Latn-BJ': 'tbz',
        'tbz-BJ': 'tbz',
        'tbz-Latn': 'tbz',
        'tca': 'tca',
        'tca-Latn-BR': 'tca',
        'tca-BR': 'tca',
        'tca-Latn': 'tca',
        'tcb': 'tcb',
        'tcb-Latn-US': 'tcb',
        'tcb-Latn': 'tcb',
        'tcb-US': 'tcb',
        'tcc': 'tcc',
        'tcc-Latn-TZ': 'tcc',
        'tcc-Latn': 'tcc',
        'tcc-TZ': 'tcc',
        'tcd': 'tcd',
        'tcd-Latn-GH': 'tcd',
        'tcd-GH': 'tcd',
        'tcd-Latn': 'tcd',
        'tce': 'tce',
        'tce-Latn-CA': 'tce',
        'tce-CA': 'tce',
        'tce-Latn': 'tce',
        'tcf': 'tcf',
        'tcf-Latn-MX': 'tcf',
        'tcf-Latn': 'tcf',
        'tcf-MX': 'tcf',
        'tcg': 'tcg',
        'tcg-Latn-ID': 'tcg',
        'tcg-ID': 'tcg',
        'tcg-Latn': 'tcg',
        'tch': 'tch',
        'tch-Latn-TC': 'tch',
        'tch-Latn': 'tch',
        'tch-TC': 'tch',
        'tci': 'tci',
        'tci-Latn-PG': 'tci',
        'tci-Latn': 'tci',
        'tci-PG': 'tci',
        'tck': 'tck',
        'tck-Latn-GA': 'tck',
        'tck-GA': 'tck',
        'tck-Latn': 'tck',
        'tcl': 'tcl',
        'tcl-Zyyy-MM': 'tcl',
        'tcl-MM': 'tcl',
        'tcl-Zyyy': 'tcl',
        'tcm': 'tcm',
        'tcm-Latn-ID': 'tcm',
        'tcm-ID': 'tcm',
        'tcm-Latn': 'tcm',
        'tcn': 'tcn',
        'tcn-Zyyy-NP': 'tcn',
        'tcn-NP': 'tcn',
        'tcn-Zyyy': 'tcn',
        'tco': 'tco',
        'tco-Zyyy-MM': 'tco',
        'tco-MM': 'tco',
        'tco-Zyyy': 'tco',
        'tcp': 'tcp',
        'tcp-Latn-MM': 'tcp',
        'tcp-Latn': 'tcp',
        'tcp-MM': 'tcp',
        'tcq': 'tcq',
        'tcq-Latn-ID': 'tcq',
        'tcq-ID': 'tcq',
        'tcq-Latn': 'tcq',
        'tcs': 'tcs',
        'tcs-Latn-AU': 'tcs',
        'tcs-AU': 'tcs',
        'tcs-Latn': 'tcs',
        'tct': 'tct',
        'tct-Zyyy-CN': 'tct',
        'tct-CN': 'tct',
        'tct-Zyyy': 'tct',
        'tcu': 'tcu',
        'tcu-Latn-MX': 'tcu',
        'tcu-Latn': 'tcu',
        'tcu-MX': 'tcu',
        'tcw': 'tcw',
        'tcw-Latn-MX': 'tcw',
        'tcw-Latn': 'tcw',
        'tcw-MX': 'tcw',
        'tcx': 'tcx',
        'tcx-Taml-IN': 'tcx',
        'tcx-IN': 'tcx',
        'tcx-Taml': 'tcx',
        'tcy': 'tcy',
        'tcy-Knda-IN': 'tcy',
        'tcy-IN': 'tcy',
        'tcy-Knda': 'tcy',
        'tcy-Zzzz-x-tulu': 'tcy-Zzzz-x-tulu',
        'tcy-Zzzz-IN-x-tulu': 'tcy-Zzzz-x-tulu',
        'tcy-IN-x-tulu': 'tcy-Zzzz-x-tulu',
        'tcz': 'tcz',
        'tcz-Latn-IN': 'tcz',
        'tcz-IN': 'tcz',
        'tcz-Latn': 'tcz',
        'tda-Arab': 'tda-Arab',
        'tda-Arab-NE': 'tda-Arab',
        'tda-Latn': 'tda-Latn',
        'tda-Latn-NE': 'tda-Latn',
        'tda-Tfng': 'tda-Tfng',
        'tda-Tfng-NE': 'tda-Tfng',
        'tdb': 'tdb',
        'tdb-Deva-IN': 'tdb',
        'tdb-Deva': 'tdb',
        'tdb-IN': 'tdb',
        'tdb-Beng': 'tdb-Beng',
        'tdb-Beng-IN': 'tdb-Beng',
        'tdb-Kthi': 'tdb-Kthi',
        'tdb-Kthi-IN': 'tdb-Kthi',
        'tdc': 'tdc',
        'tdc-Latn-CO': 'tdc',
        'tdc-CO': 'tdc',
        'tdc-Latn': 'tdc',
        'tdd': 'tdd',
        'tdd-Tale-CN': 'tdd',
        'tdd-CN': 'tdd',
        'tdd-Tale': 'tdd',
        'tdd-MM': 'tdd-MM',
        'tdd-Tale-MM': 'tdd-MM',
        'tde': 'tde',
        'tde-Latn-ML': 'tde',
        'tde-Latn': 'tde',
        'tde-ML': 'tde',
        'tdf': 'tdf',
        'tdf-Zyyy-LA': 'tdf',
        'kgc': 'tdf',
        'kgc-LA': 'tdf',
        'kgc-Zyyy': 'tdf',
        'kgc-Zyyy-LA': 'tdf',
        'tdf-LA': 'tdf',
        'tdf-Zyyy': 'tdf',
        'tdg': 'tdg',
        'tdg-Deva-NP': 'tdg',
        'tdg-Deva': 'tdg',
        'tdg-NP': 'tdg',
        'tdg-Tibt': 'tdg-Tibt',
        'tdg-Tibt-NP': 'tdg-Tibt',
        'tdh': 'tdh',
        'tdh-Deva-NP': 'tdh',
        'tdh-Deva': 'tdh',
        'tdh-NP': 'tdh',
        'tdi': 'tdi',
        'tdi-Latn-ID': 'tdi',
        'tdi-ID': 'tdi',
        'tdi-Latn': 'tdi',
        'tdj': 'tdj',
        'tdj-Latn-ID': 'tdj',
        'tdj-ID': 'tdj',
        'tdj-Latn': 'tdj',
        'tdk': 'tdk',
        'tdk-Latn-NG': 'tdk',
        'tdk-Latn': 'tdk',
        'tdk-NG': 'tdk',
        'tdl': 'tdl',
        'tdl-Latn-NG': 'tdl',
        'tdl-Latn': 'tdl',
        'tdl-NG': 'tdl',
        'tdm': 'tdm',
        'tdm-Latn-GY': 'tdm',
        'tdm-GY': 'tdm',
        'tdm-Latn': 'tdm',
        'tdn': 'tdn',
        'tdn-Latn-ID': 'tdn',
        'tdn-ID': 'tdn',
        'tdn-Latn': 'tdn',
        'tdo': 'tdo',
        'tdo-Latn-NG': 'tdo',
        'tdo-Latn': 'tdo',
        'tdo-NG': 'tdo',
        'tdq': 'tdq',
        'tdq-Latn-NG': 'tdq',
        'tdq-Latn': 'tdq',
        'tdq-NG': 'tdq',
        'tdr': 'tdr',
        'tdr-Latn-VN': 'tdr',
        'tdr-Latn': 'tdr',
        'tdr-VN': 'tdr',
        'tds': 'tds',
        'tds-Latn-ID': 'tds',
        'tds-ID': 'tds',
        'tds-Latn': 'tds',
        'tdt': 'tdt',
        'tdt-Latn-TL': 'tdt',
        'tdt-Latn': 'tdt',
        'tdt-TL': 'tdt',
        'tdv': 'tdv',
        'tdv-Latn-NG': 'tdv',
        'tdv-Latn': 'tdv',
        'tdv-NG': 'tdv',
        'tdx': 'tdx',
        'tdx-Latn-MG': 'tdx',
        'tdx-Latn': 'tdx',
        'tdx-MG': 'tdx',
        'tdy': 'tdy',
        'tdy-Latn-PH': 'tdy',
        'tdy-Latn': 'tdy',
        'tdy-PH': 'tdy',
        'te': 'te',
        'te-Telu-IN': 'te',
        'te-IN': 'te',
        'te-Telu': 'te',
        'te-Brai': 'te-Brai',
        'te-Brai-IN': 'te-Brai',
        'tea': 'tea',
        'tea-Latn-MY': 'tea',
        'tea-Latn': 'tea',
        'tea-MY': 'tea',
        'teb': 'teb',
        'teb-Latn-EC': 'teb',
        'teb-EC': 'teb',
        'teb-Latn': 'teb',
        'tec': 'tec',
        'tec-Latn-KE': 'tec',
        'tec-KE': 'tec',
        'tec-Latn': 'tec',
        'ted': 'ted',
        'ted-Latn-CI': 'ted',
        'ted-CI': 'ted',
        'ted-Latn': 'ted',
        'tee': 'tee',
        'tee-Latn-MX': 'tee',
        'tee-Latn': 'tee',
        'tee-MX': 'tee',
        'tef': 'tef',
        'tef-Zyyy-IN': 'tef',
        'tef-IN': 'tef',
        'tef-Zyyy': 'tef',
        'teg': 'teg',
        'teg-Latn-GA': 'teg',
        'teg-GA': 'teg',
        'teg-Latn': 'teg',
        'teh': 'teh',
        'teh-Latn-AR': 'teh',
        'teh-AR': 'teh',
        'teh-Latn': 'teh',
        'tei': 'tei',
        'tei-Latn-PG': 'tei',
        'tei-Latn': 'tei',
        'tei-PG': 'tei',
        'tek': 'tek',
        'tek-Latn-CD': 'tek',
        'tek-CD': 'tek',
        'tek-Latn': 'tek',
        'tem': 'tem',
        'tem-Latn-SL': 'tem',
        'tem-Latn': 'tem',
        'tem-SL': 'tem',
        'ten': 'ten',
        'ten-Latn-CO': 'ten',
        'ten-CO': 'ten',
        'ten-Latn': 'ten',
        'teo': 'teo',
        'teo-Latn-UG': 'teo',
        'teo-Latn': 'teo',
        'teo-UG': 'teo',
        'teo-KE': 'teo-KE',
        'teo-Latn-KE': 'teo-KE',
        'tep': 'tep',
        'tep-Latn-MX': 'tep',
        'tep-Latn': 'tep',
        'tep-MX': 'tep',
        'teq': 'teq',
        'teq-Latn-SD': 'teq',
        'teq-Latn': 'teq',
        'teq-SD': 'teq',
        'ter': 'ter',
        'ter-Latn-BR': 'ter',
        'ter-BR': 'ter',
        'ter-Latn': 'ter',
        'tes': 'tes',
        'tes-Java-ID': 'tes',
        'tes-ID': 'tes',
        'tes-Java': 'tes',
        'tet': 'tet',
        'tet-Latn-TL': 'tet',
        'tet-Latn': 'tet',
        'tet-TL': 'tet',
        'teu': 'teu',
        'teu-Latn-UG': 'teu',
        'teu-Latn': 'teu',
        'teu-UG': 'teu',
        'tev': 'tev',
        'tev-Latn-ID': 'tev',
        'tev-ID': 'tev',
        'tev-Latn': 'tev',
        'tew': 'tew',
        'tew-Latn-US': 'tew',
        'tew-Latn': 'tew',
        'tew-US': 'tew',
        'tew-x-sanclara': 'tew-x-sanclara',
        'tew-Latn-US-x-sanclara': 'tew-x-sanclara',
        'tew-Latn-x-sanclara': 'tew-x-sanclara',
        'tew-US-x-sanclara': 'tew-x-sanclara',
        'tew-x-sanjuan': 'tew-x-sanjuan',
        'tew-Latn-US-x-sanjuan': 'tew-x-sanjuan',
        'tew-Latn-x-sanjuan': 'tew-x-sanjuan',
        'tew-US-x-sanjuan': 'tew-x-sanjuan',
        'tex': 'tex',
        'tex-Latn-SS': 'tex',
        'tex-Latn': 'tex',
        'tex-SS': 'tex',
        'tey': 'tey',
        'tey-Latn-SD': 'tey',
        'tey-Latn': 'tey',
        'tey-SD': 'tey',
        'tez-Latn': 'tez-Latn',
        'tez-Latn-NE': 'tez-Latn',
        'tez-Tfng': 'tez-Tfng',
        'tez-Tfng-NE': 'tez-Tfng',
        'tfi': 'tfi',
        'tfi-Latn-BJ': 'tfi',
        'tfi-BJ': 'tfi',
        'tfi-Latn': 'tfi',
        'tfn': 'tfn',
        'tfn-Latn-US': 'tfn',
        'tfn-Latn': 'tfn',
        'tfn-US': 'tfn',
        'tfo': 'tfo',
        'tfo-Latn-ID': 'tfo',
        'tfo-ID': 'tfo',
        'tfo-Latn': 'tfo',
        'tfr': 'tfr',
        'tfr-Latn-PA': 'tfr',
        'tfr-Latn': 'tfr',
        'tfr-PA': 'tfr',
        'tft': 'tft',
        'tft-Latn-ID': 'tft',
        'tft-ID': 'tft',
        'tft-Latn': 'tft',
        'tg': 'tg',
        'tg-Cyrl-TJ': 'tg',
        'tg-Cyrl': 'tg',
        'tg-TJ': 'tg',
        'tg-Arab': 'tg-Arab',
        'tg-Arab-PK': 'tg-Arab',
        'tg-PK': 'tg-Arab',
        'tg-Hebr': 'tg-Hebr',
        'tg-Hebr-UZ': 'tg-Hebr',
        'tg-UZ': 'tg-Hebr',
        'tg-Latn': 'tg-Latn',
        'tg-Latn-TJ': 'tg-Latn',
        'tga': 'tga',
        'tga-Latn-KE': 'tga',
        'tga-KE': 'tga',
        'tga-Latn': 'tga',
        'tgb': 'tgb',
        'tgb-Latn-MY': 'tgb',
        'tgb-Latn': 'tgb',
        'tgb-MY': 'tgb',
        'tgc': 'tgc',
        'tgc-Latn-PG': 'tgc',
        'tgc-Latn': 'tgc',
        'tgc-PG': 'tgc',
        'tgd': 'tgd',
        'tgd-Latn-NG': 'tgd',
        'tgd-Latn': 'tgd',
        'tgd-NG': 'tgd',
        'tge': 'tge',
        'tge-Zyyy-NP': 'tge',
        'tge-NP': 'tge',
        'tge-Zyyy': 'tge',
        'tgf': 'tgf',
        'tgf-Zyyy-BT': 'tgf',
        'tgf-BT': 'tgf',
        'tgf-Zyyy': 'tgf',
        'tgh': 'tgh',
        'tgh-Latn-TT': 'tgh',
        'tgh-Latn': 'tgh',
        'tgh-TT': 'tgh',
        'tgi': 'tgi',
        'tgi-Latn-PG': 'tgi',
        'tgi-Latn': 'tgi',
        'tgi-PG': 'tgi',
        'tgj': 'tgj',
        'tgj-Latn-IN': 'tgj',
        'tgj-IN': 'tgj',
        'tgj-Latn': 'tgj',
        'tgn': 'tgn',
        'tgn-Latn-PH': 'tgn',
        'tgn-Latn': 'tgn',
        'tgn-PH': 'tgn',
        'tgo': 'tgo',
        'tgo-Latn-PG': 'tgo',
        'tgo-Latn': 'tgo',
        'tgo-PG': 'tgo',
        'tgp': 'tgp',
        'tgp-Latn-VU': 'tgp',
        'tgp-Latn': 'tgp',
        'tgp-VU': 'tgp',
        'tgq': 'tgq',
        'tgq-Latn-MY': 'tgq',
        'tgq-Latn': 'tgq',
        'tgq-MY': 'tgq',
        'tgr': 'tgr',
        'tgr-Zyyy-LA': 'tgr',
        'tgr-LA': 'tgr',
        'tgr-Zyyy': 'tgr',
        'tgs': 'tgs',
        'tgs-Latn-VU': 'tgs',
        'tgs-Latn': 'tgs',
        'tgs-VU': 'tgs',
        'tgt': 'tgt',
        'tgt-Latn-PH': 'tgt',
        'tgt-Latn': 'tgt',
        'tgt-PH': 'tgt',
        'tgu': 'tgu',
        'tgu-Latn-PG': 'tgu',
        'tgu-Latn': 'tgu',
        'tgu-PG': 'tgu',
        'tgv': 'tgv',
        'tgv-Latn-BR': 'tgv',
        'tgv-BR': 'tgv',
        'tgv-Latn': 'tgv',
        'tgw': 'tgw',
        'tgw-Latn-CI': 'tgw',
        'tgw-CI': 'tgw',
        'tgw-Latn': 'tgw',
        'tgx': 'tgx',
        'tgx-Latn-CA': 'tgx',
        'tgx-CA': 'tgx',
        'tgx-Latn': 'tgx',
        'tgy': 'tgy',
        'tgy-Latn-SS': 'tgy',
        'tgy-Latn': 'tgy',
        'tgy-SS': 'tgy',
        'tgz': 'tgz',
        'tgz-Latn-AU': 'tgz',
        'tgz-AU': 'tgz',
        'tgz-Latn': 'tgz',
        'th': 'th',
        'th-Thai-TH': 'th',
        'th-TH': 'th',
        'th-Thai': 'th',
        'th-Brai': 'th-Brai',
        'th-Brai-TH': 'th-Brai',
        'thd': 'thd',
        'thd-Latn-AU': 'thd',
        'thd-AU': 'thd',
        'thd-Latn': 'thd',
        'the': 'the',
        'the-Deva-NP': 'the',
        'the-Deva': 'the',
        'the-NP': 'the',
        'thf': 'thf',
        'thf-Deva-NP': 'thf',
        'thf-Deva': 'thf',
        'thf-NP': 'thf',
        'thh': 'thh',
        'thh-Latn-MX': 'thh',
        'thh-Latn': 'thh',
        'thh-MX': 'thh',
        'thi': 'thi',
        'thi-Zyyy-LA': 'thi',
        'thi-LA': 'thi',
        'thi-Zyyy': 'thi',
        'thk': 'thk',
        'thk-Latn-KE': 'thk',
        'thk-KE': 'thk',
        'thk-Latn': 'thk',
        'thl': 'thl',
        'thl-Deva-NP': 'thl',
        'thl-Deva': 'thl',
        'thl-NP': 'thl',
        'thm': 'thm',
        'thm-Zyyy-TH': 'thm',
        'thm-TH': 'thm',
        'thm-Zyyy': 'thm',
        'thn': 'thn',
        'thn-Zyyy-IN': 'thn',
        'thn-IN': 'thn',
        'thn-Zyyy': 'thn',
        'thp': 'thp',
        'thp-Latn-CA': 'thp',
        'thp-CA': 'thp',
        'thp-Latn': 'thp',
        'thp-Dupl': 'thp-Dupl',
        'thp-Dupl-CA': 'thp-Dupl',
        'thq': 'thq',
        'thq-Deva-NP': 'thq',
        'thq-Deva': 'thq',
        'thq-NP': 'thq',
        'thr': 'thr',
        'thr-Deva-NP': 'thr',
        'thr-Deva': 'thr',
        'thr-NP': 'thr',
        'ths': 'ths',
        'ths-Deva-NP': 'ths',
        'ths-Deva': 'ths',
        'ths-NP': 'ths',
        'tht': 'tht',
        'tht-Latn-CA': 'tht',
        'tht-CA': 'tht',
        'tht-Latn': 'tht',
        'thu': 'thu',
        'thu-Latn-SS': 'thu',
        'thu-Latn': 'thu',
        'thu-SS': 'thu',
        'thv-Arab': 'thv-Arab',
        'thv-Arab-DZ': 'thv-Arab',
        'thv-Latn': 'thv-Latn',
        'thv-Latn-DZ': 'thv-Latn',
        'thv-Latn-DZ-x-ahaggar': 'thv-Latn-DZ-x-ahaggar',
        'thv-Tfng': 'thv-Tfng',
        'thv-Tfng-DZ': 'thv-Tfng',
        'thw': 'thw',
        'thw-Zyyy-NP': 'thw',
        'thw-NP': 'thw',
        'thw-Zyyy': 'thw',
        'thy': 'thy',
        'thy-Latn-NG': 'thy',
        'thy-Latn': 'thy',
        'thy-NG': 'thy',
        'thz-Latn': 'thz-Latn',
        'thz-Latn-NE': 'thz-Latn',
        'thz-Tfng': 'thz-Tfng',
        'thz-Tfng-NE': 'thz-Tfng',
        'ti': 'ti',
        'ti-Ethi-ET': 'ti',
        'ti-ET': 'ti',
        'ti-Ethi': 'ti',
        'ti-Arab': 'ti-Arab',
        'ti-Arab-ET': 'ti-Arab',
        'ti-ER': 'ti-ER',
        'ti-Ethi-ER': 'ti-ER',
        'tia': 'tia',
        'tia-Zyyy-DZ': 'tia',
        'tia-DZ': 'tia',
        'tia-Zyyy': 'tia',
        'tic': 'tic',
        'tic-Latn-SD': 'tic',
        'tic-Latn': 'tic',
        'tic-SD': 'tic',
        'tif': 'tif',
        'tif-Latn-PG': 'tif',
        'tif-Latn': 'tif',
        'tif-PG': 'tif',
        'tig': 'tig',
        'tig-Ethi-ER': 'tig',
        'tig-ER': 'tig',
        'tig-Ethi': 'tig',
        'tig-SD': 'tig-SD',
        'tig-Latn-SD': 'tig-SD',
        'tig-Latn': 'tig-SD',
        'tih': 'tih',
        'tih-Latn-MY': 'tih',
        'tih-Latn': 'tih',
        'tih-MY': 'tih',
        'tii': 'tii',
        'tii-Latn-CD': 'tii',
        'tii-CD': 'tii',
        'tii-Latn': 'tii',
        'tij': 'tij',
        'tij-Deva-NP': 'tij',
        'tij-Deva': 'tij',
        'tij-NP': 'tij',
        'tik': 'tik',
        'tik-Latn-CM': 'tik',
        'tik-CM': 'tik',
        'tik-Latn': 'tik',
        'til': 'til',
        'til-Zyyy-US': 'til',
        'til-US': 'til',
        'til-Zyyy': 'til',
        'tim': 'tim',
        'tim-Latn-PG': 'tim',
        'tim-Latn': 'tim',
        'tim-PG': 'tim',
        'tin': 'tin',
        'tin-Cyrl-RU': 'tin',
        'tin-Cyrl': 'tin',
        'tin-RU': 'tin',
        'tio': 'tio',
        'tio-Latn-PG': 'tio',
        'tio-Latn': 'tio',
        'tio-PG': 'tio',
        'tip': 'tip',
        'tip-Latn-ID': 'tip',
        'tip-ID': 'tip',
        'tip-Latn': 'tip',
        'tiq': 'tiq',
        'tiq-Latn-BF': 'tiq',
        'tiq-BF': 'tiq',
        'tiq-Latn': 'tiq',
        'tis': 'tis',
        'tis-Latn-PH': 'tis',
        'tis-Latn': 'tis',
        'tis-PH': 'tis',
        'tit': 'tit',
        'tit-Latn-CO': 'tit',
        'tit-CO': 'tit',
        'tit-Latn': 'tit',
        'tiu': 'tiu',
        'tiu-Latn-PH': 'tiu',
        'tiu-Latn': 'tiu',
        'tiu-PH': 'tiu',
        'tiv': 'tiv',
        'tiv-Latn-NG': 'tiv',
        'tiv-Latn': 'tiv',
        'tiv-NG': 'tiv',
        'tiw': 'tiw',
        'tiw-Latn-AU': 'tiw',
        'tiw-AU': 'tiw',
        'tiw-Latn': 'tiw',
        'tix': 'tix',
        'tix-Latn-US': 'tix',
        'tix-Latn': 'tix',
        'tix-US': 'tix',
        'tiy': 'tiy',
        'tiy-Latn-PH': 'tiy',
        'tiy-Latn': 'tiy',
        'tiy-PH': 'tiy',
        'tiz': 'tiz',
        'tiz-Zyyy-CN': 'tiz',
        'tiz-CN': 'tiz',
        'tiz-Zyyy': 'tiz',
        'tja': 'tja',
        'tja-Latn-LR': 'tja',
        'tja-LR': 'tja',
        'tja-Latn': 'tja',
        'tjg': 'tjg',
        'tjg-Latn-ID': 'tjg',
        'tjg-ID': 'tjg',
        'tjg-Latn': 'tjg',
        'tji': 'tji',
        'tji-Zyyy-CN': 'tji',
        'tji-CN': 'tji',
        'tji-Zyyy': 'tji',
        'tjj': 'tjj',
        'tjj-Latn-AU': 'tjj',
        'tjj-AU': 'tjj',
        'tjj-Latn': 'tjj',
        'tjl': 'tjl',
        'tjl-Mymr-MM': 'tjl',
        'tjl-MM': 'tjl',
        'tjl-Mymr': 'tjl',
        'tjm': 'tjm',
        'tjm-Zyyy-XX': 'tjm',
        'tjm-XX': 'tjm',
        'tjm-Zyyy': 'tjm',
        'tjn': 'tjn',
        'tjn-Latn-CI': 'tjn',
        'tjn-CI': 'tjn',
        'tjn-Latn': 'tjn',
        'tjo': 'tjo',
        'tjo-Zyyy-DZ': 'tjo',
        'tjo-DZ': 'tjo',
        'tjo-Zyyy': 'tjo',
        'tjp': 'tjp',
        'tjp-Latn-AU': 'tjp',
        'tjp-AU': 'tjp',
        'tjp-Latn': 'tjp',
        'tjs': 'tjs',
        'tjs-Zyyy-CN': 'tjs',
        'tjs-CN': 'tjs',
        'tjs-Zyyy': 'tjs',
        'tju': 'tju',
        'tju-Latn-AU': 'tju',
        'tju-AU': 'tju',
        'tju-Latn': 'tju',
        'tjw': 'tjw',
        'tjw-Latn-AU': 'tjw',
        'tjw-AU': 'tjw',
        'tjw-Latn': 'tjw',
        'tk': 'tk',
        'tk-Latn-TM': 'tk',
        'tk-Latn': 'tk',
        'tk-TM': 'tk',
        'tk-Arab': 'tk-Arab',
        'tk-Arab-AF': 'tk-Arab',
        'tk-AF': 'tk-Arab',
        'tk-Arab-IR': 'tk-Arab-IR',
        'tk-Cyrl': 'tk-Cyrl',
        'tk-Cyrl-TM': 'tk-Cyrl',
        'tka': 'tka',
        'tka-Latn-BR': 'tka',
        'tka-BR': 'tka',
        'tka-Latn': 'tka',
        'tkb': 'tkb',
        'tkb-Deva-IN': 'tkb',
        'tkb-Deva': 'tkb',
        'tkb-IN': 'tkb',
        'tkd': 'tkd',
        'tkd-Latn-TL': 'tkd',
        'tkd-Latn': 'tkd',
        'tkd-TL': 'tkd',
        'tke': 'tke',
        'tke-Latn-MZ': 'tke',
        'tke-Latn': 'tke',
        'tke-MZ': 'tke',
        'tkf': 'tkf',
        'tkf-Latn-BR': 'tkf',
        'tkf-BR': 'tkf',
        'tkf-Latn': 'tkf',
        'tkg': 'tkg',
        'tkg-Latn-MG': 'tkg',
        'tkg-Latn': 'tkg',
        'tkg-MG': 'tkg',
        'tkl': 'tkl',
        'tkl-Latn-TK': 'tkl',
        'tkl-Latn': 'tkl',
        'tkl-TK': 'tkl',
        'tkm': 'tkm',
        'tkm-Zyyy-XX': 'tkm',
        'tkm-XX': 'tkm',
        'tkm-Zyyy': 'tkm',
        'tkn': 'tkn',
        'tkn-Zyyy-JP': 'tkn',
        'tkn-JP': 'tkn',
        'tkn-Zyyy': 'tkn',
        'tkp': 'tkp',
        'tkp-Latn-SB': 'tkp',
        'tkp-Latn': 'tkp',
        'tkp-SB': 'tkp',
        'tkq': 'tkq',
        'tkq-Latn-NG': 'tkq',
        'tkq-Latn': 'tkq',
        'tkq-NG': 'tkq',
        'tkr': 'tkr',
        'tkr-Latn-AZ': 'tkr',
        'tkr-AZ': 'tkr',
        'tkr-Latn': 'tkr',
        'tkr-Cyrl': 'tkr-Cyrl',
        'tkr-Cyrl-RU': 'tkr-Cyrl',
        'tkr-RU': 'tkr-Cyrl',
        'tks': 'tks',
        'tks-Arab-IR': 'tks',
        'tks-Arab': 'tks',
        'tks-IR': 'tks',
        'tkt': 'tkt',
        'tkt-Deva-NP': 'tkt',
        'tkt-Deva': 'tkt',
        'tkt-NP': 'tkt',
        'tku': 'tku',
        'tku-Latn-MX': 'tku',
        'tku-Latn': 'tku',
        'tku-MX': 'tku',
        'tkv': 'tkv',
        'tkv-Latn-PG': 'tkv',
        'tkv-Latn': 'tkv',
        'tkv-PG': 'tkv',
        'tkw': 'tkw',
        'tkw-Latn-SB': 'tkw',
        'tkw-Latn': 'tkw',
        'tkw-SB': 'tkw',
        'tkx': 'tkx',
        'tkx-Latn-ID': 'tkx',
        'tkx-ID': 'tkx',
        'tkx-Latn': 'tkx',
        'tkz': 'tkz',
        'tkz-Latn-VN': 'tkz',
        'tkz-Latn': 'tkz',
        'tkz-VN': 'tkz',
        'tl': 'tl',
        'tl-Latn-PH': 'tl',
        'tl-Latn': 'tl',
        'tl-PH': 'tl',
        'tl-Brai': 'tl-Brai',
        'tl-Brai-PH': 'tl-Brai',
        'tl-Tglg': 'tl-Tglg',
        'tl-Tglg-PH': 'tl-Tglg',
        'tla': 'tla',
        'tla-Latn-MX': 'tla',
        'tla-Latn': 'tla',
        'tla-MX': 'tla',
        'tlb': 'tlb',
        'tlb-Latn-ID': 'tlb',
        'tlb-ID': 'tlb',
        'tlb-Latn': 'tlb',
        'tlc': 'tlc',
        'tlc-Latn-MX': 'tlc',
        'tlc-Latn': 'tlc',
        'tlc-MX': 'tlc',
        'tld': 'tld',
        'tld-Latn-ID': 'tld',
        'tld-ID': 'tld',
        'tld-Latn': 'tld',
        'tlf': 'tlf',
        'tlf-Latn-PG': 'tlf',
        'tlf-Latn': 'tlf',
        'tlf-PG': 'tlf',
        'tlg': 'tlg',
        'tlg-Latn-ID': 'tlg',
        'tlg-ID': 'tlg',
        'tlg-Latn': 'tlg',
        'tlh': 'tlh',
        'tlh-Piqd-001': 'tlh',
        'tlh-001': 'tlh',
        'tlh-Piqd': 'tlh',
        'tlh-Latn': 'tlh-Latn',
        'tlh-Latn-001': 'tlh-Latn',
        'tli': 'tli',
        'tli-Latn-US': 'tli',
        'tli-Latn': 'tli',
        'tli-US': 'tli',
        'tli-Cyrl': 'tli-Cyrl',
        'tli-Cyrl-US': 'tli-Cyrl',
        'tlj': 'tlj',
        'tlj-Latn-UG': 'tlj',
        'tlj-Latn': 'tlj',
        'tlj-UG': 'tlj',
        'tlj-GH': 'tlj-GH',
        'tlj-Latn-GH': 'tlj-GH',
        'tlk': 'tlk',
        'tlk-Latn-ID': 'tlk',
        'tlk-ID': 'tlk',
        'tlk-Latn': 'tlk',
        'tll': 'tll',
        'tll-Latn-CD': 'tll',
        'tll-CD': 'tll',
        'tll-Latn': 'tll',
        'tlm': 'tlm',
        'tlm-Latn-VU': 'tlm',
        'tlm-Latn': 'tlm',
        'tlm-VU': 'tlm',
        'tln': 'tln',
        'tln-Latn-ID': 'tln',
        'tln-ID': 'tln',
        'tln-Latn': 'tln',
        'tlo': 'tlo',
        'tlo-Zyyy-SD': 'tlo',
        'tlo-SD': 'tlo',
        'tlo-Zyyy': 'tlo',
        'tlp': 'tlp',
        'tlp-Latn-MX': 'tlp',
        'tlp-Latn': 'tlp',
        'tlp-MX': 'tlp',
        'tlq': 'tlq',
        'tlq-Latn-MM': 'tlq',
        'tlq-Latn': 'tlq',
        'tlq-MM': 'tlq',
        'tlr': 'tlr',
        'tlr-Latn-SB': 'tlr',
        'tlr-Latn': 'tlr',
        'tlr-SB': 'tlr',
        'tls': 'tls',
        'tls-Latn-VU': 'tls',
        'tls-Latn': 'tls',
        'tls-VU': 'tls',
        'tlt': 'tlt',
        'tlt-Latn-ID': 'tlt',
        'tlt-ID': 'tlt',
        'tlt-Latn': 'tlt',
        'tlu': 'tlu',
        'tlu-Latn-ID': 'tlu',
        'tlu-ID': 'tlu',
        'tlu-Latn': 'tlu',
        'tlv': 'tlv',
        'tlv-Latn-ID': 'tlv',
        'tlv-ID': 'tlv',
        'tlv-Latn': 'tlv',
        'tlx': 'tlx',
        'tlx-Latn-PG': 'tlx',
        'tlx-Latn': 'tlx',
        'tlx-PG': 'tlx',
        'tly': 'tly',
        'tly-Latn-AZ': 'tly',
        'tly-AZ': 'tly',
        'tly-Latn': 'tly',
        'tly-Arab': 'tly-Arab',
        'tly-Arab-AZ': 'tly-Arab',
        'tly-Cyrl': 'tly-Cyrl',
        'tly-Cyrl-AZ': 'tly-Cyrl',
        'tma': 'tma',
        'tma-Latn-TD': 'tma',
        'tma-Latn': 'tma',
        'tma-TD': 'tma',
        'tmb': 'tmb',
        'tmb-Latn-VU': 'tmb',
        'tmb-Latn': 'tmb',
        'tmb-VU': 'tmb',
        'tmc': 'tmc',
        'tmc-Latn-TD': 'tmc',
        'tmc-Latn': 'tmc',
        'tmc-TD': 'tmc',
        'tmd': 'tmd',
        'tmd-Latn-PG': 'tmd',
        'tmd-Latn': 'tmd',
        'tmd-PG': 'tmd',
        'tme': 'tme',
        'tme-Latn-BR': 'tme',
        'tme-BR': 'tme',
        'tme-Latn': 'tme',
        'tmf': 'tmf',
        'tmf-Latn-PY': 'tmf',
        'tmf-Latn': 'tmf',
        'tmf-PY': 'tmf',
        'tmg': 'tmg',
        'tmg-Latn-ID': 'tmg',
        'tmg-ID': 'tmg',
        'tmg-Latn': 'tmg',
        'tmh': 'tmh',
        'tmh-Latn-NE': 'tmh',
        'tmh-Latn': 'tmh',
        'tmh-NE': 'tmh',
        'ttq': 'tmh',
        'ttq-Latn': 'tmh',
        'ttq-Latn-NE': 'tmh',
        'ttq-NE': 'tmh',
        'tmh-Arab': 'tmh-Arab',
        'tmh-Arab-NE': 'tmh-Arab',
        'ttq-Arab': 'tmh-Arab',
        'ttq-Arab-NE': 'tmh-Arab',
        'tmh-Tfng': 'tmh-Tfng',
        'tmh-Tfng-NE': 'tmh-Tfng',
        'ttq-Tfng': 'tmh-Tfng',
        'ttq-Tfng-NE': 'tmh-Tfng',
        'tmi': 'tmi',
        'tmi-Latn-VU': 'tmi',
        'tmi-Latn': 'tmi',
        'tmi-VU': 'tmi',
        'tmj': 'tmj',
        'tmj-Latn-ID': 'tmj',
        'tmj-ID': 'tmj',
        'tmj-Latn': 'tmj',
        'tmk': 'tmk',
        'tmk-Deva-NP': 'tmk',
        'tmk-Deva': 'tmk',
        'tmk-NP': 'tmk',
        'tml': 'tml',
        'tml-Latn-ID': 'tml',
        'tml-ID': 'tml',
        'tml-Latn': 'tml',
        'tmm': 'tmm',
        'tmm-Latn-VN': 'tmm',
        'tmm-Latn': 'tmm',
        'tmm-VN': 'tmm',
        'tmn': 'tmn',
        'tmn-Latn-ID': 'tmn',
        'tmn-ID': 'tmn',
        'tmn-Latn': 'tmn',
        'tmo': 'tmo',
        'tmo-Latn-MY': 'tmo',
        'tmo-Latn': 'tmo',
        'tmo-MY': 'tmo',
        'tmq': 'tmq',
        'tmq-Latn-PG': 'tmq',
        'tmq-Latn': 'tmq',
        'tmq-PG': 'tmq',
        'tmr': 'tmr',
        'tmr-Syrc-IL': 'tmr',
        'tmr-IL': 'tmr',
        'tmr-Syrc': 'tmr',
        'tms': 'tms',
        'tms-Zyyy-SD': 'tms',
        'tms-SD': 'tms',
        'tms-Zyyy': 'tms',
        'tmt': 'tmt',
        'tmt-Latn-VU': 'tmt',
        'tmt-Latn': 'tmt',
        'tmt-VU': 'tmt',
        'tmu': 'tmu',
        'tmu-Latn-ID': 'tmu',
        'tmu-ID': 'tmu',
        'tmu-Latn': 'tmu',
        'tmv': 'tmv',
        'tmv-Latn-CD': 'tmv',
        'tmv-CD': 'tmv',
        'tmv-Latn': 'tmv',
        'tmw': 'tmw',
        'tmw-Latn-MY': 'tmw',
        'ms-tmw': 'tmw',
        'ms-tmw-MY': 'tmw',
        'tmw-Latn': 'tmw',
        'tmw-MY': 'tmw',
        'tmy': 'tmy',
        'tmy-Latn-PG': 'tmy',
        'tmy-Latn': 'tmy',
        'tmy-PG': 'tmy',
        'tmz': 'tmz',
        'tmz-Latn-VE': 'tmz',
        'tmz-Latn': 'tmz',
        'tmz-VE': 'tmz',
        'tn': 'tn',
        'tn-Latn-ZA': 'tn',
        'tn-Latn': 'tn',
        'tn-ZA': 'tn',
        'tn-BW': 'tn-BW',
        'tn-Latn-BW': 'tn-BW',
        'tna': 'tna',
        'tna-Latn-BO': 'tna',
        'tna-BO': 'tna',
        'tna-Latn': 'tna',
        'tnb': 'tnb',
        'tnb-Latn-CO': 'tnb',
        'tnb-CO': 'tnb',
        'tnb-Latn': 'tnb',
        'tnc': 'tnc',
        'tnc-Latn-CO': 'tnc',
        'tnc-CO': 'tnc',
        'tnc-Latn': 'tnc',
        'tnd': 'tnd',
        'tnd-Latn-CO': 'tnd',
        'tnd-CO': 'tnd',
        'tnd-Latn': 'tnd',
        'tng': 'tng',
        'tng-Latn-TD': 'tng',
        'tng-Latn': 'tng',
        'tng-TD': 'tng',
        'tnh': 'tnh',
        'tnh-Latn-PG': 'tnh',
        'tnh-Latn': 'tnh',
        'tnh-PG': 'tnh',
        'tni': 'tni',
        'tni-Latn-ID': 'tni',
        'tni-ID': 'tni',
        'tni-Latn': 'tni',
        'tnk': 'tnk',
        'tnk-Latn-VU': 'tnk',
        'tnk-Latn': 'tnk',
        'tnk-VU': 'tnk',
        'tnl': 'tnl',
        'tnl-Latn-VU': 'tnl',
        'tnl-Latn': 'tnl',
        'tnl-VU': 'tnl',
        'tnm': 'tnm',
        'tnm-Latn-ID': 'tnm',
        'tnm-ID': 'tnm',
        'tnm-Latn': 'tnm',
        'tnn': 'tnn',
        'tnn-Latn-VU': 'tnn',
        'tnn-Latn': 'tnn',
        'tnn-VU': 'tnn',
        'tno': 'tno',
        'tno-Latn-BO': 'tno',
        'tno-BO': 'tno',
        'tno-Latn': 'tno',
        'tnp': 'tnp',
        'tnp-Latn-VU': 'tnp',
        'tnp-Latn': 'tnp',
        'tnp-VU': 'tnp',
        'tnq': 'tnq',
        'tnq-Latn-PR': 'tnq',
        'tnq-Latn': 'tnq',
        'tnq-PR': 'tnq',
        'tnr': 'tnr',
        'tnr-Latn-SN': 'tnr',
        'tnr-Latn': 'tnr',
        'tnr-SN': 'tnr',
        'tns': 'tns',
        'tns-Latn-PG': 'tns',
        'tns-Latn': 'tns',
        'tns-PG': 'tns',
        'tnt': 'tnt',
        'tnt-Latn-ID': 'tnt',
        'tnt-ID': 'tnt',
        'tnt-Latn': 'tnt',
        'tnu': 'tnu',
        'tnu-Zyyy-LA': 'tnu',
        'tnu-LA': 'tnu',
        'tnu-Zyyy': 'tnu',
        'tnv': 'tnv',
        'tnv-Cakm-BD': 'tnv',
        'tnv-BD': 'tnv',
        'tnv-Cakm': 'tnv',
        'tnw': 'tnw',
        'tnw-Latn-ID': 'tnw',
        'tnw-ID': 'tnw',
        'tnw-Latn': 'tnw',
        'tnx': 'tnx',
        'tnx-Latn-SB': 'tnx',
        'tnx-Latn': 'tnx',
        'tnx-SB': 'tnx',
        'tny': 'tny',
        'tny-Latn-TZ': 'tny',
        'tny-Latn': 'tny',
        'tny-TZ': 'tny',
        'tnz': 'tnz',
        'tnz-Zyyy-TH': 'tnz',
        'tnz-TH': 'tnz',
        'tnz-Zyyy': 'tnz',
        'to': 'to',
        'to-Latn-TO': 'to',
        'to-Latn': 'to',
        'to-TO': 'to',
        'tob': 'tob',
        'tob-Latn-AR': 'tob',
        'tob-AR': 'tob',
        'tob-Latn': 'tob',
        'toc': 'toc',
        'toc-Latn-MX': 'toc',
        'toc-Latn': 'toc',
        'toc-MX': 'toc',
        'tod': 'tod',
        'tod-Latn-GN': 'tod',
        'tod-GN': 'tod',
        'tod-Latn': 'tod',
        'tof': 'tof',
        'tof-Latn-PG': 'tof',
        'tof-Latn': 'tof',
        'tof-PG': 'tof',
        'tog': 'tog',
        'tog-Latn-MW': 'tog',
        'tog-Latn': 'tog',
        'tog-MW': 'tog',
        'toh': 'toh',
        'toh-Latn-MZ': 'toh',
        'toh-Latn': 'toh',
        'toh-MZ': 'toh',
        'toi': 'toi',
        'toi-Latn-ZM': 'toi',
        'toi-Latn': 'toi',
        'toi-ZM': 'toi',
        'toj': 'toj',
        'toj-Latn-MX': 'toj',
        'toj-Latn': 'toj',
        'toj-MX': 'toj',
        'tol': 'tol',
        'tol-Latn-US': 'tol',
        'tol-Latn': 'tol',
        'tol-US': 'tol',
        'tom': 'tom',
        'tom-Latn-ID': 'tom',
        'tom-ID': 'tom',
        'tom-Latn': 'tom',
        'too': 'too',
        'too-Latn-MX': 'too',
        'too-Latn': 'too',
        'too-MX': 'too',
        'top': 'top',
        'top-Latn-MX': 'top',
        'top-Latn': 'top',
        'top-MX': 'top',
        'toq': 'toq',
        'toq-Latn-SS': 'toq',
        'toq-Latn': 'toq',
        'toq-SS': 'toq',
        'tor': 'tor',
        'tor-Latn-CD': 'tor',
        'tor-CD': 'tor',
        'tor-Latn': 'tor',
        'tos': 'tos',
        'tos-Latn-MX': 'tos',
        'tos-Latn': 'tos',
        'tos-MX': 'tos',
        'tou': 'tou',
        'tou-Latn-VN': 'tou',
        'tou-Latn': 'tou',
        'tou-VN': 'tou',
        'tov': 'tov',
        'tov-Zyyy-IR': 'tov',
        'tov-IR': 'tov',
        'tov-Zyyy': 'tov',
        'tow': 'tow',
        'tow-Latn-US': 'tow',
        'tow-Latn': 'tow',
        'tow-US': 'tow',
        'tox': 'tox',
        'tox-Latn-PW': 'tox',
        'tox-Latn': 'tox',
        'tox-PW': 'tox',
        'toy': 'toy',
        'toy-Latn-ID': 'toy',
        'toy-ID': 'toy',
        'toy-Latn': 'toy',
        'toz': 'toz',
        'toz-Latn-CM': 'toz',
        'toz-CM': 'toz',
        'toz-Latn': 'toz',
        'tpa': 'tpa',
        'tpa-Latn-PG': 'tpa',
        'tpa-Latn': 'tpa',
        'tpa-PG': 'tpa',
        'tpc': 'tpc',
        'tpc-Latn-MX': 'tpc',
        'tpc-Latn': 'tpc',
        'tpc-MX': 'tpc',
        'tpe-Beng': 'tpe-Beng',
        'tpe-Beng-BD': 'tpe-Beng',
        'tpe-Latn': 'tpe-Latn',
        'tpe-Latn-BD': 'tpe-Latn',
        'tpf': 'tpf',
        'tpf-Latn-ID': 'tpf',
        'tpf-ID': 'tpf',
        'tpf-Latn': 'tpf',
        'tpg': 'tpg',
        'tpg-Latn-ID': 'tpg',
        'tpg-ID': 'tpg',
        'tpg-Latn': 'tpg',
        'tpi': 'tpi',
        'tpi-Latn-PG': 'tpi',
        'tpi-Latn': 'tpi',
        'tpi-PG': 'tpi',
        'tpj': 'tpj',
        'tpj-Latn-PY': 'tpj',
        'tpj-Latn': 'tpj',
        'tpj-PY': 'tpj',
        'tpk': 'tpk',
        'tpk-Latn-BR': 'tpk',
        'tpk-BR': 'tpk',
        'tpk-Latn': 'tpk',
        'tpl': 'tpl',
        'tpl-Latn-MX': 'tpl',
        'tpl-Latn': 'tpl',
        'tpl-MX': 'tpl',
        'tpm': 'tpm',
        'tpm-Latn-GH': 'tpm',
        'tpm-GH': 'tpm',
        'tpm-Latn': 'tpm',
        'tpn': 'tpn',
        'tpn-Latn-BR': 'tpn',
        'tpn-BR': 'tpn',
        'tpn-Latn': 'tpn',
        'tpo': 'tpo',
        'tpo-Zyyy-LA': 'tpo',
        'thc': 'tpo',
        'thc-LA': 'tpo',
        'thc-Zyyy': 'tpo',
        'thc-Zyyy-LA': 'tpo',
        'tpo-LA': 'tpo',
        'tpo-Zyyy': 'tpo',
        'tpp': 'tpp',
        'tpp-Latn-MX': 'tpp',
        'tpp-Latn': 'tpp',
        'tpp-MX': 'tpp',
        'tpq': 'tpq',
        'tpq-Zyyy-IN': 'tpq',
        'tpq-IN': 'tpq',
        'tpq-Zyyy': 'tpq',
        'tpr': 'tpr',
        'tpr-Latn-BR': 'tpr',
        'tpr-BR': 'tpr',
        'tpr-Latn': 'tpr',
        'tpt': 'tpt',
        'tpt-Latn-MX': 'tpt',
        'tpt-Latn': 'tpt',
        'tpt-MX': 'tpt',
        'tpu': 'tpu',
        'tpu-Khmr-KH': 'tpu',
        'tpu-KH': 'tpu',
        'tpu-Khmr': 'tpu',
        'tpv': 'tpv',
        'tpv-Latn-MP': 'tpv',
        'tpv-Latn': 'tpv',
        'tpv-MP': 'tpv',
        'tpw': 'tpw',
        'tpw-Zyyy-XX': 'tpw',
        'tpw-XX': 'tpw',
        'tpw-Zyyy': 'tpw',
        'tpx': 'tpx',
        'tpx-Latn-MX': 'tpx',
        'tpx-Latn': 'tpx',
        'tpx-MX': 'tpx',
        'tpy': 'tpy',
        'tpy-Latn-BR': 'tpy',
        'tpy-BR': 'tpy',
        'tpy-Latn': 'tpy',
        'tpz': 'tpz',
        'tpz-Latn-PG': 'tpz',
        'tpz-Latn': 'tpz',
        'tpz-PG': 'tpz',
        'tqb': 'tqb',
        'tqb-Latn-BR': 'tqb',
        'tqb-BR': 'tqb',
        'tqb-Latn': 'tqb',
        'tql': 'tql',
        'tql-Latn-VU': 'tql',
        'tql-Latn': 'tql',
        'tql-VU': 'tql',
        'tqm': 'tqm',
        'tqm-Latn-PG': 'tqm',
        'tqm-Latn': 'tqm',
        'tqm-PG': 'tqm',
        'tqn': 'tqn',
        'tqn-Latn-US': 'tqn',
        'tqn-Latn': 'tqn',
        'tqn-US': 'tqn',
        'tqo': 'tqo',
        'tqo-Latn-PG': 'tqo',
        'tqo-Latn': 'tqo',
        'tqo-PG': 'tqo',
        'tqp': 'tqp',
        'tqp-Latn-PG': 'tqp',
        'tqp-Latn': 'tqp',
        'tqp-PG': 'tqp',
        'tqq': 'tqq',
        'tqq-Zyyy-SO': 'tqq',
        'tqq-SO': 'tqq',
        'tqq-Zyyy': 'tqq',
        'tqr': 'tqr',
        'tqr-Zyyy-SD': 'tqr',
        'tqr-SD': 'tqr',
        'tqr-Zyyy': 'tqr',
        'tqt': 'tqt',
        'tqt-Latn-MX': 'tqt',
        'tqt-Latn': 'tqt',
        'tqt-MX': 'tqt',
        'tqu': 'tqu',
        'tqu-Latn-SB': 'tqu',
        'tqu-Latn': 'tqu',
        'tqu-SB': 'tqu',
        'tqw': 'tqw',
        'tqw-Zyyy-US': 'tqw',
        'tqw-US': 'tqw',
        'tqw-Zyyy': 'tqw',
        'tr': 'tr',
        'tr-Latn-TR': 'tr',
        'tr-Latn': 'tr',
        'tr-TR': 'tr',
        'tr-Arab': 'tr-Arab',
        'tr-Arab-TR': 'tr-Arab',
        'tr-Brai': 'tr-Brai',
        'tr-Brai-TR': 'tr-Brai',
        'tr-CY': 'tr-CY',
        'tr-Latn-CY': 'tr-CY',
        'tr-Cyrl': 'tr-Cyrl',
        'tr-Cyrl-BG': 'tr-Cyrl',
        'tr-BG': 'tr-Cyrl',
        'tr-Grek': 'tr-Grek',
        'tr-Grek-TR': 'tr-Grek',
        'tra': 'tra',
        'tra-Arab-AF': 'tra',
        'tra-AF': 'tra',
        'tra-Arab': 'tra',
        'trb': 'trb',
        'trb-Latn-PG': 'trb',
        'trb-Latn': 'trb',
        'trb-PG': 'trb',
        'trc': 'trc',
        'trc-Latn-MX': 'trc',
        'trc-Latn': 'trc',
        'trc-MX': 'trc',
        'trd': 'trd',
        'trd-Zyyy-IN': 'trd',
        'trd-IN': 'trd',
        'trd-Zyyy': 'trd',
        'tre': 'tre',
        'tre-Latn-ID': 'tre',
        'tre-ID': 'tre',
        'tre-Latn': 'tre',
        'trf': 'trf',
        'trf-Latn-TT': 'trf',
        'trf-Latn': 'trf',
        'trf-TT': 'trf',
        'trg': 'trg',
        'trg-Hebr-IL': 'trg',
        'trg-Hebr': 'trg',
        'trg-IL': 'trg',
        'trh': 'trh',
        'trh-Latn-PG': 'trh',
        'trh-Latn': 'trh',
        'trh-PG': 'trh',
        'tri': 'tri',
        'tri-Latn-SR': 'tri',
        'tri-Latn': 'tri',
        'tri-SR': 'tri',
        'trj': 'trj',
        'trj-Latn-TD': 'trj',
        'trj-Latn': 'trj',
        'trj-TD': 'trj',
        'trl': 'trl',
        'trl-Zyyy-GB': 'trl',
        'trl-GB': 'trl',
        'trl-Zyyy': 'trl',
        'trm': 'trm',
        'trm-Arab-AF': 'trm',
        'trm-AF': 'trm',
        'trm-Arab': 'trm',
        'trn': 'trn',
        'trn-Latn-BO': 'trn',
        'trn-BO': 'trn',
        'trn-Latn': 'trn',
        'tro': 'tro',
        'tro-Latn-IN': 'tro',
        'tro-IN': 'tro',
        'tro-Latn': 'tro',
        'trp-Beng': 'trp-Beng',
        'trp-Beng-IN': 'trp-Beng',
        'trp-Latn': 'trp-Latn',
        'trp-Latn-IN': 'trp-Latn',
        'trq': 'trq',
        'trq-Latn-MX': 'trq',
        'trq-Latn': 'trq',
        'trq-MX': 'trq',
        'trr': 'trr',
        'trr-Latn-PE': 'trr',
        'trr-Latn': 'trr',
        'trr-PE': 'trr',
        'trs': 'trs',
        'trs-Latn-MX': 'trs',
        'trs-Latn': 'trs',
        'trs-MX': 'trs',
        'trt': 'trt',
        'trt-Latn-ID': 'trt',
        'trt-ID': 'trt',
        'trt-Latn': 'trt',
        'tru': 'tru',
        'tru-Latn-TR': 'tru',
        'tru-Latn': 'tru',
        'tru-TR': 'tru',
        'tru-Syrc': 'tru-Syrc',
        'tru-Syrc-TR': 'tru-Syrc',
        'trv': 'trv',
        'trv-Latn-TW': 'trv',
        'trv-Latn': 'trv',
        'trv-TW': 'trv',
        'trw': 'trw',
        'trw-Arab-PK': 'trw',
        'trw-Arab': 'trw',
        'trw-PK': 'trw',
        'trx': 'trx',
        'trx-Latn-MY': 'trx',
        'trx-Latn': 'trx',
        'trx-MY': 'trx',
        'try': 'try',
        'try-Latn-IN': 'try',
        'try-IN': 'try',
        'try-Latn': 'try',
        'trz': 'trz',
        'trz-Latn-BR': 'trz',
        'trz-BR': 'trz',
        'trz-Latn': 'trz',
        'ts': 'ts',
        'ts-Latn-ZA': 'ts',
        'ts-Latn': 'ts',
        'ts-ZA': 'ts',
        'ts-Brai': 'ts-Brai',
        'ts-Brai-ZA': 'ts-Brai',
        'tsa': 'tsa',
        'tsa-Latn-CG': 'tsa',
        'tsa-CG': 'tsa',
        'tsa-Latn': 'tsa',
        'tsb': 'tsb',
        'tsb-Latn-ET': 'tsb',
        'tsb-ET': 'tsb',
        'tsb-Latn': 'tsb',
        'tsc': 'tsc',
        'tsc-Latn-MZ': 'tsc',
        'tsc-Latn': 'tsc',
        'tsc-MZ': 'tsc',
        'tsd': 'tsd',
        'tsd-Grek-GR': 'tsd',
        'tsd-GR': 'tsd',
        'tsd-Grek': 'tsd',
        'tse': 'tse',
        'tse-Zxxx-TN': 'tse',
        'sgn-tse': 'tse',
        'sgn-tse-TN': 'tse',
        'tse-TN': 'tse',
        'tse-Zxxx': 'tse',
        'tsg': 'tsg',
        'tsg-Latn-PH': 'tsg',
        'tsg-Latn': 'tsg',
        'tsg-PH': 'tsg',
        'tsg-Arab': 'tsg-Arab',
        'tsg-Arab-PH': 'tsg-Arab',
        'tsh': 'tsh',
        'tsh-Latn-CM': 'tsh',
        'tsh-CM': 'tsh',
        'tsh-Latn': 'tsh',
        'tsi': 'tsi',
        'tsi-Latn-CA': 'tsi',
        'tsi-CA': 'tsi',
        'tsi-Latn': 'tsi',
        'tsj': 'tsj',
        'tsj-Tibt-BT': 'tsj',
        'tsj-BT': 'tsj',
        'tsj-Tibt': 'tsj',
        'tsk': 'tsk',
        'tsk-Zyyy-CN': 'tsk',
        'tsk-CN': 'tsk',
        'tsk-Zyyy': 'tsk',
        'tsl': 'tsl',
        'tsl-Latn-VN': 'tsl',
        'tsl-Latn': 'tsl',
        'tsl-VN': 'tsl',
        'tsm': 'tsm',
        'tsm-Zxxx-TR': 'tsm',
        'sgn-tsm': 'tsm',
        'sgn-tsm-TR': 'tsm',
        'tsm-TR': 'tsm',
        'tsm-Zxxx': 'tsm',
        'tsp': 'tsp',
        'tsp-Latn-BF': 'tsp',
        'tsp-BF': 'tsp',
        'tsp-Latn': 'tsp',
        'tsq': 'tsq',
        'tsq-Zxxx-TH': 'tsq',
        'sgn-tsq': 'tsq',
        'sgn-tsq-TH': 'tsq',
        'tsq-TH': 'tsq',
        'tsq-Zxxx': 'tsq',
        'tsr': 'tsr',
        'tsr-Latn-VU': 'tsr',
        'tsr-Latn': 'tsr',
        'tsr-VU': 'tsr',
        'tss': 'tss',
        'tss-Zxxx-TW': 'tss',
        'sgn-tss': 'tss',
        'sgn-tss-TW': 'tss',
        'tss-TW': 'tss',
        'tss-Zxxx': 'tss',
        'tst': 'tst',
        'tst-Latn-ML': 'tst',
        'tst-Latn': 'tst',
        'tst-ML': 'tst',
        'tsu': 'tsu',
        'tsu-Latn-TW': 'tsu',
        'tsu-Latn': 'tsu',
        'tsu-TW': 'tsu',
        'tsv': 'tsv',
        'tsv-Latn-GA': 'tsv',
        'tsv-GA': 'tsv',
        'tsv-Latn': 'tsv',
        'tsw': 'tsw',
        'tsw-Latn-NG': 'tsw',
        'tsw-Latn': 'tsw',
        'tsw-NG': 'tsw',
        'tsx': 'tsx',
        'tsx-Latn-PG': 'tsx',
        'tsx-Latn': 'tsx',
        'tsx-PG': 'tsx',
        'tsy': 'tsy',
        'tsy-Zxxx-ML': 'tsy',
        'sgn-tsy': 'tsy',
        'sgn-tsy-ML': 'tsy',
        'tsy-ML': 'tsy',
        'tsy-Zxxx': 'tsy',
        'tsz': 'tsz',
        'tsz-Latn-MX': 'tsz',
        'tsz-Latn': 'tsz',
        'tsz-MX': 'tsz',
        'tt': 'tt',
        'tt-Cyrl-RU': 'tt',
        'tt-Cyrl': 'tt',
        'tt-RU': 'tt',
        'tt-Latn': 'tt-Latn',
        'tt-Latn-RU': 'tt-Latn',
        'tta': 'tta',
        'tta-Zyyy-XX': 'tta',
        'tta-XX': 'tta',
        'tta-Zyyy': 'tta',
        'ttb': 'ttb',
        'ttb-Latn-NG': 'ttb',
        'ttb-Latn': 'ttb',
        'ttb-NG': 'ttb',
        'ttc': 'ttc',
        'ttc-Latn-GT': 'ttc',
        'ttc-GT': 'ttc',
        'ttc-Latn': 'ttc',
        'ttd': 'ttd',
        'ttd-Latn-PG': 'ttd',
        'ttd-Latn': 'ttd',
        'ttd-PG': 'ttd',
        'tte': 'tte',
        'tte-Latn-PG': 'tte',
        'tte-Latn': 'tte',
        'tte-PG': 'tte',
        'ttf': 'ttf',
        'ttf-Latn-CM': 'ttf',
        'ttf-CM': 'ttf',
        'ttf-Latn': 'ttf',
        'ttg': 'ttg',
        'ttg-Zyyy-BN': 'ttg',
        'ttg-BN': 'ttg',
        'ttg-Zyyy': 'ttg',
        'tth': 'tth',
        'tth-Laoo-LA': 'tth',
        'tth-LA': 'tth',
        'tth-Laoo': 'tth',
        'tti': 'tti',
        'tti-Latn-ID': 'tti',
        'tti-ID': 'tti',
        'tti-Latn': 'tti',
        'ttj': 'ttj',
        'ttj-Latn-UG': 'ttj',
        'ttj-Latn': 'ttj',
        'ttj-UG': 'ttj',
        'ttk': 'ttk',
        'ttk-Latn-CO': 'ttk',
        'ttk-CO': 'ttk',
        'ttk-Latn': 'ttk',
        'ttl': 'ttl',
        'ttl-Latn-ZM': 'ttl',
        'ttl-Latn': 'ttl',
        'ttl-ZM': 'ttl',
        'ttm': 'ttm',
        'ttm-Latn-CA': 'ttm',
        'ttm-CA': 'ttm',
        'ttm-Latn': 'ttm',
        'ttn': 'ttn',
        'ttn-Latn-ID': 'ttn',
        'ttn-ID': 'ttn',
        'ttn-Latn': 'ttn',
        'tto': 'tto',
        'tto-Laoo-LA': 'tto',
        'tto-LA': 'tto',
        'tto-Laoo': 'tto',
        'ttp': 'ttp',
        'ttp-Latn-ID': 'ttp',
        'ttp-ID': 'ttp',
        'ttp-Latn': 'ttp',
        'ttr': 'ttr',
        'ttr-Latn-NG': 'ttr',
        'ttr-Latn': 'ttr',
        'ttr-NG': 'ttr',
        'tts': 'tts',
        'tts-Thai-TH': 'tts',
        'tts-TH': 'tts',
        'tts-Thai': 'tts',
        'ttt': 'ttt',
        'ttt-Latn-AZ': 'ttt',
        'ttt-AZ': 'ttt',
        'ttt-Latn': 'ttt',
        'ttt-Arab': 'ttt-Arab',
        'ttt-Arab-IR': 'ttt-Arab',
        'ttt-IR': 'ttt-Arab',
        'ttt-Cyrl': 'ttt-Cyrl',
        'ttt-Cyrl-AZ': 'ttt-Cyrl',
        'ttu': 'ttu',
        'ttu-Latn-PG': 'ttu',
        'ttu-Latn': 'ttu',
        'ttu-PG': 'ttu',
        'ttv': 'ttv',
        'ttv-Latn-PG': 'ttv',
        'ttv-Latn': 'ttv',
        'ttv-PG': 'ttv',
        'ttw': 'ttw',
        'ttw-Latn-MY': 'ttw',
        'ttw-Latn': 'ttw',
        'ttw-MY': 'ttw',
        'tty': 'tty',
        'tty-Latn-ID': 'tty',
        'tty-ID': 'tty',
        'tty-Latn': 'tty',
        'ttz': 'ttz',
        'ttz-Zyyy-NP': 'ttz',
        'ttz-NP': 'ttz',
        'ttz-Zyyy': 'ttz',
        'tua': 'tua',
        'tua-Latn-PG': 'tua',
        'tua-Latn': 'tua',
        'tua-PG': 'tua',
        'tub': 'tub',
        'tub-Latn-US': 'tub',
        'tub-Latn': 'tub',
        'tub-US': 'tub',
        'tuc': 'tuc',
        'tuc-Latn-PG': 'tuc',
        'tuc-Latn': 'tuc',
        'tuc-PG': 'tuc',
        'tuc-x-oov': 'tuc-x-oov',
        'tuc-Latn-PG-x-oov': 'tuc-x-oov',
        'tuc-Latn-x-oov': 'tuc-x-oov',
        'tuc-PG-x-oov': 'tuc-x-oov',
        'tuc-x-tuam': 'tuc-x-tuam',
        'tuc-Latn-PG-x-tuam': 'tuc-x-tuam',
        'tuc-Latn-x-tuam': 'tuc-x-tuam',
        'tuc-PG-x-tuam': 'tuc-x-tuam',
        'tud': 'tud',
        'tud-Latn-BR': 'tud',
        'tud-BR': 'tud',
        'tud-Latn': 'tud',
        'tue': 'tue',
        'tue-Latn-CO': 'tue',
        'tue-CO': 'tue',
        'tue-Latn': 'tue',
        'tuf': 'tuf',
        'tuf-Latn-CO': 'tuf',
        'tuf-CO': 'tuf',
        'tuf-Latn': 'tuf',
        'tug': 'tug',
        'tug-Latn-TD': 'tug',
        'tug-Latn': 'tug',
        'tug-TD': 'tug',
        'tuh': 'tuh',
        'tuh-Latn-PG': 'tuh',
        'tuh-Latn': 'tuh',
        'tuh-PG': 'tuh',
        'tui': 'tui',
        'tui-Latn-CM': 'tui',
        'tui-CM': 'tui',
        'tui-Latn': 'tui',
        'tuj': 'tuj',
        'tuj-Latn-ID': 'tuj',
        'tuj-ID': 'tuj',
        'tuj-Latn': 'tuj',
        'tul': 'tul',
        'tul-Latn-NG': 'tul',
        'tul-Latn': 'tul',
        'tul-NG': 'tul',
        'tum': 'tum',
        'tum-Latn-MW': 'tum',
        'tum-Latn': 'tum',
        'tum-MW': 'tum',
        'tun': 'tun',
        'tun-Zyyy-US': 'tun',
        'tun-US': 'tun',
        'tun-Zyyy': 'tun',
        'tuo': 'tuo',
        'tuo-Latn-BR': 'tuo',
        'tuo-BR': 'tuo',
        'tuo-Latn': 'tuo',
        'tuq': 'tuq',
        'tuq-Latn-TD': 'tuq',
        'tuq-Latn': 'tuq',
        'tuq-TD': 'tuq',
        'tus': 'tus',
        'tus-Latn-CA': 'tus',
        'tus-CA': 'tus',
        'tus-Latn': 'tus',
        'tuu': 'tuu',
        'tuu-Latn-US': 'tuu',
        'tuu-Latn': 'tuu',
        'tuu-US': 'tuu',
        'tuv': 'tuv',
        'tuv-Latn-KE': 'tuv',
        'tuv-KE': 'tuv',
        'tuv-Latn': 'tuv',
        'tux': 'tux',
        'tux-Latn-BR': 'tux',
        'tux-BR': 'tux',
        'tux-Latn': 'tux',
        'tuy': 'tuy',
        'tuy-Latn-KE': 'tuy',
        'tuy-KE': 'tuy',
        'tuy-Latn': 'tuy',
        'tuz': 'tuz',
        'tuz-Latn-BF': 'tuz',
        'tuz-BF': 'tuz',
        'tuz-Latn': 'tuz',
        'tva': 'tva',
        'tva-Latn-SB': 'tva',
        'tva-Latn': 'tva',
        'tva-SB': 'tva',
        'tvd': 'tvd',
        'tvd-Latn-NG': 'tvd',
        'kxe': 'tvd',
        'kxe-Latn': 'tvd',
        'kxe-Latn-NG': 'tvd',
        'kxe-NG': 'tvd',
        'tvd-Latn': 'tvd',
        'tvd-NG': 'tvd',
        'tve': 'tve',
        'tve-Latn-ID': 'tve',
        'tve-ID': 'tve',
        'tve-Latn': 'tve',
        'tvk': 'tvk',
        'tvk-Latn-VU': 'tvk',
        'tvk-Latn': 'tvk',
        'tvk-VU': 'tvk',
        'tvl': 'tvl',
        'tvl-Latn-TV': 'tvl',
        'tvl-Latn': 'tvl',
        'tvl-TV': 'tvl',
        'tvm': 'tvm',
        'tvm-Latn-ID': 'tvm',
        'tvm-ID': 'tvm',
        'tvm-Latn': 'tvm',
        'tvn': 'tvn',
        'tvn-Zyyy-MM': 'tvn',
        'tvn-MM': 'tvn',
        'tvn-Zyyy': 'tvn',
        'tvo': 'tvo',
        'tvo-Latn-ID': 'tvo',
        'tvo-ID': 'tvo',
        'tvo-Latn': 'tvo',
        'tvs': 'tvs',
        'tvs-Latn-KE': 'tvs',
        'tvs-KE': 'tvs',
        'tvs-Latn': 'tvs',
        'tvt': 'tvt',
        'tvt-Latn-IN': 'tvt',
        'tvt-IN': 'tvt',
        'tvt-Latn': 'tvt',
        'tvu': 'tvu',
        'tvu-Latn-CM': 'tvu',
        'baz': 'tvu',
        'baz-CM': 'tvu',
        'baz-Latn': 'tvu',
        'baz-Latn-CM': 'tvu',
        'tvu-CM': 'tvu',
        'tvu-Latn': 'tvu',
        'tvw': 'tvw',
        'tvw-Latn-ID': 'tvw',
        'tvw-ID': 'tvw',
        'tvw-Latn': 'tvw',
        'tvx': 'tvx',
        'tvx-Latn-TW': 'tvx',
        'tvx-Latn': 'tvx',
        'tvx-TW': 'tvx',
        'tvy': 'tvy',
        'tvy-Zyyy-TL': 'tvy',
        'tvy-TL': 'tvy',
        'tvy-Zyyy': 'tvy',
        'twa': 'twa',
        'twa-Zyyy-US': 'twa',
        'twa-US': 'twa',
        'twa-Zyyy': 'twa',
        'twb': 'twb',
        'twb-Latn-PH': 'twb',
        'twb-Latn': 'twb',
        'twb-PH': 'twb',
        'twc': 'twc',
        'twc-Zyyy-XX': 'twc',
        'twc-XX': 'twc',
        'twc-Zyyy': 'twc',
        'twd': 'twd',
        'twd-Latn-NL': 'twd',
        'twd-Latn': 'twd',
        'twd-NL': 'twd',
        'twe': 'twe',
        'twe-Latn-ID': 'twe',
        'twe-ID': 'twe',
        'twe-Latn': 'twe',
        'twf': 'twf',
        'twf-Latn-US': 'twf',
        'twf-Latn': 'twf',
        'twf-US': 'twf',
        'twg': 'twg',
        'twg-Latn-ID': 'twg',
        'twg-ID': 'twg',
        'twg-Latn': 'twg',
        'twh': 'twh',
        'twh-Latn-VN': 'twh',
        'twh-Latn': 'twh',
        'twh-VN': 'twh',
        'twh-Tavt': 'twh-Tavt',
        'twh-Tavt-VN': 'twh-Tavt',
        'twl': 'twl',
        'twl-Latn-MZ': 'twl',
        'twl-Latn': 'twl',
        'twl-MZ': 'twl',
        'twm': 'twm',
        'twm-Deva-IN': 'twm',
        'tkk': 'twm',
        'tkk-Deva': 'twm',
        'tkk-Deva-IN': 'twm',
        'tkk-IN': 'twm',
        'twm-Deva': 'twm',
        'twm-IN': 'twm',
        'twn': 'twn',
        'twn-Latn-CM': 'twn',
        'twn-CM': 'twn',
        'twn-Latn': 'twn',
        'two': 'two',
        'two-Latn-BW': 'two',
        'two-BW': 'two',
        'two-Latn': 'two',
        'twp': 'twp',
        'twp-Latn-PG': 'twp',
        'twp-Latn': 'twp',
        'twp-PG': 'twp',
        'twq': 'twq',
        'twq-Latn-NE': 'twq',
        'twq-Latn': 'twq',
        'twq-NE': 'twq',
        'twr': 'twr',
        'twr-Latn-MX': 'twr',
        'twr-Latn': 'twr',
        'twr-MX': 'twr',
        'twt': 'twt',
        'twt-Latn-BR': 'twt',
        'twt-BR': 'twt',
        'twt-Latn': 'twt',
        'twu': 'twu',
        'twu-Latn-ID': 'twu',
        'twu-ID': 'twu',
        'twu-Latn': 'twu',
        'tww': 'tww',
        'tww-Latn-PG': 'tww',
        'tww-Latn': 'tww',
        'tww-PG': 'tww',
        'twx': 'twx',
        'twx-Latn-MZ': 'twx',
        'twx-Latn': 'twx',
        'twx-MZ': 'twx',
        'twy': 'twy',
        'twy-Latn-ID': 'twy',
        'twy-ID': 'twy',
        'twy-Latn': 'twy',
        'txa': 'txa',
        'txa-Latn-MY': 'txa',
        'txa-Latn': 'txa',
        'txa-MY': 'txa',
        'txb': 'txb',
        'txb-Zyyy-XX': 'txb',
        'txb-XX': 'txb',
        'txb-Zyyy': 'txb',
        'txc': 'txc',
        'txc-Zyyy-XX': 'txc',
        'txc-XX': 'txc',
        'txc-Zyyy': 'txc',
        'txe': 'txe',
        'txe-Latn-ID': 'txe',
        'txe-ID': 'txe',
        'txe-Latn': 'txe',
        'txg-Tang': 'txg-Tang',
        'txg-Tang-CN': 'txg-Tang',
        'txg-CN': 'txg-Tang',
        'txh': 'txh',
        'txh-Zyyy-XX': 'txh',
        'txh-XX': 'txh',
        'txh-Zyyy': 'txh',
        'txi': 'txi',
        'txi-Latn-BR': 'txi',
        'txi-BR': 'txi',
        'txi-Latn': 'txi',
        'txj': 'txj',
        'txj-Latn-NG': 'txj',
        'txj-Latn': 'txj',
        'txj-NG': 'txj',
        'txm': 'txm',
        'txm-Latn-ID': 'txm',
        'txm-ID': 'txm',
        'txm-Latn': 'txm',
        'txn': 'txn',
        'txn-Latn-ID': 'txn',
        'txn-ID': 'txn',
        'txn-Latn': 'txn',
        'txo-Beng': 'txo-Beng',
        'txo-Beng-IN': 'txo-Beng',
        'txo-Deva': 'txo-Deva',
        'txo-Deva-IN': 'txo-Deva',
        'txo-Toto': 'txo-Toto',
        'txo-Toto-IN': 'txo-Toto',
        'txq': 'txq',
        'txq-Latn-ID': 'txq',
        'txq-ID': 'txq',
        'txq-Latn': 'txq',
        'txr': 'txr',
        'txr-Zyyy-XX': 'txr',
        'txr-XX': 'txr',
        'txr-Zyyy': 'txr',
        'txs': 'txs',
        'txs-Latn-ID': 'txs',
        'txs-ID': 'txs',
        'txs-Latn': 'txs',
        'txt': 'txt',
        'txt-Latn-ID': 'txt',
        'txt-ID': 'txt',
        'txt-Latn': 'txt',
        'txu': 'txu',
        'txu-Latn-BR': 'txu',
        'txu-BR': 'txu',
        'txu-Latn': 'txu',
        'txx': 'txx',
        'txx-Latn-MY': 'txx',
        'txx-Latn': 'txx',
        'txx-MY': 'txx',
        'txy': 'txy',
        'txy-Latn-MG': 'txy',
        'txy-Latn': 'txy',
        'txy-MG': 'txy',
        'ty': 'ty',
        'ty-Latn-PF': 'ty',
        'ty-Latn': 'ty',
        'ty-PF': 'ty',
        'tya': 'tya',
        'tya-Latn-PG': 'tya',
        'tya-Latn': 'tya',
        'tya-PG': 'tya',
        'tye': 'tye',
        'tye-Latn-NG': 'tye',
        'tye-Latn': 'tye',
        'tye-NG': 'tye',
        'tyh': 'tyh',
        'tyh-Latn-VN': 'tyh',
        'tyh-Latn': 'tyh',
        'tyh-VN': 'tyh',
        'tyi': 'tyi',
        'tyi-Latn-CG': 'tyi',
        'tyi-CG': 'tyi',
        'tyi-Latn': 'tyi',
        'tyj': 'tyj',
        'tyj-Latn-VN': 'tyj',
        'tmp': 'tyj',
        'tmp-Latn': 'tyj',
        'tmp-Latn-VN': 'tyj',
        'tmp-VN': 'tyj',
        'tyj-Latn': 'tyj',
        'tyj-VN': 'tyj',
        'tyj-Zzzz-x-taiyo': 'tyj-Zzzz-x-taiyo',
        'tyj-Zzzz-VN-x-taiyo': 'tyj-Zzzz-x-taiyo',
        'tmp-VN-x-taiyo': 'tyj-Zzzz-x-taiyo',
        'tyj-VN-x-taiyo': 'tyj-Zzzz-x-taiyo',
        'tyl': 'tyl',
        'tyl-Latn-VN': 'tyl',
        'tyl-Latn': 'tyl',
        'tyl-VN': 'tyl',
        'tyn': 'tyn',
        'tyn-Latn-ID': 'tyn',
        'tyn-ID': 'tyn',
        'tyn-Latn': 'tyn',
        'typ': 'typ',
        'typ-Latn-AU': 'typ',
        'typ-AU': 'typ',
        'typ-Latn': 'typ',
        'tyr': 'tyr',
        'tyr-Tavt-VN': 'tyr',
        'tyr-Tavt': 'tyr',
        'tyr-VN': 'tyr',
        'tys': 'tys',
        'tys-Latn-VN': 'tys',
        'tys-Latn': 'tys',
        'tys-VN': 'tys',
        'tyt-Latn': 'tyt-Latn',
        'tyt-Latn-VN': 'tyt-Latn',
        'tyt-Tavt': 'tyt-Tavt',
        'tyt-Tavt-VN': 'tyt-Tavt',
        'tyu': 'tyu',
        'tyu-Latn-BW': 'tyu',
        'tyu-BW': 'tyu',
        'tyu-Latn': 'tyu',
        'tyv': 'tyv',
        'tyv-Cyrl-RU': 'tyv',
        'tyv-Cyrl': 'tyv',
        'tyv-RU': 'tyv',
        'tyx': 'tyx',
        'tyx-Latn-CG': 'tyx',
        'tyx-CG': 'tyx',
        'tyx-Latn': 'tyx',
        'tyz': 'tyz',
        'tyz-Latn-VN': 'tyz',
        'tyz-Latn': 'tyz',
        'tyz-VN': 'tyz',
        'tza': 'tza',
        'tza-Zxxx-TZ': 'tza',
        'sgn-tza': 'tza',
        'sgn-tza-TZ': 'tza',
        'tza-TZ': 'tza',
        'tza-Zxxx': 'tza',
        'tzh': 'tzh',
        'tzh-Latn-MX': 'tzh',
        'tzh-Latn': 'tzh',
        'tzh-MX': 'tzh',
        'tzj': 'tzj',
        'tzj-Latn-GT': 'tzj',
        'tzj-GT': 'tzj',
        'tzj-Latn': 'tzj',
        'tzj-x-western': 'tzj-x-western',
        'tzj-Latn-GT-x-western': 'tzj-x-western',
        'tzj-GT-x-western': 'tzj-x-western',
        'tzj-Latn-x-western': 'tzj-x-western',
        'tzl': 'tzl',
        'tzl-Zyyy-001': 'tzl',
        'tzl-001': 'tzl',
        'tzl-Zyyy': 'tzl',
        'tzm': 'tzm',
        'tzm-Latn-MA': 'tzm',
        'tzm-Latn': 'tzm',
        'tzm-MA': 'tzm',
        'tzm-Arab': 'tzm-Arab',
        'tzm-Arab-MA': 'tzm-Arab',
        'tzm-Tfng': 'tzm-Tfng',
        'tzm-Tfng-MA': 'tzm-Tfng',
        'tzn': 'tzn',
        'tzn-Latn-ID': 'tzn',
        'tzn-ID': 'tzn',
        'tzn-Latn': 'tzn',
        'tzo': 'tzo',
        'tzo-Latn-MX': 'tzo',
        'tzo-Latn': 'tzo',
        'tzo-MX': 'tzo',
        'tzo-x-huixtan': 'tzo-x-huixtan',
        'tzo-Latn-MX-x-huixtan': 'tzo-x-huixtan',
        'tzo-Latn-x-huixtan': 'tzo-x-huixtan',
        'tzo-MX-x-huixtan': 'tzo-x-huixtan',
        'tzo-x-sanandre': 'tzo-x-sanandre',
        'tzo-Latn-MX-x-sanandre': 'tzo-x-sanandre',
        'tzo-Latn-x-sanandre': 'tzo-x-sanandre',
        'tzo-MX-x-sanandre': 'tzo-x-sanandre',
        'tzo-x-zinacntn': 'tzo-x-zinacntn',
        'tzo-Latn-MX-x-zinacntn': 'tzo-x-zinacntn',
        'tzo-Latn-x-zinacntn': 'tzo-x-zinacntn',
        'tzo-MX-x-zinacntn': 'tzo-x-zinacntn',
        'tzx': 'tzx',
        'tzx-Latn-PG': 'tzx',
        'tzx-Latn': 'tzx',
        'tzx-PG': 'tzx',
        'uam': 'uam',
        'uam-Latn-BR': 'uam',
        'uam-BR': 'uam',
        'uam-Latn': 'uam',
        'uan': 'uan',
        'uan-Zyyy-LA': 'uan',
        'uan-LA': 'uan',
        'uan-Zyyy': 'uan',
        'uar': 'uar',
        'uar-Latn-PG': 'uar',
        'uar-Latn': 'uar',
        'uar-PG': 'uar',
        'uba': 'uba',
        'uba-Latn-NG': 'uba',
        'uba-Latn': 'uba',
        'uba-NG': 'uba',
        'ubi': 'ubi',
        'ubi-Latn-TD': 'ubi',
        'ubi-Latn': 'ubi',
        'ubi-TD': 'ubi',
        'ubl': 'ubl',
        'ubl-Latn-PH': 'ubl',
        'ubl-Latn': 'ubl',
        'ubl-PH': 'ubl',
        'ubr': 'ubr',
        'ubr-Latn-PG': 'ubr',
        'ubr-Latn': 'ubr',
        'ubr-PG': 'ubr',
        'ubu': 'ubu',
        'ubu-Latn-PG': 'ubu',
        'ubu-Latn': 'ubu',
        'ubu-PG': 'ubu',
        'ubu-x-kala': 'ubu-x-kala',
        'ubu-Latn-PG-x-kala': 'ubu-x-kala',
        'ubu-Latn-x-kala': 'ubu-x-kala',
        'ubu-PG-x-kala': 'ubu-x-kala',
        'ubu-x-nopenge': 'ubu-x-nopenge',
        'ubu-Latn-PG-x-nopenge': 'ubu-x-nopenge',
        'ubu-Latn-x-nopenge': 'ubu-x-nopenge',
        'ubu-PG-x-nopenge': 'ubu-x-nopenge',
        'uby': 'uby',
        'uby-Zyyy-TR': 'uby',
        'uby-TR': 'uby',
        'uby-Zyyy': 'uby',
        'uda': 'uda',
        'uda-Latn-NG': 'uda',
        'uda-Latn': 'uda',
        'uda-NG': 'uda',
        'ude': 'ude',
        'ude-Cyrl-RU': 'ude',
        'ude-Cyrl': 'ude',
        'ude-RU': 'ude',
        'udg': 'udg',
        'udg-Mlym-IN': 'udg',
        'udg-IN': 'udg',
        'udg-Mlym': 'udg',
        'udi': 'udi',
        'udi-Cyrl-AZ': 'udi',
        'udi-AZ': 'udi',
        'udi-Cyrl': 'udi',
        'udj': 'udj',
        'udj-Latn-ID': 'udj',
        'udj-ID': 'udj',
        'udj-Latn': 'udj',
        'udl': 'udl',
        'udl-Latn-CM': 'udl',
        'udl-CM': 'udl',
        'udl-Latn': 'udl',
        'udm': 'udm',
        'udm-Cyrl-RU': 'udm',
        'udm-Cyrl': 'udm',
        'udm-RU': 'udm',
        'udm-Latn': 'udm-Latn',
        'udm-Latn-RU': 'udm-Latn',
        'udu': 'udu',
        'udu-Latn-SD': 'udu',
        'udu-Latn': 'udu',
        'udu-SD': 'udu',
        'ues': 'ues',
        'ues-Latn-ID': 'ues',
        'ues-ID': 'ues',
        'ues-Latn': 'ues',
        'ufi': 'ufi',
        'ufi-Latn-PG': 'ufi',
        'ufi-Latn': 'ufi',
        'ufi-PG': 'ufi',
        'ug': 'ug',
        'ug-Arab-CN': 'ug',
        'ug-Arab': 'ug',
        'ug-CN': 'ug',
        'ug-KZ': 'ug-KZ',
        'ug-Cyrl-KZ': 'ug-KZ',
        'ug-Cyrl': 'ug-KZ',
        'ug-Latn': 'ug-Latn',
        'ug-Latn-CN': 'ug-Latn',
        'ug-MN': 'ug-MN',
        'ug-Cyrl-MN': 'ug-MN',
        'uga': 'uga',
        'uga-Ugar-SY': 'uga',
        'uga-SY': 'uga',
        'uga-Ugar': 'uga',
        'ugb': 'ugb',
        'ugb-Latn-AU': 'ugb',
        'ugb-AU': 'ugb',
        'ugb-Latn': 'ugb',
        'uge': 'uge',
        'uge-Latn-SB': 'uge',
        'uge-Latn': 'uge',
        'uge-SB': 'uge',
        'ugn': 'ugn',
        'ugn-Zxxx-UG': 'ugn',
        'sgn-ugn': 'ugn',
        'sgn-ugn-UG': 'ugn',
        'ugn-UG': 'ugn',
        'ugn-Zxxx': 'ugn',
        'ugo': 'ugo',
        'ugo-Zyyy-TH': 'ugo',
        'ugo-TH': 'ugo',
        'ugo-Zyyy': 'ugo',
        'ugy': 'ugy',
        'ugy-Zxxx-UY': 'ugy',
        'sgn-ugy': 'ugy',
        'sgn-ugy-UY': 'ugy',
        'ugy-UY': 'ugy',
        'ugy-Zxxx': 'ugy',
        'uha': 'uha',
        'uha-Latn-NG': 'uha',
        'uha-Latn': 'uha',
        'uha-NG': 'uha',
        'uhn': 'uhn',
        'uhn-Latn-ID': 'uhn',
        'uhn-ID': 'uhn',
        'uhn-Latn': 'uhn',
        'uis': 'uis',
        'uis-Latn-PG': 'uis',
        'uis-Latn': 'uis',
        'uis-PG': 'uis',
        'uiv': 'uiv',
        'uiv-Latn-CM': 'uiv',
        'uiv-CM': 'uiv',
        'uiv-Latn': 'uiv',
        'uji': 'uji',
        'uji-Latn-NG': 'uji',
        'uji-Latn': 'uji',
        'uji-NG': 'uji',
        'uk': 'uk',
        'uk-Cyrl-UA': 'uk',
        'uk-Cyrl': 'uk',
        'uk-UA': 'uk',
        'uka': 'uka',
        'uka-Latn-ID': 'uka',
        'uka-ID': 'uka',
        'uka-Latn': 'uka',
        'ukg': 'ukg',
        'ukg-Latn-PG': 'ukg',
        'ukg-Latn': 'ukg',
        'ukg-PG': 'ukg',
        'ukh': 'ukh',
        'ukh-Latn-CF': 'ukh',
        'ukh-CF': 'ukh',
        'ukh-Latn': 'ukh',
        'uki': 'uki',
        'uki-Orya-IN': 'uki',
        'uki-IN': 'uki',
        'uki-Orya': 'uki',
        'ukk': 'ukk',
        'ukk-Latn-MM': 'ukk',
        'ukk-Latn': 'ukk',
        'ukk-MM': 'ukk',
        'ukl': 'ukl',
        'ukl-Zxxx-UA': 'ukl',
        'sgn-ukl': 'ukl',
        'sgn-ukl-UA': 'ukl',
        'ukl-UA': 'ukl',
        'ukl-Zxxx': 'ukl',
        'ukp': 'ukp',
        'ukp-Latn-NG': 'ukp',
        'ukp-Latn': 'ukp',
        'ukp-NG': 'ukp',
        'ukq': 'ukq',
        'ukq-Latn-NG': 'ukq',
        'ukq-Latn': 'ukq',
        'ukq-NG': 'ukq',
        'uks': 'uks',
        'uks-Zxxx-BR': 'uks',
        'sgn-uks': 'uks',
        'sgn-uks-BR': 'uks',
        'uks-BR': 'uks',
        'uks-Zxxx': 'uks',
        'uku': 'uku',
        'uku-Latn-NG': 'uku',
        'uku-Latn': 'uku',
        'uku-NG': 'uku',
        'ukw': 'ukw',
        'ukw-Latn-NG': 'ukw',
        'ukw-Latn': 'ukw',
        'ukw-NG': 'ukw',
        'uky': 'uky',
        'uky-Latn-AU': 'uky',
        'uky-AU': 'uky',
        'uky-Latn': 'uky',
        'ula': 'ula',
        'ula-Latn-NG': 'ula',
        'ula-Latn': 'ula',
        'ula-NG': 'ula',
        'ulb': 'ulb',
        'ulb-Latn-NG': 'ulb',
        'ulb-Latn': 'ulb',
        'ulb-NG': 'ulb',
        'ulc': 'ulc',
        'ulc-Cyrl-RU': 'ulc',
        'ulc-Cyrl': 'ulc',
        'ulc-RU': 'ulc',
        'ule': 'ule',
        'ule-Latn-AR': 'ule',
        'ule-AR': 'ule',
        'ule-Latn': 'ule',
        'ulf': 'ulf',
        'ulf-Latn-ID': 'ulf',
        'ulf-ID': 'ulf',
        'ulf-Latn': 'ulf',
        'uli': 'uli',
        'uli-Latn-FM': 'uli',
        'uli-FM': 'uli',
        'uli-Latn': 'uli',
        'ulk': 'ulk',
        'ulk-Latn-AU': 'ulk',
        'ulk-AU': 'ulk',
        'ulk-Latn': 'ulk',
        'ull': 'ull',
        'ull-Zyyy-IN': 'ull',
        'ull-IN': 'ull',
        'ull-Zyyy': 'ull',
        'ulm': 'ulm',
        'ulm-Latn-ID': 'ulm',
        'ulm-ID': 'ulm',
        'ulm-Latn': 'ulm',
        'uln': 'uln',
        'uln-Latn-PG': 'uln',
        'uln-Latn': 'uln',
        'uln-PG': 'uln',
        'ulu': 'ulu',
        'ulu-Latn-ID': 'ulu',
        'ulu-ID': 'ulu',
        'ulu-Latn': 'ulu',
        'ulw': 'ulw',
        'ulw-Latn-NI': 'ulw',
        'ulw-Latn': 'ulw',
        'ulw-NI': 'ulw',
        'uma': 'uma',
        'uma-Latn-US': 'uma',
        'uma-Latn': 'uma',
        'uma-US': 'uma',
        'umb': 'umb',
        'umb-Latn-AO': 'umb',
        'umb-AO': 'umb',
        'umb-Latn': 'umb',
        'umc': 'umc',
        'umc-Zyyy-XX': 'umc',
        'umc-XX': 'umc',
        'umc-Zyyy': 'umc',
        'umd': 'umd',
        'umd-Latn-AU': 'umd',
        'umd-AU': 'umd',
        'umd-Latn': 'umd',
        'umg': 'umg',
        'umg-Qaax-AU': 'umg',
        'umg-AU': 'umg',
        'umg-Qaax': 'umg',
        'umi': 'umi',
        'umi-Latn-MY': 'umi',
        'umi-Latn': 'umi',
        'umi-MY': 'umi',
        'umm': 'umm',
        'umm-Latn-NG': 'umm',
        'umm-Latn': 'umm',
        'umm-NG': 'umm',
        'umn': 'umn',
        'umn-Latn-MM': 'umn',
        'umn-Latn': 'umn',
        'umn-MM': 'umn',
        'umo': 'umo',
        'umo-Latn-BR': 'umo',
        'umo-BR': 'umo',
        'umo-Latn': 'umo',
        'ump': 'ump',
        'ump-Latn-AU': 'ump',
        'ump-AU': 'ump',
        'ump-Latn': 'ump',
        'umr': 'umr',
        'umr-Latn-AU': 'umr',
        'umr-AU': 'umr',
        'umr-Latn': 'umr',
        'ums': 'ums',
        'ums-Latn-ID': 'ums',
        'ums-ID': 'ums',
        'ums-Latn': 'ums',
        'una': 'una',
        'una-Latn-PG': 'una',
        'una-Latn': 'una',
        'una-PG': 'una',
        'und': 'und',
        'und-Zyyy-001': 'und',
        'und-001': 'und',
        'und-Zyyy': 'und',
        'une': 'une',
        'une-Latn-NG': 'une',
        'une-Latn': 'une',
        'une-NG': 'une',
        'ung': 'ung',
        'ung-Latn-AU': 'ung',
        'ung-AU': 'ung',
        'ung-Latn': 'ung',
        'unk': 'unk',
        'unk-Latn-BR': 'unk',
        'unk-BR': 'unk',
        'unk-Latn': 'unk',
        'unm': 'unm',
        'unm-Zyyy-US': 'unm',
        'unm-US': 'unm',
        'unm-Zyyy': 'unm',
        'unn': 'unn',
        'unn-Latn-AU': 'unn',
        'unn-AU': 'unn',
        'unn-Latn': 'unn',
        'unr': 'unr',
        'unr-Beng-IN': 'unr',
        'unr-Beng': 'unr',
        'unr-IN': 'unr',
        'unr-Latn': 'unr-Latn',
        'unr-Latn-IN': 'unr-Latn',
        'unr-NP': 'unr-NP',
        'unr-Deva-NP': 'unr-NP',
        'unr-Deva': 'unr-NP',
        'unr-Orya': 'unr-Orya',
        'unr-Orya-IN': 'unr-Orya',
        'unu': 'unu',
        'unu-Latn-PG': 'unu',
        'unu-Latn': 'unu',
        'unu-PG': 'unu',
        'unx': 'unx',
        'unx-Beng-IN': 'unx',
        'unx-Beng': 'unx',
        'unx-IN': 'unx',
        'unx-Deva': 'unx-Deva',
        'unx-Deva-IN': 'unx-Deva',
        'unz': 'unz',
        'unz-Latn-ID': 'unz',
        'unz-ID': 'unz',
        'unz-Latn': 'unz',
        'upi': 'upi',
        'upi-Latn-PG': 'upi',
        'upi-Latn': 'upi',
        'upi-PG': 'upi',
        'upv': 'upv',
        'upv-Latn-VU': 'upv',
        'upv-Latn': 'upv',
        'upv-VU': 'upv',
        'ur': 'ur',
        'ur-Arab-PK': 'ur',
        'ur-Arab': 'ur',
        'ur-PK': 'ur',
        'ur-Brai': 'ur-Brai',
        'ur-Brai-PK': 'ur-Brai',
        'ur-IN': 'ur-IN',
        'ur-Arab-IN': 'ur-IN',
        'ur-Latn': 'ur-Latn',
        'ur-Latn-PK': 'ur-Latn',
        'ura': 'ura',
        'ura-Latn-PE': 'ura',
        'ura-Latn': 'ura',
        'ura-PE': 'ura',
        'urb': 'urb',
        'urb-Latn-BR': 'urb',
        'urb-BR': 'urb',
        'urb-Latn': 'urb',
        'urc': 'urc',
        'urc-Latn-AU': 'urc',
        'urc-AU': 'urc',
        'urc-Latn': 'urc',
        'ure': 'ure',
        'ure-Latn-BO': 'ure',
        'ure-BO': 'ure',
        'ure-Latn': 'ure',
        'urf': 'urf',
        'urf-Latn-AU': 'urf',
        'urf-AU': 'urf',
        'urf-Latn': 'urf',
        'urg': 'urg',
        'urg-Latn-PG': 'urg',
        'urg-Latn': 'urg',
        'urg-PG': 'urg',
        'urh': 'urh',
        'urh-Latn-NG': 'urh',
        'urh-Latn': 'urh',
        'urh-NG': 'urh',
        'uri': 'uri',
        'uri-Latn-PG': 'uri',
        'uri-Latn': 'uri',
        'uri-PG': 'uri',
        'urk': 'urk',
        'urk-Thai-TH': 'urk',
        'ms-urk': 'urk',
        'ms-urk-TH': 'urk',
        'urk-TH': 'urk',
        'urk-Thai': 'urk',
        'url': 'url',
        'url-Zyyy-IN': 'url',
        'url-IN': 'url',
        'url-Zyyy': 'url',
        'urm': 'urm',
        'urm-Latn-PG': 'urm',
        'urm-Latn': 'urm',
        'urm-PG': 'urm',
        'urn': 'urn',
        'urn-Latn-ID': 'urn',
        'urn-ID': 'urn',
        'urn-Latn': 'urn',
        'uro': 'uro',
        'uro-Latn-PG': 'uro',
        'uro-Latn': 'uro',
        'uro-PG': 'uro',
        'urp': 'urp',
        'urp-Latn-BR': 'urp',
        'urp-BR': 'urp',
        'urp-Latn': 'urp',
        'urr': 'urr',
        'urr-Latn-VU': 'urr',
        'urr-Latn': 'urr',
        'urr-VU': 'urr',
        'urt': 'urt',
        'urt-Latn-PG': 'urt',
        'urt-Latn': 'urt',
        'urt-PG': 'urt',
        'uru': 'uru',
        'uru-Latn-BR': 'uru',
        'uru-BR': 'uru',
        'uru-Latn': 'uru',
        'urv': 'urv',
        'urv-Latn-PG': 'urv',
        'urv-Latn': 'urv',
        'urv-PG': 'urv',
        'urw': 'urw',
        'urw-Latn-PG': 'urw',
        'urw-Latn': 'urw',
        'urw-PG': 'urw',
        'urx': 'urx',
        'urx-Latn-PG': 'urx',
        'urx-Latn': 'urx',
        'urx-PG': 'urx',
        'ury': 'ury',
        'ury-Latn-ID': 'ury',
        'ury-ID': 'ury',
        'ury-Latn': 'ury',
        'urz': 'urz',
        'urz-Latn-BR': 'urz',
        'urz-BR': 'urz',
        'urz-Latn': 'urz',
        'usa': 'usa',
        'usa-Latn-PG': 'usa',
        'usa-Latn': 'usa',
        'usa-PG': 'usa',
        'ush': 'ush',
        'ush-Arab-PK': 'ush',
        'ush-Arab': 'ush',
        'ush-PK': 'ush',
        'usi-Beng': 'usi-Beng',
        'usi-Beng-BD': 'usi-Beng',
        'usi-Latn': 'usi-Latn',
        'usi-Latn-BD': 'usi-Latn',
        'usk': 'usk',
        'usk-Latn-CM': 'usk',
        'usk-CM': 'usk',
        'usk-Latn': 'usk',
        'usp': 'usp',
        'usp-Latn-GT': 'usp',
        'usp-GT': 'usp',
        'usp-Latn': 'usp',
        'uss': 'uss',
        'uss-Latn-NG': 'uss',
        'uss-Latn': 'uss',
        'uss-NG': 'uss',
        'usu': 'usu',
        'usu-Latn-PG': 'usu',
        'usu-Latn': 'usu',
        'usu-PG': 'usu',
        'uta': 'uta',
        'uta-Latn-NG': 'uta',
        'uta-Latn': 'uta',
        'uta-NG': 'uta',
        'ute': 'ute',
        'ute-Latn-US': 'ute',
        'ute-Latn': 'ute',
        'ute-US': 'ute',
        'uth': 'uth',
        'uth-Latn-NG': 'uth',
        'dud': 'uth',
        'dud-Latn': 'uth',
        'dud-Latn-NG': 'uth',
        'dud-NG': 'uth',
        'uth-Latn': 'uth',
        'uth-NG': 'uth',
        'utp': 'utp',
        'utp-Latn-SB': 'utp',
        'utp-Latn': 'utp',
        'utp-SB': 'utp',
        'utr': 'utr',
        'utr-Latn-NG': 'utr',
        'utr-Latn': 'utr',
        'utr-NG': 'utr',
        'utu': 'utu',
        'utu-Latn-PG': 'utu',
        'utu-Latn': 'utu',
        'utu-PG': 'utu',
        'uum': 'uum',
        'uum-Grek-GE': 'uum',
        'uum-GE': 'uum',
        'uum-Grek': 'uum',
        'uum-Cyrl': 'uum-Cyrl',
        'uum-Cyrl-GE': 'uum-Cyrl',
        'uun': 'uun',
        'uun-Latn-TW': 'uun',
        'uun-Latn': 'uun',
        'uun-TW': 'uun',
        'uur': 'uur',
        'uur-Latn-VU': 'uur',
        'uur-Latn': 'uur',
        'uur-VU': 'uur',
        'uuu': 'uuu',
        'uuu-Zyyy-CN': 'uuu',
        'uuu-CN': 'uuu',
        'uuu-Zyyy': 'uuu',
        'uve': 'uve',
        'uve-Latn-NC': 'uve',
        'uve-Latn': 'uve',
        'uve-NC': 'uve',
        'uvh': 'uvh',
        'uvh-Latn-PG': 'uvh',
        'uvh-Latn': 'uvh',
        'uvh-PG': 'uvh',
        'uvl': 'uvl',
        'uvl-Latn-PG': 'uvl',
        'uvl-Latn': 'uvl',
        'uvl-PG': 'uvl',
        'uwa': 'uwa',
        'uwa-Latn-AU': 'uwa',
        'uwa-AU': 'uwa',
        'uwa-Latn': 'uwa',
        'uya': 'uya',
        'uya-Latn-NG': 'uya',
        'uya-Latn': 'uya',
        'uya-NG': 'uya',
        'uz': 'uz',
        'uz-Latn-UZ': 'uz',
        'uz-Latn': 'uz',
        'uz-UZ': 'uz',
        'uz-uzn': 'uz',
        'uz-uzn-UZ': 'uz',
        'uzn': 'uz',
        'uzn-Latn': 'uz',
        'uzn-Latn-UZ': 'uz',
        'uzn-UZ': 'uz',
        'uz-AF': 'uz-AF',
        'uz-Arab-AF': 'uz-AF',
        'uz-Arab': 'uz-AF',
        'uzn-Arab': 'uz-AF',
        'uzn-Arab-AF': 'uz-AF',
        'uz-Brai': 'uz-Brai',
        'uz-Brai-UZ': 'uz-Brai',
        'uzn-Brai': 'uz-Brai',
        'uzn-Brai-UZ': 'uz-Brai',
        'uz-CN': 'uz-CN',
        'uz-Cyrl-CN': 'uz-CN',
        'uz-Cyrl': 'uz-Cyrl',
        'uz-Cyrl-UZ': 'uz-Cyrl',
        'uzn-Cyrl': 'uz-Cyrl',
        'uzn-Cyrl-UZ': 'uz-Cyrl',
        'uz-Sogd': 'uz-Sogd',
        'uz-Sogd-CN': 'uz-Sogd',
        'uzn-Sogd': 'uz-Sogd',
        'uzn-Sogd-CN': 'uz-Sogd',
        'uzs': 'uzs',
        'uzs-Arab-AF': 'uzs',
        'uz-uzs': 'uzs',
        'uz-uzs-AF': 'uzs',
        'uzs-AF': 'uzs',
        'uzs-Arab': 'uzs',
        'vaa': 'vaa',
        'vaa-Taml-IN': 'vaa',
        'vaa-IN': 'vaa',
        'vaa-Taml': 'vaa',
        'vae': 'vae',
        'vae-Latn-CF': 'vae',
        'vae-CF': 'vae',
        'vae-Latn': 'vae',
        'vaf': 'vaf',
        'vaf-Arab-IR': 'vaf',
        'vaf-Arab': 'vaf',
        'vaf-IR': 'vaf',
        'vag': 'vag',
        'vag-Latn-GH': 'vag',
        'vag-GH': 'vag',
        'vag-Latn': 'vag',
        'vah': 'vah',
        'vah-Deva-IN': 'vah',
        'vah-Deva': 'vah',
        'vah-IN': 'vah',
        'vai': 'vai',
        'vai-Vaii-LR': 'vai',
        'vai-LR': 'vai',
        'vai-Vaii': 'vai',
        'vai-Latn': 'vai-Latn',
        'vai-Latn-LR': 'vai-Latn',
        'vaj': 'vaj',
        'vaj-Latn-NA': 'vaj',
        'gfx': 'vaj',
        'gfx-Latn': 'vaj',
        'gfx-Latn-NA': 'vaj',
        'gfx-NA': 'vaj',
        'mwj': 'vaj',
        'mwj-Latn': 'vaj',
        'mwj-Latn-NA': 'vaj',
        'mwj-NA': 'vaj',
        'oun': 'vaj',
        'oun-Latn': 'vaj',
        'oun-Latn-NA': 'vaj',
        'oun-NA': 'vaj',
        'vaj-Latn': 'vaj',
        'vaj-NA': 'vaj',
        'val': 'val',
        'val-Latn-PG': 'val',
        'val-Latn': 'val',
        'val-PG': 'val',
        'vam': 'vam',
        'vam-Latn-PG': 'vam',
        'vam-Latn': 'vam',
        'vam-PG': 'vam',
        'van': 'van',
        'van-Latn-PG': 'van',
        'van-Latn': 'van',
        'van-PG': 'van',
        'vao': 'vao',
        'vao-Latn-VU': 'vao',
        'vao-Latn': 'vao',
        'vao-VU': 'vao',
        'vap': 'vap',
        'vap-Latn-IN': 'vap',
        'vap-IN': 'vap',
        'vap-Latn': 'vap',
        'var': 'var',
        'var-Latn-MX': 'var',
        'var-Latn': 'var',
        'var-MX': 'var',
        'vas': 'vas',
        'vas-Deva-IN': 'vas',
        'vas-Deva': 'vas',
        'vas-IN': 'vas',
        'vas-Gujr': 'vas-Gujr',
        'vas-Gujr-IN': 'vas-Gujr',
        'vau': 'vau',
        'vau-Latn-CD': 'vau',
        'vau-CD': 'vau',
        'vau-Latn': 'vau',
        'vav': 'vav',
        'vav-Deva-IN': 'vav',
        'vav-Deva': 'vav',
        'vav-IN': 'vav',
        'vav-Gujr': 'vav-Gujr',
        'vav-Gujr-IN': 'vav-Gujr',
        'vay': 'vay',
        'vay-Deva-NP': 'vay',
        'vay-Deva': 'vay',
        'vay-NP': 'vay',
        'vbb': 'vbb',
        'vbb-Latn-ID': 'vbb',
        'vbb-ID': 'vbb',
        'vbb-Latn': 'vbb',
        'vbk': 'vbk',
        'vbk-Latn-PH': 'vbk',
        'vbk-Latn': 'vbk',
        'vbk-PH': 'vbk',
        've': 've',
        've-Latn-ZA': 've',
        've-Latn': 've',
        've-ZA': 've',
        've-Brai': 've-Brai',
        've-Brai-ZA': 've-Brai',
        'vec': 'vec',
        'vec-Latn-IT': 'vec',
        'vec-IT': 'vec',
        'vec-Latn': 'vec',
        'ved': 'ved',
        'ved-Zyyy-LK': 'ved',
        'ved-LK': 'ved',
        'ved-Zyyy': 'ved',
        'vel': 'vel',
        'vel-Zyyy-NL': 'vel',
        'vel-NL': 'vel',
        'vel-Zyyy': 'vel',
        'vem': 'vem',
        'vem-Latn-NG': 'vem',
        'vem-Latn': 'vem',
        'vem-NG': 'vem',
        'veo': 'veo',
        'veo-Zyyy-US': 'veo',
        'veo-US': 'veo',
        'veo-Zyyy': 'veo',
        'vep': 'vep',
        'vep-Latn-RU': 'vep',
        'vep-Latn': 'vep',
        'vep-RU': 'vep',
        'ver': 'ver',
        'ver-Latn-NG': 'ver',
        'ver-Latn': 'ver',
        'ver-NG': 'ver',
        'vgr': 'vgr',
        'vgr-Arab-PK': 'vgr',
        'vgr-Arab': 'vgr',
        'vgr-PK': 'vgr',
        'vgt': 'vgt',
        'vgt-Zxxx-BE': 'vgt',
        'sgn-vgt': 'vgt',
        'sgn-vgt-BE': 'vgt',
        'vgt-BE': 'vgt',
        'vgt-Zxxx': 'vgt',
        'vi': 'vi',
        'vi-Latn-VN': 'vi',
        'vi-Latn': 'vi',
        'vi-VN': 'vi',
        'vi-Brai': 'vi-Brai',
        'vi-Brai-VN': 'vi-Brai',
        'vi-Hani': 'vi-Hani',
        'vi-Hani-VN': 'vi-Hani',
        'vic': 'vic',
        'vic-Latn-SX': 'vic',
        'vic-Latn': 'vic',
        'vic-SX': 'vic',
        'vid': 'vid',
        'vid-Latn-TZ': 'vid',
        'vid-Latn': 'vid',
        'vid-TZ': 'vid',
        'vif': 'vif',
        'vif-Latn-CG': 'vif',
        'vif-CG': 'vif',
        'vif-Latn': 'vif',
        'vig': 'vig',
        'vig-Latn-BF': 'vig',
        'vig-BF': 'vig',
        'vig-Latn': 'vig',
        'vil': 'vil',
        'vil-Latn-AR': 'vil',
        'vil-AR': 'vil',
        'vil-Latn': 'vil',
        'vin': 'vin',
        'vin-Latn-TZ': 'vin',
        'vin-Latn': 'vin',
        'vin-TZ': 'vin',
        'vis': 'vis',
        'vis-Zyyy-IN': 'vis',
        'vis-IN': 'vis',
        'vis-Zyyy': 'vis',
        'vit': 'vit',
        'vit-Latn-NG': 'vit',
        'vit-Latn': 'vit',
        'vit-NG': 'vit',
        'viv': 'viv',
        'viv-Latn-PG': 'viv',
        'viv-Latn': 'viv',
        'viv-PG': 'viv',
        'vka': 'vka',
        'vka-Latn-AU': 'vka',
        'vka-AU': 'vka',
        'vka-Latn': 'vka',
        'vki': 'vki',
        'vki-Latn-NG': 'vki',
        'vki-Latn': 'vki',
        'vki-NG': 'vki',
        'vkj': 'vkj',
        'vkj-Latn-TD': 'vkj',
        'vkj-Latn': 'vkj',
        'vkj-TD': 'vkj',
        'vkk': 'vkk',
        'vkk-Latn-ID': 'vkk',
        'ms-vkk': 'vkk',
        'ms-vkk-ID': 'vkk',
        'vkk-ID': 'vkk',
        'vkk-Latn': 'vkk',
        'vkl': 'vkl',
        'vkl-Latn-ID': 'vkl',
        'vkl-ID': 'vkl',
        'vkl-Latn': 'vkl',
        'vkm': 'vkm',
        'vkm-Latn-BR': 'vkm',
        'vkm-BR': 'vkm',
        'vkm-Latn': 'vkm',
        'vko': 'vko',
        'vko-Latn-ID': 'vko',
        'vko-ID': 'vko',
        'vko-Latn': 'vko',
        'vkp-Deva': 'vkp-Deva',
        'vkp-Deva-IN': 'vkp-Deva',
        'vkp-Latn': 'vkp-Latn',
        'vkp-Latn-IN': 'vkp-Latn',
        'vkt': 'vkt',
        'vkt-Latn-ID': 'vkt',
        'ms-vkt': 'vkt',
        'ms-vkt-ID': 'vkt',
        'vkt-ID': 'vkt',
        'vkt-Latn': 'vkt',
        'vku': 'vku',
        'vku-Latn-AU': 'vku',
        'vku-AU': 'vku',
        'vku-Latn': 'vku',
        'vlp': 'vlp',
        'vlp-Latn-VU': 'vlp',
        'vlp-Latn': 'vlp',
        'vlp-VU': 'vlp',
        'vls': 'vls',
        'vls-Latn-BE': 'vls',
        'vls-BE': 'vls',
        'vls-Latn': 'vls',
        'vma': 'vma',
        'vma-Latn-AU': 'vma',
        'vma-AU': 'vma',
        'vma-Latn': 'vma',
        'vmb': 'vmb',
        'vmb-Latn-AU': 'vmb',
        'vmb-AU': 'vmb',
        'vmb-Latn': 'vmb',
        'vmc': 'vmc',
        'vmc-Latn-MX': 'vmc',
        'vmc-Latn': 'vmc',
        'vmc-MX': 'vmc',
        'vmd': 'vmd',
        'vmd-Zyyy-IN': 'vmd',
        'vmd-IN': 'vmd',
        'vmd-Zyyy': 'vmd',
        'vme': 'vme',
        'vme-Latn-ID': 'vme',
        'vme-ID': 'vme',
        'vme-Latn': 'vme',
        'vmf': 'vmf',
        'vmf-Latn-DE': 'vmf',
        'vmf-DE': 'vmf',
        'vmf-Latn': 'vmf',
        'vmg': 'vmg',
        'vmg-Latn-PG': 'vmg',
        'vmg-Latn': 'vmg',
        'vmg-PG': 'vmg',
        'vmh': 'vmh',
        'vmh-Zyyy-IR': 'vmh',
        'vmh-IR': 'vmh',
        'vmh-Zyyy': 'vmh',
        'vmi': 'vmi',
        'vmi-Latn-AU': 'vmi',
        'vmi-AU': 'vmi',
        'vmi-Latn': 'vmi',
        'vmj': 'vmj',
        'vmj-Latn-MX': 'vmj',
        'vmj-Latn': 'vmj',
        'vmj-MX': 'vmj',
        'vmk': 'vmk',
        'vmk-Latn-MZ': 'vmk',
        'vmk-Latn': 'vmk',
        'vmk-MZ': 'vmk',
        'vml': 'vml',
        'vml-Latn-AU': 'vml',
        'vml-AU': 'vml',
        'vml-Latn': 'vml',
        'vmm': 'vmm',
        'vmm-Latn-MX': 'vmm',
        'vmm-Latn': 'vmm',
        'vmm-MX': 'vmm',
        'vmp': 'vmp',
        'vmp-Latn-MX': 'vmp',
        'vmp-Latn': 'vmp',
        'vmp-MX': 'vmp',
        'vmq': 'vmq',
        'vmq-Latn-MX': 'vmq',
        'vmq-Latn': 'vmq',
        'vmq-MX': 'vmq',
        'vmr': 'vmr',
        'vmr-Latn-MZ': 'vmr',
        'vmr-Latn': 'vmr',
        'vmr-MZ': 'vmr',
        'vms': 'vms',
        'vms-Latn-ID': 'vms',
        'vms-ID': 'vms',
        'vms-Latn': 'vms',
        'vmu': 'vmu',
        'vmu-Latn-AU': 'vmu',
        'vmu-AU': 'vmu',
        'vmu-Latn': 'vmu',
        'vmv': 'vmv',
        'vmv-Zyyy-US': 'vmv',
        'vmv-US': 'vmv',
        'vmv-Zyyy': 'vmv',
        'vmw': 'vmw',
        'vmw-Latn-MZ': 'vmw',
        'vmw-Latn': 'vmw',
        'vmw-MZ': 'vmw',
        'vmw-Arab': 'vmw-Arab',
        'vmw-Arab-MZ': 'vmw-Arab',
        'vmx': 'vmx',
        'vmx-Latn-MX': 'vmx',
        'vmx-Latn': 'vmx',
        'vmx-MX': 'vmx',
        'vmy': 'vmy',
        'vmy-Latn-MX': 'vmy',
        'vmy-Latn': 'vmy',
        'vmy-MX': 'vmy',
        'vmz': 'vmz',
        'vmz-Latn-MX': 'vmz',
        'vmz-Latn': 'vmz',
        'vmz-MX': 'vmz',
        'vnk': 'vnk',
        'vnk-Latn-SB': 'vnk',
        'vnk-Latn': 'vnk',
        'vnk-SB': 'vnk',
        'vnm': 'vnm',
        'vnm-Latn-VU': 'vnm',
        'vnm-Latn': 'vnm',
        'vnm-VU': 'vnm',
        'vnp': 'vnp',
        'vnp-Latn-VU': 'vnp',
        'vnp-Latn': 'vnp',
        'vnp-VU': 'vnp',
        'vo': 'vo',
        'vo-Latn-001': 'vo',
        'vo-001': 'vo',
        'vo-Latn': 'vo',
        'vor': 'vor',
        'vor-Latn-NG': 'vor',
        'vor-Latn': 'vor',
        'vor-NG': 'vor',
        'vot': 'vot',
        'vot-Latn-RU': 'vot',
        'vot-Latn': 'vot',
        'vot-RU': 'vot',
        'vot-Cyrl': 'vot-Cyrl',
        'vot-Cyrl-RU': 'vot-Cyrl',
        'vra': 'vra',
        'vra-Latn-VU': 'vra',
        'vra-Latn': 'vra',
        'vra-VU': 'vra',
        'vro': 'vro',
        'vro-Latn-EE': 'vro',
        'vro-EE': 'vro',
        'vro-Latn': 'vro',
        'vrs': 'vrs',
        'vrs-Latn-SB': 'vrs',
        'vrs-Latn': 'vrs',
        'vrs-SB': 'vrs',
        'vrt': 'vrt',
        'vrt-Latn-VU': 'vrt',
        'vrt-Latn': 'vrt',
        'vrt-VU': 'vrt',
        'vsi': 'vsi',
        'vsi-Zxxx-MD': 'vsi',
        'sgn-vsi': 'vsi',
        'sgn-vsi-MD': 'vsi',
        'vsi-MD': 'vsi',
        'vsi-Zxxx': 'vsi',
        'vsl': 'vsl',
        'vsl-Zxxx-VE': 'vsl',
        'sgn-vsl': 'vsl',
        'sgn-vsl-VE': 'vsl',
        'vsl-VE': 'vsl',
        'vsl-Zxxx': 'vsl',
        'vsv': 'vsv',
        'vsv-Zxxx-ES': 'vsv',
        'sgn-vsv': 'vsv',
        'sgn-vsv-ES': 'vsv',
        'vsv-ES': 'vsv',
        'vsv-Zxxx': 'vsv',
        'vto': 'vto',
        'vto-Latn-ID': 'vto',
        'vto-ID': 'vto',
        'vto-Latn': 'vto',
        'vum': 'vum',
        'vum-Latn-GA': 'vum',
        'vum-GA': 'vum',
        'vum-Latn': 'vum',
        'vun': 'vun',
        'vun-Latn-TZ': 'vun',
        'vun-Latn': 'vun',
        'vun-TZ': 'vun',
        'vut': 'vut',
        'vut-Latn-CM': 'vut',
        'vut-CM': 'vut',
        'vut-Latn': 'vut',
        'vwa': 'vwa',
        'vwa-Zyyy-CN': 'vwa',
        'vwa-CN': 'vwa',
        'vwa-Zyyy': 'vwa',
        'wa': 'wa',
        'wa-Latn-BE': 'wa',
        'wa-BE': 'wa',
        'wa-Latn': 'wa',
        'waa': 'waa',
        'waa-Latn-US': 'waa',
        'waa-Latn': 'waa',
        'waa-US': 'waa',
        'wab': 'wab',
        'wab-Latn-PG': 'wab',
        'wab-Latn': 'wab',
        'wab-PG': 'wab',
        'wac': 'wac',
        'wac-Latn-US': 'wac',
        'wac-Latn': 'wac',
        'wac-US': 'wac',
        'wad': 'wad',
        'wad-Latn-ID': 'wad',
        'wad-ID': 'wad',
        'wad-Latn': 'wad',
        'wae': 'wae',
        'wae-Latn-CH': 'wae',
        'wae-CH': 'wae',
        'wae-Latn': 'wae',
        'waf': 'waf',
        'waf-Latn-BR': 'waf',
        'waf-BR': 'waf',
        'waf-Latn': 'waf',
        'wag': 'wag',
        'wag-Latn-PG': 'wag',
        'wag-Latn': 'wag',
        'wag-PG': 'wag',
        'wah': 'wah',
        'wah-Latn-ID': 'wah',
        'wah-ID': 'wah',
        'wah-Latn': 'wah',
        'wai': 'wai',
        'wai-Latn-ID': 'wai',
        'wai-ID': 'wai',
        'wai-Latn': 'wai',
        'waj': 'waj',
        'waj-Latn-PG': 'waj',
        'waj-Latn': 'waj',
        'waj-PG': 'waj',
        'wal': 'wal',
        'wal-Ethi-ET': 'wal',
        'wal-ET': 'wal',
        'wal-Ethi': 'wal',
        'wal-Latn': 'wal-Latn',
        'wal-Latn-ET': 'wal-Latn',
        'wam': 'wam',
        'wam-Latn-US': 'wam',
        'wam-Latn': 'wam',
        'wam-US': 'wam',
        'wan': 'wan',
        'wan-Latn-CI': 'wan',
        'wan-CI': 'wan',
        'wan-Latn': 'wan',
        'wao': 'wao',
        'wao-Zyyy-US': 'wao',
        'wao-US': 'wao',
        'wao-Zyyy': 'wao',
        'wap': 'wap',
        'wap-Latn-GY': 'wap',
        'wap-GY': 'wap',
        'wap-Latn': 'wap',
        'waq': 'waq',
        'waq-Latn-AU': 'waq',
        'waq-AU': 'waq',
        'waq-Latn': 'waq',
        'war': 'war',
        'war-Latn-PH': 'war',
        'war-Latn': 'war',
        'war-PH': 'war',
        'war-Brai': 'war-Brai',
        'war-Brai-PH': 'war-Brai',
        'was': 'was',
        'was-Latn-US': 'was',
        'was-Latn': 'was',
        'was-US': 'was',
        'wat': 'wat',
        'wat-Latn-PG': 'wat',
        'wat-Latn': 'wat',
        'wat-PG': 'wat',
        'wau': 'wau',
        'wau-Latn-BR': 'wau',
        'wau-BR': 'wau',
        'wau-Latn': 'wau',
        'wav': 'wav',
        'wav-Latn-NG': 'wav',
        'wav-Latn': 'wav',
        'wav-NG': 'wav',
        'waw': 'waw',
        'waw-Latn-BR': 'waw',
        'waw-BR': 'waw',
        'waw-Latn': 'waw',
        'xkh': 'waw',
        'xkh-BR': 'waw',
        'xkh-Latn': 'waw',
        'xkh-Latn-BR': 'waw',
        'wax': 'wax',
        'wax-Latn-PG': 'wax',
        'wax-Latn': 'wax',
        'wax-PG': 'wax',
        'way': 'way',
        'way-Latn-SR': 'way',
        'way-Latn': 'way',
        'way-SR': 'way',
        'waz': 'waz',
        'waz-Latn-PG': 'waz',
        'waz-Latn': 'waz',
        'waz-PG': 'waz',
        'wba': 'wba',
        'wba-Latn-VE': 'wba',
        'wba-Latn': 'wba',
        'wba-VE': 'wba',
        'wbb': 'wbb',
        'wbb-Latn-ID': 'wbb',
        'wbb-ID': 'wbb',
        'wbb-Latn': 'wbb',
        'wbe': 'wbe',
        'wbe-Latn-ID': 'wbe',
        'wbe-ID': 'wbe',
        'wbe-Latn': 'wbe',
        'wbf': 'wbf',
        'wbf-Latn-BF': 'wbf',
        'wbf-BF': 'wbf',
        'wbf-Latn': 'wbf',
        'wbh': 'wbh',
        'wbh-Latn-TZ': 'wbh',
        'wbh-Latn': 'wbh',
        'wbh-TZ': 'wbh',
        'wbi': 'wbi',
        'wbi-Latn-TZ': 'wbi',
        'wbi-Latn': 'wbi',
        'wbi-TZ': 'wbi',
        'wbj': 'wbj',
        'wbj-Latn-TZ': 'wbj',
        'wbj-Latn': 'wbj',
        'wbj-TZ': 'wbj',
        'wbk': 'wbk',
        'wbk-Arab-AF': 'wbk',
        'wbk-AF': 'wbk',
        'wbk-Arab': 'wbk',
        'wbl': 'wbl',
        'wbl-Latn-PK': 'wbl',
        'wbl-Latn': 'wbl',
        'wbl-PK': 'wbl',
        'wbl-Arab': 'wbl-Arab',
        'wbl-Arab-AF': 'wbl-Arab',
        'wbl-AF': 'wbl-Arab',
        'wbl-Cyrl': 'wbl-Cyrl',
        'wbl-Cyrl-TJ': 'wbl-Cyrl',
        'wbl-TJ': 'wbl-Cyrl',
        'wbm': 'wbm',
        'wbm-Latn-CN': 'wbm',
        'wbm-CN': 'wbm',
        'wbm-Latn': 'wbm',
        'wbp': 'wbp',
        'wbp-Latn-AU': 'wbp',
        'wbp-AU': 'wbp',
        'wbp-Latn': 'wbp',
        'wbq': 'wbq',
        'wbq-Telu-IN': 'wbq',
        'wbq-IN': 'wbq',
        'wbq-Telu': 'wbq',
        'wbr': 'wbr',
        'wbr-Deva-IN': 'wbr',
        'wbr-Deva': 'wbr',
        'wbr-IN': 'wbr',
        'wbs': 'wbs',
        'wbs-Zxxx-IN': 'wbs',
        'sgn-wbs': 'wbs',
        'sgn-wbs-IN': 'wbs',
        'wbs-IN': 'wbs',
        'wbs-Zxxx': 'wbs',
        'wbt': 'wbt',
        'wbt-Latn-AU': 'wbt',
        'wbt-AU': 'wbt',
        'wbt-Latn': 'wbt',
        'wbv': 'wbv',
        'wbv-Latn-AU': 'wbv',
        'wbv-AU': 'wbv',
        'wbv-Latn': 'wbv',
        'wbw': 'wbw',
        'wbw-Latn-ID': 'wbw',
        'wbw-ID': 'wbw',
        'wbw-Latn': 'wbw',
        'wca': 'wca',
        'wca-Latn-BR': 'wca',
        'wca-BR': 'wca',
        'wca-Latn': 'wca',
        'wci': 'wci',
        'wci-Latn-TG': 'wci',
        'wci-Latn': 'wci',
        'wci-TG': 'wci',
        'wdd': 'wdd',
        'wdd-Latn-GA': 'wdd',
        'wdd-GA': 'wdd',
        'wdd-Latn': 'wdd',
        'wdg': 'wdg',
        'wdg-Latn-PG': 'wdg',
        'wdg-Latn': 'wdg',
        'wdg-PG': 'wdg',
        'wdj': 'wdj',
        'wdj-Latn-AU': 'wdj',
        'wdj-AU': 'wdj',
        'wdj-Latn': 'wdj',
        'wdk': 'wdk',
        'wdk-Latn-AU': 'wdk',
        'wdk-AU': 'wdk',
        'wdk-Latn': 'wdk',
        'wdu': 'wdu',
        'wdu-Latn-AU': 'wdu',
        'wdu-AU': 'wdu',
        'wdu-Latn': 'wdu',
        'wdy': 'wdy',
        'wdy-Latn-AU': 'wdy',
        'wdy-AU': 'wdy',
        'wdy-Latn': 'wdy',
        'wea': 'wea',
        'wea-Zyyy-MM': 'wea',
        'wea-MM': 'wea',
        'wea-Zyyy': 'wea',
        'wec': 'wec',
        'wec-Latn-CI': 'wec',
        'wec-CI': 'wec',
        'wec-Latn': 'wec',
        'wed': 'wed',
        'wed-Latn-PG': 'wed',
        'wed-Latn': 'wed',
        'wed-PG': 'wed',
        'weg': 'weg',
        'weg-Latn-AU': 'weg',
        'weg-AU': 'weg',
        'weg-Latn': 'weg',
        'weh': 'weh',
        'weh-Latn-CM': 'weh',
        'weh-CM': 'weh',
        'weh-Latn': 'weh',
        'wei': 'wei',
        'wei-Latn-PG': 'wei',
        'wei-Latn': 'wei',
        'wei-PG': 'wei',
        'wem': 'wem',
        'wem-Latn-BJ': 'wem',
        'wem-BJ': 'wem',
        'wem-Latn': 'wem',
        'weo': 'weo',
        'weo-Latn-ID': 'weo',
        'tlw': 'weo',
        'tlw-ID': 'weo',
        'tlw-Latn': 'weo',
        'tlw-Latn-ID': 'weo',
        'weo-ID': 'weo',
        'weo-Latn': 'weo',
        'wep': 'wep',
        'wep-Latn-DE': 'wep',
        'wep-DE': 'wep',
        'wep-Latn': 'wep',
        'wer': 'wer',
        'wer-Latn-PG': 'wer',
        'wer-Latn': 'wer',
        'wer-PG': 'wer',
        'wes': 'wes',
        'wes-Latn-CM': 'wes',
        'wes-CM': 'wes',
        'wes-Latn': 'wes',
        'wet': 'wet',
        'wet-Latn-ID': 'wet',
        'wet-ID': 'wet',
        'wet-Latn': 'wet',
        'weu': 'weu',
        'weu-Latn-MM': 'weu',
        'weu-Latn': 'weu',
        'weu-MM': 'weu',
        'wew': 'wew',
        'wew-Latn-ID': 'wew',
        'wew-ID': 'wew',
        'wew-Latn': 'wew',
        'wfg': 'wfg',
        'wfg-Latn-ID': 'wfg',
        'wfg-ID': 'wfg',
        'wfg-Latn': 'wfg',
        'wga': 'wga',
        'wga-Latn-AU': 'wga',
        'wga-AU': 'wga',
        'wga-Latn': 'wga',
        'wgb': 'wgb',
        'wgb-Latn-PG': 'wgb',
        'wgb-Latn': 'wgb',
        'wgb-PG': 'wgb',
        'wgw': 'wgb',
        'wgw-Latn': 'wgb',
        'wgw-Latn-PG': 'wgb',
        'wgw-PG': 'wgb',
        'wgg': 'wgg',
        'wgg-Latn-AU': 'wgg',
        'wgg-AU': 'wgg',
        'wgg-Latn': 'wgg',
        'wgi': 'wgi',
        'wgi-Latn-PG': 'wgi',
        'wgi-Latn': 'wgi',
        'wgi-PG': 'wgi',
        'wgo': 'wgo',
        'wgo-Latn-ID': 'wgo',
        'wgo-ID': 'wgo',
        'wgo-Latn': 'wgo',
        'wgu': 'wgu',
        'wgu-Latn-AU': 'wgu',
        'wgu-AU': 'wgu',
        'wgu-Latn': 'wgu',
        'wgy': 'wgy',
        'wgy-Latn-AU': 'wgy',
        'wgy-AU': 'wgy',
        'wgy-Latn': 'wgy',
        'wha': 'wha',
        'wha-Latn-ID': 'wha',
        'wha-ID': 'wha',
        'wha-Latn': 'wha',
        'whg': 'whg',
        'whg-Latn-PG': 'whg',
        'whg-Latn': 'whg',
        'whg-PG': 'whg',
        'whk': 'whk',
        'whk-Latn-ID': 'whk',
        'whk-ID': 'whk',
        'whk-Latn': 'whk',
        'whu': 'whu',
        'whu-Latn-ID': 'whu',
        'whu-ID': 'whu',
        'whu-Latn': 'whu',
        'wib': 'wib',
        'wib-Latn-BF': 'wib',
        'wib-BF': 'wib',
        'wib-Latn': 'wib',
        'wic': 'wic',
        'wic-Latn-US': 'wic',
        'wic-Latn': 'wic',
        'wic-US': 'wic',
        'wie': 'wie',
        'wie-Latn-AU': 'wie',
        'wie-AU': 'wie',
        'wie-Latn': 'wie',
        'wif': 'wif',
        'wif-Latn-AU': 'wif',
        'wif-AU': 'wif',
        'wif-Latn': 'wif',
        'wig': 'wig',
        'wig-Latn-AU': 'wig',
        'wig-AU': 'wig',
        'wig-Latn': 'wig',
        'wih': 'wih',
        'wih-Latn-AU': 'wih',
        'wih-AU': 'wih',
        'wih-Latn': 'wih',
        'wii': 'wii',
        'wii-Latn-PG': 'wii',
        'wii-Latn': 'wii',
        'wii-PG': 'wii',
        'wij': 'wij',
        'wij-Latn-AU': 'wij',
        'wij-AU': 'wij',
        'wij-Latn': 'wij',
        'wik': 'wik',
        'wik-Latn-AU': 'wik',
        'wik-AU': 'wik',
        'wik-Latn': 'wik',
        'wil': 'wil',
        'wil-Latn-AU': 'wil',
        'wil-AU': 'wil',
        'wil-Latn': 'wil',
        'wim': 'wim',
        'wim-Latn-AU': 'wim',
        'wim-AU': 'wim',
        'wim-Latn': 'wim',
        'win': 'win',
        'win-Latn-US': 'win',
        'win-Latn': 'win',
        'win-US': 'win',
        'wir': 'wir',
        'wir-Latn-BR': 'wir',
        'wir-BR': 'wir',
        'wir-Latn': 'wir',
        'wiu': 'wiu',
        'wiu-Latn-PG': 'wiu',
        'wiu-Latn': 'wiu',
        'wiu-PG': 'wiu',
        'wiv': 'wiv',
        'wiv-Latn-PG': 'wiv',
        'wiv-Latn': 'wiv',
        'wiv-PG': 'wiv',
        'wiy': 'wiy',
        'wiy-Latn-US': 'wiy',
        'wiy-Latn': 'wiy',
        'wiy-US': 'wiy',
        'wja': 'wja',
        'wja-Latn-NG': 'wja',
        'wja-Latn': 'wja',
        'wja-NG': 'wja',
        'wji': 'wji',
        'wji-Latn-NG': 'wji',
        'wji-Latn': 'wji',
        'wji-NG': 'wji',
        'wka': 'wka',
        'wka-Latn-TZ': 'wka',
        'wka-Latn': 'wka',
        'wka-TZ': 'wka',
        'wkb': 'wkb',
        'wkb-Zyyy-IN': 'wkb',
        'wkb-IN': 'wkb',
        'wkb-Zyyy': 'wkb',
        'wkd': 'wkd',
        'wkd-Latn-ID': 'wkd',
        'wkd-ID': 'wkd',
        'wkd-Latn': 'wkd',
        'wkl': 'wkl',
        'wkl-Zyyy-IN': 'wkl',
        'wkl-IN': 'wkl',
        'wkl-Zyyy': 'wkl',
        'wkr': 'wkr',
        'wkr-Latn-AU': 'wkr',
        'wkr-AU': 'wkr',
        'wkr-Latn': 'wkr',
        'wku': 'wku',
        'wku-Zyyy-IN': 'wku',
        'wku-IN': 'wku',
        'wku-Zyyy': 'wku',
        'wkw': 'wkw',
        'wkw-Latn-AU': 'wkw',
        'wkw-AU': 'wkw',
        'wkw-Latn': 'wkw',
        'wky': 'wky',
        'wky-Latn-AU': 'wky',
        'wky-AU': 'wky',
        'wky-Latn': 'wky',
        'wla': 'wla',
        'wla-Latn-PG': 'wla',
        'wla-Latn': 'wla',
        'wla-PG': 'wla',
        'wlc': 'wlc',
        'wlc-Zyyy-KM': 'wlc',
        'wlc-KM': 'wlc',
        'wlc-Zyyy': 'wlc',
        'wle-Arab': 'wle-Arab',
        'wle-Arab-ET': 'wle-Arab',
        'wle-ET': 'wle-Arab',
        'wlg': 'wlg',
        'wlg-Latn-AU': 'wlg',
        'wlg-AU': 'wlg',
        'wlg-Latn': 'wlg',
        'wlh': 'wlh',
        'wlh-Latn-TL': 'wlh',
        'wlh-Latn': 'wlh',
        'wlh-TL': 'wlh',
        'wli': 'wli',
        'wli-Latn-ID': 'wli',
        'wli-ID': 'wli',
        'wli-Latn': 'wli',
        'wlk': 'wlk',
        'wlk-Zyyy-US': 'wlk',
        'wlk-US': 'wlk',
        'wlk-Zyyy': 'wlk',
        'wll': 'wll',
        'wll-Zyyy-SD': 'wll',
        'wll-SD': 'wll',
        'wll-Zyyy': 'wll',
        'wlm': 'wlm',
        'wlm-Latn-GB': 'wlm',
        'wlm-GB': 'wlm',
        'wlm-Latn': 'wlm',
        'wlo': 'wlo',
        'wlo-Arab-ID': 'wlo',
        'wlo-Arab': 'wlo',
        'wlo-ID': 'wlo',
        'wlr': 'wlr',
        'wlr-Latn-VU': 'wlr',
        'wlr-Latn': 'wlr',
        'wlr-VU': 'wlr',
        'wls': 'wls',
        'wls-Latn-WF': 'wls',
        'wls-Latn': 'wls',
        'wls-WF': 'wls',
        'wlu': 'wlu',
        'wlu-Latn-AU': 'wlu',
        'wlu-AU': 'wlu',
        'wlu-Latn': 'wlu',
        'wlv': 'wlv',
        'wlv-Latn-AR': 'wlv',
        'wlv-AR': 'wlv',
        'wlv-Latn': 'wlv',
        'wlw': 'wlw',
        'wlw-Latn-ID': 'wlw',
        'wlw-ID': 'wlw',
        'wlw-Latn': 'wlw',
        'wlx': 'wlx',
        'wlx-Latn-GH': 'wlx',
        'wlx-GH': 'wlx',
        'wlx-Latn': 'wlx',
        'wly': 'wly',
        'wly-Zyyy-NP': 'wly',
        'wly-NP': 'wly',
        'wly-Zyyy': 'wly',
        'wma': 'wma',
        'wma-Latn-NG': 'wma',
        'wma-Latn': 'wma',
        'wma-NG': 'wma',
        'wmb': 'wmb',
        'wmb-Latn-AU': 'wmb',
        'wmb-AU': 'wmb',
        'wmb-Latn': 'wmb',
        'wmc': 'wmc',
        'wmc-Latn-PG': 'wmc',
        'wmc-Latn': 'wmc',
        'wmc-PG': 'wmc',
        'wmd': 'wmd',
        'wmd-Latn-BR': 'wmd',
        'wmd-BR': 'wmd',
        'wmd-Latn': 'wmd',
        'wme': 'wme',
        'wme-Deva-NP': 'wme',
        'wme-Deva': 'wme',
        'wme-NP': 'wme',
        'wmh': 'wmh',
        'wmh-Latn-TL': 'wmh',
        'wmh-Latn': 'wmh',
        'wmh-TL': 'wmh',
        'wmi': 'wmi',
        'wmi-Latn-AU': 'wmi',
        'wmi-AU': 'wmi',
        'wmi-Latn': 'wmi',
        'wmm': 'wmm',
        'wmm-Latn-ID': 'wmm',
        'wmm-ID': 'wmm',
        'wmm-Latn': 'wmm',
        'wmn': 'wmn',
        'wmn-Latn-NC': 'wmn',
        'wmn-Latn': 'wmn',
        'wmn-NC': 'wmn',
        'wmo': 'wmo',
        'wmo-Latn-PG': 'wmo',
        'wmo-Latn': 'wmo',
        'wmo-PG': 'wmo',
        'wms': 'wms',
        'wms-Latn-ID': 'wms',
        'wms-ID': 'wms',
        'wms-Latn': 'wms',
        'wmt': 'wmt',
        'wmt-Latn-AU': 'wmt',
        'wmt-AU': 'wmt',
        'wmt-Latn': 'wmt',
        'wmw': 'wmw',
        'wmw-Latn-MZ': 'wmw',
        'wmw-Latn': 'wmw',
        'wmw-MZ': 'wmw',
        'wmw-Arab': 'wmw-Arab',
        'wmw-Arab-MZ': 'wmw-Arab',
        'wmx': 'wmx',
        'wmx-Latn-PG': 'wmx',
        'wmx-Latn': 'wmx',
        'wmx-PG': 'wmx',
        'wnb': 'wnb',
        'wnb-Latn-PG': 'wnb',
        'wnb-Latn': 'wnb',
        'wnb-PG': 'wnb',
        'wnc': 'wnc',
        'wnc-Latn-PG': 'wnc',
        'wnc-Latn': 'wnc',
        'wnc-PG': 'wnc',
        'wnd': 'wnd',
        'wnd-Latn-AU': 'wnd',
        'wnd-AU': 'wnd',
        'wnd-Latn': 'wnd',
        'wne': 'wne',
        'wne-Arab-PK': 'wne',
        'wne-Arab': 'wne',
        'wne-PK': 'wne',
        'wng': 'wng',
        'wng-Latn-ID': 'wng',
        'wng-ID': 'wng',
        'wng-Latn': 'wng',
        'wni': 'wni',
        'wni-Arab-KM': 'wni',
        'wni-Arab': 'wni',
        'wni-KM': 'wni',
        'wni-Latn': 'wni-Latn',
        'wni-Latn-KM': 'wni-Latn',
        'wnk': 'wnk',
        'wnk-Latn-ID': 'wnk',
        'wnk-ID': 'wnk',
        'wnk-Latn': 'wnk',
        'wnm': 'wnm',
        'wnm-Latn-AU': 'wnm',
        'wnm-AU': 'wnm',
        'wnm-Latn': 'wnm',
        'wnn': 'wnn',
        'wnn-Latn-AU': 'wnn',
        'wnn-AU': 'wnn',
        'wnn-Latn': 'wnn',
        'wno': 'wno',
        'wno-Latn-ID': 'wno',
        'wno-ID': 'wno',
        'wno-Latn': 'wno',
        'wnp': 'wnp',
        'wnp-Latn-PG': 'wnp',
        'wnp-Latn': 'wnp',
        'wnp-PG': 'wnp',
        'wnu': 'wnu',
        'wnu-Latn-PG': 'wnu',
        'wnu-Latn': 'wnu',
        'wnu-PG': 'wnu',
        'wnw': 'wnw',
        'wnw-Latn-US': 'wnw',
        'wnw-Latn': 'wnw',
        'wnw-US': 'wnw',
        'wny': 'wny',
        'wny-Latn-AU': 'wny',
        'wny-AU': 'wny',
        'wny-Latn': 'wny',
        'wo': 'wo',
        'wo-Latn-SN': 'wo',
        'wo-Latn': 'wo',
        'wo-SN': 'wo',
        'wo-Arab': 'wo-Arab',
        'wo-Arab-SN': 'wo-Arab',
        'woa': 'woa',
        'woa-Latn-AU': 'woa',
        'woa-AU': 'woa',
        'woa-Latn': 'woa',
        'wob': 'wob',
        'wob-Latn-CI': 'wob',
        'wob-CI': 'wob',
        'wob-Latn': 'wob',
        'woc': 'woc',
        'woc-Latn-PG': 'woc',
        'woc-Latn': 'woc',
        'woc-PG': 'woc',
        'wod': 'wod',
        'wod-Latn-ID': 'wod',
        'wod-ID': 'wod',
        'wod-Latn': 'wod',
        'woe': 'woe',
        'woe-Latn-FM': 'woe',
        'woe-FM': 'woe',
        'woe-Latn': 'woe',
        'woe-Wole': 'woe-Wole',
        'woe-Wole-FM': 'woe-Wole',
        'wof': 'wof',
        'wof-Latn-GM': 'wof',
        'wof-GM': 'wof',
        'wof-Latn': 'wof',
        'wof-Arab': 'wof-Arab',
        'wof-Arab-GM': 'wof-Arab',
        'wog': 'wog',
        'wog-Latn-PG': 'wog',
        'wog-Latn': 'wog',
        'wog-PG': 'wog',
        'woi': 'woi',
        'woi-Latn-ID': 'woi',
        'woi-ID': 'woi',
        'woi-Latn': 'woi',
        'wok': 'wok',
        'wok-Latn-CM': 'wok',
        'wok-CM': 'wok',
        'wok-Latn': 'wok',
        'wom': 'wom',
        'wom-Latn-NG': 'wom',
        'wom-Latn': 'wom',
        'wom-NG': 'wom',
        'won': 'won',
        'won-Latn-CD': 'won',
        'won-CD': 'won',
        'won-Latn': 'won',
        'woo': 'woo',
        'woo-Latn-ID': 'woo',
        'woo-ID': 'woo',
        'woo-Latn': 'woo',
        'wor': 'wor',
        'wor-Latn-ID': 'wor',
        'wor-ID': 'wor',
        'wor-Latn': 'wor',
        'wos': 'wos',
        'wos-Latn-PG': 'wos',
        'wos-Latn': 'wos',
        'wos-PG': 'wos',
        'wow': 'wow',
        'wow-Latn-ID': 'wow',
        'wow-ID': 'wow',
        'wow-Latn': 'wow',
        'woy': 'woy',
        'woy-Zyyy-ET': 'woy',
        'woy-ET': 'woy',
        'woy-Zyyy': 'woy',
        'wpc': 'wpc',
        'wpc-Latn-VE': 'wpc',
        'wpc-Latn': 'wpc',
        'wpc-VE': 'wpc',
        'wra': 'wra',
        'wra-Latn-PG': 'wra',
        'wra-Latn': 'wra',
        'wra-PG': 'wra',
        'wrb': 'wrb',
        'wrb-Latn-AU': 'wrb',
        'wrb-AU': 'wrb',
        'wrb-Latn': 'wrb',
        'wrd': 'wrd',
        'wrd-Arab-AF': 'wrd',
        'wrd-AF': 'wrd',
        'wrd-Arab': 'wrd',
        'wrg': 'wrg',
        'wrg-Latn-AU': 'wrg',
        'wrg-AU': 'wrg',
        'wrg-Latn': 'wrg',
        'wrh': 'wrh',
        'wrh-Latn-AU': 'wrh',
        'wrh-AU': 'wrh',
        'wrh-Latn': 'wrh',
        'wri': 'wri',
        'wri-Latn-AU': 'wri',
        'wri-AU': 'wri',
        'wri-Latn': 'wri',
        'wrk': 'wrk',
        'wrk-Latn-AU': 'wrk',
        'gbc': 'wrk',
        'gbc-AU': 'wrk',
        'gbc-Latn': 'wrk',
        'gbc-Latn-AU': 'wrk',
        'wrk-AU': 'wrk',
        'wrk-Latn': 'wrk',
        'wrl': 'wrl',
        'wrl-Latn-AU': 'wrl',
        'wrl-AU': 'wrl',
        'wrl-Latn': 'wrl',
        'wrm': 'wrm',
        'wrm-Latn-AU': 'wrm',
        'wrm-AU': 'wrm',
        'wrm-Latn': 'wrm',
        'wrn': 'wrn',
        'wrn-Zyyy-SD': 'wrn',
        'wrn-SD': 'wrn',
        'wrn-Zyyy': 'wrn',
        'wro': 'wro',
        'wro-Latn-AU': 'wro',
        'unp': 'wro',
        'unp-AU': 'wro',
        'unp-Latn': 'wro',
        'unp-Latn-AU': 'wro',
        'wro-AU': 'wro',
        'wro-Latn': 'wro',
        'wrp': 'wrp',
        'wrp-Latn-ID': 'wrp',
        'wrp-ID': 'wrp',
        'wrp-Latn': 'wrp',
        'wrr': 'wrr',
        'wrr-Latn-AU': 'wrr',
        'wrr-AU': 'wrr',
        'wrr-Latn': 'wrr',
        'wrs': 'wrs',
        'wrs-Latn-PG': 'wrs',
        'wrs-Latn': 'wrs',
        'wrs-PG': 'wrs',
        'wru': 'wru',
        'wru-Latn-ID': 'wru',
        'wru-ID': 'wru',
        'wru-Latn': 'wru',
        'wrv': 'wrv',
        'wrv-Latn-PG': 'wrv',
        'wrv-Latn': 'wrv',
        'wrv-PG': 'wrv',
        'wrw': 'wrw',
        'wrw-Latn-AU': 'wrw',
        'wrw-AU': 'wrw',
        'wrw-Latn': 'wrw',
        'wrx': 'wrx',
        'wrx-Latn-ID': 'wrx',
        'wrx-ID': 'wrx',
        'wrx-Latn': 'wrx',
        'wry': 'wry',
        'wry-Zyyy-IN': 'wry',
        'wry-IN': 'wry',
        'wry-Zyyy': 'wry',
        'wrz': 'wrz',
        'wrz-Latn-AU': 'wrz',
        'wrz-AU': 'wrz',
        'wrz-Latn': 'wrz',
        'wsa': 'wsa',
        'wsa-Latn-ID': 'wsa',
        'wsa-ID': 'wsa',
        'wsa-Latn': 'wsa',
        'wsg': 'wsg',
        'wsg-Telu-IN': 'wsg',
        'ggo': 'wsg',
        'ggo-IN': 'wsg',
        'ggo-Telu': 'wsg',
        'ggo-Telu-IN': 'wsg',
        'wsg-IN': 'wsg',
        'wsg-Telu': 'wsg',
        'wsg-Deva': 'wsg-Deva',
        'wsg-Deva-IN': 'wsg-Deva',
        'wsg-Gong': 'wsg-Gong',
        'wsg-Gong-IN': 'wsg-Gong',
        'wsg-Gonm': 'wsg-Gonm',
        'wsg-Gonm-IN': 'wsg-Gonm',
        'wsi': 'wsi',
        'wsi-Latn-VU': 'wsi',
        'wsi-Latn': 'wsi',
        'wsi-VU': 'wsi',
        'wsk': 'wsk',
        'wsk-Latn-PG': 'wsk',
        'wsk-Latn': 'wsk',
        'wsk-PG': 'wsk',
        'wsr': 'wsr',
        'wsr-Latn-PG': 'wsr',
        'wsr-Latn': 'wsr',
        'wsr-PG': 'wsr',
        'wss': 'wss',
        'wss-Latn-GH': 'wss',
        'wss-GH': 'wss',
        'wss-Latn': 'wss',
        'wsu': 'wsu',
        'wsu-Latn-BR': 'wsu',
        'wsu-BR': 'wsu',
        'wsu-Latn': 'wsu',
        'wsv': 'wsv',
        'wsv-Arab-AF': 'wsv',
        'wsv-AF': 'wsv',
        'wsv-Arab': 'wsv',
        'wtf': 'wtf',
        'wtf-Latn-PG': 'wtf',
        'wtf-Latn': 'wtf',
        'wtf-PG': 'wtf',
        'wth': 'wth',
        'wth-Latn-AU': 'wth',
        'wth-AU': 'wth',
        'wth-Latn': 'wth',
        'wti': 'wti',
        'wti-Latn-ET': 'wti',
        'wti-ET': 'wti',
        'wti-Latn': 'wti',
        'wtk': 'wtk',
        'wtk-Latn-PG': 'wtk',
        'wtk-Latn': 'wtk',
        'wtk-PG': 'wtk',
        'wtm': 'wtm',
        'wtm-Deva-IN': 'wtm',
        'wtm-Deva': 'wtm',
        'wtm-IN': 'wtm',
        'wtw': 'wtw',
        'wtw-Latn-ID': 'wtw',
        'wtw-ID': 'wtw',
        'wtw-Latn': 'wtw',
        'wtw-Bugi': 'wtw-Bugi',
        'wtw-Bugi-ID': 'wtw-Bugi',
        'wua': 'wua',
        'wua-Latn-AU': 'wua',
        'wua-AU': 'wua',
        'wua-Latn': 'wua',
        'wub': 'wub',
        'wub-Latn-AU': 'wub',
        'wub-AU': 'wub',
        'wub-Latn': 'wub',
        'wud': 'wud',
        'wud-Latn-TG': 'wud',
        'wud-Latn': 'wud',
        'wud-TG': 'wud',
        'wuh': 'wuh',
        'wuh-Zyyy-CN': 'wuh',
        'wuh-CN': 'wuh',
        'wuh-Zyyy': 'wuh',
        'wul': 'wul',
        'wul-Latn-ID': 'wul',
        'wul-ID': 'wul',
        'wul-Latn': 'wul',
        'wum': 'wum',
        'wum-Latn-GA': 'wum',
        'wum-GA': 'wum',
        'wum-Latn': 'wum',
        'wun': 'wun',
        'wun-Latn-TZ': 'wun',
        'wun-Latn': 'wun',
        'wun-TZ': 'wun',
        'wur': 'wur',
        'wur-Latn-AU': 'wur',
        'wur-AU': 'wur',
        'wur-Latn': 'wur',
        'wut': 'wut',
        'wut-Latn-PG': 'wut',
        'wut-Latn': 'wut',
        'wut-PG': 'wut',
        'wuu': 'wuu',
        'wuu-Hans-CN': 'wuu',
        'wuu-CN': 'wuu',
        'wuu-Hans': 'wuu',
        'zh-wuu': 'wuu',
        'zh-wuu-CN': 'wuu',
        'wuu-Hant': 'wuu-Hant',
        'wuu-Hant-CN': 'wuu-Hant',
        'wuu-Latn': 'wuu-Latn',
        'wuu-Latn-CN': 'wuu-Latn',
        'wuv': 'wuv',
        'wuv-Latn-PG': 'wuv',
        'wuv-Latn': 'wuv',
        'wuv-PG': 'wuv',
        'wux': 'wux',
        'wux-Latn-AU': 'wux',
        'wux-AU': 'wux',
        'wux-Latn': 'wux',
        'wuy': 'wuy',
        'wuy-Latn-ID': 'wuy',
        'wuy-ID': 'wuy',
        'wuy-Latn': 'wuy',
        'wwa': 'wwa',
        'wwa-Latn-BJ': 'wwa',
        'wwa-BJ': 'wwa',
        'wwa-Latn': 'wwa',
        'wwb': 'wwb',
        'wwb-Latn-AU': 'wwb',
        'wwb-AU': 'wwb',
        'wwb-Latn': 'wwb',
        'wwo': 'wwo',
        'wwo-Latn-VU': 'wwo',
        'wwo-Latn': 'wwo',
        'wwo-VU': 'wwo',
        'wwr': 'wwr',
        'wwr-Latn-AU': 'wwr',
        'wwr-AU': 'wwr',
        'wwr-Latn': 'wwr',
        'www': 'www',
        'www-Latn-CM': 'www',
        'www-CM': 'www',
        'www-Latn': 'www',
        'wxa': 'wxa',
        'wxa-Zyyy-CN': 'wxa',
        'wxa-CN': 'wxa',
        'wxa-Zyyy': 'wxa',
        'wxw': 'wxw',
        'wxw-Latn-AU': 'wxw',
        'wxw-AU': 'wxw',
        'wxw-Latn': 'wxw',
        'wya': 'wya',
        'wya-Latn-US': 'wya',
        'wya-Latn': 'wya',
        'wya-US': 'wya',
        'wyb': 'wyb',
        'wyb-Latn-AU': 'wyb',
        'wyb-AU': 'wyb',
        'wyb-Latn': 'wyb',
        'wyi': 'wyi',
        'wyi-Latn-AU': 'wyi',
        'wyi-AU': 'wyi',
        'wyi-Latn': 'wyi',
        'wym': 'wym',
        'wym-Latn-PL': 'wym',
        'wym-Latn': 'wym',
        'wym-PL': 'wym',
        'wyr': 'wyr',
        'wyr-Latn-BR': 'wyr',
        'wyr-BR': 'wyr',
        'wyr-Latn': 'wyr',
        'wyy': 'wyy',
        'wyy-Latn-FJ': 'wyy',
        'wyy-FJ': 'wyy',
        'wyy-Latn': 'wyy',
        'x-bad-mru': 'x-bad-mru',
        'x-bad-mru-Cyrl-RU': 'x-bad-mru',
        'x-bad-mru-Cyrl': 'x-bad-mru',
        'x-bad-mru-RU': 'x-bad-mru',
        'xaa': 'xaa',
        'xaa-Latn-ES': 'xaa',
        'xaa-ES': 'xaa',
        'xaa-Latn': 'xaa',
        'xab': 'xab',
        'xab-Latn-NG': 'xab',
        'xab-Latn': 'xab',
        'xab-NG': 'xab',
        'xac': 'xac',
        'xac-Zyyy-IN': 'xac',
        'xac-IN': 'xac',
        'xac-Zyyy': 'xac',
        'xad': 'xad',
        'xad-Zyyy-XX': 'xad',
        'xad-XX': 'xad',
        'xad-Zyyy': 'xad',
        'xae': 'xae',
        'xae-Zyyy-XX': 'xae',
        'xae-XX': 'xae',
        'xae-Zyyy': 'xae',
        'xag': 'xag',
        'xag-Zyyy-XX': 'xag',
        'xag-XX': 'xag',
        'xag-Zyyy': 'xag',
        'xai': 'xai',
        'xai-Latn-BR': 'xai',
        'xai-BR': 'xai',
        'xai-Latn': 'xai',
        'xaj': 'xaj',
        'xaj-Latn-BR': 'xaj',
        'xaj-BR': 'xaj',
        'xaj-Latn': 'xaj',
        'xak': 'xak',
        'xak-Latn-VE': 'xak',
        'xak-Latn': 'xak',
        'xak-VE': 'xak',
        'xal': 'xal',
        'xal-Cyrl-RU': 'xal',
        'xal-Cyrl': 'xal',
        'xal-RU': 'xal',
        'xal-Mong-x-todo': 'xal-Mong-x-todo',
        'xal-Mong-CN-x-todo': 'xal-Mong-x-todo',
        'xal-CN-x-todo': 'xal-Mong-x-todo',
        'xam': 'xam',
        'xam-Latn-ZA': 'xam',
        'xam-Latn': 'xam',
        'xam-ZA': 'xam',
        'xan': 'xan',
        'xan-Ethi-ET': 'xan',
        'xan-ET': 'xan',
        'xan-Ethi': 'xan',
        'xao': 'xao',
        'xao-Latn-VN': 'xao',
        'xao-Latn': 'xao',
        'xao-VN': 'xao',
        'xap': 'xap',
        'xap-Zyyy-XX': 'xap',
        'xap-XX': 'xap',
        'xap-Zyyy': 'xap',
        'xaq': 'xaq',
        'xaq-Zyyy-XX': 'xaq',
        'xaq-XX': 'xaq',
        'xaq-Zyyy': 'xaq',
        'xar': 'xar',
        'xar-Latn-PG': 'xar',
        'xar-Latn': 'xar',
        'xar-PG': 'xar',
        'xas': 'xas',
        'xas-Cyrl-RU': 'xas',
        'xas-Cyrl': 'xas',
        'xas-RU': 'xas',
        'xat': 'xat',
        'xat-Latn-BR': 'xat',
        'xat-BR': 'xat',
        'xat-Latn': 'xat',
        'xau': 'xau',
        'xau-Latn-ID': 'xau',
        'xau-ID': 'xau',
        'xau-Latn': 'xau',
        'xav': 'xav',
        'xav-Latn-BR': 'xav',
        'xav-BR': 'xav',
        'xav-Latn': 'xav',
        'xaw': 'xaw',
        'xaw-Latn-US': 'xaw',
        'xaw-Latn': 'xaw',
        'xaw-US': 'xaw',
        'xay': 'xay',
        'xay-Latn-ID': 'xay',
        'xay-ID': 'xay',
        'xay-Latn': 'xay',
        'xbb': 'xbb',
        'xbb-Latn-AU': 'xbb',
        'xbb-AU': 'xbb',
        'xbb-Latn': 'xbb',
        'xbc': 'xbc',
        'xbc-Zyyy-XX': 'xbc',
        'xbc-XX': 'xbc',
        'xbc-Zyyy': 'xbc',
        'xbd': 'xbd',
        'xbd-Latn-AU': 'xbd',
        'xbd-AU': 'xbd',
        'xbd-Latn': 'xbd',
        'xbe': 'xbe',
        'xbe-Latn-AU': 'xbe',
        'xbe-AU': 'xbe',
        'xbe-Latn': 'xbe',
        'xbg': 'xbg',
        'xbg-Latn-AU': 'xbg',
        'xbg-AU': 'xbg',
        'xbg-Latn': 'xbg',
        'xbi': 'xbi',
        'xbi-Latn-PG': 'xbi',
        'xbi-Latn': 'xbi',
        'xbi-PG': 'xbi',
        'xbj': 'xbj',
        'xbj-Latn-AU': 'xbj',
        'xbj-AU': 'xbj',
        'xbj-Latn': 'xbj',
        'xbm': 'xbm',
        'xbm-Latn-FR': 'xbm',
        'xbm-FR': 'xbm',
        'xbm-Latn': 'xbm',
        'xbn': 'xbn',
        'xbn-Latn-MY': 'xbn',
        'xbn-Latn': 'xbn',
        'xbn-MY': 'xbn',
        'xbo': 'xbo',
        'xbo-Zyyy-XX': 'xbo',
        'xbo-XX': 'xbo',
        'xbo-Zyyy': 'xbo',
        'xbp': 'xbp',
        'xbp-Latn-AU': 'xbp',
        'xbp-AU': 'xbp',
        'xbp-Latn': 'xbp',
        'xbr': 'xbr',
        'xbr-Latn-ID': 'xbr',
        'xbr-ID': 'xbr',
        'xbr-Latn': 'xbr',
        'xbw': 'xbw',
        'xbw-Latn-BR': 'xbw',
        'xbw-BR': 'xbw',
        'xbw-Latn': 'xbw',
        'xby': 'xby',
        'xby-Latn-AU': 'xby',
        'xby-AU': 'xby',
        'xby-Latn': 'xby',
        'xcb': 'xcb',
        'xcb-Zyyy-XX': 'xcb',
        'xcb-XX': 'xcb',
        'xcb-Zyyy': 'xcb',
        'xcc': 'xcc',
        'xcc-Zyyy-XX': 'xcc',
        'xcc-XX': 'xcc',
        'xcc-Zyyy': 'xcc',
        'xce': 'xce',
        'xce-Zyyy-XX': 'xce',
        'xce-XX': 'xce',
        'xce-Zyyy': 'xce',
        'xcg': 'xcg',
        'xcg-Zyyy-XX': 'xcg',
        'xcg-XX': 'xcg',
        'xcg-Zyyy': 'xcg',
        'xch': 'xch',
        'xch-Zyyy-XX': 'xch',
        'cmk': 'xch',
        'cmk-XX': 'xch',
        'cmk-Zyyy': 'xch',
        'cmk-Zyyy-XX': 'xch',
        'xch-XX': 'xch',
        'xch-Zyyy': 'xch',
        'xcl': 'xcl',
        'xcl-Zyyy-XX': 'xcl',
        'xcl-XX': 'xcl',
        'xcl-Zyyy': 'xcl',
        'xcm': 'xcm',
        'xcm-Zyyy-XX': 'xcm',
        'xcm-XX': 'xcm',
        'xcm-Zyyy': 'xcm',
        'xcn': 'xcn',
        'xcn-Zyyy-XX': 'xcn',
        'xcn-XX': 'xcn',
        'xcn-Zyyy': 'xcn',
        'xco': 'xco',
        'xco-Arab-XX': 'xco',
        'xco-Arab': 'xco',
        'xco-XX': 'xco',
        'xco-Chrs': 'xco-Chrs',
        'xco-Chrs-XX': 'xco-Chrs',
        'xcr': 'xcr',
        'xcr-Cari-TR': 'xcr',
        'xcr-Cari': 'xcr',
        'xcr-TR': 'xcr',
        'xct': 'xct',
        'xct-Tibt-XX': 'xct',
        'xct-Tibt': 'xct',
        'xct-XX': 'xct',
        'xcu': 'xcu',
        'xcu-Zyyy-XX': 'xcu',
        'xcu-XX': 'xcu',
        'xcu-Zyyy': 'xcu',
        'xcv': 'xcv',
        'xcv-Zyyy-XX': 'xcv',
        'xcv-XX': 'xcv',
        'xcv-Zyyy': 'xcv',
        'xcw': 'xcw',
        'xcw-Zyyy-XX': 'xcw',
        'xcw-XX': 'xcw',
        'xcw-Zyyy': 'xcw',
        'xcy': 'xcy',
        'xcy-Zyyy-XX': 'xcy',
        'xcy-XX': 'xcy',
        'xcy-Zyyy': 'xcy',
        'xda': 'xda',
        'xda-Latn-AU': 'xda',
        'xda-AU': 'xda',
        'xda-Latn': 'xda',
        'xdc': 'xdc',
        'xdc-Zyyy-XX': 'xdc',
        'xdc-XX': 'xdc',
        'xdc-Zyyy': 'xdc',
        'xdk': 'xdk',
        'xdk-Latn-AU': 'xdk',
        'xdk-AU': 'xdk',
        'xdk-Latn': 'xdk',
        'xdm': 'xdm',
        'xdm-Zyyy-XX': 'xdm',
        'xdm-XX': 'xdm',
        'xdm-Zyyy': 'xdm',
        'xdo': 'xdo',
        'xdo-Latn-AO': 'xdo',
        'xdo-AO': 'xdo',
        'xdo-Latn': 'xdo',
        'xdy': 'xdy',
        'xdy-Latn-ID': 'xdy',
        'xdy-ID': 'xdy',
        'xdy-Latn': 'xdy',
        'xeb': 'xeb',
        'xeb-Zyyy-XX': 'xeb',
        'xeb-XX': 'xeb',
        'xeb-Zyyy': 'xeb',
        'xed': 'xed',
        'xed-Latn-CM': 'xed',
        'xed-CM': 'xed',
        'xed-Latn': 'xed',
        'xeg': 'xeg',
        'xeg-Latn-ZA': 'xeg',
        'xeg-Latn': 'xeg',
        'xeg-ZA': 'xeg',
        'xel': 'xel',
        'xel-Zyyy-SD': 'xel',
        'xel-SD': 'xel',
        'xel-Zyyy': 'xel',
        'xem': 'xem',
        'xem-Latn-ID': 'xem',
        'xem-ID': 'xem',
        'xem-Latn': 'xem',
        'xep': 'xep',
        'xep-Zyyy-XX': 'xep',
        'xep-XX': 'xep',
        'xep-Zyyy': 'xep',
        'xer': 'xer',
        'xer-Latn-BR': 'xer',
        'xer-BR': 'xer',
        'xer-Latn': 'xer',
        'xes': 'xes',
        'xes-Latn-PG': 'xes',
        'xes-Latn': 'xes',
        'xes-PG': 'xes',
        'xet': 'xet',
        'xet-Latn-BR': 'xet',
        'xet-BR': 'xet',
        'xet-Latn': 'xet',
        'xeu': 'xeu',
        'xeu-Latn-PG': 'xeu',
        'xeu-Latn': 'xeu',
        'xeu-PG': 'xeu',
        'xfa': 'xfa',
        'xfa-Zyyy-XX': 'xfa',
        'xfa-XX': 'xfa',
        'xfa-Zyyy': 'xfa',
        'xga': 'xga',
        'xga-Zyyy-XX': 'xga',
        'xga-XX': 'xga',
        'xga-Zyyy': 'xga',
        'xgb': 'xgb',
        'xgb-Latn-CI': 'xgb',
        'xgb-CI': 'xgb',
        'xgb-Latn': 'xgb',
        'xgd': 'xgd',
        'xgd-Latn-AU': 'xgd',
        'xgd-AU': 'xgd',
        'xgd-Latn': 'xgd',
        'xgf': 'xgf',
        'xgf-Zyyy-XX': 'xgf',
        'xgf-XX': 'xgf',
        'xgf-Zyyy': 'xgf',
        'xgg': 'xgg',
        'xgg-Latn-AU': 'xgg',
        'xgg-AU': 'xgg',
        'xgg-Latn': 'xgg',
        'xgi': 'xgi',
        'xgi-Latn-AU': 'xgi',
        'xgi-AU': 'xgi',
        'xgi-Latn': 'xgi',
        'xgl': 'xgl',
        'xgl-Zyyy-XX': 'xgl',
        'xgl-XX': 'xgl',
        'xgl-Zyyy': 'xgl',
        'xgm': 'xgm',
        'xgm-Latn-AU': 'xgm',
        'xgm-AU': 'xgm',
        'xgm-Latn': 'xgm',
        'xgr': 'xgr',
        'xgr-Zyyy-XX': 'xgr',
        'xgr-XX': 'xgr',
        'xgr-Zyyy': 'xgr',
        'xgu': 'xgu',
        'xgu-Latn-AU': 'xgu',
        'xgu-AU': 'xgu',
        'xgu-Latn': 'xgu',
        'xgw': 'xgw',
        'xgw-Latn-AU': 'xgw',
        'xgw-AU': 'xgw',
        'xgw-Latn': 'xgw',
        'xh': 'xh',
        'xh-Latn-ZA': 'xh',
        'xh-Latn': 'xh',
        'xh-ZA': 'xh',
        'xh-Brai': 'xh-Brai',
        'xh-Brai-ZA': 'xh-Brai',
        'xha': 'xha',
        'xha-Zyyy-XX': 'xha',
        'xha-XX': 'xha',
        'xha-Zyyy': 'xha',
        'xhc': 'xhc',
        'xhc-Zyyy-XX': 'xhc',
        'xhc-XX': 'xhc',
        'xhc-Zyyy': 'xhc',
        'xhd': 'xhd',
        'xhd-Zyyy-XX': 'xhd',
        'xhd-XX': 'xhd',
        'xhd-Zyyy': 'xhd',
        'xhe': 'xhe',
        'xhe-Arab-PK': 'xhe',
        'xhe-Arab': 'xhe',
        'xhe-PK': 'xhe',
        'xhr': 'xhr',
        'xhr-Zyyy-XX': 'xhr',
        'xhr-XX': 'xhr',
        'xhr-Zyyy': 'xhr',
        'xht': 'xht',
        'xht-Zyyy-TR': 'xht',
        'xht-TR': 'xht',
        'xht-Zyyy': 'xht',
        'xhu': 'xhu',
        'xhu-Zyyy-XX': 'xhu',
        'xhu-XX': 'xhu',
        'xhu-Zyyy': 'xhu',
        'xhv': 'xhv',
        'xhv-Latn-VN': 'xhv',
        'xhv-Latn': 'xhv',
        'xhv-VN': 'xhv',
        'xib': 'xib',
        'xib-Zyyy-XX': 'xib',
        'xib-XX': 'xib',
        'xib-Zyyy': 'xib',
        'xii': 'xii',
        'xii-Latn-ZA': 'xii',
        'xii-Latn': 'xii',
        'xii-ZA': 'xii',
        'xil': 'xil',
        'xil-Zyyy-XX': 'xil',
        'xil-XX': 'xil',
        'xil-Zyyy': 'xil',
        'xin': 'xin',
        'xin-Latn-GT': 'xin',
        'xin-GT': 'xin',
        'xin-Latn': 'xin',
        'xir': 'xir',
        'xir-Latn-BR': 'xir',
        'xir-BR': 'xir',
        'xir-Latn': 'xir',
        'xis': 'xis',
        'xis-Orya-IN': 'xis',
        'xis-IN': 'xis',
        'xis-Orya': 'xis',
        'xiv': 'xiv',
        'xiv-Zyyy-XX': 'xiv',
        'xiv-XX': 'xiv',
        'xiv-Zyyy': 'xiv',
        'xiy': 'xiy',
        'xiy-Latn-BR': 'xiy',
        'xiy-BR': 'xiy',
        'xiy-Latn': 'xiy',
        'xjb': 'xjb',
        'xjb-Latn-AU': 'xjb',
        'xjb-AU': 'xjb',
        'xjb-Latn': 'xjb',
        'xjt': 'xjt',
        'xjt-Latn-AU': 'xjt',
        'xjt-AU': 'xjt',
        'xjt-Latn': 'xjt',
        'xka': 'xka',
        'xka-Arab-PK': 'xka',
        'xka-Arab': 'xka',
        'xka-PK': 'xka',
        'xkb': 'xkb',
        'xkb-Latn-BJ': 'xkb',
        'xkb-BJ': 'xkb',
        'xkb-Latn': 'xkb',
        'xkc': 'xkc',
        'xkc-Zyyy-IR': 'xkc',
        'xkc-IR': 'xkc',
        'xkc-Zyyy': 'xkc',
        'xkd': 'xkd',
        'xkd-Latn-ID': 'xkd',
        'xkd-ID': 'xkd',
        'xkd-Latn': 'xkd',
        'xke': 'xke',
        'xke-Latn-ID': 'xke',
        'xke-ID': 'xke',
        'xke-Latn': 'xke',
        'xkf-Tibt': 'xkf-Tibt',
        'xkf-Tibt-BT-x-uchen': 'xkf-Tibt',
        'xkf-BT-x-uchen': 'xkf-Tibt',
        'xkf-Tibt-BT': 'xkf-Tibt',
        'xkf-Tibt-x-uchen': 'xkf-Tibt',
        'xkg': 'xkg',
        'xkg-Latn-ML': 'xkg',
        'xkg-Latn': 'xkg',
        'xkg-ML': 'xkg',
        'xki': 'xki',
        'xki-Zxxx-KE': 'xki',
        'sgn-xki': 'xki',
        'sgn-xki-KE': 'xki',
        'xki-KE': 'xki',
        'xki-Zxxx': 'xki',
        'xkj': 'xkj',
        'xkj-Arab-IR': 'xkj',
        'xkj-Arab': 'xkj',
        'xkj-IR': 'xkj',
        'xkk': 'xkk',
        'xkk-Zyyy-KH': 'xkk',
        'xkk-KH': 'xkk',
        'xkk-Zyyy': 'xkk',
        'xkl': 'xkl',
        'xkl-Latn-ID': 'xkl',
        'xkl-ID': 'xkl',
        'xkl-Latn': 'xkl',
        'xkn': 'xkn',
        'xkn-Latn-ID': 'xkn',
        'xkn-ID': 'xkn',
        'xkn-Latn': 'xkn',
        'xko': 'xko',
        'xko-Zyyy-LA': 'xko',
        'xko-LA': 'xko',
        'xko-Zyyy': 'xko',
        'xkp': 'xkp',
        'xkp-Zyyy-IR': 'xkp',
        'xkp-IR': 'xkp',
        'xkp-Zyyy': 'xkp',
        'xkq': 'xkq',
        'xkq-Latn-ID': 'xkq',
        'xkq-ID': 'xkq',
        'xkq-Latn': 'xkq',
        'xkr': 'xkr',
        'xkr-Latn-BR': 'xkr',
        'xkr-BR': 'xkr',
        'xkr-Latn': 'xkr',
        'xks': 'xks',
        'xks-Latn-ID': 'xks',
        'xks-ID': 'xks',
        'xks-Latn': 'xks',
        'xkt': 'xkt',
        'xkt-Latn-GH': 'xkt',
        'xkt-GH': 'xkt',
        'xkt-Latn': 'xkt',
        'xku': 'xku',
        'xku-Latn-CG': 'xku',
        'xku-CG': 'xku',
        'xku-Latn': 'xku',
        'xkv': 'xkv',
        'xkv-Latn-BW': 'xkv',
        'xkv-BW': 'xkv',
        'xkv-Latn': 'xkv',
        'xkw': 'xkw',
        'xkw-Latn-ID': 'xkw',
        'xkw-ID': 'xkw',
        'xkw-Latn': 'xkw',
        'xkx': 'xkx',
        'xkx-Latn-PG': 'xkx',
        'xkx-Latn': 'xkx',
        'xkx-PG': 'xkx',
        'xky': 'xky',
        'xky-Latn-MY': 'xky',
        'xky-Latn': 'xky',
        'xky-MY': 'xky',
        'xkz': 'xkz',
        'xkz-Latn-BT': 'xkz',
        'xkz-BT': 'xkz',
        'xkz-Latn': 'xkz',
        'xkz-Tibt-x-uchen': 'xkz-Tibt-x-uchen',
        'xkz-Tibt-BT-x-uchen': 'xkz-Tibt-x-uchen',
        'xkz-BT-x-uchen': 'xkz-Tibt-x-uchen',
        'xla': 'xla',
        'xla-Latn-PG': 'xla',
        'xla-Latn': 'xla',
        'xla-PG': 'xla',
        'xlb': 'xlb',
        'xlb-Zyyy-XX': 'xlb',
        'xlb-XX': 'xlb',
        'xlb-Zyyy': 'xlb',
        'xlc': 'xlc',
        'xlc-Lyci-TR': 'xlc',
        'xlc-Lyci': 'xlc',
        'xlc-TR': 'xlc',
        'xld': 'xld',
        'xld-Lydi-TR': 'xld',
        'xld-Lydi': 'xld',
        'xld-TR': 'xld',
        'xle': 'xle',
        'xle-Zyyy-XX': 'xle',
        'xle-XX': 'xle',
        'xle-Zyyy': 'xle',
        'xlg': 'xlg',
        'xlg-Zyyy-XX': 'xlg',
        'xlg-XX': 'xlg',
        'xlg-Zyyy': 'xlg',
        'xli': 'xli',
        'xli-Zyyy-XX': 'xli',
        'xli-XX': 'xli',
        'xli-Zyyy': 'xli',
        'xln': 'xln',
        'xln-Zyyy-XX': 'xln',
        'xln-XX': 'xln',
        'xln-Zyyy': 'xln',
        'xlo': 'xlo',
        'xlo-Zyyy-XX': 'xlo',
        'xlo-XX': 'xlo',
        'xlo-Zyyy': 'xlo',
        'xlp': 'xlp',
        'xlp-Zyyy-XX': 'xlp',
        'xlp-XX': 'xlp',
        'xlp-Zyyy': 'xlp',
        'xls': 'xls',
        'xls-Zyyy-XX': 'xls',
        'xls-XX': 'xls',
        'xls-Zyyy': 'xls',
        'xlu': 'xlu',
        'xlu-Zyyy-XX': 'xlu',
        'xlu-XX': 'xlu',
        'xlu-Zyyy': 'xlu',
        'xly': 'xly',
        'xly-Elym-IR': 'xly',
        'xly-Elym': 'xly',
        'xly-IR': 'xly',
        'xma': 'xma',
        'xma-Zyyy-SO': 'xma',
        'xma-SO': 'xma',
        'xma-Zyyy': 'xma',
        'xmb': 'xmb',
        'xmb-Latn-CM': 'xmb',
        'xmb-CM': 'xmb',
        'xmb-Latn': 'xmb',
        'xmc': 'xmc',
        'xmc-Latn-MZ': 'xmc',
        'xmc-Latn': 'xmc',
        'xmc-MZ': 'xmc',
        'xmd': 'xmd',
        'xmd-Latn-CM': 'xmd',
        'xmd-CM': 'xmd',
        'xmd-Latn': 'xmd',
        'xme': 'xme',
        'xme-Zyyy-XX': 'xme',
        'xme-XX': 'xme',
        'xme-Zyyy': 'xme',
        'xmf': 'xmf',
        'xmf-Geor-GE': 'xmf',
        'xmf-GE': 'xmf',
        'xmf-Geor': 'xmf',
        'xmg': 'xmg',
        'xmg-Latn-CM': 'xmg',
        'xmg-CM': 'xmg',
        'xmg-Latn': 'xmg',
        'xmg-Zzzz-x-bagam': 'xmg-Zzzz-x-bagam',
        'xmg-Zzzz-CM-x-bagam': 'xmg-Zzzz-x-bagam',
        'xmg-CM-x-bagam': 'xmg-Zzzz-x-bagam',
        'xmh': 'xmh',
        'xmh-Latn-AU': 'xmh',
        'xmh-AU': 'xmh',
        'xmh-Latn': 'xmh',
        'xmj': 'xmj',
        'xmj-Latn-CM': 'xmj',
        'xmj-CM': 'xmj',
        'xmj-Latn': 'xmj',
        'xmk': 'xmk',
        'xmk-Zyyy-XX': 'xmk',
        'xmk-XX': 'xmk',
        'xmk-Zyyy': 'xmk',
        'xml': 'xml',
        'xml-Zxxx-MY': 'xml',
        'sgn-xml': 'xml',
        'sgn-xml-MY': 'xml',
        'xml-MY': 'xml',
        'xml-Zxxx': 'xml',
        'xmm': 'xmm',
        'xmm-Latn-ID': 'xmm',
        'ms-xmm': 'xmm',
        'ms-xmm-ID': 'xmm',
        'xmm-ID': 'xmm',
        'xmm-Latn': 'xmm',
        'xmn': 'xmn',
        'xmn-Mani-CN': 'xmn',
        'xmn-CN': 'xmn',
        'xmn-Mani': 'xmn',
        'xmo': 'xmo',
        'xmo-Latn-BR': 'xmo',
        'xmo-BR': 'xmo',
        'xmo-Latn': 'xmo',
        'xmp': 'xmp',
        'xmp-Latn-AU': 'xmp',
        'xmp-AU': 'xmp',
        'xmp-Latn': 'xmp',
        'xmq': 'xmq',
        'xmq-Latn-AU': 'xmq',
        'xmq-AU': 'xmq',
        'xmq-Latn': 'xmq',
        'xmr': 'xmr',
        'xmr-Merc-SD': 'xmr',
        'xmr-Merc': 'xmr',
        'xmr-SD': 'xmr',
        'xms': 'xms',
        'xms-Zxxx-MA': 'xms',
        'sgn-xms': 'xms',
        'sgn-xms-MA': 'xms',
        'xms-MA': 'xms',
        'xms-Zxxx': 'xms',
        'xmt': 'xmt',
        'xmt-Latn-ID': 'xmt',
        'xmt-ID': 'xmt',
        'xmt-Latn': 'xmt',
        'xmu': 'xmu',
        'xmu-Latn-AU': 'xmu',
        'xmu-AU': 'xmu',
        'xmu-Latn': 'xmu',
        'xmv': 'xmv',
        'xmv-Latn-MG': 'xmv',
        'xmv-Latn': 'xmv',
        'xmv-MG': 'xmv',
        'xmw': 'xmw',
        'xmw-Latn-MG': 'xmw',
        'xmw-Latn': 'xmw',
        'xmw-MG': 'xmw',
        'xmx': 'xmx',
        'xmx-Latn-ID': 'xmx',
        'xmx-ID': 'xmx',
        'xmx-Latn': 'xmx',
        'xmy': 'xmy',
        'xmy-Latn-AU': 'xmy',
        'xmy-AU': 'xmy',
        'xmy-Latn': 'xmy',
        'xmz': 'xmz',
        'xmz-Latn-ID': 'xmz',
        'xmz-ID': 'xmz',
        'xmz-Latn': 'xmz',
        'xna': 'xna',
        'xna-Narb-SA': 'xna',
        'xna-Narb': 'xna',
        'xna-SA': 'xna',
        'xnb': 'xnb',
        'xnb-Zyyy-TW': 'xnb',
        'xnb-TW': 'xnb',
        'xnb-Zyyy': 'xnb',
        'xng': 'xng',
        'xng-Zyyy-XX': 'xng',
        'xng-XX': 'xng',
        'xng-Zyyy': 'xng',
        'xnh': 'xnh',
        'xnh-Zyyy-CN': 'xnh',
        'xnh-CN': 'xnh',
        'xnh-Zyyy': 'xnh',
        'xni': 'xni',
        'xni-Latn-AU': 'xni',
        'xni-AU': 'xni',
        'xni-Latn': 'xni',
        'xnk': 'xnk',
        'xnk-Latn-AU': 'xnk',
        'xnk-AU': 'xnk',
        'xnk-Latn': 'xnk',
        'xnm': 'xnm',
        'xnm-Latn-AU': 'xnm',
        'xnm-AU': 'xnm',
        'xnm-Latn': 'xnm',
        'xnn': 'xnn',
        'xnn-Latn-PH': 'xnn',
        'xnn-Latn': 'xnn',
        'xnn-PH': 'xnn',
        'xno': 'xno',
        'xno-Zyyy-XX': 'xno',
        'xno-XX': 'xno',
        'xno-Zyyy': 'xno',
        'xnr': 'xnr',
        'xnr-Deva-IN': 'xnr',
        'xnr-Deva': 'xnr',
        'xnr-IN': 'xnr',
        'xns': 'xns',
        'xns-Zyyy-IN': 'xns',
        'xns-IN': 'xns',
        'xns-Zyyy': 'xns',
        'xnt': 'xnt',
        'xnt-Zyyy-US': 'xnt',
        'xnt-US': 'xnt',
        'xnt-Zyyy': 'xnt',
        'xnu': 'xnu',
        'xnu-Latn-AU': 'xnu',
        'xnu-AU': 'xnu',
        'xnu-Latn': 'xnu',
        'xny': 'xny',
        'xny-Latn-AU': 'xny',
        'nad': 'xny',
        'nad-AU': 'xny',
        'nad-Latn': 'xny',
        'nad-Latn-AU': 'xny',
        'xny-AU': 'xny',
        'xny-Latn': 'xny',
        'xnz-Arab': 'xnz-Arab',
        'xnz-Arab-EG': 'xnz-Arab',
        'xnz-Copt': 'xnz-Copt',
        'xnz-Copt-EG-x-olnubian': 'xnz-Copt',
        'xnz-Copt-EG': 'xnz-Copt',
        'xnz-Copt-x-olnubian': 'xnz-Copt',
        'xnz-EG-x-olnubian': 'xnz-Copt',
        'xnz-Latn': 'xnz-Latn',
        'xnz-Latn-EG': 'xnz-Latn',
        'xoc': 'xoc',
        'xoc-Latn-NG': 'xoc',
        'xoc-Latn': 'xoc',
        'xoc-NG': 'xoc',
        'xod': 'xod',
        'xod-Latn-ID': 'xod',
        'xod-ID': 'xod',
        'xod-Latn': 'xod',
        'xog': 'xog',
        'xog-Latn-UG': 'xog',
        'xog-Latn': 'xog',
        'xog-UG': 'xog',
        'xoi': 'xoi',
        'xoi-Latn-PG': 'xoi',
        'xoi-Latn': 'xoi',
        'xoi-PG': 'xoi',
        'xok': 'xok',
        'xok-Latn-BR': 'xok',
        'xok-BR': 'xok',
        'xok-Latn': 'xok',
        'xom': 'xom',
        'xom-Latn-SD': 'xom',
        'xom-Latn': 'xom',
        'xom-SD': 'xom',
        'xom-Ethi': 'xom-Ethi',
        'xom-Ethi-ET': 'xom-Ethi',
        'xom-ET': 'xom-Ethi',
        'xon': 'xon',
        'xon-Latn-GH': 'xon',
        'xon-GH': 'xon',
        'xon-Latn': 'xon',
        'xon-Brai': 'xon-Brai',
        'xon-Brai-GH': 'xon-Brai',
        'xoo': 'xoo',
        'xoo-Latn-BR': 'xoo',
        'xoo-BR': 'xoo',
        'xoo-Latn': 'xoo',
        'xop': 'xop',
        'xop-Latn-PG': 'xop',
        'xop-Latn': 'xop',
        'xop-PG': 'xop',
        'xor': 'xor',
        'xor-Latn-BR': 'xor',
        'xor-BR': 'xor',
        'xor-Latn': 'xor',
        'xow': 'xow',
        'xow-Latn-PG': 'xow',
        'xow-Latn': 'xow',
        'xow-PG': 'xow',
        'xpa': 'xpa',
        'xpa-Latn-AU': 'xpa',
        'xpa-AU': 'xpa',
        'xpa-Latn': 'xpa',
        'xpb': 'xpb',
        'xpb-Latn-AU': 'xpb',
        'xpb-AU': 'xpb',
        'xpb-Latn': 'xpb',
        'xpc': 'xpc',
        'xpc-Zyyy-XX': 'xpc',
        'xpc-XX': 'xpc',
        'xpc-Zyyy': 'xpc',
        'xpd': 'xpd',
        'xpd-Latn-AU': 'xpd',
        'xpd-AU': 'xpd',
        'xpd-Latn': 'xpd',
        'xpf': 'xpf',
        'xpf-Latn-AU': 'xpf',
        'xpf-AU': 'xpf',
        'xpf-Latn': 'xpf',
        'xpg': 'xpg',
        'xpg-Grek-TR': 'xpg',
        'xpg-Grek': 'xpg',
        'xpg-TR': 'xpg',
        'xph': 'xph',
        'xph-Latn-AU': 'xph',
        'xph-AU': 'xph',
        'xph-Latn': 'xph',
        'xpi': 'xpi',
        'xpi-Zyyy-GB': 'xpi',
        'xpi-GB': 'xpi',
        'xpi-Zyyy': 'xpi',
        'xpj': 'xpj',
        'xpj-Latn-AU': 'xpj',
        'xpj-AU': 'xpj',
        'xpj-Latn': 'xpj',
        'xpk': 'xpk',
        'xpk-Latn-BR': 'xpk',
        'xpk-BR': 'xpk',
        'xpk-Latn': 'xpk',
        'xpl': 'xpl',
        'xpl-Latn-AU': 'xpl',
        'xpl-AU': 'xpl',
        'xpl-Latn': 'xpl',
        'xpm': 'xpm',
        'xpm-Cyrl-RU': 'xpm',
        'xpm-Cyrl': 'xpm',
        'xpm-RU': 'xpm',
        'xpn': 'xpn',
        'xpn-Latn-BR': 'xpn',
        'xpn-BR': 'xpn',
        'xpn-Latn': 'xpn',
        'xpo': 'xpo',
        'xpo-Latn-MX': 'xpo',
        'xpo-Latn': 'xpo',
        'xpo-MX': 'xpo',
        'xpp': 'xpp',
        'xpp-Zyyy-CN': 'xpp',
        'xpp-CN': 'xpp',
        'xpp-Zyyy': 'xpp',
        'xpq': 'xpq',
        'xpq-Zyyy-US': 'xpq',
        'xpq-US': 'xpq',
        'xpq-Zyyy': 'xpq',
        'xpr': 'xpr',
        'xpr-Prti-IR': 'xpr',
        'xpr-IR': 'xpr',
        'xpr-Prti': 'xpr',
        'xps': 'xps',
        'xps-Zyyy-TR': 'xps',
        'xps-TR': 'xps',
        'xps-Zyyy': 'xps',
        'xpt': 'xpt',
        'xpt-Latn-AU': 'xpt',
        'xpt-AU': 'xpt',
        'xpt-Latn': 'xpt',
        'xpu': 'xpu',
        'xpu-Zyyy-XX': 'xpu',
        'xpu-XX': 'xpu',
        'xpu-Zyyy': 'xpu',
        'xpv': 'xpv',
        'xpv-Latn-AU': 'xpv',
        'xpv-AU': 'xpv',
        'xpv-Latn': 'xpv',
        'xpw': 'xpw',
        'xpw-Latn-AU': 'xpw',
        'xpw-AU': 'xpw',
        'xpw-Latn': 'xpw',
        'xpx': 'xpx',
        'xpx-Latn-AU': 'xpx',
        'xpx-AU': 'xpx',
        'xpx-Latn': 'xpx',
        'xpy': 'xpy',
        'xpy-Zyyy-CN': 'xpy',
        'xpy-CN': 'xpy',
        'xpy-Zyyy': 'xpy',
        'xpz': 'xpz',
        'xpz-Latn-AU': 'xpz',
        'xpz-AU': 'xpz',
        'xpz-Latn': 'xpz',
        'xqa': 'xqa',
        'xqa-Zyyy-TR': 'xqa',
        'xqa-TR': 'xqa',
        'xqa-Zyyy': 'xqa',
        'xqt': 'xqt',
        'xqt-Zyyy-YE': 'xqt',
        'xqt-YE': 'xqt',
        'xqt-Zyyy': 'xqt',
        'xra': 'xra',
        'xra-Latn-BR': 'xra',
        'xra-BR': 'xra',
        'xra-Latn': 'xra',
        'xrb': 'xrb',
        'xrb-Latn-BF': 'xrb',
        'xrb-BF': 'xrb',
        'xrb-Latn': 'xrb',
        'xrd': 'xrd',
        'xrd-Latn-AU': 'xrd',
        'xrd-AU': 'xrd',
        'xrd-Latn': 'xrd',
        'xre': 'xre',
        'xre-Latn-BR': 'xre',
        'xre-BR': 'xre',
        'xre-Latn': 'xre',
        'xrg': 'xrg',
        'xrg-Latn-AU': 'xrg',
        'xrg-AU': 'xrg',
        'xrg-Latn': 'xrg',
        'xri': 'xri',
        'xri-Latn-BR': 'xri',
        'xri-BR': 'xri',
        'xri-Latn': 'xri',
        'xrm': 'xrm',
        'xrm-Cyrl-RU': 'xrm',
        'xrm-Cyrl': 'xrm',
        'xrm-RU': 'xrm',
        'xrn': 'xrn',
        'xrn-Cyrl-RU': 'xrn',
        'xrn-Cyrl': 'xrn',
        'xrn-RU': 'xrn',
        'xrr': 'xrr',
        'xrr-Zyyy-IT': 'xrr',
        'xrr-IT': 'xrr',
        'xrr-Zyyy': 'xrr',
        'xrt': 'xrt',
        'xrt-Zyyy-US': 'xrt',
        'xrt-US': 'xrt',
        'xrt-Zyyy': 'xrt',
        'xru': 'xru',
        'xru-Latn-AU': 'xru',
        'xru-AU': 'xru',
        'xru-Latn': 'xru',
        'xrw': 'xrw',
        'xrw-Latn-PG': 'xrw',
        'xrw-Latn': 'xrw',
        'xrw-PG': 'xrw',
        'xsa': 'xsa',
        'xsa-Sarb-YE': 'xsa',
        'xsa-Sarb': 'xsa',
        'xsa-YE': 'xsa',
        'xsb': 'xsb',
        'xsb-Latn-PH': 'xsb',
        'xsb-Latn': 'xsb',
        'xsb-PH': 'xsb',
        'xsc': 'xsc',
        'xsc-Zyyy-XX': 'xsc',
        'xsc-XX': 'xsc',
        'xsc-Zyyy': 'xsc',
        'xsd': 'xsd',
        'xsd-Zyyy-TR': 'xsd',
        'xsd-TR': 'xsd',
        'xsd-Zyyy': 'xsd',
        'xse': 'xse',
        'xse-Latn-ID': 'xse',
        'xse-ID': 'xse',
        'xse-Latn': 'xse',
        'xsh': 'xsh',
        'xsh-Latn-NG': 'xsh',
        'xsh-Latn': 'xsh',
        'xsh-NG': 'xsh',
        'xsi': 'xsi',
        'xsi-Latn-PG': 'xsi',
        'xsi-Latn': 'xsi',
        'xsi-PG': 'xsi',
        'xsm': 'xsm',
        'xsm-Latn-GH': 'xsm',
        'xsm-GH': 'xsm',
        'xsm-Latn': 'xsm',
        'xsn': 'xsn',
        'xsn-Latn-NG': 'xsn',
        'xsn-Latn': 'xsn',
        'xsn-NG': 'xsn',
        'xso': 'xso',
        'xso-Zyyy-US': 'xso',
        'xso-US': 'xso',
        'xso-Zyyy': 'xso',
        'xsp': 'xsp',
        'xsp-Latn-PG': 'xsp',
        'xsp-Latn': 'xsp',
        'xsp-PG': 'xsp',
        'xsq': 'xsq',
        'xsq-Latn-MZ': 'xsq',
        'xsq-Latn': 'xsq',
        'xsq-MZ': 'xsq',
        'xsr': 'xsr',
        'xsr-Deva-NP': 'xsr',
        'xsr-Deva': 'xsr',
        'xsr-NP': 'xsr',
        'xsr-Tibt': 'xsr-Tibt',
        'xsr-Tibt-CN': 'xsr-Tibt',
        'xsr-CN': 'xsr-Tibt',
        'xss': 'xss',
        'xss-Cyrl-RU': 'xss',
        'xss-Cyrl': 'xss',
        'xss-RU': 'xss',
        'xsu': 'xsu',
        'xsu-Latn-VE': 'xsu',
        'xsu-Latn': 'xsu',
        'xsu-VE': 'xsu',
        'xsv': 'xsv',
        'xsv-Zyyy-XX': 'xsv',
        'xsv-XX': 'xsv',
        'xsv-Zyyy': 'xsv',
        'xsy': 'xsy',
        'xsy-Latn-TW': 'xsy',
        'xsy-Latn': 'xsy',
        'xsy-TW': 'xsy',
        'xta': 'xta',
        'xta-Latn-MX': 'xta',
        'xta-Latn': 'xta',
        'xta-MX': 'xta',
        'xtb': 'xtb',
        'xtb-Latn-MX': 'xtb',
        'xtb-Latn': 'xtb',
        'xtb-MX': 'xtb',
        'xtc': 'xtc',
        'xtc-Latn-SD': 'xtc',
        'xtc-Latn': 'xtc',
        'xtc-SD': 'xtc',
        'xtd': 'xtd',
        'xtd-Latn-MX': 'xtd',
        'xtd-Latn': 'xtd',
        'xtd-MX': 'xtd',
        'xte': 'xte',
        'xte-Latn-ID': 'xte',
        'xte-ID': 'xte',
        'xte-Latn': 'xte',
        'xtg': 'xtg',
        'xtg-Zyyy-XX': 'xtg',
        'xtg-XX': 'xtg',
        'xtg-Zyyy': 'xtg',
        'xth': 'xth',
        'xth-Latn-AU': 'xth',
        'xth-AU': 'xth',
        'xth-Latn': 'xth',
        'xti': 'xti',
        'xti-Latn-MX': 'xti',
        'xti-Latn': 'xti',
        'xti-MX': 'xti',
        'xtj': 'xtj',
        'xtj-Latn-MX': 'xtj',
        'xtj-Latn': 'xtj',
        'xtj-MX': 'xtj',
        'xtl': 'xtl',
        'xtl-Latn-MX': 'xtl',
        'xtl-Latn': 'xtl',
        'xtl-MX': 'xtl',
        'xtm': 'xtm',
        'xtm-Latn-MX': 'xtm',
        'xtm-Latn': 'xtm',
        'xtm-MX': 'xtm',
        'xtn': 'xtn',
        'xtn-Latn-MX': 'xtn',
        'xtn-Latn': 'xtn',
        'xtn-MX': 'xtn',
        'xto': 'xto',
        'xto-Zyyy-CN': 'xto',
        'xto-CN': 'xto',
        'xto-Zyyy': 'xto',
        'xtp': 'xtp',
        'xtp-Latn-MX': 'xtp',
        'xtp-Latn': 'xtp',
        'xtp-MX': 'xtp',
        'xtq': 'xtq',
        'xtq-Zyyy-IR': 'xtq',
        'xtq-IR': 'xtq',
        'xtq-Zyyy': 'xtq',
        'xtr': 'xtr',
        'xtr-Zyyy-IN': 'xtr',
        'xtr-IN': 'xtr',
        'xtr-Zyyy': 'xtr',
        'xts': 'xts',
        'xts-Latn-MX': 'xts',
        'xts-Latn': 'xts',
        'xts-MX': 'xts',
        'xtt': 'xtt',
        'xtt-Latn-MX': 'xtt',
        'xtt-Latn': 'xtt',
        'xtt-MX': 'xtt',
        'xtu': 'xtu',
        'xtu-Latn-MX': 'xtu',
        'xtu-Latn': 'xtu',
        'xtu-MX': 'xtu',
        'xtv': 'xtv',
        'xtv-Latn-AU': 'xtv',
        'xtv-AU': 'xtv',
        'xtv-Latn': 'xtv',
        'xtw': 'xtw',
        'xtw-Latn-BR': 'xtw',
        'xtw-BR': 'xtw',
        'xtw-Latn': 'xtw',
        'xty': 'xty',
        'xty-Latn-MX': 'xty',
        'xty-Latn': 'xty',
        'xty-MX': 'xty',
        'xtz': 'xtz',
        'xtz-Latn-AU': 'xtz',
        'xtz-AU': 'xtz',
        'xtz-Latn': 'xtz',
        'xua': 'xua',
        'xua-Zyyy-IN': 'xua',
        'xua-IN': 'xua',
        'xua-Zyyy': 'xua',
        'xub-Knda': 'xub-Knda',
        'xub-Knda-IN': 'xub-Knda',
        'xub-Mlym': 'xub-Mlym',
        'xub-Mlym-IN': 'xub-Mlym',
        'xub-Taml': 'xub-Taml',
        'xub-Taml-IN': 'xub-Taml',
        'xud': 'xud',
        'xud-Latn-AU': 'xud',
        'xud-AU': 'xud',
        'xud-Latn': 'xud',
        'xug': 'xug',
        'xug-Zyyy-JP': 'xug',
        'xug-JP': 'xug',
        'xug-Zyyy': 'xug',
        'xuj': 'xuj',
        'xuj-Zyyy-IN': 'xuj',
        'xuj-IN': 'xuj',
        'xuj-Zyyy': 'xuj',
        'xul': 'xul',
        'xul-Latn-AU': 'xul',
        'xul-AU': 'xul',
        'xul-Latn': 'xul',
        'xum': 'xum',
        'xum-Latn-IT': 'xum',
        'xum-IT': 'xum',
        'xum-Latn': 'xum',
        'xum-Ital': 'xum-Ital',
        'xum-Ital-IT': 'xum-Ital',
        'xun': 'xun',
        'xun-Latn-AU': 'xun',
        'xun-AU': 'xun',
        'xun-Latn': 'xun',
        'xuo': 'xuo',
        'xuo-Latn-TD': 'xuo',
        'xuo-Latn': 'xuo',
        'xuo-TD': 'xuo',
        'xup': 'xup',
        'xup-Zyyy-US': 'xup',
        'xup-US': 'xup',
        'xup-Zyyy': 'xup',
        'xur': 'xur',
        'xur-Zyyy-TR': 'xur',
        'xur-TR': 'xur',
        'xur-Zyyy': 'xur',
        'xut': 'xut',
        'xut-Latn-AU': 'xut',
        'xut-AU': 'xut',
        'xut-Latn': 'xut',
        'xuu': 'xuu',
        'xuu-Latn-NA': 'xuu',
        'xuu-Latn': 'xuu',
        'xuu-NA': 'xuu',
        'xve': 'xve',
        'xve-Ital-IT': 'xve',
        'xve-IT': 'xve',
        'xve-Ital': 'xve',
        'xvi': 'xvi',
        'xvi-Arab-AF': 'xvi',
        'xvi-AF': 'xvi',
        'xvi-Arab': 'xvi',
        'xvn': 'xvn',
        'xvn-Latn-ES': 'xvn',
        'xvn-ES': 'xvn',
        'xvn-Latn': 'xvn',
        'xvo': 'xvo',
        'xvo-Latn-IT': 'xvo',
        'xvo-IT': 'xvo',
        'xvo-Latn': 'xvo',
        'xvs': 'xvs',
        'xvs-Latn-IT': 'xvs',
        'xvs-IT': 'xvs',
        'xvs-Latn': 'xvs',
        'xwa': 'xwa',
        'xwa-Latn-BR': 'xwa',
        'xwa-BR': 'xwa',
        'xwa-Latn': 'xwa',
        'xwc': 'xwc',
        'xwc-Zyyy-US': 'xwc',
        'xwc-US': 'xwc',
        'xwc-Zyyy': 'xwc',
        'xwd': 'xwd',
        'xwd-Latn-AU': 'xwd',
        'xwd-AU': 'xwd',
        'xwd-Latn': 'xwd',
        'xwe': 'xwe',
        'xwe-Latn-BJ': 'xwe',
        'xwe-BJ': 'xwe',
        'xwe-Latn': 'xwe',
        'xwg': 'xwg',
        'xwg-Zyyy-ET': 'xwg',
        'xwg-ET': 'xwg',
        'xwg-Zyyy': 'xwg',
        'xwj': 'xwj',
        'xwj-Latn-AU': 'xwj',
        'xwj-AU': 'xwj',
        'xwj-Latn': 'xwj',
        'xwk': 'xwk',
        'xwk-Latn-AU': 'xwk',
        'xwk-AU': 'xwk',
        'xwk-Latn': 'xwk',
        'xwl': 'xwl',
        'xwl-Latn-BJ': 'xwl',
        'xwl-BJ': 'xwl',
        'xwl-Latn': 'xwl',
        'xwo': 'xwo',
        'xwo-Cyrl-RU': 'xwo',
        'xwo-Cyrl': 'xwo',
        'xwo-RU': 'xwo',
        'xwr': 'xwr',
        'xwr-Latn-ID': 'xwr',
        'xwr-ID': 'xwr',
        'xwr-Latn': 'xwr',
        'xwt': 'xwt',
        'xwt-Latn-AU': 'xwt',
        'xwt-AU': 'xwt',
        'xwt-Latn': 'xwt',
        'xww': 'xww',
        'xww-Latn-AU': 'xww',
        'xww-AU': 'xww',
        'xww-Latn': 'xww',
        'xxb': 'xxb',
        'xxb-Latn-GH': 'xxb',
        'xxb-GH': 'xxb',
        'xxb-Latn': 'xxb',
        'xxk': 'xxk',
        'xxk-Latn-ID': 'xxk',
        'xxk-ID': 'xxk',
        'xxk-Latn': 'xxk',
        'xxm': 'xxm',
        'xxm-Latn-AU': 'xxm',
        'xxm-AU': 'xxm',
        'xxm-Latn': 'xxm',
        'xxr': 'xxr',
        'xxr-Latn-BR': 'xxr',
        'xxr-BR': 'xxr',
        'xxr-Latn': 'xxr',
        'xxt': 'xxt',
        'xxt-Latn-ID': 'xxt',
        'xxt-ID': 'xxt',
        'xxt-Latn': 'xxt',
        'xya': 'xya',
        'xya-Latn-AU': 'xya',
        'xya-AU': 'xya',
        'xya-Latn': 'xya',
        'xyb': 'xyb',
        'xyb-Latn-AU': 'xyb',
        'xyb-AU': 'xyb',
        'xyb-Latn': 'xyb',
        'xyj': 'xyj',
        'xyj-Latn-AU': 'xyj',
        'xyj-AU': 'xyj',
        'xyj-Latn': 'xyj',
        'xyk': 'xyk',
        'xyk-Latn-AU': 'xyk',
        'xyk-AU': 'xyk',
        'xyk-Latn': 'xyk',
        'xyl': 'xyl',
        'xyl-Latn-BR': 'xyl',
        'xyl-BR': 'xyl',
        'xyl-Latn': 'xyl',
        'xyt': 'xyt',
        'xyt-Latn-AU': 'xyt',
        'xyt-AU': 'xyt',
        'xyt-Latn': 'xyt',
        'xyy': 'xyy',
        'xyy-Latn-AU': 'xyy',
        'xyy-AU': 'xyy',
        'xyy-Latn': 'xyy',
        'xzh': 'xzh',
        'xzh-Zyyy-CN': 'xzh',
        'xzh-CN': 'xzh',
        'xzh-Zyyy': 'xzh',
        'xzm': 'xzm',
        'xzm-Zyyy-XX': 'xzm',
        'xzm-XX': 'xzm',
        'xzm-Zyyy': 'xzm',
        'xzp': 'xzp',
        'xzp-Latn-MX': 'xzp',
        'xzp-Latn': 'xzp',
        'xzp-MX': 'xzp',
        'yaa': 'yaa',
        'yaa-Latn-PE': 'yaa',
        'yaa-Latn': 'yaa',
        'yaa-PE': 'yaa',
        'yab': 'yab',
        'yab-Latn-BR': 'yab',
        'yab-BR': 'yab',
        'yab-Latn': 'yab',
        'yac': 'yac',
        'yac-Latn-ID': 'yac',
        'yac-ID': 'yac',
        'yac-Latn': 'yac',
        'yad': 'yad',
        'yad-Latn-PE': 'yad',
        'yad-Latn': 'yad',
        'yad-PE': 'yad',
        'yae': 'yae',
        'yae-Latn-VE': 'yae',
        'yae-Latn': 'yae',
        'yae-VE': 'yae',
        'yaf': 'yaf',
        'yaf-Latn-CD': 'yaf',
        'yaf-CD': 'yaf',
        'yaf-Latn': 'yaf',
        'yag': 'yag',
        'yag-Latn-CL': 'yag',
        'yag-CL': 'yag',
        'yag-Latn': 'yag',
        'yah-Cyrl': 'yah-Cyrl',
        'yah-Cyrl-TJ': 'yah-Cyrl',
        'yah-Latn': 'yah-Latn',
        'yah-Latn-TJ': 'yah-Latn',
        'yai': 'yai',
        'yai-Cyrl-TJ': 'yai',
        'yai-Cyrl': 'yai',
        'yai-TJ': 'yai',
        'yaj': 'yaj',
        'yaj-Latn-CF': 'yaj',
        'yaj-CF': 'yaj',
        'yaj-Latn': 'yaj',
        'yak': 'yak',
        'yak-Latn-US': 'yak',
        'yak-Latn': 'yak',
        'yak-US': 'yak',
        'yal-Arab': 'yal-Arab',
        'yal-Arab-GN': 'yal-Arab',
        'yal-Latn': 'yal-Latn',
        'yal-Latn-GN': 'yal-Latn',
        'yam': 'yam',
        'yam-Latn-CM': 'yam',
        'kwq': 'yam',
        'kwq-CM': 'yam',
        'kwq-Latn': 'yam',
        'kwq-Latn-CM': 'yam',
        'yam-CM': 'yam',
        'yam-Latn': 'yam',
        'yan': 'yan',
        'yan-Latn-NI': 'yan',
        'sum': 'yan',
        'sum-Latn': 'yan',
        'sum-Latn-NI': 'yan',
        'sum-NI': 'yan',
        'yan-Latn': 'yan',
        'yan-NI': 'yan',
        'yao': 'yao',
        'yao-Latn-MZ': 'yao',
        'yao-Latn': 'yao',
        'yao-MZ': 'yao',
        'yao-Arab': 'yao-Arab',
        'yao-Arab-MZ': 'yao-Arab',
        'yap': 'yap',
        'yap-Latn-FM': 'yap',
        'yap-FM': 'yap',
        'yap-Latn': 'yap',
        'yaq': 'yaq',
        'yaq-Latn-MX': 'yaq',
        'yaq-Latn': 'yaq',
        'yaq-MX': 'yaq',
        'yar': 'yar',
        'yar-Latn-VE': 'yar',
        'yar-Latn': 'yar',
        'yar-VE': 'yar',
        'yas': 'yas',
        'yas-Latn-CM': 'yas',
        'yas-CM': 'yas',
        'yas-Latn': 'yas',
        'yat': 'yat',
        'yat-Latn-CM': 'yat',
        'yat-CM': 'yat',
        'yat-Latn': 'yat',
        'yau': 'yau',
        'yau-Latn-VE': 'yau',
        'yau-Latn': 'yau',
        'yau-VE': 'yau',
        'yav': 'yav',
        'yav-Latn-CM': 'yav',
        'yav-CM': 'yav',
        'yav-Latn': 'yav',
        'yaw': 'yaw',
        'yaw-Latn-BR': 'yaw',
        'yaw-BR': 'yaw',
        'yaw-Latn': 'yaw',
        'yax': 'yax',
        'yax-Latn-AO': 'yax',
        'yax-AO': 'yax',
        'yax-Latn': 'yax',
        'yay': 'yay',
        'yay-Latn-NG': 'yay',
        'yay-Latn': 'yay',
        'yay-NG': 'yay',
        'yaz': 'yaz',
        'yaz-Latn-NG': 'yaz',
        'yaz-Latn': 'yaz',
        'yaz-NG': 'yaz',
        'yba': 'yba',
        'yba-Latn-NG': 'yba',
        'yba-Latn': 'yba',
        'yba-NG': 'yba',
        'ybb': 'ybb',
        'ybb-Latn-CM': 'ybb',
        'ybb-CM': 'ybb',
        'ybb-Latn': 'ybb',
        'ybe': 'ybe',
        'ybe-Zyyy-CN': 'ybe',
        'ybe-CN': 'ybe',
        'ybe-Zyyy': 'ybe',
        'ybh': 'ybh',
        'ybh-Deva-NP': 'ybh',
        'ybh-Deva': 'ybh',
        'ybh-NP': 'ybh',
        'ybi': 'ybi',
        'ybi-Deva-NP': 'ybi',
        'ybi-Deva': 'ybi',
        'ybi-NP': 'ybi',
        'ybj': 'ybj',
        'ybj-Latn-NG': 'ybj',
        'ybj-Latn': 'ybj',
        'ybj-NG': 'ybj',
        'ybk': 'ybk',
        'ybk-Zyyy-CN': 'ybk',
        'ybk-CN': 'ybk',
        'ybk-Zyyy': 'ybk',
        'ybl': 'ybl',
        'ybl-Latn-NG': 'ybl',
        'ybl-Latn': 'ybl',
        'ybl-NG': 'ybl',
        'ybm': 'ybm',
        'ybm-Latn-PG': 'ybm',
        'ybm-Latn': 'ybm',
        'ybm-PG': 'ybm',
        'ybn': 'ybn',
        'ybn-Latn-BR': 'ybn',
        'ybn-BR': 'ybn',
        'ybn-Latn': 'ybn',
        'ybo': 'ybo',
        'ybo-Latn-PG': 'ybo',
        'ybo-Latn': 'ybo',
        'ybo-PG': 'ybo',
        'ybx': 'ybx',
        'ybx-Latn-PG': 'ybx',
        'ybx-Latn': 'ybx',
        'ybx-PG': 'ybx',
        'yby': 'yby',
        'yby-Latn-PG': 'yby',
        'yby-Latn': 'yby',
        'yby-PG': 'yby',
        'ych': 'ych',
        'ych-Zyyy-CN': 'ych',
        'ych-CN': 'ych',
        'ych-Zyyy': 'ych',
        'ycl': 'ycl',
        'ycl-Latn-CN': 'ycl',
        'ycl-CN': 'ycl',
        'ycl-Latn': 'ycl',
        'ycn': 'ycn',
        'ycn-Latn-CO': 'ycn',
        'ycn-CO': 'ycn',
        'ycn-Latn': 'ycn',
        'ycp': 'ycp',
        'ycp-Zyyy-LA': 'ycp',
        'ycp-LA': 'ycp',
        'ycp-Zyyy': 'ycp',
        'yda': 'yda',
        'yda-Latn-AU': 'yda',
        'yda-AU': 'yda',
        'yda-Latn': 'yda',
        'yde': 'yde',
        'yde-Latn-PG': 'yde',
        'yde-Latn': 'yde',
        'yde-PG': 'yde',
        'ydg': 'ydg',
        'ydg-Arab-PK': 'ydg',
        'ydg-Arab': 'ydg',
        'ydg-PK': 'ydg',
        'ydk': 'ydk',
        'ydk-Latn-PG': 'ydk',
        'ydk-Latn': 'ydk',
        'ydk-PG': 'ydk',
        'yea-Knda': 'yea-Knda',
        'yea-Knda-IN': 'yea-Knda',
        'yea-Mlym': 'yea-Mlym',
        'yea-Mlym-IN': 'yea-Mlym',
        'yec': 'yec',
        'yec-Zyyy-DE': 'yec',
        'yec-DE': 'yec',
        'yec-Zyyy': 'yec',
        'yee': 'yee',
        'yee-Latn-PG': 'yee',
        'yee-Latn': 'yee',
        'yee-PG': 'yee',
        'yei': 'yei',
        'yei-Latn-CM': 'yei',
        'yei-CM': 'yei',
        'yei-Latn': 'yei',
        'yej': 'yej',
        'yej-Grek-IL': 'yej',
        'yej-Grek': 'yej',
        'yej-IL': 'yej',
        'yel': 'yel',
        'yel-Latn-CD': 'yel',
        'yel-CD': 'yel',
        'yel-Latn': 'yel',
        'yer': 'yer',
        'yer-Latn-NG': 'yer',
        'yer-Latn': 'yer',
        'yer-NG': 'yer',
        'yes': 'yes',
        'yes-Latn-NG': 'yes',
        'yes-Latn': 'yes',
        'yes-NG': 'yes',
        'yet': 'yet',
        'yet-Latn-ID': 'yet',
        'yet-ID': 'yet',
        'yet-Latn': 'yet',
        'yeu': 'yeu',
        'yeu-Telu-IN': 'yeu',
        'yeu-IN': 'yeu',
        'yeu-Telu': 'yeu',
        'yev': 'yev',
        'yev-Latn-PG': 'yev',
        'yev-Latn': 'yev',
        'yev-PG': 'yev',
        'yey': 'yey',
        'yey-Latn-BW': 'yey',
        'yey-BW': 'yey',
        'yey-Latn': 'yey',
        'yga': 'yga',
        'yga-Latn-AU': 'yga',
        'yga-AU': 'yga',
        'yga-Latn': 'yga',
        'ygi': 'ygi',
        'ygi-Latn-AU': 'ygi',
        'ygi-AU': 'ygi',
        'ygi-Latn': 'ygi',
        'ygl': 'ygl',
        'ygl-Latn-PG': 'ygl',
        'ygl-Latn': 'ygl',
        'ygl-PG': 'ygl',
        'ygm': 'ygm',
        'ygm-Latn-PG': 'ygm',
        'ygm-Latn': 'ygm',
        'ygm-PG': 'ygm',
        'ygp': 'ygp',
        'ygp-Plrd-CN': 'ygp',
        'ygp-CN': 'ygp',
        'ygp-Plrd': 'ygp',
        'ygr': 'ygr',
        'ygr-Latn-PG': 'ygr',
        'ygr-Latn': 'ygr',
        'ygr-PG': 'ygr',
        'ygs': 'ygs',
        'ygs-Zxxx-AU': 'ygs',
        'sgn-ygs': 'ygs',
        'sgn-ygs-AU': 'ygs',
        'ygs-AU': 'ygs',
        'ygs-Zxxx': 'ygs',
        'ygu': 'ygu',
        'ygu-Latn-AU': 'ygu',
        'ygu-AU': 'ygu',
        'ygu-Latn': 'ygu',
        'ygw': 'ygw',
        'ygw-Latn-PG': 'ygw',
        'ygw-Latn': 'ygw',
        'ygw-PG': 'ygw',
        'yha': 'yha',
        'yha-Zyyy-CN': 'yha',
        'yha-CN': 'yha',
        'yha-Zyyy': 'yha',
        'yhd': 'yhd',
        'yhd-Hebr-IL': 'yhd',
        'yhd-Hebr': 'yhd',
        'yhd-IL': 'yhd',
        'yhl': 'yhl',
        'yhl-Zyyy-CN': 'yhl',
        'yhl-CN': 'yhl',
        'yhl-Zyyy': 'yhl',
        'yhs': 'yhs',
        'yhs-Zxxx-AU': 'yhs',
        'sgn-yhs': 'yhs',
        'sgn-yhs-AU': 'yhs',
        'yhs-AU': 'yhs',
        'yhs-Zxxx': 'yhs',
        'yi': 'yi',
        'yi-Hebr-001': 'yi',
        'ji': 'yi',
        'ji-001': 'yi',
        'ji-Hebr': 'yi',
        'ji-Hebr-001': 'yi',
        'ydd': 'yi',
        'ydd-001': 'yi',
        'ydd-Hebr': 'yi',
        'ydd-Hebr-001': 'yi',
        'yi-001': 'yi',
        'yi-Hebr': 'yi',
        'yia': 'yia',
        'yia-Latn-AU': 'yia',
        'yia-AU': 'yia',
        'yia-Latn': 'yia',
        'yif': 'yif',
        'yif-Zyyy-CN': 'yif',
        'yif-CN': 'yif',
        'yif-Zyyy': 'yif',
        'yig': 'yig',
        'yig-Yiii-CN': 'yig',
        'yig-CN': 'yig',
        'yig-Yiii': 'yig',
        'yih': 'yih',
        'yih-Hebr-DE': 'yih',
        'yih-DE': 'yih',
        'yih-Hebr': 'yih',
        'yii': 'yii',
        'yii-Latn-AU': 'yii',
        'yii-AU': 'yii',
        'yii-Latn': 'yii',
        'yij': 'yij',
        'yij-Latn-AU': 'yij',
        'yij-AU': 'yij',
        'yij-Latn': 'yij',
        'yik': 'yik',
        'yik-Zyyy-CN': 'yik',
        'yik-CN': 'yik',
        'yik-Zyyy': 'yik',
        'yil': 'yil',
        'yil-Latn-AU': 'yil',
        'yil-AU': 'yil',
        'yil-Latn': 'yil',
        'yim': 'yim',
        'yim-Latn-IN': 'yim',
        'yim-IN': 'yim',
        'yim-Latn': 'yim',
        'yin': 'yin',
        'yin-Zyyy-MM': 'yin',
        'yin-MM': 'yin',
        'yin-Zyyy': 'yin',
        'yip': 'yip',
        'yip-Zyyy-CN': 'yip',
        'yip-CN': 'yip',
        'yip-Zyyy': 'yip',
        'yiq': 'yiq',
        'yiq-Zyyy-CN': 'yiq',
        'yiq-CN': 'yiq',
        'yiq-Zyyy': 'yiq',
        'yir': 'yir',
        'yir-Latn-ID': 'yir',
        'yir-ID': 'yir',
        'yir-Latn': 'yir',
        'yis': 'yis',
        'yis-Latn-PG': 'yis',
        'yis-Latn': 'yis',
        'yis-PG': 'yis',
        'yit': 'yit',
        'yit-Zyyy-CN': 'yit',
        'yit-CN': 'yit',
        'yit-Zyyy': 'yit',
        'yiu': 'yiu',
        'yiu-Zyyy-CN': 'yiu',
        'yiu-CN': 'yiu',
        'yiu-Zyyy': 'yiu',
        'yiv': 'yiv',
        'yiv-Zyyy-CN': 'yiv',
        'yiv-CN': 'yiv',
        'yiv-Zyyy': 'yiv',
        'yix': 'yix',
        'yix-Zyyy-CN': 'yix',
        'yix-CN': 'yix',
        'yix-Zyyy': 'yix',
        'yiz': 'yiz',
        'yiz-Zyyy-CN': 'yiz',
        'yiz-CN': 'yiz',
        'yiz-Zyyy': 'yiz',
        'yka': 'yka',
        'yka-Latn-PH': 'yka',
        'yka-Latn': 'yka',
        'yka-PH': 'yka',
        'yka-Arab': 'yka-Arab',
        'yka-Arab-PH': 'yka-Arab',
        'ykg': 'ykg',
        'ykg-Cyrl-RU': 'ykg',
        'ykg-Cyrl': 'ykg',
        'ykg-RU': 'ykg',
        'yki': 'yki',
        'yki-Latn-ID': 'yki',
        'yki-ID': 'yki',
        'yki-Latn': 'yki',
        'ykk': 'ykk',
        'ykk-Latn-PG': 'ykk',
        'ykk-Latn': 'ykk',
        'ykk-PG': 'ykk',
        'ykl': 'ykl',
        'ykl-Zyyy-CN': 'ykl',
        'ykl-CN': 'ykl',
        'ykl-Zyyy': 'ykl',
        'ykm': 'ykm',
        'ykm-Latn-PG': 'ykm',
        'ykm-Latn': 'ykm',
        'ykm-PG': 'ykm',
        'ykn': 'ykn',
        'ykn-Zyyy-CN': 'ykn',
        'ykn-CN': 'ykn',
        'ykn-Zyyy': 'ykn',
        'yko': 'yko',
        'yko-Latn-CM': 'yko',
        'yko-CM': 'yko',
        'yko-Latn': 'yko',
        'ykr': 'ykr',
        'ykr-Latn-PG': 'ykr',
        'ykr-Latn': 'ykr',
        'ykr-PG': 'ykr',
        'ykt': 'ykt',
        'ykt-Zyyy-CN': 'ykt',
        'ykt-CN': 'ykt',
        'ykt-Zyyy': 'ykt',
        'yku': 'yku',
        'yku-Zyyy-CN': 'yku',
        'yku-CN': 'yku',
        'yku-Zyyy': 'yku',
        'yky': 'yky',
        'yky-Latn-CF': 'yky',
        'yky-CF': 'yky',
        'yky-Latn': 'yky',
        'yla': 'yla',
        'yla-Latn-PG': 'yla',
        'yla-Latn': 'yla',
        'yla-PG': 'yla',
        'ylb': 'ylb',
        'ylb-Latn-PG': 'ylb',
        'ylb-Latn': 'ylb',
        'ylb-PG': 'ylb',
        'yle': 'yle',
        'yle-Latn-PG': 'yle',
        'yle-Latn': 'yle',
        'yle-PG': 'yle',
        'ylg': 'ylg',
        'ylg-Latn-PG': 'ylg',
        'ylg-Latn': 'ylg',
        'ylg-PG': 'ylg',
        'yli': 'yli',
        'yli-Latn-ID': 'yli',
        'yli-ID': 'yli',
        'yli-Latn': 'yli',
        'yll': 'yll',
        'yll-Latn-PG': 'yll',
        'yll-Latn': 'yll',
        'yll-PG': 'yll',
        'ylm': 'ylm',
        'ylm-Zyyy-CN': 'ylm',
        'ylm-CN': 'ylm',
        'ylm-Zyyy': 'ylm',
        'yln': 'yln',
        'yln-Zyyy-CN': 'yln',
        'yln-CN': 'yln',
        'yln-Zyyy': 'yln',
        'ylo': 'ylo',
        'ylo-Zyyy-CN': 'ylo',
        'ylo-CN': 'ylo',
        'ylo-Zyyy': 'ylo',
        'ylr': 'ylr',
        'ylr-Latn-AU': 'ylr',
        'ylr-AU': 'ylr',
        'ylr-Latn': 'ylr',
        'ylu': 'ylu',
        'ylu-Latn-PG': 'ylu',
        'ylu-Latn': 'ylu',
        'ylu-PG': 'ylu',
        'yly': 'yly',
        'yly-Latn-NC': 'yly',
        'yly-Latn': 'yly',
        'yly-NC': 'yly',
        'ymb': 'ymb',
        'ymb-Latn-PG': 'ymb',
        'ymb-Latn': 'ymb',
        'ymb-PG': 'ymb',
        'ymc': 'ymc',
        'ymc-Zyyy-CN': 'ymc',
        'ymc-CN': 'ymc',
        'ymc-Zyyy': 'ymc',
        'ymd': 'ymd',
        'ymd-Zyyy-CN': 'ymd',
        'ymd-CN': 'ymd',
        'ymd-Zyyy': 'ymd',
        'yme': 'yme',
        'yme-Latn-PE': 'yme',
        'yme-Latn': 'yme',
        'yme-PE': 'yme',
        'ymg': 'ymg',
        'ymg-Latn-CD': 'ymg',
        'ymg-CD': 'ymg',
        'ymg-Latn': 'ymg',
        'ymh': 'ymh',
        'ymh-Zyyy-CN': 'ymh',
        'ymh-CN': 'ymh',
        'ymh-Zyyy': 'ymh',
        'ymi': 'ymi',
        'ymi-Zyyy-CN': 'ymi',
        'ymi-CN': 'ymi',
        'ymi-Zyyy': 'ymi',
        'ymk': 'ymk',
        'ymk-Latn-MZ': 'ymk',
        'ymk-Latn': 'ymk',
        'ymk-MZ': 'ymk',
        'ymk-Arab': 'ymk-Arab',
        'ymk-Arab-MZ': 'ymk-Arab',
        'yml': 'yml',
        'yml-Latn-PG': 'yml',
        'yml-Latn': 'yml',
        'yml-PG': 'yml',
        'ymm': 'ymm',
        'ymm-Latn-SO': 'ymm',
        'ymm-Latn': 'ymm',
        'ymm-SO': 'ymm',
        'ymn': 'ymn',
        'ymn-Latn-ID': 'ymn',
        'ymn-ID': 'ymn',
        'ymn-Latn': 'ymn',
        'ymo': 'ymo',
        'ymo-Latn-PG': 'ymo',
        'ymo-Latn': 'ymo',
        'ymo-PG': 'ymo',
        'ymp': 'ymp',
        'ymp-Latn-PG': 'ymp',
        'ymp-Latn': 'ymp',
        'ymp-PG': 'ymp',
        'ymq': 'ymq',
        'ymq-Zyyy-CN': 'ymq',
        'ymq-CN': 'ymq',
        'ymq-Zyyy': 'ymq',
        'ymr': 'ymr',
        'ymr-Zyyy-IN': 'ymr',
        'ymr-IN': 'ymr',
        'ymr-Zyyy': 'ymr',
        'yms': 'yms',
        'yms-Zyyy-TR': 'yms',
        'yms-TR': 'yms',
        'yms-Zyyy': 'yms',
        'ymx': 'ymx',
        'ymx-Zyyy-CN': 'ymx',
        'ymx-CN': 'ymx',
        'ymx-Zyyy': 'ymx',
        'ymz': 'ymz',
        'ymz-Zyyy-CN': 'ymz',
        'ymz-CN': 'ymz',
        'ymz-Zyyy': 'ymz',
        'yna': 'yna',
        'yna-Plrd-CN': 'yna',
        'yna-CN': 'yna',
        'yna-Plrd': 'yna',
        'ynd': 'ynd',
        'ynd-Latn-AU': 'ynd',
        'ynd-AU': 'ynd',
        'ynd-Latn': 'ynd',
        'yne': 'yne',
        'yne-Zyyy-CN': 'yne',
        'yne-CN': 'yne',
        'yne-Zyyy': 'yne',
        'yng': 'yng',
        'yng-Latn-CD': 'yng',
        'yng-CD': 'yng',
        'yng-Latn': 'yng',
        'ynk': 'ynk',
        'ynk-Cyrl-RU': 'ynk',
        'ynk-Cyrl': 'ynk',
        'ynk-RU': 'ynk',
        'ynl': 'ynl',
        'ynl-Latn-PG': 'ynl',
        'ynl-Latn': 'ynl',
        'ynl-PG': 'ynl',
        'ynn': 'ynn',
        'ynn-Zyyy-US': 'ynn',
        'ynn-US': 'ynn',
        'ynn-Zyyy': 'ynn',
        'yno': 'yno',
        'yno-Zyyy-TH': 'yno',
        'yno-TH': 'yno',
        'yno-Zyyy': 'yno',
        'ynq': 'ynq',
        'ynq-Latn-NG': 'ynq',
        'yen': 'ynq',
        'yen-Latn': 'ynq',
        'yen-Latn-NG': 'ynq',
        'yen-NG': 'ynq',
        'ynq-Latn': 'ynq',
        'ynq-NG': 'ynq',
        'yns': 'yns',
        'yns-Latn-CD': 'yns',
        'yns-CD': 'yns',
        'yns-Latn': 'yns',
        'ynu': 'ynu',
        'ynu-Latn-CO': 'ynu',
        'ynu-CO': 'ynu',
        'ynu-Latn': 'ynu',
        'yo': 'yo',
        'yo-Latn-NG': 'yo',
        'yo-Latn': 'yo',
        'yo-NG': 'yo',
        'yo-Arab': 'yo-Arab',
        'yo-Arab-NG': 'yo-Arab',
        'yo-BJ': 'yo-BJ',
        'yo-Latn-BJ': 'yo-BJ',
        'yo-Brai': 'yo-Brai',
        'yo-Brai-NG': 'yo-Brai',
        'yob': 'yob',
        'yob-Latn-PG': 'yob',
        'yob-Latn': 'yob',
        'yob-PG': 'yob',
        'yog': 'yog',
        'yog-Latn-PH': 'yog',
        'yog-Latn': 'yog',
        'yog-PH': 'yog',
        'yoi': 'yoi',
        'yoi-Zyyy-JP': 'yoi',
        'yoi-JP': 'yoi',
        'yoi-Zyyy': 'yoi',
        'yok': 'yok',
        'yok-Latn-US': 'yok',
        'yok-Latn': 'yok',
        'yok-US': 'yok',
        'yol': 'yol',
        'yol-Zyyy-GB': 'yol',
        'yol-GB': 'yol',
        'yol-Zyyy': 'yol',
        'yom': 'yom',
        'yom-Latn-CD': 'yom',
        'yom-CD': 'yom',
        'yom-Latn': 'yom',
        'yon': 'yon',
        'yon-Latn-PG': 'yon',
        'yon-Latn': 'yon',
        'yon-PG': 'yon',
        'yot': 'yot',
        'yot-Latn-NG': 'yot',
        'yot-Latn': 'yot',
        'yot-NG': 'yot',
        'yox': 'yox',
        'yox-Zyyy-JP': 'yox',
        'yox-JP': 'yox',
        'yox-Zyyy': 'yox',
        'yoy': 'yoy',
        'yoy-Zyyy-TH': 'yoy',
        'yoy-TH': 'yoy',
        'yoy-Zyyy': 'yoy',
        'ypa': 'ypa',
        'ypa-Zyyy-CN': 'ypa',
        'ypa-CN': 'ypa',
        'ypa-Zyyy': 'ypa',
        'ypb': 'ypb',
        'ypb-Zyyy-CN': 'ypb',
        'ypb-CN': 'ypb',
        'ypb-Zyyy': 'ypb',
        'ypg': 'ypg',
        'ypg-Zyyy-CN': 'ypg',
        'ypg-CN': 'ypg',
        'ypg-Zyyy': 'ypg',
        'yph': 'yph',
        'yph-Zyyy-CN': 'yph',
        'yph-CN': 'yph',
        'yph-Zyyy': 'yph',
        'ypm': 'ypm',
        'ypm-Zyyy-CN': 'ypm',
        'ypm-CN': 'ypm',
        'ypm-Zyyy': 'ypm',
        'ypn': 'ypn',
        'ypn-Zyyy-CN': 'ypn',
        'ypn-CN': 'ypn',
        'ypn-Zyyy': 'ypn',
        'ypo': 'ypo',
        'ypo-Zyyy-CN': 'ypo',
        'ypo-CN': 'ypo',
        'ypo-Zyyy': 'ypo',
        'ypp': 'ypp',
        'ypp-Zyyy-CN': 'ypp',
        'ypp-CN': 'ypp',
        'ypp-Zyyy': 'ypp',
        'ypz': 'ypz',
        'ypz-Zyyy-CN': 'ypz',
        'ypz-CN': 'ypz',
        'ypz-Zyyy': 'ypz',
        'yra': 'yra',
        'yra-Latn-PG': 'yra',
        'yra-Latn': 'yra',
        'yra-PG': 'yra',
        'yrb': 'yrb',
        'yrb-Latn-PG': 'yrb',
        'yrb-Latn': 'yrb',
        'yrb-PG': 'yrb',
        'yre': 'yre',
        'yre-Latn-CI': 'yre',
        'yre-CI': 'yre',
        'yre-Latn': 'yre',
        'yrk': 'yrk',
        'yrk-Cyrl-RU': 'yrk',
        'yrk-Cyrl': 'yrk',
        'yrk-RU': 'yrk',
        'yrl': 'yrl',
        'yrl-Latn-BR': 'yrl',
        'yrl-BR': 'yrl',
        'yrl-Latn': 'yrl',
        'yrm': 'yrm',
        'yrm-Latn-AU': 'yrm',
        'yrm-AU': 'yrm',
        'yrm-Latn': 'yrm',
        'yrn': 'yrn',
        'yrn-Zyyy-CN': 'yrn',
        'yrn-CN': 'yrn',
        'yrn-Zyyy': 'yrn',
        'yro': 'yro',
        'yro-Latn-BR': 'yro',
        'yro-BR': 'yro',
        'yro-Latn': 'yro',
        'yrs': 'yrs',
        'yrs-Latn-ID': 'yrs',
        'yrs-ID': 'yrs',
        'yrs-Latn': 'yrs',
        'yrw': 'yrw',
        'yrw-Latn-PG': 'yrw',
        'yrw-Latn': 'yrw',
        'yrw-PG': 'yrw',
        'yry': 'yry',
        'yry-Latn-AU': 'yry',
        'yry-AU': 'yry',
        'yry-Latn': 'yry',
        'ysc': 'ysc',
        'ysc-Zyyy-HU': 'ysc',
        'ysc-HU': 'ysc',
        'ysc-Zyyy': 'ysc',
        'ysd': 'ysd',
        'ysd-Yiii-CN': 'ysd',
        'ysd-CN': 'ysd',
        'ysd-Yiii': 'ysd',
        'ysg': 'ysg',
        'ysg-Zyyy-CN': 'ysg',
        'ysg-CN': 'ysg',
        'ysg-Zyyy': 'ysg',
        'ysl': 'ysl',
        'ysl-Zxxx-RS': 'ysl',
        'sgn-ysl': 'ysl',
        'sgn-ysl-RS': 'ysl',
        'ysl-RS': 'ysl',
        'ysl-Zxxx': 'ysl',
        'ysn': 'ysn',
        'ysn-Yiii-CN': 'ysn',
        'ysn-CN': 'ysn',
        'ysn-Yiii': 'ysn',
        'yso': 'yso',
        'yso-Zyyy-CN': 'yso',
        'yso-CN': 'yso',
        'yso-Zyyy': 'yso',
        'ysp': 'ysp',
        'ysp-Zyyy-CN': 'ysp',
        'ysp-CN': 'ysp',
        'ysp-Zyyy': 'ysp',
        'ysr': 'ysr',
        'ysr-Cyrl-RU': 'ysr',
        'ysr-Cyrl': 'ysr',
        'ysr-RU': 'ysr',
        'yss': 'yss',
        'yss-Latn-PG': 'yss',
        'yss-Latn': 'yss',
        'yss-PG': 'yss',
        'ysy': 'ysy',
        'ysy-Plrd-CN': 'ysy',
        'ysy-CN': 'ysy',
        'ysy-Plrd': 'ysy',
        'yta': 'yta',
        'yta-Zyyy-CN': 'yta',
        'yta-CN': 'yta',
        'yta-Zyyy': 'yta',
        'ytl': 'ytl',
        'ytl-Zyyy-CN': 'ytl',
        'ytl-CN': 'ytl',
        'ytl-Zyyy': 'ytl',
        'ytp': 'ytp',
        'ytp-Zyyy-CN': 'ytp',
        'ytp-CN': 'ytp',
        'ytp-Zyyy': 'ytp',
        'ytw': 'ytw',
        'ytw-Latn-PG': 'ytw',
        'ytw-Latn': 'ytw',
        'ytw-PG': 'ytw',
        'yty': 'yty',
        'yty-Latn-AU': 'yty',
        'yty-AU': 'yty',
        'yty-Latn': 'yty',
        'yua': 'yua',
        'yua-Latn-MX': 'yua',
        'yua-Latn': 'yua',
        'yua-MX': 'yua',
        'yub': 'yub',
        'yub-Latn-AU': 'yub',
        'yub-AU': 'yub',
        'yub-Latn': 'yub',
        'yuc': 'yuc',
        'yuc-Latn-US': 'yuc',
        'yuc-Latn': 'yuc',
        'yuc-US': 'yuc',
        'yud': 'yud',
        'yud-Hebr-IL': 'yud',
        'yud-Hebr': 'yud',
        'yud-IL': 'yud',
        'yue': 'yue',
        'yue-Hant-HK': 'yue',
        'yue-HK': 'yue',
        'yue-Hant': 'yue',
        'zh-yue': 'yue',
        'zh-yue-HK': 'yue',
        'yue-Brai': 'yue-Brai',
        'yue-Brai-HK': 'yue-Brai',
        'yue-CN': 'yue-CN',
        'yue-Hans-CN': 'yue-CN',
        'yue-Hans': 'yue-CN',
        'zh-yue-CN': 'yue-CN',
        'yue-Latn': 'yue-Latn',
        'yue-Latn-CN': 'yue-Latn',
        'yuf': 'yuf',
        'yuf-Latn-US': 'yuf',
        'yuf-Latn': 'yuf',
        'yuf-US': 'yuf',
        'yug': 'yug',
        'yug-Cyrl-RU': 'yug',
        'yug-Cyrl': 'yug',
        'yug-RU': 'yug',
        'yuu': 'yug',
        'yuu-Cyrl': 'yug',
        'yuu-Cyrl-RU': 'yug',
        'yuu-RU': 'yug',
        'yui': 'yui',
        'yui-Latn-CO': 'yui',
        'yui-CO': 'yui',
        'yui-Latn': 'yui',
        'yuj': 'yuj',
        'yuj-Latn-PG': 'yuj',
        'yuj-Latn': 'yuj',
        'yuj-PG': 'yuj',
        'yuk': 'yuk',
        'yuk-Zyyy-US': 'yuk',
        'yuk-US': 'yuk',
        'yuk-Zyyy': 'yuk',
        'yul': 'yul',
        'yul-Latn-CF': 'yul',
        'yul-CF': 'yul',
        'yul-Latn': 'yul',
        'yum': 'yum',
        'yum-Latn-US': 'yum',
        'yum-Latn': 'yum',
        'yum-US': 'yum',
        'yun': 'yun',
        'yun-Latn-NG': 'yun',
        'yun-Latn': 'yun',
        'yun-NG': 'yun',
        'yup': 'yup',
        'yup-Latn-CO': 'yup',
        'yup-CO': 'yup',
        'yup-Latn': 'yup',
        'yuq': 'yuq',
        'yuq-Latn-BO': 'yuq',
        'yuq-BO': 'yuq',
        'yuq-Latn': 'yuq',
        'yur': 'yur',
        'yur-Latn-US': 'yur',
        'yur-Latn': 'yur',
        'yur-US': 'yur',
        'yut': 'yut',
        'yut-Latn-PG': 'yut',
        'yut-Latn': 'yut',
        'yut-PG': 'yut',
        'yuw': 'yuw',
        'yuw-Latn-PG': 'yuw',
        'yuw-Latn': 'yuw',
        'yuw-PG': 'yuw',
        'yux': 'yux',
        'yux-Cyrl-RU': 'yux',
        'yux-Cyrl': 'yux',
        'yux-RU': 'yux',
        'yuy': 'yuy',
        'yuy-Zyyy-CN': 'yuy',
        'yuy-CN': 'yuy',
        'yuy-Zyyy': 'yuy',
        'yuz': 'yuz',
        'yuz-Latn-BO': 'yuz',
        'yuz-BO': 'yuz',
        'yuz-Latn': 'yuz',
        'yva': 'yva',
        'yva-Latn-ID': 'yva',
        'yva-ID': 'yva',
        'yva-Latn': 'yva',
        'yvt': 'yvt',
        'yvt-Latn-VE': 'yvt',
        'yvt-Latn': 'yvt',
        'yvt-VE': 'yvt',
        'ywa': 'ywa',
        'ywa-Latn-PG': 'ywa',
        'ywa-Latn': 'ywa',
        'ywa-PG': 'ywa',
        'ywg': 'ywg',
        'ywg-Latn-AU': 'ywg',
        'ywg-AU': 'ywg',
        'ywg-Latn': 'ywg',
        'ywl': 'ywl',
        'ywl-Zyyy-CN': 'ywl',
        'ywl-CN': 'ywl',
        'ywl-Zyyy': 'ywl',
        'ywn': 'ywn',
        'ywn-Latn-BR': 'ywn',
        'ywn-BR': 'ywn',
        'ywn-Latn': 'ywn',
        'ywq': 'ywq',
        'ywq-Plrd-CN': 'ywq',
        'ywq-CN': 'ywq',
        'ywq-Plrd': 'ywq',
        'ywq-Yiii': 'ywq-Yiii',
        'ywq-Yiii-CN': 'ywq-Yiii',
        'ywr': 'ywr',
        'ywr-Latn-AU': 'ywr',
        'ywr-AU': 'ywr',
        'ywr-Latn': 'ywr',
        'ywt': 'ywt',
        'ywt-Zyyy-CN': 'ywt',
        'ywt-CN': 'ywt',
        'ywt-Zyyy': 'ywt',
        'ywu': 'ywu',
        'ywu-Zyyy-CN': 'ywu',
        'ywu-CN': 'ywu',
        'ywu-Zyyy': 'ywu',
        'yww': 'yww',
        'yww-Latn-AU': 'yww',
        'yww-AU': 'yww',
        'yww-Latn': 'yww',
        'yxa': 'yxa',
        'yxa-Latn-AU': 'yxa',
        'yxa-AU': 'yxa',
        'yxa-Latn': 'yxa',
        'yxg': 'yxg',
        'yxg-Latn-AU': 'yxg',
        'yxg-AU': 'yxg',
        'yxg-Latn': 'yxg',
        'yxl': 'yxl',
        'yxl-Latn-AU': 'yxl',
        'yxl-AU': 'yxl',
        'yxl-Latn': 'yxl',
        'yxm': 'yxm',
        'yxm-Latn-AU': 'yxm',
        'yxm-AU': 'yxm',
        'yxm-Latn': 'yxm',
        'yxu': 'yxu',
        'yxu-Latn-AU': 'yxu',
        'yxu-AU': 'yxu',
        'yxu-Latn': 'yxu',
        'yxy': 'yxy',
        'yxy-Latn-AU': 'yxy',
        'yxy-AU': 'yxy',
        'yxy-Latn': 'yxy',
        'yyr': 'yyr',
        'yyr-Latn-AU': 'yyr',
        'yiy': 'yyr',
        'yiy-AU': 'yyr',
        'yiy-Latn': 'yyr',
        'yiy-Latn-AU': 'yyr',
        'yyr-AU': 'yyr',
        'yyr-Latn': 'yyr',
        'yyu': 'yyu',
        'yyu-Latn-PG': 'yyu',
        'yyu-Latn': 'yyu',
        'yyu-PG': 'yyu',
        'yyz': 'yyz',
        'yyz-Zyyy-CN': 'yyz',
        'yyz-CN': 'yyz',
        'yyz-Zyyy': 'yyz',
        'yzg': 'yzg',
        'yzg-Zyyy-CN': 'yzg',
        'yzg-CN': 'yzg',
        'yzg-Zyyy': 'yzg',
        'yzk': 'yzk',
        'yzk-Zyyy-CN': 'yzk',
        'yzk-CN': 'yzk',
        'yzk-Zyyy': 'yzk',
        'za': 'za',
        'za-Latn-CN': 'za',
        'za-CN': 'za',
        'za-Latn': 'za',
        'zyb': 'za',
        'zyb-CN': 'za',
        'zyb-Latn': 'za',
        'zyb-Latn-CN': 'za',
        'za-Hani': 'za-Hani',
        'za-Hani-CN': 'za-Hani',
        'zyb-Hani': 'za-Hani',
        'zyb-Hani-CN': 'za-Hani',
        'za-Hans': 'za-Hans',
        'za-Hans-CN': 'za-Hans',
        'zaa': 'zaa',
        'zaa-Latn-MX': 'zaa',
        'zaa-Latn': 'zaa',
        'zaa-MX': 'zaa',
        'zab': 'zab',
        'zab-Latn-MX': 'zab',
        'zab-Latn': 'zab',
        'zab-MX': 'zab',
        'zac': 'zac',
        'zac-Latn-MX': 'zac',
        'zac-Latn': 'zac',
        'zac-MX': 'zac',
        'zad': 'zad',
        'zad-Latn-MX': 'zad',
        'zad-Latn': 'zad',
        'zad-MX': 'zad',
        'zae': 'zae',
        'zae-Latn-MX': 'zae',
        'zae-Latn': 'zae',
        'zae-MX': 'zae',
        'zaf': 'zaf',
        'zaf-Latn-MX': 'zaf',
        'zaf-Latn': 'zaf',
        'zaf-MX': 'zaf',
        'zag': 'zag',
        'zag-Latn-SD': 'zag',
        'zag-Latn': 'zag',
        'zag-SD': 'zag',
        'zag-Arab': 'zag-Arab',
        'zag-Arab-SD': 'zag-Arab',
        'zag-Zzzz-x-beria': 'zag-Zzzz-x-beria',
        'zag-Zzzz-SD-x-beria': 'zag-Zzzz-x-beria',
        'zag-SD-x-beria': 'zag-Zzzz-x-beria',
        'zah': 'zah',
        'zah-Latn-NG': 'zah',
        'zah-Latn': 'zah',
        'zah-NG': 'zah',
        'zaj': 'zaj',
        'zaj-Latn-TZ': 'zaj',
        'zaj-Latn': 'zaj',
        'zaj-TZ': 'zaj',
        'zak': 'zak',
        'zak-Latn-TZ': 'zak',
        'zak-Latn': 'zak',
        'zak-TZ': 'zak',
        'zal': 'zal',
        'zal-Zyyy-CN': 'zal',
        'zal-CN': 'zal',
        'zal-Zyyy': 'zal',
        'zam': 'zam',
        'zam-Latn-MX': 'zam',
        'zam-Latn': 'zam',
        'zam-MX': 'zam',
        'zao': 'zao',
        'zao-Latn-MX': 'zao',
        'zao-Latn': 'zao',
        'zao-MX': 'zao',
        'zap': 'zap',
        'zap-Latn-MX': 'zap',
        'zai': 'zap',
        'zai-Latn': 'zap',
        'zai-Latn-MX': 'zap',
        'zai-MX': 'zap',
        'zap-Latn': 'zap',
        'zap-MX': 'zap',
        'zaq': 'zaq',
        'zaq-Latn-MX': 'zaq',
        'zaq-Latn': 'zaq',
        'zaq-MX': 'zaq',
        'zar': 'zar',
        'zar-Latn-MX': 'zar',
        'zar-Latn': 'zar',
        'zar-MX': 'zar',
        'zas': 'zas',
        'zas-Latn-MX': 'zas',
        'zas-Latn': 'zas',
        'zas-MX': 'zas',
        'zat': 'zat',
        'zat-Latn-MX': 'zat',
        'zat-Latn': 'zat',
        'zat-MX': 'zat',
        'zau': 'zau',
        'zau-Tibt-IN': 'zau',
        'zau-IN': 'zau',
        'zau-Tibt': 'zau',
        'zav': 'zav',
        'zav-Latn-MX': 'zav',
        'zav-Latn': 'zav',
        'zav-MX': 'zav',
        'zaw': 'zaw',
        'zaw-Latn-MX': 'zaw',
        'zaw-Latn': 'zaw',
        'zaw-MX': 'zaw',
        'zax': 'zax',
        'zax-Latn-MX': 'zax',
        'zax-Latn': 'zax',
        'zax-MX': 'zax',
        'zay': 'zay',
        'zay-Latn-ET': 'zay',
        'zay-ET': 'zay',
        'zay-Latn': 'zay',
        'zay-Ethi': 'zay-Ethi',
        'zay-Ethi-ET': 'zay-Ethi',
        'zaz': 'zaz',
        'zaz-Latn-NG': 'zaz',
        'zaz-Latn': 'zaz',
        'zaz-NG': 'zaz',
        'zba': 'zba',
        'zba-Zyyy-001': 'zba',
        'zba-001': 'zba',
        'zba-Zyyy': 'zba',
        'zbc': 'zbc',
        'zbc-Latn-MY': 'zbc',
        'zbc-Latn': 'zbc',
        'zbc-MY': 'zbc',
        'zbe': 'zbe',
        'zbe-Latn-MY': 'zbe',
        'zbe-Latn': 'zbe',
        'zbe-MY': 'zbe',
        'zbl': 'zbl',
        'zbl-Blis-001': 'zbl',
        'zbl-001': 'zbl',
        'zbl-Blis': 'zbl',
        'zbt': 'zbt',
        'zbt-Latn-ID': 'zbt',
        'zbt-ID': 'zbt',
        'zbt-Latn': 'zbt',
        'zbw': 'zbw',
        'zbw-Latn-MY': 'zbw',
        'zbw-Latn': 'zbw',
        'zbw-MY': 'zbw',
        'zca': 'zca',
        'zca-Latn-MX': 'zca',
        'zca-Latn': 'zca',
        'zca-MX': 'zca',
        'zch': 'zch',
        'zch-Hani-CN': 'zch',
        'zch-CN': 'zch',
        'zch-Hani': 'zch',
        'zdj': 'zdj',
        'zdj-Arab-KM': 'zdj',
        'zdj-Arab': 'zdj',
        'zdj-KM': 'zdj',
        'zdj-Latn': 'zdj-Latn',
        'zdj-Latn-KM': 'zdj-Latn',
        'zea': 'zea',
        'zea-Latn-NL': 'zea',
        'zea-Latn': 'zea',
        'zea-NL': 'zea',
        'zeg': 'zeg',
        'zeg-Latn-PG': 'zeg',
        'zeg-Latn': 'zeg',
        'zeg-PG': 'zeg',
        'zeh': 'zeh',
        'zeh-Hani-CN': 'zeh',
        'zeh-CN': 'zeh',
        'zeh-Hani': 'zeh',
        'zen': 'zen',
        'zen-Tfng-MR': 'zen',
        'zen-MR': 'zen',
        'zen-Tfng': 'zen',
        'zen-Arab': 'zen-Arab',
        'zen-Arab-MR': 'zen-Arab',
        'zga': 'zga',
        'zga-Latn-TZ': 'zga',
        'zga-Latn': 'zga',
        'zga-TZ': 'zga',
        'zgb': 'zgb',
        'zgb-Hani-CN': 'zgb',
        'zgb-CN': 'zgb',
        'zgb-Hani': 'zgb',
        'zgh': 'zgh',
        'zgh-Tfng-MA': 'zgh',
        'zgh-MA': 'zgh',
        'zgh-Tfng': 'zgh',
        'zgm': 'zgm',
        'zgm-Hani-CN': 'zgm',
        'zgm-CN': 'zgm',
        'zgm-Hani': 'zgm',
        'zgn': 'zgn',
        'zgn-Hani-CN': 'zgn',
        'zgn-CN': 'zgn',
        'zgn-Hani': 'zgn',
        'zgr': 'zgr',
        'zgr-Latn-PG': 'zgr',
        'zgr-Latn': 'zgr',
        'zgr-PG': 'zgr',
        'zh-AU': 'zh-AU',
        'zh-Hant-AU': 'zh-AU',
        'zh-BN': 'zh-BN',
        'zh-Hant-BN': 'zh-BN',
        'zh-Bopo': 'zh-Bopo',
        'zh-Bopo-TW': 'zh-Bopo',
        'cmn-Bopo': 'zh-Bopo',
        'cmn-Bopo-TW': 'zh-Bopo',
        'zh-Brai': 'zh-Brai',
        'zh-Brai-CN': 'zh-Brai',
        'cmn-Brai': 'zh-Brai',
        'cmn-Brai-CN': 'zh-Brai',
        'zh-CN': 'zh-CN',
        'zh-Hans-CN': 'zh-CN',
        'cmn': 'zh-CN',
        'cmn-CN': 'zh-CN',
        'cmn-Hans': 'zh-CN',
        'cmn-Hans-CN': 'zh-CN',
        'zh': 'zh-CN',
        'zh-Hans': 'zh-CN',
        'zh-cmn': 'zh-CN',
        'zh-cmn-CN': 'zh-CN',
        'zh-GB': 'zh-GB',
        'zh-Hant-GB': 'zh-GB',
        'zh-GF': 'zh-GF',
        'zh-Hant-GF': 'zh-GF',
        'zh-HK': 'zh-HK',
        'zh-Hant-HK': 'zh-HK',
        'zh-Hanb': 'zh-Hanb',
        'zh-Hanb-TW': 'zh-Hanb',
        'zh-Hans-HK': 'zh-Hans-HK',
        'zh-Hans-MO': 'zh-Hans-MO',
        'zh-ID': 'zh-ID',
        'zh-Hant-ID': 'zh-ID',
        'zh-Latn': 'zh-Latn',
        'zh-Latn-CN': 'zh-Latn',
        'cmn-Latn': 'zh-Latn',
        'cmn-Latn-CN': 'zh-Latn',
        'zh-MO': 'zh-MO',
        'zh-Hant-MO': 'zh-MO',
        'zh-MY': 'zh-MY',
        'zh-Hant-MY': 'zh-MY',
        'zh-PA': 'zh-PA',
        'zh-Hant-PA': 'zh-PA',
        'zh-PF': 'zh-PF',
        'zh-Hant-PF': 'zh-PF',
        'zh-PH': 'zh-PH',
        'zh-Hant-PH': 'zh-PH',
        'zh-Phag': 'zh-Phag',
        'zh-Phag-CN': 'zh-Phag',
        'zh-SG': 'zh-SG',
        'zh-Hans-SG': 'zh-SG',
        'zh-SR': 'zh-SR',
        'zh-Hant-SR': 'zh-SR',
        'zh-TH': 'zh-TH',
        'zh-Hant-TH': 'zh-TH',
        'zh-TW': 'zh-TW',
        'zh-Hant-TW': 'zh-TW',
        'cmn-Hant': 'zh-TW',
        'cmn-Hant-TW': 'zh-TW',
        'zh-Hant': 'zh-TW',
        'zh-US': 'zh-US',
        'zh-Hant-US': 'zh-US',
        'zh-VN': 'zh-VN',
        'zh-Hant-VN': 'zh-VN',
        'zhb': 'zhb',
        'zhb-Zyyy-CN': 'zhb',
        'zhb-CN': 'zhb',
        'zhb-Zyyy': 'zhb',
        'zhd-Hani': 'zhd-Hani',
        'zhd-Hani-CN': 'zhd-Hani',
        'zhd-CN': 'zhd-Hani',
        'zhd-Latn': 'zhd-Latn',
        'zhd-Latn-VN': 'zhd-Latn',
        'zhd-VN': 'zhd-Latn',
        'zhi': 'zhi',
        'zhi-Latn-NG': 'zhi',
        'zhi-Latn': 'zhi',
        'zhi-NG': 'zhi',
        'zhn-Hani': 'zhn-Hani',
        'zhn-Hani-CN': 'zhn-Hani',
        'zhn-Latn': 'zhn-Latn',
        'zhn-Latn-CN': 'zhn-Latn',
        'zhw': 'zhw',
        'zhw-Latn-CM': 'zhw',
        'zhw-CM': 'zhw',
        'zhw-Latn': 'zhw',
        'zhx': 'zhx',
        'zhx-Nshu-CN': 'zhx',
        'zhx-CN': 'zhx',
        'zhx-Nshu': 'zhx',
        'zia': 'zia',
        'zia-Latn-PG': 'zia',
        'zia-Latn': 'zia',
        'zia-PG': 'zia',
        'zib': 'zib',
        'zib-Zxxx-ZW': 'zib',
        'sgn-zib': 'zib',
        'sgn-zib-ZW': 'zib',
        'zib-ZW': 'zib',
        'zib-Zxxx': 'zib',
        'zik': 'zik',
        'zik-Latn-PG': 'zik',
        'zik-Latn': 'zik',
        'zik-PG': 'zik',
        'zil': 'zil',
        'zil-Latn-GN': 'zil',
        'zil-GN': 'zil',
        'zil-Latn': 'zil',
        'zim': 'zim',
        'zim-Latn-TD': 'zim',
        'zim-Latn': 'zim',
        'zim-TD': 'zim',
        'zin': 'zin',
        'zin-Latn-TZ': 'zin',
        'zin-Latn': 'zin',
        'zin-TZ': 'zin',
        'zir': 'zir',
        'zir-Latn-NG': 'zir',
        'zir-Latn': 'zir',
        'zir-NG': 'zir',
        'ziw': 'ziw',
        'ziw-Latn-TZ': 'ziw',
        'ziw-Latn': 'ziw',
        'ziw-TZ': 'ziw',
        'ziz': 'ziz',
        'ziz-Latn-NG': 'ziz',
        'ziz-Latn': 'ziz',
        'ziz-NG': 'ziz',
        'zka': 'zka',
        'zka-Latn-ID': 'zka',
        'zka-ID': 'zka',
        'zka-Latn': 'zka',
        'zkb': 'zkb',
        'zkb-Cyrl-RU': 'zkb',
        'zkb-Cyrl': 'zkb',
        'zkb-RU': 'zkb',
        'zkd': 'zkd',
        'zkd-Latn-MM': 'zkd',
        'kdv': 'zkd',
        'kdv-Latn': 'zkd',
        'kdv-Latn-MM': 'zkd',
        'kdv-MM': 'zkd',
        'zkd-Latn': 'zkd',
        'zkd-MM': 'zkd',
        'zkg': 'zkg',
        'zkg-Zyyy-CN': 'zkg',
        'zkg-CN': 'zkg',
        'zkg-Zyyy': 'zkg',
        'zkh': 'zkh',
        'zkh-Zyyy-TR': 'zkh',
        'zkh-TR': 'zkh',
        'zkh-Zyyy': 'zkh',
        'zkk': 'zkk',
        'zkk-Zyyy-US': 'zkk',
        'zkk-US': 'zkk',
        'zkk-Zyyy': 'zkk',
        'zkn': 'zkn',
        'zkn-Zyyy-MM': 'zkn',
        'zkn-MM': 'zkn',
        'zkn-Zyyy': 'zkn',
        'zko': 'zko',
        'zko-Cyrl-RU': 'zko',
        'zko-Cyrl': 'zko',
        'zko-RU': 'zko',
        'zkp': 'zkp',
        'zkp-Latn-BR': 'zkp',
        'zkp-BR': 'zkp',
        'zkp-Latn': 'zkp',
        'zkr': 'zkr',
        'zkr-Zyyy-CN': 'zkr',
        'zkr-CN': 'zkr',
        'zkr-Zyyy': 'zkr',
        'zkt-Kitl': 'zkt-Kitl',
        'zkt-Kitl-CN': 'zkt-Kitl',
        'zkt-Kits': 'zkt-Kits',
        'zkt-Kits-CN': 'zkt-Kits',
        'zku': 'zku',
        'zku-Latn-AU': 'zku',
        'zku-AU': 'zku',
        'zku-Latn': 'zku',
        'zkv': 'zkv',
        'zkv-Zyyy-LV': 'zkv',
        'zkv-LV': 'zkv',
        'zkv-Zyyy': 'zkv',
        'zkz': 'zkz',
        'zkz-Cyrl-RU': 'zkz',
        'zkz-Cyrl': 'zkz',
        'zkz-RU': 'zkz',
        'zlj': 'zlj',
        'zlj-Hani-CN': 'zlj',
        'zlj-CN': 'zlj',
        'zlj-Hani': 'zlj',
        'zlj-Latn': 'zlj-Latn',
        'zlj-Latn-CN': 'zlj-Latn',
        'zlm': 'zlm',
        'zlm-Latn-TG': 'zlm',
        'ms-zlm': 'zlm',
        'ms-zlm-TG': 'zlm',
        'zlm-Latn': 'zlm',
        'zlm-TG': 'zlm',
        'zlm-Arab': 'zlm-Arab',
        'zlm-Arab-MY': 'zlm-Arab',
        'ms-zlm-MY': 'zlm-Arab',
        'zlm-MY': 'zlm-Arab',
        'zln': 'zln',
        'zln-Hani-CN': 'zln',
        'zln-CN': 'zln',
        'zln-Hani': 'zln',
        'zlq': 'zlq',
        'zlq-Hani-CN': 'zlq',
        'zlq-CN': 'zlq',
        'zlq-Hani': 'zlq',
        'zma': 'zma',
        'zma-Latn-AU': 'zma',
        'zma-AU': 'zma',
        'zma-Latn': 'zma',
        'zmb': 'zmb',
        'zmb-Latn-CD': 'zmb',
        'zmb-CD': 'zmb',
        'zmb-Latn': 'zmb',
        'zmc': 'zmc',
        'zmc-Latn-AU': 'zmc',
        'zmc-AU': 'zmc',
        'zmc-Latn': 'zmc',
        'zmd': 'zmd',
        'zmd-Latn-AU': 'zmd',
        'zmd-AU': 'zmd',
        'zmd-Latn': 'zmd',
        'zme': 'zme',
        'zme-Latn-AU': 'zme',
        'zme-AU': 'zme',
        'zme-Latn': 'zme',
        'zmf': 'zmf',
        'zmf-Latn-CD': 'zmf',
        'zmf-CD': 'zmf',
        'zmf-Latn': 'zmf',
        'zmg': 'zmg',
        'zmg-Latn-AU': 'zmg',
        'zmg-AU': 'zmg',
        'zmg-Latn': 'zmg',
        'zmh': 'zmh',
        'zmh-Latn-PG': 'zmh',
        'zmh-Latn': 'zmh',
        'zmh-PG': 'zmh',
        'zmi': 'zmi',
        'zmi-Latn-MY': 'zmi',
        'ms-zmi': 'zmi',
        'ms-zmi-MY': 'zmi',
        'zmi-Latn': 'zmi',
        'zmi-MY': 'zmi',
        'zmj': 'zmj',
        'zmj-Latn-AU': 'zmj',
        'zmj-AU': 'zmj',
        'zmj-Latn': 'zmj',
        'zmk': 'zmk',
        'zmk-Latn-AU': 'zmk',
        'zmk-AU': 'zmk',
        'zmk-Latn': 'zmk',
        'zml': 'zml',
        'zml-Latn-AU': 'zml',
        'zml-AU': 'zml',
        'zml-Latn': 'zml',
        'zmm': 'zmm',
        'zmm-Latn-AU': 'zmm',
        'zmm-AU': 'zmm',
        'zmm-Latn': 'zmm',
        'zmn': 'zmn',
        'zmn-Latn-GA': 'zmn',
        'zmn-GA': 'zmn',
        'zmn-Latn': 'zmn',
        'zmo': 'zmo',
        'zmo-Latn-SD': 'zmo',
        'zmo-Latn': 'zmo',
        'zmo-SD': 'zmo',
        'zmp': 'zmp',
        'zmp-Latn-CD': 'zmp',
        'zmp-CD': 'zmp',
        'zmp-Latn': 'zmp',
        'zmq': 'zmq',
        'zmq-Latn-CD': 'zmq',
        'zmq-CD': 'zmq',
        'zmq-Latn': 'zmq',
        'zmr': 'zmr',
        'zmr-Latn-AU': 'zmr',
        'zmr-AU': 'zmr',
        'zmr-Latn': 'zmr',
        'zms': 'zms',
        'zms-Latn-CD': 'zms',
        'zms-CD': 'zms',
        'zms-Latn': 'zms',
        'zmt': 'zmt',
        'zmt-Latn-AU': 'zmt',
        'zmt-AU': 'zmt',
        'zmt-Latn': 'zmt',
        'zmu': 'zmu',
        'zmu-Latn-AU': 'zmu',
        'zmu-AU': 'zmu',
        'zmu-Latn': 'zmu',
        'zmv': 'zmv',
        'zmv-Latn-AU': 'zmv',
        'zmv-AU': 'zmv',
        'zmv-Latn': 'zmv',
        'zmw': 'zmw',
        'zmw-Latn-CD': 'zmw',
        'zmw-CD': 'zmw',
        'zmw-Latn': 'zmw',
        'zmx': 'zmx',
        'zmx-Latn-CG': 'zmx',
        'zmx-CG': 'zmx',
        'zmx-Latn': 'zmx',
        'zmy': 'zmy',
        'zmy-Latn-AU': 'zmy',
        'zmy-AU': 'zmy',
        'zmy-Latn': 'zmy',
        'zmz': 'zmz',
        'zmz-Latn-CD': 'zmz',
        'zmz-CD': 'zmz',
        'zmz-Latn': 'zmz',
        'zna': 'zna',
        'zna-Latn-TD': 'zna',
        'zna-Latn': 'zna',
        'zna-TD': 'zna',
        'zne': 'zne',
        'zne-Latn-CD': 'zne',
        'zne-CD': 'zne',
        'zne-Latn': 'zne',
        'zne-Arab': 'zne-Arab',
        'zne-Arab-SS': 'zne-Arab',
        'zne-SS': 'zne-Arab',
        'zng': 'zng',
        'zng-Latn-VN': 'zng',
        'zng-Latn': 'zng',
        'zng-VN': 'zng',
        'znk': 'znk',
        'znk-Latn-AU': 'znk',
        'znk-AU': 'znk',
        'znk-Latn': 'znk',
        'zns': 'zns',
        'zns-Latn-NG': 'zns',
        'zns-Latn': 'zns',
        'zns-NG': 'zns',
        'zoc': 'zoc',
        'zoc-Latn-MX': 'zoc',
        'zoc-Latn': 'zoc',
        'zoc-MX': 'zoc',
        'zoh': 'zoh',
        'zoh-Latn-MX': 'zoh',
        'zoh-Latn': 'zoh',
        'zoh-MX': 'zoh',
        'zom': 'zom',
        'zom-Latn-IN': 'zom',
        'yos': 'zom',
        'yos-IN': 'zom',
        'yos-Latn': 'zom',
        'yos-Latn-IN': 'zom',
        'zom-IN': 'zom',
        'zom-Latn': 'zom',
        'zoo': 'zoo',
        'zoo-Latn-MX': 'zoo',
        'zoo-Latn': 'zoo',
        'zoo-MX': 'zoo',
        'zoq': 'zoq',
        'zoq-Latn-MX': 'zoq',
        'zoq-Latn': 'zoq',
        'zoq-MX': 'zoq',
        'zor': 'zor',
        'zor-Latn-MX': 'zor',
        'zor-Latn': 'zor',
        'zor-MX': 'zor',
        'zos': 'zos',
        'zos-Latn-MX': 'zos',
        'zos-Latn': 'zos',
        'zos-MX': 'zos',
        'zpa': 'zpa',
        'zpa-Latn-MX': 'zpa',
        'zpa-Latn': 'zpa',
        'zpa-MX': 'zpa',
        'zpb': 'zpb',
        'zpb-Latn-MX': 'zpb',
        'zpb-Latn': 'zpb',
        'zpb-MX': 'zpb',
        'zpc': 'zpc',
        'zpc-Latn-MX': 'zpc',
        'zpc-Latn': 'zpc',
        'zpc-MX': 'zpc',
        'zpd': 'zpd',
        'zpd-Latn-MX': 'zpd',
        'zpd-Latn': 'zpd',
        'zpd-MX': 'zpd',
        'zpe': 'zpe',
        'zpe-Latn-MX': 'zpe',
        'zpe-Latn': 'zpe',
        'zpe-MX': 'zpe',
        'zpf': 'zpf',
        'zpf-Latn-MX': 'zpf',
        'zpf-Latn': 'zpf',
        'zpf-MX': 'zpf',
        'zpg': 'zpg',
        'zpg-Latn-MX': 'zpg',
        'zpg-Latn': 'zpg',
        'zpg-MX': 'zpg',
        'zph': 'zph',
        'zph-Latn-MX': 'zph',
        'zph-Latn': 'zph',
        'zph-MX': 'zph',
        'zpi': 'zpi',
        'zpi-Latn-MX': 'zpi',
        'zpi-Latn': 'zpi',
        'zpi-MX': 'zpi',
        'zpj': 'zpj',
        'zpj-Latn-MX': 'zpj',
        'zpj-Latn': 'zpj',
        'zpj-MX': 'zpj',
        'zpk': 'zpk',
        'zpk-Latn-MX': 'zpk',
        'zpk-Latn': 'zpk',
        'zpk-MX': 'zpk',
        'zpl': 'zpl',
        'zpl-Latn-MX': 'zpl',
        'zpl-Latn': 'zpl',
        'zpl-MX': 'zpl',
        'zpm': 'zpm',
        'zpm-Latn-MX': 'zpm',
        'zpm-Latn': 'zpm',
        'zpm-MX': 'zpm',
        'zpn': 'zpn',
        'zpn-Latn-MX': 'zpn',
        'zpn-Latn': 'zpn',
        'zpn-MX': 'zpn',
        'zpo': 'zpo',
        'zpo-Latn-MX': 'zpo',
        'zpo-Latn': 'zpo',
        'zpo-MX': 'zpo',
        'zpp': 'zpp',
        'zpp-Latn-MX': 'zpp',
        'zpp-Latn': 'zpp',
        'zpp-MX': 'zpp',
        'zpq': 'zpq',
        'zpq-Latn-MX': 'zpq',
        'zpq-Latn': 'zpq',
        'zpq-MX': 'zpq',
        'zpr': 'zpr',
        'zpr-Latn-MX': 'zpr',
        'zpr-Latn': 'zpr',
        'zpr-MX': 'zpr',
        'zps': 'zps',
        'zps-Latn-MX': 'zps',
        'zps-Latn': 'zps',
        'zps-MX': 'zps',
        'zpt': 'zpt',
        'zpt-Latn-MX': 'zpt',
        'zpt-Latn': 'zpt',
        'zpt-MX': 'zpt',
        'zpu': 'zpu',
        'zpu-Latn-MX': 'zpu',
        'zpu-Latn': 'zpu',
        'zpu-MX': 'zpu',
        'zpv': 'zpv',
        'zpv-Latn-MX': 'zpv',
        'zpv-Latn': 'zpv',
        'zpv-MX': 'zpv',
        'zpw': 'zpw',
        'zpw-Latn-MX': 'zpw',
        'zpw-Latn': 'zpw',
        'zpw-MX': 'zpw',
        'zpx': 'zpx',
        'zpx-Latn-MX': 'zpx',
        'zpx-Latn': 'zpx',
        'zpx-MX': 'zpx',
        'zpy': 'zpy',
        'zpy-Latn-MX': 'zpy',
        'zpy-Latn': 'zpy',
        'zpy-MX': 'zpy',
        'zpz': 'zpz',
        'zpz-Latn-MX': 'zpz',
        'zpz-Latn': 'zpz',
        'zpz-MX': 'zpz',
        'zqe': 'zqe',
        'zqe-Hani-CN': 'zqe',
        'zqe-CN': 'zqe',
        'zqe-Hani': 'zqe',
        'zqe-Latn': 'zqe-Latn',
        'zqe-Latn-CN': 'zqe-Latn',
        'zra': 'zra',
        'zra-Zyyy-KR': 'zra',
        'zra-KR': 'zra',
        'zra-Zyyy': 'zra',
        'zrg-Orya': 'zrg-Orya',
        'zrg-Orya-IN': 'zrg-Orya',
        'zrg-Telu': 'zrg-Telu',
        'zrg-Telu-IN': 'zrg-Telu',
        'zrn': 'zrn',
        'zrn-Latn-TD': 'zrn',
        'zrn-Latn': 'zrn',
        'zrn-TD': 'zrn',
        'zro': 'zro',
        'zro-Latn-EC': 'zro',
        'zro-EC': 'zro',
        'zro-Latn': 'zro',
        'zrp': 'zrp',
        'zrp-Zyyy-FR': 'zrp',
        'zrp-FR': 'zrp',
        'zrp-Zyyy': 'zrp',
        'zrs': 'zrs',
        'zrs-Latn-ID': 'zrs',
        'zrs-ID': 'zrs',
        'zrs-Latn': 'zrs',
        'zsa': 'zsa',
        'zsa-Latn-PG': 'zsa',
        'zsa-Latn': 'zsa',
        'zsa-PG': 'zsa',
        'zsk': 'zsk',
        'zsk-Zyyy-TR': 'zsk',
        'zsk-TR': 'zsk',
        'zsk-Zyyy': 'zsk',
        'zsl': 'zsl',
        'zsl-Zxxx-ZM': 'zsl',
        'sgn-zsl': 'zsl',
        'sgn-zsl-ZM': 'zsl',
        'zsl-ZM': 'zsl',
        'zsl-Zxxx': 'zsl',
        'zsr': 'zsr',
        'zsr-Latn-MX': 'zsr',
        'zsr-Latn': 'zsr',
        'zsr-MX': 'zsr',
        'zsu': 'zsu',
        'zsu-Latn-PG': 'zsu',
        'zsu-Latn': 'zsu',
        'zsu-PG': 'zsu',
        'zte': 'zte',
        'zte-Latn-MX': 'zte',
        'zte-Latn': 'zte',
        'zte-MX': 'zte',
        'ztg': 'ztg',
        'ztg-Latn-MX': 'ztg',
        'ztg-Latn': 'ztg',
        'ztg-MX': 'ztg',
        'ztl': 'ztl',
        'ztl-Latn-MX': 'ztl',
        'ztl-Latn': 'ztl',
        'ztl-MX': 'ztl',
        'ztm': 'ztm',
        'ztm-Latn-MX': 'ztm',
        'ztm-Latn': 'ztm',
        'ztm-MX': 'ztm',
        'ztn': 'ztn',
        'ztn-Latn-MX': 'ztn',
        'ztn-Latn': 'ztn',
        'ztn-MX': 'ztn',
        'ztp': 'ztp',
        'ztp-Latn-MX': 'ztp',
        'ztp-Latn': 'ztp',
        'ztp-MX': 'ztp',
        'ztq': 'ztq',
        'ztq-Latn-MX': 'ztq',
        'ztq-Latn': 'ztq',
        'ztq-MX': 'ztq',
        'zts': 'zts',
        'zts-Latn-MX': 'zts',
        'zts-Latn': 'zts',
        'zts-MX': 'zts',
        'ztt': 'ztt',
        'ztt-Latn-MX': 'ztt',
        'ztt-Latn': 'ztt',
        'ztt-MX': 'ztt',
        'ztu': 'ztu',
        'ztu-Latn-MX': 'ztu',
        'ztu-Latn': 'ztu',
        'ztu-MX': 'ztu',
        'ztx': 'ztx',
        'ztx-Latn-MX': 'ztx',
        'ztx-Latn': 'ztx',
        'ztx-MX': 'ztx',
        'zty': 'zty',
        'zty-Latn-MX': 'zty',
        'zty-Latn': 'zty',
        'zty-MX': 'zty',
        'zu': 'zu',
        'zu-Latn-ZA': 'zu',
        'zu-Latn': 'zu',
        'zu-ZA': 'zu',
        'zu-Brai': 'zu-Brai',
        'zu-Brai-ZA': 'zu-Brai',
        'zua': 'zua',
        'zua-Latn-NG': 'zua',
        'zua-Latn': 'zua',
        'zua-NG': 'zua',
        'zuh': 'zuh',
        'zuh-Latn-PG': 'zuh',
        'zuh-Latn': 'zuh',
        'zuh-PG': 'zuh',
        'zum': 'zum',
        'zum-Zyyy-OM': 'zum',
        'zum-OM': 'zum',
        'zum-Zyyy': 'zum',
        'zun': 'zun',
        'zun-Latn-US': 'zun',
        'zun-Latn': 'zun',
        'zun-US': 'zun',
        'zuy': 'zuy',
        'zuy-Latn-CM': 'zuy',
        'zuy-CM': 'zuy',
        'zuy-Latn': 'zuy',
        'zwa': 'zwa',
        'zwa-Zyyy-ET': 'zwa',
        'zwa-ET': 'zwa',
        'zwa-Zyyy': 'zwa',
        'zxx': 'zxx',
        'zxx-Zyyy-001': 'zxx',
        'zxx-001': 'zxx',
        'zxx-Zyyy': 'zxx',
        'zyg': 'zyg',
        'zyg-Hani-CN': 'zyg',
        'zyg-CN': 'zyg',
        'zyg-Hani': 'zyg',
        'zyg-Nshu': 'zyg-Nshu',
        'zyg-Nshu-CN': 'zyg-Nshu',
        'zyj': 'zyj',
        'zyj-Latn-CN': 'zyj',
        'zyj-CN': 'zyj',
        'zyj-Latn': 'zyj',
        'zyj-Hani': 'zyj-Hani',
        'zyj-Hani-CN': 'zyj-Hani',
        'zyn': 'zyn',
        'zyn-Hani-CN': 'zyn',
        'zyn-CN': 'zyn',
        'zyn-Hani': 'zyn',
        'zyp': 'zyp',
        'zyp-Latn-MM': 'zyp',
        'zyp-Latn': 'zyp',
        'zyp-MM': 'zyp',
        'zza': 'zza',
        'zza-Latn-TR': 'zza',
        'diq': 'zza',
        'diq-Latn': 'zza',
        'diq-Latn-TR': 'zza',
        'diq-TR': 'zza',
        'zza-Latn': 'zza',
        'zza-TR': 'zza',
        'zza-Arab': 'zza-Arab',
        'zza-Arab-TR': 'zza-Arab',
        'diq-Arab': 'zza-Arab',
        'diq-Arab-TR': 'zza-Arab',
        'zzj': 'zzj',
        'zzj-Hani-CN': 'zzj',
        'zzj-CN': 'zzj',
        'zzj-Hani': 'zzj' }

    __map3To2 = { 'aar': 'aa',
        'abk': 'ab',
        'ave': 'ae',
        'afr': 'af',
        'aka': 'ak',
        'amh': 'am',
        'arg': 'an',
        'ara': 'ar',
        'asm': 'as',
        'ava': 'av',
        'aym': 'ay',
        'aze': 'az',
        'bak': 'ba',
        'bel': 'be',
        'bul': 'bg',
        'bis': 'bi',
        'bam': 'bm',
        'ben': 'bn',
        'bod': 'bo',
        'bre': 'br',
        'bos': 'bs',
        'cat': 'ca',
        'che': 'ce',
        'cha': 'ch',
        'cos': 'co',
        'cre': 'cr',
        'ces': 'cs',
        'chu': 'cu',
        'chv': 'cv',
        'cym': 'cy',
        'dan': 'da',
        'deu': 'de',
        'div': 'dv',
        'dzo': 'dz',
        'ewe': 'ee',
        'ell': 'el',
        'eng': 'en',
        'epo': 'eo',
        'spa': 'es',
        'est': 'et',
        'eus': 'eu',
        'fas': 'fa',
        'ful': 'ff',
        'fin': 'fi',
        'fij': 'fj',
        'fao': 'fo',
        'fra': 'fr',
        'fry': 'fy',
        'gle': 'ga',
        'gla': 'gd',
        'glg': 'gl',
        'grn': 'gn',
        'guj': 'gu',
        'glv': 'gv',
        'hau': 'ha',
        'heb': 'he',
        'hin': 'hi',
        'hmo': 'ho',
        'hrv': 'hr',
        'hat': 'ht',
        'hun': 'hu',
        'hye': 'hy',
        'her': 'hz',
        'ina': 'ia',
        'ind': 'id',
        'ile': 'ie',
        'ibo': 'ig',
        'iii': 'ii',
        'ipk': 'ik',
        'ido': 'io',
        'isl': 'is',
        'ita': 'it',
        'iku': 'iu',
        'jpn': 'ja',
        'jav': 'jv',
        'kat': 'ka',
        'kon': 'kg',
        'kik': 'ki',
        'kua': 'kj',
        'kaz': 'kk',
        'kal': 'kl',
        'khm': 'km',
        'kan': 'kn',
        'kor': 'ko',
        'kau': 'kr',
        'kas': 'ks',
        'kur': 'ku',
        'kom': 'kv',
        'cor': 'kw',
        'kir': 'ky',
        'lat': 'la',
        'ltz': 'lb',
        'lug': 'lg',
        'lim': 'li',
        'lin': 'ln',
        'lao': 'lo',
        'lit': 'lt',
        'lub': 'lu',
        'lav': 'lv',
        'mlg': 'mg',
        'mah': 'mh',
        'mri': 'mi',
        'mkd': 'mk',
        'mal': 'ml',
        'mon': 'mn',
        'mar': 'mr',
        'msa': 'ms',
        'mlt': 'mt',
        'mya': 'my',
        'nau': 'na',
        'nob': 'nb',
        'nde': 'nd',
        'nep': 'ne',
        'ndo': 'ng',
        'nld': 'nl',
        'nno': 'nn',
        'nor': 'no',
        'nbl': 'nr',
        'nav': 'nv',
        'nya': 'ny',
        'oci': 'oc',
        'oji': 'oj',
        'orm': 'om',
        'ori': 'or',
        'oss': 'os',
        'pan': 'pa',
        'pol': 'pl',
        'pus': 'ps',
        'por': 'pt',
        'que': 'qu',
        'roh': 'rm',
        'run': 'rn',
        'ron': 'ro',
        'rus': 'ru',
        'kin': 'rw',
        'san': 'sa',
        'srd': 'sc',
        'snd': 'sd',
        'sme': 'se',
        'sag': 'sg',
        'hbs': 'sh',
        'sin': 'si',
        'slk': 'sk',
        'slv': 'sl',
        'smo': 'sm',
        'sna': 'sn',
        'som': 'so',
        'sqi': 'sq',
        'srp': 'sr',
        'ssw': 'ss',
        'sot': 'st',
        'sun': 'su',
        'swe': 'sv',
        'swa': 'sw',
        'tam': 'ta',
        'tel': 'te',
        'tgk': 'tg',
        'tha': 'th',
        'tir': 'ti',
        'tuk': 'tk',
        'tgl': 'tl',
        'tsn': 'tn',
        'ton': 'to',
        'tur': 'tr',
        'tso': 'ts',
        'tat': 'tt',
        'tah': 'ty',
        'uig': 'ug',
        'ukr': 'uk',
        'urd': 'ur',
        'uzb': 'uz',
        'ven': 've',
        'vie': 'vi',
        'vol': 'vo',
        'wln': 'wa',
        'wol': 'wo',
        'xho': 'xh',
        'yid': 'yi',
        'yor': 'yo',
        'zha': 'za',
        'zul': 'zu' }
